version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"

program main
    local hsanum "hsa"
    local statenum "state"
    load_data
    foreach unit in hsa state {
        forv i=1/50 {
            bootstrap_delta, unit(`unit') unitnum(``unit'num')
            use ../temp/pat_data, clear
            bsample, cluster(bene_id)
            event_study, unit(`unit') delta_var(delta) iteration(`i')
        }
    }
end

program load_data
    use bene_id year baseline_samp rel_yr_rit  hsa* state* LnRBU age_5yr_bins ///
        in 1/${obsno} if baseline_samp==1 ///
        using ../external_links/compiled/CompiledPatYrDataMovers, clear
    egen rel_yr_group = group(rel_yr_rit), label
    keep bene_id year rel_yr_rit rel_yr_group LnRBU age_5yr_bins hsa* state*
    save_data ../temp/pat_data, replace key(bene_id year)
end

program bootstrap_delta
    syntax, unit(str) unitnum(str)

    use ../external/ranks/LnRBU_`unit'_mean, clear
    egen tag=tag(`unitnum')
    gen gamma_temp=rnormal(LnRBU_total, LnRBU_total_se) if tag==1
    by `unitnum', sort: egen gamma=max(gamma_temp)
    save ../temp/`unit'_gamma, replace

    use `unit'_orig `unit'_dest using ../external_links/compiled/CompiledPatYrDataMovers, clear
    bys `unit'_orig `unit'_dest: keep if _n==1
    foreach loc in orig dest {
        rename `unit'_`loc' `unitnum'
        merge m:1 `unitnum' using ../temp/`unit'_gamma, assert(1 3) keep(3) keepusing(*) nogen
        rename gamma gamma_`loc'
        rename `unitnum' `unit'_`loc'
    }
    gen delta=gamma_dest-gamma_orig
    keep `unit'_orig `unit'_dest delta
    save ../temp/bootstrap_delta, replace

end

program event_study
    syntax, unit(str) delta_var(str) iteration(str)

    use ../temp/pat_data, clear
    merge m:1 `unit'_orig `unit'_dest using ../temp/bootstrap_delta, ///
        assert(1 2 3) keep(3) keepusing(*) nogen
    rename `delta_var' delta_i
    summ rel_yr_group if rel_yr_rit==-1
    local rydrop `r(mean)'
    areg LnRBU i.year o`rydrop'.rel_yr_group o`rydrop'.rel_yr_group#o.delta_i ///
        i.age_5yr_bins, absorb(bene_id)
    cap drop coefficient
    cap gen coefficient=.
    levelsof rel_yr_group, local(RYs)
    foreach RY of local RYs {
        cap replace coefficient = _b[`RY'.rel_yr_group#c.delta_i] if rel_yr_group==`RY'
    }
    collapse (mean) coefficient, by(rel_yr_rit)
    cap mkdir ../output/`unit'_`iteration'/
    save_data ../output/`unit'_`iteration'/estimates, replace key(rel_yr_rit)

end

* EXECUTE
main

