version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"

program main
    load_data
    foreach unit in hsa state {
        event_study, unit(`unit') delta_var(delta_`unit'_LnRBU_i)
    }
end

program load_data
    use bene_id year baseline_samp rel_yr_rit  hsa* state* *_move LnRBU age_5yr_bins ///
        in 1/${obsno} if baseline_samp==1 ///
        using ../external_links/compiled/CompiledPatYrDataMovers, clear
    foreach unit in hsa state {
        merge m:1 `unit'_orig `unit'_dest using ../external/ranks/delta_`unit'_LnRBU, ///
            assert(1 2 3) keep(3) keepusing(*) nogen
    }
    egen rel_yr_group = group(rel_yr_rit), label
    keep bene_id year rel_yr_rit rel_yr_group LnRBU delta_*_LnRBU_i age_5yr_bins
    save_data ../temp/pat_data, replace key(bene_id year)
end


program event_study
    syntax, unit(str) delta_var(str)

    use ../temp/pat_data, clear
    rename `delta_var' delta_i
    summ rel_yr_group if rel_yr_rit==-1
    local rydrop `r(mean)'
    areg LnRBU i.year o`rydrop'.rel_yr_group o`rydrop'.rel_yr_group#o.delta_i ///
        i.age_5yr_bins, absorb(bene_id)
    cap drop coefficient
    cap gen coefficient=.
    levelsof rel_yr_group, local(RYs)
    foreach RY of local RYs {
        cap replace coefficient = _b[`RY'.rel_yr_group#c.delta_i] if rel_yr_group==`RY'
    }
    collapse (mean) coefficient, by(rel_yr_rit)
    cap mkdir ../output/`unit'/
    save_data ../output/`unit'/estimates, replace key(rel_yr_rit)

end

* EXECUTE
main

