version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    local health_measures "Lnnumcon Lnhcccom Lnchr Lniez"
    load_data_event_study, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest *_samp mover age_5yr_bins ///
        `health_measures' te_move) saving(../temp/data_loaded)
    foreach hm in `health_measures' {
        merge m:1 hrr_orig hrr_dest using ../external/ranks/delta_`hm', ///
            assert(3) keep(3) keepusing(delta_hrrnum_`hm'_i) nogen
        gen up_`hm'=delta_hrrnum_`hm'_i>0
        gen down_`hm'=delta_hrrnum_`hm'_i<0
        drop delta_hrrnum_`hm'_i
        merge m:1 hrr_orig hrr_dest using ../external/ranks/delta_`hm'_te_move, ///
            assert(3) keep(3) keepusing(delta_hrrnum_`hm'_i) nogen        
        gen up_`hm'_e=delta_hrrnum_`hm'_i>0 & te_move==1
        gen down_`hm'_e=delta_hrrnum_`hm'_i<0 & te_move==1
        drop delta_hrrnum_`hm'_i
    }
    save ../temp/data_loaded, replace
    foreach hm in `health_measures' {
        forv i=1/50 {
            create_bootstrap_delta using ../external/ranks/`hm'_hrr_mean, ///
                mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
                gamma_mean(`hm'_total) gamma_standard_error(`hm'_total_se) ///
                saving(../temp/bootstrap_delta)
            use ../temp/data_loaded if ${`hm'_samp==1}, clear
            bsample, cluster(bene_id)
            run_event_study, ///
                y_it(`hm') delta(../temp/bootstrap_delta) absorb(bene_id) ///
                x_it(i.year o${omit}.rel_yr_group o${omit}.rel_yr_group#o.delta i.age_5yr_bins) ///
                specification_name(`hm'_`i')
            foreach dir in up down {
                create_bootstrap_delta using ../external/ranks/`hm'_hrr_mean_te_move, ///
                    mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
                    gamma_mean(`hm'_total) gamma_standard_error(`hm'_total_se) ///
                    saving(../temp/bootstrap_delta)
                use ../temp/data_loaded if `dir'_`hm'_e==1 & ${`hm'_samp==1}, clear
                bsample, cluster(bene_id)
                run_event_study, ///
                    y_it(`hm') delta(../temp/bootstrap_delta) absorb(bene_id) ///
                    x_it(i.year o${omit}.rel_yr_group o${omit}.rel_yr_group#o.delta ///
                    i.age_5yr_bins) specification_name(`hm'_`dir'_e_`i')
            }
        }
    }
end

* Execute
main


