version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global Ranks = "dest_p50_rank dest_p25_rank dest_p20_rank dest_p10_rank dest_p5_rank dest_texas_rank dest_M_rank orig_p50_rank orig_p25_rank orig_p20_rank orig_p10_rank orig_p5_rank orig_texas_rank orig_M_rank"
global Strata = "p50_rank p25_rank p20_rank p10_rank p5_rank texas_rank M_rank"
program main
    load_data_event_study, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest LnRBU ${LnRBU_samp} mover age_5yr_bins ///
        te_move tm_move tl_move) keep_condition(${LnRBU_samp}==1) saving(../temp/data_temp)
    load_rank_data using ../temp/data_temp
    forv i=1/50 {
        create_bootstrap_delta using ../external/ranks/LnRBU_hrr_mean, ///
            mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
            gamma_mean(LnRBU_total) gamma_standard_error(LnRBU_total_se) ///
            saving(../temp/bootstrap_delta)
        foreach stratum in ${Strata} {
            use ../temp/`stratum', clear
            bsample, cluster(bene_id)
            run_event_study, ///
                y_it(LnRBU) delta(../temp/bootstrap_delta) absorb(bene_id) ///
                x_it(i.year o${omit}.rel_yr_group o${omit}.rel_yr_group#o.delta i.age_5yr_bins) ///
                specification_name(LnRBU_`stratum'_`i')
        }
    }
end

program load_rank_data
    syntax using
    use `using', clear
    rename hrrnum hrrnum_temp
    foreach loc in dest orig {
        rename hrr_`loc' hrrnum 
        merge m:1 hrrnum using ../external/ranks/hrr_rank_LnRBU, assert(3) keep(3) nogen
        rename LnRBU_* `loc'_*
        rename hrrnum hrr_`loc'
    }
    rename hrrnum_temp hrrnum
    foreach rank in ${Ranks} {
        sum `rank'
        local rank_min = r(min)
        local rank_max = r(max)
        gen `rank'_temp = 1 if `rank' == `rank_min'
        replace `rank'_temp = 4 if `rank' == `rank_max'
        replace `rank'_temp = 0 if `rank' != `rank_min' & `rank' != `rank_max'
        drop `rank'
        rename `rank'_temp `rank'
    }
    save ../temp/rank_data, replace
    
    foreach stratum in ${Strata} {
        use ../temp/rank_data, clear
        keep if (dest_`stratum'==1 & orig_`stratum'==4) | (dest_`stratum'==4 & orig_`stratum'==1)
        save ../temp/`stratum', replace 
    }
end

* Execute
main


