version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    

    move_determinants

end

program move_determinants

    use "../external/HRS/HRS", clear

    foreach var in "relative_wave" {
        insert_tag tab_`var', open
            tab `var'
        insert_tag tab_`var', close
    }

    forv i=1/2 {
        insert_tag move_reason`i', open
            tab reason`i' mover, col nofreq
        insert_tag move_reason`i', close
    }


    graph pie if mover, over(reason1) plabel(1 name, gap(15)) plabel(2 name, gap(15)) ///
        plabel(3 name, gap(15)) plabel(4 name, gap(15)) plabel(5 name, gap(15)) ///
        plabel(6 name, gap(15)) plabel(7 name, gap(20))  plabel(1 percent, gap(5)) ///
        plabel(2 percent, gap(5)) plabel(3 percent, gap(5)) plabel(4 percent, gap(5)) ///
        plabel(5 percent, gap(5))  plabel(6 percent, gap(5)) plabel(7 percent) ///
        legend(off) sort descending

    graph export "../output/figures/Move_Reasons.eps", replace as(eps)

    matrix movers_nonmovers_comparison=J(1,3,.)

    foreach var in  $HRS_compare_variables1 $HRS_compare_variables2 $HRS_compare_variables3 {

            if  "`var'"=="Age" |  "`var'"=="Earnings" |  "`var'"=="Health" |  ///
                "`var'"=="N_DoctorVisits" | "`var'"=="N_HospStay" |  "`var'"=="T_HospNight" | ///
                "`var'"=="N_NursHomeStay" |  "`var'"=="T_NursHomeNight" {

                ttest `var', by(mover)
                matrix movers_nonmovers_comparison = ///
                    (movers_nonmovers_comparison\r(mu_1),r(mu_2),r(t))

            }

            else {

                ttest `var', by(mover)
                matrix movers_nonmovers_comparison = ///
                    (movers_nonmovers_comparison\100*r(mu_1),100*r(mu_2),r(t))

            }

    }

    matrix_to_txt, saving(../output/tables/movers_nonmovers_comparison.txt) ///
        mat(movers_nonmovers_comparison) format(%20.4f) ///
        title(<tab:movers_nonmovers_comparison>) replace
 
    save ../temp/data_before_collapse, replace

    forv i=2/3 {
        
        use ../temp/data_before_collapse if balanced_incl`i'==1

        collapse (mean) $HRS_collapse_variables, by(mover relative_wave)
  
        foreach var in $HRS_collapse_variables {
            rename `var' `var'_balanced`i'
        }

        save ../temp/balanced`i'_data_for_graph, replace
    
    }

    use ../temp/data_before_collapse
    collapse (mean) $HRS_collapse_variables, by(mover relative_wave)
    merge 1:1 mover relative_wave using "../temp/balanced3_data_for_graph", ///
        assert(match master) keep(match master) keepusing(*) nogen
    merge 1:1 mover relative_wave using "../temp/balanced2_data_for_graph", ///
        assert(match master) keep(match master) keepusing(*) nogen

    foreach var in $HRS_collapse_variables {

        twoway (connected `var' relative_wave if mover) ///
            (connected `var'_balanced3 relative_wave ///
            if mover & relative_wave>-4 & relative_wave<4 & relative_wave!=.) ///
            (connected `var'_balanced2 relative_wave ///
            if mover & relative_wave>-3 & relative_wave<3 & relative_wave!=.), ///
            xlabel(#6) legend(off)
        graph export "../output/figures/`var'.eps", replace as (eps)

    }
    
    use ../temp/data_before_collapse, clear

    insert_tag move_wave, open

        tab wave moved

    insert_tag move_wave, close

    collapse (mean) $HRS_collapse_variables, by(mover wave)

    foreach var in $HRS_collapse_variables {

        twoway (connected `var' wave if mover==1) ///
            (connected `var' wave if mover==0), xlabel(#6) legend(off)
        graph export "../output/figures/`var'2.eps", replace as(eps)

    }

    use ../temp/data_before_collapse, clear

    tab relative_wave, gen(relative_wave_ind)
    
    forv i=1/13 {

        replace relative_wave_ind`i'=0 if relative_wave_ind`i'==.

    }

    by relative_wave, sort: gen n2=_n

    gen rcendiv_origin_temp=rcendiv if relative_wave==-1
    by hhidpn, sort: egen rcendiv_origin=max(rcendiv_origin_temp)
    drop rcendiv_origin_temp
    gen rcendiv_dest_temp=rcendiv if relative_wave==0
    by hhidpn, sort: egen rcendiv_dest=max(rcendiv_dest_temp)
    drop rcendiv_dest_temp

    foreach var in $HRS_collapse_variables {

        reg `var' mover relative_wave_ind1-relative_wave_ind5 ///
            relative_wave_ind7-relative_wave_ind13 relative_wave_ind6 i.wave
        mat B_`var'66=e(b)

        gen beta_`var'66=.

        replace beta_`var'66=B_`var'66[1,2] if relative_wave_ind1==1
        replace beta_`var'66=B_`var'66[1,3] if relative_wave_ind2==1
        replace beta_`var'66=B_`var'66[1,4] if relative_wave_ind3==1
        replace beta_`var'66=B_`var'66[1,5] if relative_wave_ind4==1
        replace beta_`var'66=B_`var'66[1,6] if relative_wave_ind5==1
        replace beta_`var'66=B_`var'66[1,7] if relative_wave_ind7==1
        replace beta_`var'66=B_`var'66[1,8] if relative_wave_ind8==1
        replace beta_`var'66=B_`var'66[1,9] if relative_wave_ind9==1
        replace beta_`var'66=B_`var'66[1,10] if relative_wave_ind10==1
        replace beta_`var'66=B_`var'66[1,11] if relative_wave_ind11==1
        replace beta_`var'66=B_`var'66[1,12] if relative_wave_ind12==1
        replace beta_`var'66=B_`var'66[1,13] if relative_wave_ind13==1
        replace beta_`var'66=B_`var'66[1,14] if relative_wave_ind6==1

        reg `var' mover relative_wave_ind4 relative_wave_ind5 ///
            relative_wave_ind7-relative_wave_ind10 relative_wave_ind6 i.wave ///
            if (balanced_incl3 & relative_wave > -4 & relative_wave<4) | mover==0
        mat B_`var'33=e(b)

        gen beta_`var'33=.

        replace beta_`var'33=B_`var'33[1,2] if relative_wave_ind4==1
        replace beta_`var'33=B_`var'33[1,3] if relative_wave_ind5==1
        replace beta_`var'33=B_`var'33[1,4] if relative_wave_ind7==1
        replace beta_`var'33=B_`var'33[1,5] if relative_wave_ind8==1
        replace beta_`var'33=B_`var'33[1,6] if relative_wave_ind9==1
        replace beta_`var'33=B_`var'33[1,7] if relative_wave_ind10==1
        replace beta_`var'33=B_`var'33[1,8] if relative_wave_ind6==1

        reg `var' mover relative_wave_ind5 relative_wave_ind7 relative_wave_ind8 ///
            relative_wave_ind9 relative_wave_ind6 i.wave ///
            if (balanced_incl2 & relative_wave > -3 & relative_wave<3) | mover==0
        mat B_`var'22=e(b)

        gen beta_`var'22=.

        replace beta_`var'22=B_`var'22[1,2] if relative_wave_ind5==1
        replace beta_`var'22=B_`var'22[1,3] if relative_wave_ind7==1
        replace beta_`var'22=B_`var'22[1,4] if relative_wave_ind8==1
        replace beta_`var'22=B_`var'22[1,5] if relative_wave_ind9==1
        replace beta_`var'22=B_`var'22[1,6] if relative_wave_ind6==1

    }

    foreach var in $HRS_collapse_variables {

        twoway (connected beta_`var'66 relative_wave if n2==1, sort) ///
        (connected beta_`var'33 relative_wave if n2==1, sort) ///
        (connected beta_`var'22 relative_wave if n2==1, sort), ///
        xlabel(#6) legend(off) ytitle(Coefficient)
        graph export "../output/figures/`var'_es.eps", replace as(eps)

    }

    

end

*EXECUTE
main

