****Preliminaries*******************************************************************
version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

global hrr_data "..\temp\hrr_data"
global hrr_data_person "..\temp\hrr_data_person"
global hrr_data_move_reason "..\temp\hrr_data_mover_reason"
global output_target "..\output"
global temp_directory "..\temp"
global HRS_collapse_variables "MarriedPartnered SeparatedDivorced Widowed Earnings_1000 Health HealthChange Retired PartlyRetired VisitsDoctor N_DoctorVisits HospStay N_HospStay T_HospNight NursHomeStay N_NursHomeStay T_NursHomeNight LivesNursHome"

cap log close
log using ../output/make.log, replace
************************************************************************************
cap program drop main
program main
    use ${hrr_data_move_reason}, clear
	bys reason1: gen N=_N
	replace reason1="Other" if N<50
    graph pie, over(reason1) plabel(1 name, gap(15)) plabel(2 name, gap(15)) ///
        plabel(3 name, gap(15)) plabel(4 name, gap(15)) plabel(5 name, gap(15)) ///
        plabel(6 name, gap(15))  plabel(7 name, gap(15)) plabel(8 name, gap(15)) /// 
		plabel(1 percent, gap(5)) plabel(2 percent, gap(5)) plabel(3 percent, gap(5)) ///
		plabel(4 percent, gap(-10)) plabel(5 percent, gap(5))  plabel(6 percent, gap(5)) ///
		plabel(7 percent, gap(5)) plabel(8 percent, gap(5)) legend(off) sort descending
    graph export "${output_target}/figures/Move_Reasons.eps", replace as(eps)
	use ${hrr_data}, clear
	foreach var in  Age {
		ttest `var', by(mover)
		matrix movers_nonmovers_comparison = ///
			(nullmat(movers_nonmovers_comparison)\r(mu_1),r(mu_2),r(t))
		ttest `var' if first_observed_wave==1, by(mover)
		matrix movers_nonmovers_comparison = ///
			(nullmat(movers_nonmovers_comparison)\r(mu_1),r(mu_2),r(t))
	}
	use ${hrr_data_person}, clear
	foreach var in  $HRS_compare_variables_person {
		ttest `var', by(mover)
		matrix movers_nonmovers_comparison = ///
			(nullmat(movers_nonmovers_comparison)\r(mu_1),r(mu_2),r(t))
	}
	use ${hrr_data}, clear
    foreach var in  $HRS_compare_variables {
		if "`var'"=="Earnings_positive" {		
			ttest Earnings if Earnings>0, by(mover)
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison)\r(mu_1),r(mu_2),r(t))
		}
		else if "`var'"=="Earnings_median" {
			sum Earnings if mover==1 & Earnings>0 & first_observed_wave==1, d
			global median_earnings_mover_f=`r(p50)'
			sum Earnings if mover==0 & Earnings>0 & first_observed_wave==1, d
			global median_earnings_nonmover_f=`r(p50)'
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison) \ ///
				${median_earnings_nonmover_f},${median_earnings_mover_f},.)
			forv m=0/1 {
				count if mover==`m' & first_observed_wave==1
				global total_count_`m'_f=`r(N)'
				count if Earnings==0 & mover==`m' & first_observed_wave==1
				global zero_earnings_count_`m'_f=`r(N)'
				global zero_earnings_pct_`m'_f=${zero_earnings_count_`m'_f}/${total_count_`m'_f}
			}
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison)\ ///
					${zero_earnings_pct_0_f},${zero_earnings_pct_1_f},.)

		}
		else if "`var'"=="N" {
			unique hhidpn if mover==1
			global patients_mover=`r(sum)'
			unique hhidpn if mover==0
			global patients_nonmover=`r(sum)'
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison) \ ///
				${patients_nonmover},${patients_mover},.)
			count if mover==1
			global patient_years_mover=`r(N)'
			count if mover==0
			global patient_years_nonmover=`r(N)'
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison) \ ///
				${patient_years_nonmover},${patient_years_mover},.)
		}
		else {
			ttest `var' if first_observed_wave==1, by(mover)
			matrix movers_nonmovers_comparison = ///
				(nullmat(movers_nonmovers_comparison)\r(mu_1),r(mu_2),r(t))	
		}
    }
    matrix_to_txt, saving(../output/tables/movers_nonmovers_comparison.txt) ///
        mat(movers_nonmovers_comparison) format(%20.4f) ///
        title(<tab:movers_nonmovers_comparison>) replace
		
	bys hhidpn: egen first_wave=min(wave)
	forv w=1/9 {
		forv m=0/1 {
			unique hhidpn if first_wave==`w' & mover==`m'
			global c`w'`m'=`r(sum)'
		}
		matrix first_observed=nullmat(first_observed) \ ///
			${c`w'0},${c`w'0}/${patients_nonmover},${c`w'1},${c`w'1}/${patients_mover}
	}
	matrix_to_txt, saving(../output/tables/first_observed.txt) ///
		mat(first_observed) format(%20.4f) ///
        title(<tab:first_observed>) replace	
		
	use ${hrr_data}, clear
	order *lag3 *lag2 *lag1 *lead1 *lead2 *lead3
	foreach var in UnmarriedUnpartnered SeparatedDivorced Widowed Retired_or_Partly PoorFairHealth {
		insert_tag reg_`var', open
			areg move_in_wave `var' i.wave, a(hhidpn)
			matrix b=e(b)
			matrix V=e(V)
			di "Mean of outcome (percent move in wave over observed waves) in regression sample"
			sum move_in_wave if `var'!=.
			global reg_mean=`r(mean)'
			global reg_N=`r(N)'
			clogit move_in_wave `var' i.wave, group(hhidpn)
			cap drop in_sample
			gen in_sample=e(sample)
			matrix b_logit=e(b)
			matrix V_logit=e(V)
			di "Mean of outcome (percent move in wave over observed waves) in regression sample"
			sum move_in_wave if in_sample==1
			global logit_mean=`r(mean)'
			global logit_N=`r(N)'
			matrix reg_table=nullmat(reg_table) \ ///
				${reg_N},${reg_mean},b[1,1],sqrt(V[1,1])
			areg move_in_wave `var'lag2 `var'lag1 `var' `var'lead1 `var'lead2 i.wave, a(hhidpn)
			di "Mean of outcome (percent move in wave over observed waves) in regression sample"
			egen miss`var'1=rowmiss(`var' `var'*1 `var'*2)
			sum move_in_wave if miss`var'1==0
			areg move_in_wave `var'lag3 `var'lag2 `var'lag1 `var' `var'lead1 `var'lead2 ///
				`var'lead3 i.wave, a(hhidpn)
			di "Mean of outcome (percent move in wave over observed waves) in regression sample"
			egen miss`var'2=rowmiss(`var'*)
			sum move_in_wave if miss`var'2==0
			clogit move_in_wave `var'lag3 `var'lag2 `var'lag1 `var' `var'lead1 ///
				`var'lead2 i.wave, group(hhidpn)
			cap drop in_sample2
			gen in_sample2=e(sample)
			di "Mean of outcome (percent move in wave over observed waves) in regression sample"
			sum move_in_wave if in_sample2==1
		insert_tag reg_`var', close
	}

		foreach var in UnmarriedUnpartnered SeparatedDivorced Widowed Retired_or_Partly PoorFairHealth {
		insert_tag reg_`var'_or, open
			clogit move_in_wave `var' i.wave, group(hhidpn) or
		insert_tag reg_`var'_or, close
	}
	
	matrix_to_txt, saving(../output/tables/reg_table.txt) ///
		mat(reg_table) format(%20.4f) ///
        title(<tab:reg_table>) replace	
	
end

*EXECUTE
main

