****
*Change line 1 of D:\hrs\users\dprinz\GeoCode\Detail\sda\sda\stata\HRSXGEO.dct
*to "dictionary using D:\hrs\users\dprinz\GeoCode\Detail\sda\data\HRSXGEO.da"
****
****Preliminaries*******************************************************************
version 11
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

set more off
global dct "D:\hrs\users\dprinz\GeoCode\Detail\sda\stata\HRSXGEO.dct"
global xwalk "..\external\Geography\ziphrrxwalk"
global hrs "..\external\HRS\HRS_for_restricted_analysis"
global save_target "..\temp\hrr_data"
global save_target_person "..\temp\hrr_data_person"
global save_target_move_reason "..\temp\hrr_data_mover_reason"
************************************************************************************
cap program drop main
program main
	infile using ${dct}, clear
	gen hhidpn=HHID+PN
	destring hhidpn, replace
	keep hhidpn ZIP*
	foreach YR in "92" "93" "94" "95" "96" "98" {
		rename ZIP`YR' zipcode19`YR'
	}
	foreach YR in "00" "02" "04" "06" "08" {
		rename ZIP`YR' zipcode20`YR'
	}
	reshape long zipcode, i(hhidpn) j(year)
	drop if zip==""
	gen wave = 1 if year == 1992
	replace wave = 2 if year == 1994 | year == 1993
	replace wave = 3 if year == 1995 | year == 1996
	replace wave = 4 if year == 1998
	replace wave = 5 if year == 2000
	replace wave = 6 if year == 2002
	replace wave = 7 if year == 2004
	replace wave = 8 if year == 2006
	replace wave = 9 if year == 2008
	merge m:1 zipcode using ${xwalk}, assert(1 2 3) keep(3) keepusing(hrrnum) nogen
	merge 1:1 hhidpn wave using ${hrs}, assert(1 2 3) keep(3) keepusing(*) nogen
	keep if ragey_b>64
	sort hhidpn wave
	gen moved = 0
	replace moved = 1 if hrrnum != hrrnum[_n-1] & hhidpn == hhidpn[_n-1] & hrrnum !=. & ///
		hrrnum[_n-1]!=. & hhidpn!=. & hhidpn[_n-1]!=.
    by hhidpn, sort: egen mover=max(moved)
    by hhidpn, sort: egen num_moves=total(moved)
    drop if num_moves>1 & num_moves !=.
    drop num_moves
    gen move_wave_temp=wave if moved==1
    by hhidpn, sort: egen move_wave=max(move_wave_temp)
    drop move_wave_temp
    gen relative_wave=.
    replace relative_wave=wave-move_wave if mover==1
		
    recode ragender 1=0 2=1, gen(Female)
    tab raracem, gen(race)
    rename race1 White
    rename race2 Black
    rename race3 Other
    rename rahispan Hispanic
    tab rarelig, gen(religion)
    rename religion1 Protestant
    rename religion2 Catholic
    rename religion3 Jewish
    rename religion4 None
    recode rmstat 2=1 3=1 5=4 6=4, gen(marriage_status_temp)
    tab marriage_status_temp, gen(marriage_status)
    drop marriage_status_temp
    rename marriage_status1 MarriedPartnered
    rename marriage_status2 SeparatedDivorced
    rename marriage_status3 Widowed
    rename marriage_status4 NeverMarried
    tab rcenreg, gen(region)
    rename region1 Northeast
    rename region2 Midwest
    rename region3 South
    rename region4 West
    tab rcendiv, gen(division)
    rename division1 NewEngland
    rename division2 MidAtlantic
    rename division3 ENCentral
    rename division4 WNCentral
    rename division5 SouthAtlantic
    rename division6 ESCentral
    rename division7 WSCentral
    rename division8 Mountain
    rename division9 Pacific
    tab rsayret, gen(retirement_status)
    rename retirement_status1 NotRetired
    rename retirement_status2 Retired
    rename retirement_status3 PartlyRetired
	gen Retired_or_Partly = Retired==1 | PartlyRetired==1
	replace Retired_or_Partly=. if Retired==. & PartlyRetired==.
    gen Over79=ragey_b>79
    rename ragey_b Age
	gen Age_1992=1992-(year-Age)
    rename riearn Earnings
    rename rshlt Health
	gen health_exc_vg_g=Health<4
	gen health_fair_poor=Health>3
	gen PoorFairHealth=Health==5|Health==4
    rename rshltc HealthChange
    rename rnhmliv LivesNursHome
    rename rdoctor VisitsDoctor
    rename rdoctim N_DoctorVisits
    rename rhosp HospStay
    rename rhsptim N_HospStay
    rename rhspnit T_HospNight
    rename rnrshom NursHomeStay
    rename rnrstim N_NursHomeStay
    rename rnrsnit T_NursHomeNight
    rename rhigov Some
    rename rgovmr Medicare
    rename rgovmd Medicaid
    rename rgovva ChampusVA
    rename rgovot OtherInsurance
    rename rcholst CholesterolTest
    rename rflusht FluShot
    rename rmammog Mammogram
    rename rbreast BreastCheck
    rename rpapsm PapSmear
    rename rprost ProstateExam
    gen Earnings_1000=Earnings/1000
	
	tab raeduc, gen(educ_level)
	rename educ_level1 less_then_hs
	rename educ_level2 ged
	rename educ_level3 hs
	rename educ_level4 some_college
	rename educ_level5 college
	
	sort hhidpn wave
	bys hhidpn: gen first_observed_wave=_n==1
	
	gen move_in_wave=wave==move_wave
	
	recode MarriedPartnered 1=0 0=1, gen(UnmarriedUnpartnered)
	
	foreach var of varlist UnmarriedUnpartnered SeparatedDivorced Widowed Retired_or_Partly PoorFairHealth {
		forv l=1/3 {
			sort hhidpn wave
			gen `var'lead`l'=`var'[_n+`l'] if hhidpn[_n]==hhidpn[_n+`l']&wave[_n]==wave[_n+`l']-`l'
			gen `var'lag`l'=`var'[_n-`l'] if hhidpn[_n]==hhidpn[_n-`l']&wave[_n]==wave[_n-`l']+`l'
		}
	}
	
	save ${save_target}, replace
	bys hhidpn: keep if _n==1
	save ${save_target_person}, replace
	
	use ${save_target}, clear
	foreach n in "1" "2" {
        gen reason`n'=""
        replace reason`n'="Near/with children" if move_reason`n'==1
        replace reason`n'="Near/with relatives/friends" if move_reason`n'==2
        replace reason`n'="Health prob/services" if move_reason`n'==3
        replace reason`n'="Climate or weather" if move_reason`n'==4
        replace reason`n'="Leisure" if move_reason`n'==5
        replace reason`n'="Smaller/less expensive" if move_reason`n'==6
        replace reason`n'="Larger home/yard" if move_reason`n'==7
        replace reason`n'="Work/retirement" if move_reason`n'==8
        replace reason`n'="Marital status change" if move_reason`n'==9
        replace reason`n'="Public transportation" if move_reason`n'==10
        replace reason`n'="Closer to work" if move_reason`n'==11
        replace reason`n'="Shopping or consumption services" if move_reason`n'==12
        replace reason`n'="Old neighborhood or location bad" if move_reason`n'==20
        replace reason`n'="Dispossessed or forced to move" if move_reason`n'==21
        replace reason`n'="Old home too expensive" if move_reason`n'==22
        replace reason`n'="Moved into a house" if move_reason`n'==23
        replace reason`n'="Not happy in last location" if move_reason`n'==24
        replace reason`n'="Sold old home" if move_reason`n'==25
        replace reason`n'="Natural disaster" if move_reason`n'==26
        replace reason`n'="New neighborhood or location better" if move_reason`n'==30
        replace reason`n'="Cheaper area" if move_reason`n'==32
        replace reason`n'="Moved to retirement housing" if move_reason`n'==33
        replace reason`n'="Moved into area where had lives previously" if move_reason`n'==34
        replace reason`n'="New house or apartment has specific desirable features" if move_reason`n'==40
        replace reason`n'="Simpler house to take care of" if move_reason`n'==41
        replace reason`n'="Moved into previously owned property" if move_reason`n'==42
        replace reason`n'="Bought own or new home" if move_reason`n'==43
        replace reason`n'="Wanted to own instead of rent" if move_reason`n'==44
        replace reason`n'="In temporary housing" if move_reason`n'==45
        replace reason`n'="Moved into house where grew up" if move_reason`n'==46
        replace reason`n'="Desperation, nowhere else to go" if move_reason`n'==47
        replace reason`n'="Financial reasons" if move_reason`n'==48
        replace reason`n'="Family problems" if move_reason`n'==49
        replace reason`n'="Could not live by self" if move_reason`n'==50
        replace reason`n'="Wanted to live by self" if move_reason`n'==51
        replace reason`n'="Negative change in economic status" if move_reason`n'==52
        replace reason`n'="Positive change in economic status" if move_reason`n'==53
        replace reason`n'="Job change" if move_reason`n'==54
        replace reason`n'="Retirement" if move_reason`n'==55
        replace reason`n'="Retirement of spouse" if move_reason`n'==56
        replace reason`n'="To care for relative or family member" if move_reason`n'==57
        replace reason`n'="To move in with or nearby non-family member" if move_reason`n'==58
        replace reason`n'="Personal reasons" if move_reason`n'==59
        replace reason`n'="To get away from family members" if move_reason`n'==60
        replace reason`n'="To get away from non-family members" if move_reason`n'==61
        replace reason`n'="Positive change in health" if move_reason`n'==62
        replace reason`n'="Other" if move_reason`n'==97
        replace reason`n'="Don't know" if move_reason`n'==98
        replace reason`n'="Refused" if move_reason`n'==99    
    }
	
	keep if reason1!=""
	bys hhidpn reason1: keep if _n==1
	keep if mover==1
	keep hhidpn reason1
	save ${save_target_move_reason}, replace
	
end

** EXECUTE
main



