version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest LnRBU baseline_samp mover) ///
        keep_condition(baseline_samp==1 & rel_yr_rit!=0) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)

	run_main_model, y_it(LnRBU) fixed_effects(_I* _Y* _RY* _A*) ///
		specification_name(ExponentiatedModel`i') absorb(bene_id) keep_fe_estimates
		
	use ../temp/estimation_data_uncollapsed, clear
	
	*Check for unique initial sorting by year
	bys year bene_id: assert _N==1
	bys year (bene_id): gen obs_num=_n
	*Create and check unique random sort
	gen double u1=runiform()
	gen double u2=runiform()		
	bys year u1 u2: assert _N==1
	bys year (u1 u2): gen rand_num=_n
	*Give each observation the chat of their randomly matched observation from the same year
	sort year obs_num
	bys year (obs_num): gen chat_rand=chat[rand_num]	
		
	summ gammatilde_j, meanonly
	local plmean `r(mean)'

	gen yhat = exp(cons+chat+gammatilde_j+tau)
	gen yhat_pateq = exp(cons+chat_rand+gammatilde_j+tau)
	gen yhat_pleq = exp(cons+chat+`plmean'+tau)
	collapse (mean) yhat* [fw=fwgt], by(hrrnum year)
	collapse (mean) yhat*, by(hrrnum)
	save_data ../output/ExponentiatedModel/hrr_fe, replace key(hrrnum)

end

* Execute
main
