version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest LnRBU baseline_samp mover) ///
        keep_condition(baseline_samp==1 & rel_yr_rit!=0) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)
    run_split_sample_model
end

program run_split_sample_model
    use ../temp/data_loaded, clear
	foreach var in hrr_orig hrr_dest hrrnum {
       	gen `var'_str = string(`var',"%03.0f")
	} 
	egen orig_dest_pair = concat(hrr_orig_str hrr_dest_str)
    replace orig_dest_pair = hrrnum_str if orig_dest_pair==".."
	bys bene_id: gen u=runiform() if _n==1
	bys bene_id: gen v=runiform() if _n==1
	bys orig_dest_pair (u v): gen randnum = _n if u!=. & v!=.
	bys orig_dest_pair: egen median = median(randnum) 
	bys orig_dest_pair (randnum):gen subsamp = (_n<=median) if randnum!=.
	gsort bene_id -subsamp
	replace subsamp = subsamp[_n-1] if bene_id==bene_id[_n-1] & subsamp==.
	insert_tag split_samp, open
	tab subsamp
	insert_tag split_samp, close
	save ../temp/subsamp, replace
	
	foreach i in 0 1 {
	    use ../temp/subsamp if subsamp==`i', clear
		run_main_model, y_it(LnRBU) fixed_effects(_I* _Y* _RY* _A*) ///
		    specification_name(Split`i') absorb(gbene_id)
    }
end

* Execute
main
