version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    local   age_vars    "_Aage_5yr_b_65 _Aage_5yr_b_70 _Aage_5yr_b_75 _Aage_5yr_b_80 _Aage_5yr_b_85 _Aage_5yr_b_90 _Aage_5yr_b_95"
    local   race_vars   "_Rrace_0 _Rrace_1"
    local   sex_vars    "_Ssex_0 _Ssex_1"
    local   arsm_vars   "_RASras_1 _RASras_2 _RASras_3 _RASras_4 _RASras_5 _RASras_6 _RASras_7 _RASras_8 _RASras_9 _RASras_10 _RASras_11 _RASras_12 _RASras_13 _RASras_14 _RASras_15 _RASras_16 _RASras_17 _RASras_18 _RASras_19 _RASras_20 _RASras_21 _RASras_22 _RASras_23 _RASras_24 _RASras_25 _RASras_26 _RASras_27 _RASras_28"
    local   health      "Lnnumcon Lnhcccom Lnchr Lniez"
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest LnRBU baseline_samp mover age_5yr_bins ///
        race sex Lnnumcon Lnhcccom Lnchr Lniez) keep_condition(baseline_samp==1 & rel_yr_rit!=0) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)
    xi i.race, prefix(_R) noomit
    xi i.sex, prefix(_S) noomit
    save ../temp/data_loaded, replace
    run_main_model, ///
        y_it(LnRBU) fixed_effects(_I* _Y* _RY* _A*) specification_name(LnRBU) absorb(gbene_id)
    use ../temp/estimation_data_uncollapsed if mover==0, clear
    merge 1:1 bene_id year using ../temp/data_loaded, assert(2 3) keep(3) keepusing(*) nogen
	gen chat=LnRBU-gammatilde_j
    save ../temp/estimation_data_uncollapsed_nonmover, replace
    foreach h in `health' {
        use ../temp/data_loaded, clear
        run_main_model, ///
            y_it(`h') fixed_effects(_I* _Y* _RY* _A*) specification_name(`h') absorb(gbene_id)
        use ../temp/estimation_data_uncollapsed, clear
        gen chat_`h'=`h'-gammatilde_j
        save ../temp/estimation_data_uncollapsed_`h', replace
    }
    use ../temp/estimation_data_uncollapsed_nonmover, clear
    foreach h in `health' {
        merge 1:1 bene_id year using ../temp/estimation_data_uncollapsed_`h', ///
            assert(2 3) keep(3) keepusing(chat_`h') nogen
    }
    save, replace
    use ../temp/data_loaded, clear
    foreach h in `health' {
        merge 1:1 bene_id year using ../temp/estimation_data_uncollapsed_`h', ///
            assert(3) keep(3) keepusing(chat_`h') nogen
    }
    save, replace
    foreach group in age race sex arsm {
        run_patobs, variables(``group'_vars') saving(../output/`group'/hrr_fe)
    }
    foreach var in `health' {
        run_patobs, variables(`var') saving(../output/`var'_patobs/hrr_fe)
        run_patobs, variables(chat_`var') saving(../output/chat_`var'_patobs/hrr_fe)
    }
end

program run_patobs
    syntax, variables(str) saving(str)

        use ../temp/estimation_data_uncollapsed_nonmover, clear
		reg chat `variables' i.hrrnum i.year
		matrix b=e(b)
		foreach patob in `variables' {
			scalar beta_`patob'=_b[`patob']
		}
        use ../temp/data_loaded, clear
        gen ghat=0
		foreach patob in `variables' {
            replace ghat=ghat+beta_`patob'*`patob'
		}
        gen fwgt = ${mover_weight}
        replace fwgt = ${nonmover_weight} if mover==0
        gen N=1
        collapse (mean) LnRBU_bar_jt=LnRBU ghat (rawsum) N [fw=fwgt], by(hrrnum year)
        collapse (mean) LnRBU_bar_j=LnRBU_bar_jt ghat (sum) N, by(hrrnum)
        save_data `saving', replace key(hrrnum)

end

* Execute
main
