set.seed(1010)
k_folds = 10
lasso_alpha = 1

main <- function()
{
    patient <- c("../temp/patient_effect.csv",
        "../temp/covariates.csv",
        "../output/figures/PatientCovariates.eps",
        "../temp/patient_beta_lasso.csv")
    place <- c("../temp/place_effect.csv",
        "../temp/covariates.csv",
        "../output/figures/PlaceCovariates.eps",
        "../temp/place_beta_lasso.csv")
    nons_96hrr_patient <- c("../temp/nons_96hrr_patient_effect.csv",
        "../temp/nons_96hrr_covariates.csv",
        "../temp/nons_96hrr_patient_beta_lasso.csv")
    nons_96hrr_place <- c("../temp/nons_96hrr_place_effect.csv",
        "../temp/nons_96hrr_covariates.csv",
        "../temp/nons_96hrr_place_beta_lasso.csv")
    nons_306hrr_patient <- c("../temp/nons_306hrr_patient_effect.csv",
        "../temp/nons_306hrr_covariates.csv",
        "../temp/nons_306hrr_patient_beta_lasso.csv")
    nons_306hrr_place <- c("../temp/nons_306hrr_place_effect.csv",
        "../temp/nons_306hrr_covariates.csv",
        "../temp/nons_306hrr_place_beta_lasso.csv")

    file_matrix <- matrix(c(patient, place), nrow = 2, ncol = 4, byrow = TRUE)
    nons_file_matrix <- matrix(c(nons_96hrr_patient, nons_96hrr_place, 
        nons_306hrr_patient, nons_306hrr_place), nrow = 4, ncol = 3, byrow = TRUE)


    varlabel1 <- c(2, "Percent Black")
    varlabel2 <- c(3, "Percent Female")
    varlabel3 <- c(5, "Average Education")
    varlabel4 <- c(7, "Adjusted Log Chronic Conditions")
    varlabel5 <- c(8, "Adjusted Log Charlson")
    varlabel6 <- c(9, "Adjusted Log Iezzoni")
    varlabel7 <- c(10, "Have Unneeded Tests")
    varlabel8 <- c(12, "Aggressive Patient")
    varlabel9 <- c(13, "Comforter Patient")
    varlabel10 <- c(14, "Hospital Compare Score")
    varlabel11 <- c(16, "PCP Per Capita")
    varlabel12 <- c(17, "Hospital Beds Per Capita")
    varlabel13 <- c(18, "Non-Profit Hospitals")
    varlabel14 <- c(19, "High follow-up PCP")
    varlabel15 <- c(20, "Low follow-up PCP")
    varlabel16 <- c(21, "Cowboy PCP")
    varlabel17 <- c(22, "Comforter PCP")
    varlabel18 <- c(23, "High Follow-up Cardiologists")
    varlabel19 <- c(24, "Low Follow-up Cardiologists")
    varlabel20 <- c(25, "Cowboy Cardiologists")
    varlabels <- matrix(c(varlabel1,
        varlabel2,
        varlabel3,
        varlabel4,
        varlabel5,
        varlabel6,
        varlabel7,
        varlabel8,
        varlabel9,
        varlabel10,
        varlabel11,
        varlabel12,
        varlabel13,
        varlabel14,
        varlabel15,
        varlabel16,
        varlabel17,
        varlabel18,
        varlabel19,
        varlabel20),
        nrow = 21,
        ncol = 2,
        byrow = TRUE)

    load_glmnet("../external/lib/r")

    for (i in 1:2)
    {
        if (i == 1) {
            patient = TRUE
        } else {
            patient = FALSE
        }
        LnRBU_fe <- get_LnRBU_fe(file_matrix[i, 1])
        covariates <- get_covariates(file_matrix[i, 2])
        lambda_cv <- get_lambda_cv(LnRBU_fe, covariates)
        plot_lasso(LnRBU_fe, covariates, lambda_cv, file_matrix[i, 3], varlabels, patient)
        lasso(LnRBU_fe, covariates, lambda_cv, file_matrix[i, 4])
    }
    for (i in 1:4)
    {
        nons_LnRBU_fe <- get_LnRBU_fe(nons_file_matrix[i, 1])
        nons_covariates <- get_covariates(nons_file_matrix[i, 2])
        nons_lambda_cv <- get_lambda_cv(nons_LnRBU_fe, nons_covariates)
        lasso(nons_LnRBU_fe, nons_covariates, nons_lambda_cv, nons_file_matrix[i, 3])
    }
}

load_glmnet <- function(lib_path)
{
    library(glmnet, lib.loc = lib_path)
}

get_LnRBU_fe <- function(infile)
{
    hrr_data <- read.csv(file = infile, header = TRUE)
    return(scale(as.matrix(hrr_data$LnRBU_fe), center = TRUE, scale = FALSE))
}

get_covariates <- function(infile)
{
    hrr_covariates <- read.csv(file = infile, header = TRUE)
    return(data.matrix(hrr_covariates))
}

get_lambda_cv <- function(response, covariates)
{
    cvfit <- cv.glmnet(x = covariates, y = response, nfolds = k_folds, standardize = FALSE)
    return(as.numeric(cvfit$lambda.min))
}

plot_lasso <- function(response, covariates, lambda, outfile, labels, patient)
{
    fit <- glmnet(x = covariates, y = response, alpha = lasso_alpha, standardize = FALSE)
    coef_grid <- as.matrix(coef(fit, exact = TRUE))

    beta_cv <- as.matrix(coef(fit, s = lambda, exact = TRUE))
    norm = 0
    for (i in 1:nrow(beta_cv))
    {
        norm = norm + abs(beta_cv[i])
    }

    if (patient) {
        var1 <- c(0.31, -0.01, labels[1, 2])
        var2 <- c(0.295, 0.02, labels[2, 2])
        var3 <- c(0.38, 0.039, labels[3, 2])
        var4 <- c(0.36, 0.051, labels[4, 2])
        var5 <- c(0.37, 0.022, labels[5, 2])
        var6 <- c(0.3, 0.034, labels[6, 2])
        var7 <- c(0.25, 0.0079, labels[7, 2])
        var8 <- c(0.2, 0.00177, labels[8, 2])
        var9 <- c(0.35, 0.00445, labels[9, 2])
        var10 <- c(0.056, 0.0159, labels[10, 2])
        var11 <- c(0.38, 0.0145, labels[11, 2])
        var12 <- c(0.35, -0.036, labels[12, 2])
        var13 <- c(0.35, -0.023, labels[13, 2])
        var14 <- c(0.35, -0.014, labels[14, 2])
        var15 <- c(0.29, 0.016, labels[15, 2])
        var16 <- c(0.38, 0.0125, labels[16, 2])
        var17 <- c(0.2, -0.001, labels[18, 2])
        var18 <- c(0.29, -0.001, labels[19, 2])
        var19 <- c(0.237, -0.006, labels[20, 2])

        setEPS()
        postscript(outfile)
        plot(fit, xvar = "norm", label = FALSE)
        abline(v = norm, lty = 2, col = "darkgray")
        text(x = as.numeric(var1[1]), y = as.numeric(var1[2]), labels = var1[3], cex = 0.4)
        text(x = as.numeric(var2[1]), y = as.numeric(var2[2]), labels = var2[3], cex = 0.4)
        text(x = as.numeric(var3[1]), y = as.numeric(var3[2]), labels = var3[3], cex = 0.4)
        text(x = as.numeric(var4[1]), y = as.numeric(var4[2]), labels = var4[3], cex = 0.4)
        text(x = as.numeric(var5[1]), y = as.numeric(var5[2]), labels = var5[3], cex = 0.4)
        text(x = as.numeric(var6[1]), y = as.numeric(var6[2]), labels = var6[3], cex = 0.4)
        text(x = as.numeric(var7[1]), y = as.numeric(var7[2]), labels = var7[3], cex = 0.4)
        text(x = as.numeric(var8[1]), y = as.numeric(var8[2]), labels = var8[3], cex = 0.4)
        text(x = as.numeric(var9[1]), y = as.numeric(var9[2]), labels = var9[3], cex = 0.4)
        text(x = as.numeric(var10[1]), y = as.numeric(var10[2]), labels = var10[3], cex = 0.4)
        text(x = as.numeric(var11[1]), y = as.numeric(var11[2]), labels = var11[3], cex = 0.4)
        text(x = as.numeric(var12[1]), y = as.numeric(var12[2]), labels = var12[3], cex = 0.4)
        text(x = as.numeric(var13[1]), y = as.numeric(var13[2]), labels = var13[3], cex = 0.4)
        text(x = as.numeric(var14[1]), y = as.numeric(var14[2]), labels = var14[3], cex = 0.4)
        text(x = as.numeric(var15[1]), y = as.numeric(var15[2]), labels = var15[3], cex = 0.4)
        text(x = as.numeric(var16[1]), y = as.numeric(var16[2]), labels = var16[3], cex = 0.4)
        text(x = as.numeric(var17[1]), y = as.numeric(var17[2]), labels = var17[3], cex = 0.4)
        text(x = as.numeric(var18[1]), y = as.numeric(var18[2]), labels = var18[3], cex = 0.4)
        text(x = as.numeric(var19[1]), y = as.numeric(var19[2]), labels = var19[3], cex = 0.4)
        dev.off()
    } else {
        var1 <- c(0.1, 0.0075, labels[2,2])
        var2 <- c(0.47, 0.031, labels[4,2])
        var3 <- c(0.5, 0.108, labels[6,2])
        var4 <- c(0.35, 0.017, labels[12,2])
        var5 <- c(0.49, -0.032, labels[13,2])
        var6 <- c(0.35, -0.021, labels[14,2])
        var7 <- c(0.2, -0.0063, labels[17,2])
        var8 <- c(0.485, 0.019, labels[20,2])

        setEPS()
        postscript(outfile)
        plot(fit, xvar = "norm", label = FALSE)
        abline(v = norm, lty = 2, col = "darkgray")
        text(x = as.numeric(var1[1]), y = as.numeric(var1[2]), labels = var1[3], cex = 0.4)
        text(x = as.numeric(var2[1]), y = as.numeric(var2[2]), labels = var2[3], cex = 0.4)
        text(x = as.numeric(var3[1]), y = as.numeric(var3[2]), labels = var3[3], cex = 0.4)
        text(x = as.numeric(var4[1]), y = as.numeric(var4[2]), labels = var4[3], cex = 0.4)
        text(x = as.numeric(var5[1]), y = as.numeric(var5[2]), labels = var5[3], cex = 0.4)
        text(x = as.numeric(var6[1]), y = as.numeric(var6[2]), labels = var6[3], cex = 0.4)
        text(x = as.numeric(var7[1]), y = as.numeric(var7[2]), labels = var7[3], cex = 0.4)
        text(x = as.numeric(var8[1]), y = as.numeric(var8[2]), labels = var8[3], cex = 0.4)
        dev.off()
    }
}

lasso <- function(response, covariates, lambda, beta_file)
{
    fit <- glmnet(x = covariates, y = response, alpha = lasso_alpha, standardize = FALSE)
    beta_lasso <- as.matrix(coef(fit, s = lambda, exact = TRUE))
    write.csv(beta_lasso, file = beta_file)
}

# EXECUTE
main()
