version 12
set more off
set type double
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

* Place characteristics
global provider_chars = "HospScore specialist_pc pcp_pc bed_pc hosp_np_pct"
local provider_beliefs = "high_followup_pcp low_followup_pcp cowboy_pcp comforter_pcp"
local provider_beliefs = "`provider_beliefs' high_followup_card low_followup_card cowboy_card"
global provider_beliefs = "`provider_beliefs' comforter_card"

* Patient characteristics
global demographics = "age black female"
global ses = "medianHHincome hsgrad_pct"
global patient_health = "Lnhcccom_c_j Lnnumcon_c_j Lnchr_c_j Lniez_c_j"
global patient_preference = "have_unneeded_tests see_unneeded_card ag_patient comf_patient"

global nons_vars = "${demographics} ${ses} ${patient_health} ${provider_chars}"
local full_vars = "${demographics} ${ses} ${patient_health} ${patient_preference}"
global full_vars = "`full_vars' ${provider_chars} ${provider_beliefs}"

program main
    make_health_covariates
    make_covariates
    make_dataset using "../external/Model/LnRBU/hrr_fe.dta", ///
        covariates_file(../temp/covariates.dta) ///
        effect("patient") invar("ctildebar_j") varname("LnRBU_fe")
    make_dataset using ../external/Model/LnRBU/hrr_fe.dta, ///
        covariates_file(../temp/covariates.dta) ///
        effect("place") invar("gammatilde_j") varname("LnRBU_fe")
    make_dataset using ../external/Model/LnRBU/hrr_fe.dta, ///
        covariates_file(../temp/nons_96hrr_covariates.dta) ///
        effect("nons_96hrr_patient") invar("ctildebar_j") varname("LnRBU_fe")
    make_dataset using ../external/Model/LnRBU/hrr_fe.dta, ///
        covariates_file(../temp/nons_96hrr_covariates.dta) ///
        effect("nons_96hrr_place") invar("gammatilde_j") varname("LnRBU_fe")
    make_dataset using ../external/Model/LnRBU/hrr_fe.dta, ///
        covariates_file(../temp/nons_306hrr_covariates.dta) ///
        effect("nons_306hrr_patient") invar("ctildebar_j") varname("LnRBU_fe")
    make_dataset using ../external/Model/LnRBU/hrr_fe.dta, ///
        covariates_file(../temp/nons_306hrr_covariates.dta) ///
        effect("nons_306hrr_place") invar("gammatilde_j") varname("LnRBU_fe")
    summarize_covariates
    make_hrr_coverage
    make_cutler_stats
end

program make_health_covariates
    foreach health in Lnhcccom Lnnumcon Lnchr Lniez {
        use ../external/Model/`health'/hrr_fe.dta, clear
        keep hrrnum ctildebar_j
        rename ctildebar_j `health'_c_j
        save ../temp/HRR`health'.dta, replace
    }
    use ../temp/HRRLnhcccom, clear
    foreach health in Lnnumcon Lnchr Lniez {
        merge 1:1 hrrnum using ../temp/HRR`health'.dta, ///
            assert(match) keep(match) keepusing(*) nogenerate
    }
    save ../temp/PatientHealth.dta, replace
end

program make_covariates
    use ../external/covariates/HRRDemographics.dta, clear
    replace medianHHincome = (medianHHincome / 1000)

    merge 1:1 hrrnum using ../temp/PatientHealth.dta, ///
        assert(match) keep(match) keepusing(*) nogenerate

    foreach covariate in BedProfitperCap HospCompare SpecPCPperCap {
        merge 1:1 hrrnum using ../external/covariates/HRR`covariate'.dta, ///
            assert(match) keep(match) keepusing(*) nogenerate
    }
    save ../temp/covariates_temp.dta, replace
    
    merge 1:1 hrrnum using ../external/covariates/hrr_skinner.dta, ///
        assert(master match) keep(match) keepusing(*)

    label_variables
    standardize_vars, varlist("${full_vars}")

    foreach var of global full_vars {
        local full_vars_std = "`full_vars_std' `var'_std"
    }
    save ../temp/covariates.dta, replace
    outsheet `full_vars_std' using ../temp/covariates.csv, comma replace

    foreach var of global nons_vars {
        local nons_vars_std = "`nons_vars_std' `var'_std"
    }    
    keep hrrnum ${nons_vars} `nons_vars_std'
    save ../temp/nons_96hrr_covariates.dta, replace
    outsheet `nons_vars_std' using ../temp/nons_96hrr_covariates.csv, comma replace

    use ../temp/covariates_temp.dta, clear
    standardize_vars, varlist("${nons_vars}")
    save ../temp/nons_306hrr_covariates.dta, replace
    outsheet `nons_vars_std' using ../temp/nons_306hrr_covariates.csv, comma replace
end

    program label_variables
        label variable age "Average age"
        label variable black "Percent black"
        label variable female "Percent female"
        label variable hsgrad_pct "HS completion rate (among 25+)"
        label variable medianHHincome "Median HH Income (thousands)"
        label variable Lnhcccom_c_j "Patient Component of Log HCC score"
        label variable Lnchr_c_j "Patient Component of Log Charlson Comorbidity Index"
        label variable Lniez_c_j "Patient Component of Log # of Iezzoni chronic conditions"
        label variable Lnnumcon_c_j "Patient Component of Log # of chronic conditions"
        label variable comf_patient "Comfort Patient Preferences Ratio"
        label variable ag_patient "Aggressive Patient Preferences Ratio"
        label variable have_unneeded_tests "Patients have unneeded tests"
        label variable see_unneeded_card "Patients see unneeded cardiologists"
        label variable pcp_pc "Primary Physicians per 1000 residents"
        label variable specialist_pc "Specialists per 1000 residents"
        label variable bed_pc "Hospital beds per 1000 residents"
        label variable hosp_np_pct "Percent non-profit hospitals"
        label variable HospScore "Hospital Compare Score"
        label variable high_followup_card "High-followup Cardiologist"
        label variable low_followup_card "Low-followup Cardiologist"
        label variable comforter_card "Comforter Cardiologist"
        label variable cowboy_card "Cowboy Cardiologist"
        label variable high_followup_pcp "High-followup PCP"
        label variable low_followup_pcp "Low-followup PCP"
        label variable comforter_pcp "Comforter PCP"
        label variable cowboy_pcp "Cowboy PCP"
    end

    program standardize_vars
        syntax, varlist(string)

        foreach var in `varlist' {
            quietly: summarize `var'
            generate `var'_std = (`var' - r(mean)) / r(sd)
            local `var'_label: variable label `var'
            label variable `var'_std "``var'_label'"
        }
    end

program make_dataset
    syntax using, effect(string) invar(string) varname(string) covariates_file(string)

    use hrrnum `invar' `using', clear
    rename `invar' `varname'
    label variable `varname' "LnRBU `effect' fixed effect"

    merge 1:1 hrrnum using `covariates_file', ///
        assert(master match) keep(match) keepusing(*) nogenerate

    order hrrnum, first
    order `varname', after(hrrnum)
    save ../temp/`effect'_effect.dta, replace
    outsheet using ../temp/`effect'_effect.csv, comma replace
end

program summarize_covariates
    use ../temp/covariates.dta, clear

    local table_order = "age black female Lnhcccom_c_j Lnnumcon_c_j Lnchr_c_j Lniez_c_j"
    local table_order = "`table_order' medianHHincome hsgrad_pct"
    local table_order = "`table_order' have_unneeded_tests see_unneeded_card ag_patient"
    local table_order = "`table_order' comf_patient high_followup_pcp low_followup_pcp cowboy_pcp"

    local table_order = "`table_order' comforter_pcp high_followup_card low_followup_card"
    local table_order = "`table_order' cowboy_card comforter_card HospScore"
    local table_order = "`table_order' specialist_pc pcp_pc bed_pc hosp_np_pct"

    foreach var of local table_order {
        quietly: summarize `var'
        local `var'_mean = r(mean)
        local `var'_sd = r(sd)
        matrix summary_stats = nullmat(summary_stats) \ (``var'_mean' , ``var'_sd')
    }

    matrix list summary_stats
    matrix_to_txt, saving(../output/tables/PatientPlaceCovariates.txt) ///
        matrix(summary_stats) format(%20.4f) ///
        title(<tab:PatientPlaceCovariatesSummary>) append

end

program make_hrr_coverage
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest *_samp mover) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)

    use ../temp/data_loaded.dta, clear
    keep if baseline_samp == 1
    keep if rel_yr_rit != 0
    generate n = ${mover_weight}
    replace n = ${nonmover_weight} if mover == 0

    merge m:1 hrrnum using ../temp/covariates.dta, ///
        assert(master match) keep(master match) keepusing(female) nogenerate
    generate covered_hrr = !missing(female)
    drop female
    generate n_covered_hrr = n
    replace n_covered_hrr = 0 if (covered_hrr == 0)

    collapse (sum) n (sum) n_covered_hrr
    local pct_covered_hrr = (n_covered_hrr / n) * 100.0

    insert_tag hrr_coverage, open
        display "Cutler survey covers `pct_covered_hrr'% of our baseline sample."
    insert_tag hrr_coverage, close
end

program make_cutler_stats
    use ../external/covariates/hrr_skinner.dta, clear

    local n_hrr = _N

    insert_tag n_cutler_hrr, open
        display "The Cutler survey covers `n_hrr' HRRs"
    insert_tag n_cutler_hrr, close

    summarize num_pat, meanonly
    local n_bene = r(sum)
    local avg_bene = r(mean)

    insert_tag cutler_bene_hrr, open
        display "Cutler survey uses `n_bene' Medicare beneficiaries"
        display "Cutler survey has about `avg_bene' beneficiary responses per HRR"
    insert_tag cutler_bene_hrr, close

    summarize num_card, meanonly
    local n_card = r(sum)
    local avg_card = r(mean)
    summarize num_pcp, meanonly
    local n_pcp = r(sum)
    local avg_pcp = r(mean)

    insert_tag cutler_card_hrr, open
        display "Cutler survey uses `n_card' cardiologists"
        display "Cutler survey has about `avg_card' cardiologist responses per HRR"
    insert_tag cutler_card_hrr, close

    insert_tag cutler_pcp_hrr, open
        display "Cutler survey uses `n_pcp' PCPs"
        display "Cutler survey has about `avg_pcp' PCP responses per HRR"
    insert_tag cutler_pcp_hrr, close

    summarize comforter_card, meanonly
    local avg_comf_card = r(mean)
    summarize cowboy_card, meanonly
    local avg_cowboy_card = r(mean)
    summarize comforter_pcp, meanonly
    local avg_comf_pcp = r(mean)
    summarize cowboy_pcp, meanonly
    local avg_cowboy_pcp = r(mean)

    insert_tag cutler_card_style, open
        display "About `avg_comf_card' cardiologists are comforters"
        display "About `avg_cowboy_card' cardiologists are cowboys"
    insert_tag cutler_card_style, close

    insert_tag cutler_pcp_style, open
        display "About `avg_comf_pcp' PCPs are comforters"
        display "About `avg_cowboy_pcp' PCPs are cowboys"
    insert_tag cutler_pcp_style, close
end

* EXECUTE
main
