version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global Ranks = "dest_p50_rank dest_p25_rank dest_p20_rank dest_p10_rank dest_p5_rank dest_texas_rank dest_M_rank orig_p50_rank orig_p25_rank orig_p20_rank orig_p10_rank orig_p5_rank"

program main
    compile_patient_data
    compile_attrition_data
    prepare_sample_tables
    summarize_RBU_Expn
    summarize_N
    summarize_delta using ../external_links/compiled/CompiledPatYrDataMovers, ///
        delta_dataset(../external/fe/delta_LnRBU) delta_variable(delta_hrrnum_LnRBU_i) ///
        xtitle(Destination-Origin Difference in Average Log Utilization) ///
        xlabel(-1.5(0.5)1.5) saving(../output/figures/hist_delta_LnRBU.eps)
    sum_det_RBU
    xboundary_moves
    share_zero_table
    sample_size_tab
end

program compile_patient_data
    use bene_id hrrnum year RBU TotExpn baseline_samp mover race sex age sdod hmo HMO ///
        using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMovers.dta", ///
        keep(bene_id year RBU TotExpn baseline_samp mover race sex age sdod hmo HMO)
    merge 1:1 bene_id year using "../external_links/chars/CharsPatientYear.dta", ///
        keepusing(age HMO) nogen assert(match using) keep(using match)
    merge m:1 bene_id using "../external_links/chars/CharsPatient.dta", ///
        keepusing(sdod sex race mover) update nogen assert(2 3 4 5) keep(2 3 4 5)
    merge 1:1 bene_id year using "../external_links/denom/denom_data.dta", ///
        keepusing(state_de) nogen assert(match using) keep(match)
    merge 1:1 bene_id year using "../external_links/cc/ChronicCondition.dta", ///
        assert(1 3) keep(1 3) nogen keepusing(ami alzh atrialfb cataract chrnkidn copd ///
        chf diabetes glaucoma hipfrac ischmcht depressn osteoprs ra_oa strketia cncrbrst ///
		cncrclrc cncrprst cncrlung alzhdmta cncrendm anemia asthma hyperl hypert hyperp hypoth)
    merge 1:1 bene_id year using "../external_links/treat/TreatPatientYear.dta", ///
         keepusing(RBU TotExpn LnRBU) update assert(1 2 3 4) keep(1 3 4)
    foreach var in RBU TotExpn LnRBU {
        replace `var' = 0 if _merge==1
        replace `var'=. if HMO==1
    }
    keep if age>=65
    *Make chronic condition flags
    gen_cc
    drop ami alzh atrialfb cataract chrnkidn copd chf diabetes glaucoma hipfrac ischmcht ///
        depressn osteoprs ra_oa strketia cncrbrst cncrclrc cncrprst cncrlung alzhdmta ///
        cncrendm anemia asthma hyperl hypert hyperp hypoth
    gen census_reg4 = .
    replace census_reg4 = 1 if inlist(state_de, 20, 22, 30, 47, 7, 41, 33, 39, 31)
    replace census_reg4 = 2 if inlist(state_de, 49, 34, 42, 51, 21, 9, 8, 18, 44, 11, 10, 25, ///
        1, 19, 45, 37, 4)
    replace census_reg4 = 3 if inlist(state_de, 23, 36, 15, 14, 52, 24, 16, 26, 17, 28, 43, 35)
    replace census_reg4 = 4 if inlist(state_de, 50, 38, 5, 29, 27, 13, 53, 6, 46, 3, 32, 2, 12)
    gen northeast = (census_reg4==1)
    gen south = (census_reg4==2)
    gen midwest = (census_reg4==3)
    gen west = (census_reg4==4)
    drop census_reg4
    gen fwgt = 1
    replace fwgt = 4 if mover==0
    gen full_samp=1
    gen nonmover = (mover==0 & baseline_samp==1)
    replace mover = (mover==1 & baseline_samp==1)
    replace baseline_samp = mover==1|nonmover==1
    gen white = (race==1)
    gen die_in_samp = (sdod>=13970 & sdod<=17987)
    foreach sample in mover nonmover {
        bys bene_id: egen numyrs_`sample' = total(1) if `sample'==1
        by bene_id: egen agefirst_`sample'=min(age) if `sample'==1
        gen agefirst_6574_`sample' = (agefirst_`sample'>=65 & agefirst_`sample'<=74) if `sample'==1
        gen agefirst_7584_`sample' = (agefirst_`sample'>=75 & agefirst_`sample'<=84) if `sample'==1
        gen agefirst_85_`sample' = (agefirst_`sample'>=85 & agefirst_`sample'!=.) if `sample'==1
        count if `sample'==1
        global patyr_`sample'_N `r(N)'
        foreach var of varlist RBU num_cond {
            gen `var'_`sample' = `var' if `sample'==1
            gen `var'_`sample'_zero = (`var'_`sample'==0) if `var'_`sample'!=.
            summ `var'_`sample'_zero [fw=fwgt] if `sample'==1, meanonly
            global `var'_zero_`sample' `r(mean)'
        }
    }
    save ../temp/temp, replace
    collapse (max) full_samp baseline_samp mover nonmover (mean) RBU RBU_mover RBU_nonmover ///
        die_in_samp num_cond num_cond_mover num_cond_nonmover hmo HMO ///
        agefirst* sex white northeast south midwest west numyrs_* fwgt , by(bene_id)
    save ../temp/patient_data.dta, replace
    use bene_id year HMO using "../external_links/chars/CharsPatientYear.dta", clear
    merge m:1 bene_id using "../external_links/chars/CharsPatient.dta", ///
        assert(3) keep(3) keepusing(mover) nogen
    gen nonmover=mover==0
    save ../temp/patient_data_hmo, replace
end

program compile_attrition_data
    use bene_id year rel_yr_rit baseline_samp mover age atr pre65 pre_enroll using ////
        ../external_links/compiled/CompiledPatYrDataMoversFull.dta, clear
    append using ../external_links/compiled/CompiledPatYrDataNonMoversFull.dta, ///
        keep(bene_id year baseline_samp mover pre65 age atr pre_enroll)
    drop if pre65==1 | pre_enroll==1
    gen fwgt = 1
    replace fwgt = 4 if mover==0
    summ atr [fw=fwgt], meanonly
    global atr_rate_baseline_samp `r(mean)'
    summ atr [fw=fwgt] if mover==1, meanonly
    global atr_rate_mover `r(mean)'
    summ atr [fw=fwgt] if mover==0, meanonly
    global atr_rate_nonmover `r(mean)'
    use bene_id year age mover fwgt using ../temp/temp.dta, clear
    merge 1:1 bene_id year using "../external/sample/sample_criteria.dta", nogen ///
        assert(using match) keep(match) keepusing(*yr)
    gen atr_full=0
    *Attrition definition is based on whether these years are attrited from the 
    *baseline sample, so mark HMO / not eligible for Part A & B years as attrited
    replace atr_full=1 if partA_pass_yr==0 | partB_pass_yr==0 | nonhmo_yr==0 | age>99
    *Now add back in all other years, first moving forward in time
    sort bene_id year
    forvalues i=1/10 {
        expand 2 if (year!=year[_n+1]-1 & bene_id == bene_id[_n+1]) | ///
            (year!=2008 & bene_id!=bene_id[_n+1]), gen(newvar)
        sort bene_id year newvar
        foreach var in age year {
            replace `var'=`var'[_n-1]+1 if newvar==1
        }
        foreach var in atr_full{
            replace `var'=1 if newvar==1
        }
        drop newvar
    }
    summ atr_full [fw=fwgt], meanonly
    global atr_rate_full_samp `r(mean)'
    di ${atr_rate_full_samp}
end

program prepare_sample_tables
    foreach sample in nonmover mover {
        use ../temp/patient_data_hmo if `sample'==1, clear
        summ HMO, meanonly
        local HMO_`sample'=r(mean)

        use ../temp/patient_data if `sample'==1, clear
        count if `sample'==1
        local `sample'_N = round(r(N))
        summ sex [fw=fwgt], meanonly
        local female_`sample' = 1 - r(mean)
        foreach var of varlist RBU num_cond {
            sum `var'_`sample' [fw=fwgt],d
            local `var'_mean_`sample' = r(mean)
            local `var'_sd_`sample' = r(sd)
        }
        foreach var of varlist white die_in_samp west midwest south northeast {
            summ `var' [fw=fwgt], meanonly
            local `var'_`sample' = r(mean)
        }
        foreach var in agefirst agefirst_6574 agefirst_7584 agefirst_85 numyrs {
            summ `var'_`sample' [fw=fwgt], meanonly
            local `var'_`sample' = r(mean)
        }
        di `HMO_`sample''
        matrix `sample' = ///
            `female_`sample'' \ `white_`sample'' \  ///
            `agefirst_6574_`sample'' \ `agefirst_7584_`sample'' \ `agefirst_85_`sample'' \ ///
            `northeast_`sample'' \ `south_`sample'' \ `midwest_`sample'' \ `west_`sample''  \ ///
            `RBU_mean_`sample'' \ `RBU_sd_`sample'' \ ${RBU_zero_`sample'} \ ///
            `num_cond_mean_`sample'' \ `num_cond_sd_`sample'' \ ${num_cond_zero_`sample'} \ /// 
            `numyrs_`sample'' \ `die_in_samp_`sample'' \ `HMO_`sample'' \ ///
            ``sample'_N' \ ${patyr_`sample'_N} 
        matrix list `sample'
            matrix `sample'_slides = ///
            ``sample'_N' \ `female_`sample'' \ `white_`sample'' \  ///
            `agefirst_`sample'' \ `numyrs_`sample'' \ `num_cond_mean_`sample'' \ ///
            `die_in_samp_`sample'' \ `RBU_mean_`sample'' \ `RBU_sd_`sample'' \ ${RBU_zero_`sample'}
        matrix list `sample'_slides
    }
    matrix SummaryStats = nonmover, mover
	matrix SummaryStats_slides = nonmover_slides, mover_slides
    matrix_to_txt, saving(../output/tables/SummaryStats.txt) mat(SummaryStats) ///
        format(%20.4f) title(<tab:SummaryStats>) append
	matrix_to_txt, saving(../output/tables/SummaryStats.txt) mat(SummaryStats_slides) ///
        format(%20.4f) title(<tab:SummaryStats_slides>) append
end

program summarize_RBU_Expn
    syntax, [samp(str)]

    use bene_id year RBU LnRBU TotExpn baseline_samp mover hrrnum rel_yr_rit `samp' ///
        using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", keep(bene_id year ///
        RBU LnRBU TotExpn baseline_samp mover hrrnum `samp')
	
    keep if rel_yr_rit!=0 & baseline_samp==1
    if "`samp'"!="" {
        keep if `samp'==1
    }
    gen N=1
    gen fwgt = 1
    replace fwgt = 4 if mover==0

    collapse (mean) RBU TotExpn (sum) N[fw=fwgt], by(hrrnum year)
    collapse (mean) RBU TotExpn (sum) N, by(hrrnum)
    if "`samp'"==""{
        merge 1:1 hrrnum using "../external/fe/LnRBU_hrr_mean", assert(3) keepusing(LnRBU_total)
        assert LnRBU==LnRBU_total
        drop LnRBU_total
    }
    if "`samp'"!="" {
        merge 1:1 hrrnum using "../external/fe/LnRBU_hrr_mean_strata", assert(3) ///
        keepusing(LnRBU_`samp')
        assert LnRBU==LnRBU_`samp'
    }

    sort hrrnum
    gen hrr_bdry_i=_n

    summ RBU
    local mean: display %8.0fc `r(mean)'
    local sd: display %8.0fc `r(sd)'
    hist RBU, fraction ///
        ytitle("Share of HRRs") xtitle("Average Utilization in HRR") ///
        legend(on order(- "Mean = `mean'" "SD = `sd'") pos(2) ring(0) region(lp(solid))) ///
        scheme(s1mono)
    graph export ../output/figures/hist_RBU`samp'.eps, replace
	format RBU %4.0f
    spmap RBU using ../external/GeographyMoves/hrrcoord, ///
        id(hrr_bdry_i) fcolor(Greys) clnumber(5) legstyle(2) legorder(lohi) ///
        line(data(../external/GeographyMoves/state_coordinates.dta) size(medthick)) ///
        legend(symy(*1) symx(*1) size(*2))
    graph export ../output/figures/map_RBU`samp'.eps, replace    

    spmap N using ../external/GeographyMoves/hrrcoord, ///
        id(hrr_bdry_i) fcolor(Greys) clnumber(5) legstyle(2) legorder(lohi) ///
        line(data(../external/GeographyMoves/state_coordinates.dta) size(medthick))
    graph export ../output/figures/map_totalN`samp'.eps, replace  
    summ TotExpn
    local mean: display %8.0fc `r(mean)'
    local sd: display %8.0fc `r(sd)'
    hist TotExpn, fraction ///
        ytitle("Share of HRRs") xtitle("Average Expenditure in HRR") ///
        legend(on order(- "Mean = `mean'" "SD = `sd'") pos(2) ring(0) region(lp(solid))) ///
        scheme(s1mono)
    graph export ../output/figures/hist_TotExpn`samp'.eps, replace

end

program summarize_N
    foreach loc in orig dest {
        use bene_id hrr_`loc' using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
        rename hrr_`loc' hrrnum
        bys bene_id: keep if _n==1
        gen N=1
        collapse (sum) N, by(hrrnum)
        sort hrrnum
        gen hrr_bdry_i=_n
        insert_tag number_of_movers_`loc', open
        summ N, d
        insert_tag number_of_movers_`loc', close
        local mean: display %8.0fc `r(mean)'
        local sd: display %8.0fc `r(sd)'
        hist N, fraction ///
            ytitle("Share of HRRs") xtitle("Number of Patient-Years in HRR") ///
            legend(on order(- "Mean = `mean'" "SD = `sd'") pos(2) ring(0) region(lp(solid))) ///
            scheme(s1mono)
        graph export ../output/figures/hist_N_`loc'.eps, replace
        spmap N using ../external/GeographyMoves/hrrcoord, ///
            id(hrr_bdry_i) fcolor(Greys) clnumber(5) legstyle(2) legorder(lohi) ///
            line(data(../external/GeographyMoves/state_coordinates.dta) size(medthick)) ///
            legend(symy(*2) symx(*2) size(*2))
        graph export ../output/figures/map_N_`loc'.eps, replace
    }
end       


program sum_det_RBU
    use bene_id year RBU mover ///
        using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", ///
        keep(bene_id year RBU mover)
    collapse RBU mover, by(bene_id)	
    gen fwgt = 1
    replace fwgt = 4 if mover==0
    insert_tag sum_det_RBU, open
        di "Utilization for Movers"
	sum RBU if mover == 1, d
	di "Utilization for Non-Movers"
        sum RBU if mover == 0, d
	di "Utilization for all patients, non-movers receive a weight of 4"
        sum RBU [fw = fwgt], d
    insert_tag sum_det_RBU, close
end    

program xboundary_moves
    use nf nfac xs xcr xcd mover using "../external/sample/subsamples.dta", clear
    count if mover == 1
    global total = `r(N)'
    foreach x of varlist xs xcr xcd{
        count if `x' == 1 & mover == 1
        global `x'_count = `r(N)'
        global `x'_pct = ${`x'_count}/${total}
    }
    count if nf == 0 & mover == 1
    global f_count = `r(N)'
    global f_pct = ${f_count}/${total}
    count if nfac == 0 & nf == 1 & mover == 1
    global ac_count = `r(N)'
    global ac_pct = ${ac_count}/${total}
	
    matrix moves = (nullmat(moves) \ ${xs_count},${xs_pct} \ ///
        ${xcr_count},${xcr_pct} \ ${xcd_count},${xcd_pct}\ ${f_count},${f_pct} \ ///
        ${ac_count},${ac_pct})
    matrix_to_txt, saving(../output/tables/moves.txt) ///
        mat(moves) format(%20.4f) title(<tab:SummaryMove>) replace
end

program share_zero_table
    use bene_id hrrnum year baseline_samp mover diag imag prev_num num_doc ///
        Ip_RBU Op_RBU Er_RBU Ot_RBU num_cond chr iez ///
        using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMovers.dta", ///
        keep(bene_id hrrnum year baseline_samp mover diag imag prev_num num_doc Ip_RBU ///
        Op_RBU Er_RBU Ot_RBU num_cond chr iez)
    keep if baseline_samp==1
    gen nonmover = mover==0
	
    foreach sample in nonmover mover {
        foreach var of varlist diag imag prev_num num_doc Ip_RBU Op_RBU Er_RBU Ot_RBU ///
            num_cond chr iez {
            gen `var'_`sample'_zero = `var'==0 if `sample'==1
            summ `var'_`sample'_zero if `sample'==1, meanonly
            matrix share_zero_`sample'=(nullmat(share_zero_`sample') \ `r(mean)')
        } 
        count if `sample'==1
        matrix share_zero=(nullmat(share_zero), (share_zero_`sample' \ `r(N)'))
    }
    matrix list share_zero
    matrix_to_txt, saving(../output/tables/share_zero.txt) mat(share_zero) ///
        format(%20.4f) title(<tab:share_zero>) append
end

program	sample_size_tab
    use bene_id baseline_samp mover *_move cc_samp age_q*_a hrr* first_third second_third ///
        third_third age_q1_a age_q2_a age_q3_a age_q4_a nondead nondh nonhmo nonatr xs xcr ///
        state_* hsa_* age using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMovers.dta", ///
        keep(bene_id baseline_samp mover rel_yr_rit *_move cc_samp age_q*_a hrr* ///
        first_third second_third third_third age_q1_a age_q2_a age_q3_a age_q4_a nondead ///
        nondh nonhmo nonatr xs xcr state_* hsa_* age)
    merge m:1 hrr_orig hrr_dest using ../external/fe/delta_LnRBU, ///
        assert(1 3) keep(1 3) keepusing(delta_hrrnum_LnRBU_i) nogen
    merge m:1 state_orig state_dest using ../external/fe/delta_state_LnRBU, ///
        assert(1 3) keep(1 3) keepusing(*) gen(state_mover_samp)
    merge m:1 hsa_orig hsa_dest using ../external/fe/delta_hsa_LnRBU, ///
        assert(1 3) keep(1 3) keepusing(*) gen(hsa_mover_samp)

    rename hrrnum hrrnum_temp
    foreach type in orig {
        rename hrr_orig hrrnum
        merge m:1 hrrnum using ../external/fe/LnRBU_hrr_mean.dta, assert(master using match) ///
            keep(master match) keepusing(hrrnum LnRBU_total) nogen
        rename hrrnum hrr_`type'
        rename LnRBU_total LnRBU_`type'
    }
    rename hrrnum_temp hrrnum
	
    xtile LnRBU_orig_median=LnRBU_orig, nq(2)
    xtile LnRBU_orig_quart=LnRBU_orig, nq(4)		
    gen up=delta_hrrnum_LnRBU_i>0 & delta_hrrnum_LnRBU!=.
    gen down=delta_hrrnum_LnRBU_i<0
    bys bene_id: gen num_pat=_n==1
	
    count
    local mover_nonmover `r(N)'
    count if mover==1
    local mover `r(N)'
    count if num_pat==1
    local mover_nonmover_numpat `r(N)'
    count if num_pat==1 & mover==1
    local mover_numpat `r(N)'
    count if (rel_yr_rit>=-5 & rel_yr_rit<=-2) | (rel_yr_rit>=2 & rel_yr_rit<=5)
    local mover_cfg_years `r(N)'
    count if (rel_yr_rit>=-5 & rel_yr_rit<=-2)
    local mover_cfg_pre_years `r(N)'
    count if (rel_yr_rit>=-5 & rel_yr_rit<=-2) & LnRBU_orig_median==2
    local mover_cfg_pre_years_orig_above `r(N)'
    count if (rel_yr_rit>=-5 & rel_yr_rit<=-2) & LnRBU_orig_median==1
    local mover_cfg_pre_years_orig_below `r(N)'
    forvalues q=1/4{
        count if (rel_yr_rit>=-5 & rel_yr_rit<=-2) & LnRBU_orig_quart==`q'
        local mover_cfg_pre_years_orig_q`q' `r(N)'
    }
    foreach sample in te_move tm_move tl_move up down age_q1_a age_q2_a age_q3_a age_q4_a ///
        first_third second_third third_third nondead nondh nonhmo nonatr xs xcr cc_samp {
        count if `sample'==1 & mover==1
        local `sample'_mover `r(N)'
    }
    foreach q in q1_a q2_a q3_a q4_a {
        sum age if age_`q'==1 & mover ==1
        local mean_age_`q' = r(mean)
    }
    count if state_mover_samp==3 & mover==1
    local state_mover_samp `r(N)'
    count if hsa_mover_samp==3 & mover==1
    local hsa_mover_samp `r(N)'
    count if cc_samp==1 & mover==1 & up==1 & te_move==1
    local cc_mover_early_up `r(N)'
    count if cc_samp==1 & mover==1 &  down==1 & te_move==1
    local cc_mover_early_down `r(N)'
    count if mover==1 & up==1 & te_move==1
    local mover_early_up `r(N)'
    count if mover==1 &  down==1 & te_move==1
    local mover_early_down `r(N)'
	
    count if rel_yr_rit!=0
    local mover_nonmover_ex0 `r(N)'
    count if rel_yr_rit!=0 & cc_samp==1
    local mover_nonmover_ex0_cc `r(N)'
    count if (mover==1 & (rel_yr_rit==-1 | rel_yr_rit==1 ))|mover==0
    local mover_1_n1_nonmover `r(N)'

    use bene_id bs_o bs_o_nsb using ../external_links/compiled/CompiledPatYrDataMoversAlt, clear
    count if bs_o==1
    local address_changers_mover `r(N)'
    count if bs_o_nsb==1
    local address_changers_nsb_mover `r(N)'

    use ../external_links/compiled/CompiledPatYrDataMovers, clear
    rename hrrnum hrrnum_temp
    foreach loc in dest orig {
        rename hrr_`loc' hrrnum 
        merge m:1 hrrnum using ../external/fe/hrr_rank_LnRBU, assert(3) keep(3) nogen
        rename LnRBU_* `loc'_*
        rename hrrnum hrr_`loc'
    }
    rename hrrnum_temp hrrnum
    foreach rank in $Ranks {
        sum `rank'
        local rank_min = r(min)
        local rank_max = r(max)
        gen `rank'_temp = 1 if `rank' == `rank_min'
        replace `rank'_temp = 4 if `rank' == `rank_max'
        replace `rank'_temp = 0 if `rank' != `rank_min' & `rank' != `rank_max'
        drop `rank'
        rename `rank'_temp `rank'
    }
    foreach stratum in p50_rank p25_rank p10_rank p5_rank {
        count if (dest_`stratum'==1 & orig_`stratum'==4) | (dest_`stratum'==4 & orig_`stratum'==1)
        local `stratum'_samp = r(N)
    }

    rename hrrnum hrrnum_temp
    rename hrr_orig hrrnum
    merge m:1 hrrnum using ../external/fe/LnRBU_hrr_mean.dta, assert(using match) ///
        keep(match) keepusing(hrrnum LnRBU_total) nogen
    rename hrrnum hrr_orig
    rename LnRBU_total LnRBU_orig
    rename hrrnum_temp hrrnum
    xtile LnRBU_orig_quart=LnRBU_orig, nq(4)
    forv q=1/4 {
        gen LnRBU_orig_q`q'=LnRBU_orig_quart==`q'
    }
    drop LnRBU_orig_quart
    forv q=1/4 {
        count if LnRBU_orig_q`q' == 1
        local LnRBU_orig_q`q'_samp = r(N)
    }
	
    insert_tag table_figure_counts, open
        di"Numbers in Patient-Years, unless stated otherwise"
        di""
        di"General Stats"
        di"All Movers and Nonmovers: `mover_nonmover'"
        di"All Movers: `mover'"
        di"All Movers and Nonmovers, Number of Patients: `mover_nonmover_numpat'"
        di"All Movers, Number of Patient Years: `mover_numpat'"
        di""
        di"Figure Stats"
        di"Mover Years between [-5,-2] and [2,5]: `mover_cfg_years'"
        di"Mover Years in [-5,-2]: `mover_cfg_pre_years'"
        di"Mover Years in [-5,-2] & Above Median Origin Util: `mover_cfg_pre_years_orig_above'"
        di"Mover Years in [-5,-2] & Below Median Origin Util: `mover_cfg_pre_years_orig_below'"
        di"Mover Years in [-5,-2] & Q1 Origin Util: `mover_cfg_pre_years_orig_q1'"
        di"Mover Years in [-5,-2] & Q2 Origin Util: `mover_cfg_pre_years_orig_q2'"
        di"Mover Years in [-5,-2] & Q3 Origin Util: `mover_cfg_pre_years_orig_q3'"
        di"Mover Years in [-5,-2] & Q4 Origin Util: `mover_cfg_pre_years_orig_q4'"
        di"Early Move Years: `te_move_mover'"
        di"Middle Move Years: `tm_move_mover'"
        di"Late Move Years: `tl_move_mover'"
        di"Moves Up: `up_mover'"
        di"Moves Down: `down_mover'"
        di"Age Quartile 1 Movers: `age_q1_a_mover'"
        di"Age Quartile 2 Movers: `age_q2_a_mover'"
        di"Age Quartile 3 Movers: `age_q3_a_mover'"
        di"Age Quartile 4 Movers: `age_q4_a_mover'"
        di"Chronic Condition Sample, Movers: `cc_samp_mover'"
        di"Chonic Condition Sample, Movers, Early Moves Up: `cc_mover_early_up'"
        di"Chonic Condition Sample, Movers, Early Moves Down: `cc_mover_early_down'"
        di""
        di"Table Stats"
        di"All Movers and NonMovers, Exclude Year 0: `mover_nonmover_ex0'"
        di"All Movers and NonMovers, Chronic Condition Samp, Exclude Year 0: `mover_nonmover_ex0_cc'"
        di""
        di"Appendix Figure Stats"
        di"Event Study: Address Changers Movers Only: `address_changers_mover'"
        di"Event Study: Address Changers NSB Movers Only: `address_changers_nsb_mover'"
        di"First Third Sample, Movers: `first_third_mover'"
        di"Second Third Sample, Movers: `second_third_mover'"
        di"Third Third Sample, Movers: `third_third_mover'"
        di"NonDead Sample, Movers: `nondead_mover'"
        di"NonDead and NonHMO, Movers: `nondh_mover'"
        di"NonHMO, Movers: `nonhmo_mover'"
        di"NonAtrit, Movers: `nonatr_mover'"
        di"Redefine Moves at State Level: `state_mover_samp'"
        di"Redefine Moves at HSA Level: `hsa_mover_samp'"
        di"Cross State, Movers: `xs_mover'"
        di"Cross Region, Movers: `xcr_mover'"
        di"Movers, Early Moves Up: `mover_early_up'"
        di"Movers, Early Moves Down: `mover_early_down'"
        di"Mean age for the first quartile of age: `mean_age_q1_a'"
        di"Mean age for the second quartile of age: `mean_age_q2_a'"
        di"Mean age for the third quartile of age: `mean_age_q3_a'"
        di"Mean age for the fourth quartile of age: `mean_age_q4_a'"
        di"All Non-movers and Movers in -1 and +1: `mover_1_n1_nonmover'"
        di"Movers who move between areas with above and below median average utilization: `p50_rank_samp'"
        di"Movers who move between areas with top and bottom quartiles of average utilization: `p25_rank_samp'"
        di"Movers who move between areas with top and bottom 10 percent of average utilization: `p10_rank_samp'"
        di"Movers who move between areas with top and bottom 5 percent of average utilization: `p5_rank_samp'"
        di"Movers whose origin utilization are in the first quartile: `LnRBU_orig_q1_samp'"
        di"Movers whose origin utilization are in the second quartile: `LnRBU_orig_q2_samp'"
        di"Movers whose origin utilization are in the third quartile: `LnRBU_orig_q3_samp'"
        di"Movers whose origin utilization are in the fourth quartile: `LnRBU_orig_q4_samp'"
    insert_tag table_figure_counts, close
end

* EXECUTE
main
