version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    BinPlots
    EventStudies
    UtilizationOverTime
    ClaimLocationFigures
    LogUtilizationAroundMove
    DistanceHistogram
end

program BinPlots
    ChettyFriedman ///
        using "../external/Chetty Friedman/delta_bins_LnRBU", ///
        saving(../output/figures/BinPlots/ChettyFriedman.eps) ///
        outcome(LnRBU) delta_group_variable(delta_group) delta_variable(delta_i) ///
        pre_period_start(-5) pre_period_end(-2) post_period_start(2) post_period_end(5) ///
        legend(on order(2 3) label(2 "Movers") label(3 "Matched Non-Movers") ///
        pos(5) ring(0) r(1) symx(*.3)) ylabel(0 [0.25] 1) ///
        xtitle(Destination-Origin Difference in Average Log Utilization) ///
        ytitle(Change in Log Utilization on Move, size(small)) scheme(s1mono)
    SelectionOnLevels ///
        using "../external/Chetty Friedman/delta_bins_LnRBU", ///
        saving(../output/figures/BinPlots/SelectionOnLevels.eps) ///
        outcome(LnRBU_relative_to_nonmovers) delta_group_variable(delta_group) ///
        delta_variable(delta_i) ///
        pre_period_start(-5) pre_period_end(-2) ///
        ylabel(-0.5 [0.25] 0.5) ///
        xtitle(Destination-Origin Difference in Average Log Utilization) ///
        ytitle(Movers-Non-Movers Difference in Average Log Utilization Before Move, size(small)) ///
        legend(off) scheme(s1mono)
end

    program ChettyFriedman
        syntax using, outcome(str) delta_group_variable(str) delta_variable(str) ///
            pre_period_start(str) pre_period_end(str) post_period_start(str) ///
            post_period_end(str) [legend(str)] [ylabel(str)] [xtitle(str)] [ytitle(str)] ///
            [scheme(str)] saving(str)

        use `using', clear
        gen beforeafter=""
        replace beforeafter="_after" ///
            if rel_yr_rit>=`post_period_start' & rel_yr_rit<=`post_period_end'
        replace beforeafter="_before" ///
            if rel_yr_rit>=`pre_period_start' & rel_yr_rit<=`pre_period_end'
        drop if beforeafter==""
        collapse (mean) `delta_variable' `outcome' [fw=count], ///
            by(beforeafter `delta_group_variable')
        reshape wide `outcome' `delta_variable', i(`delta_group_variable') j(beforeafter) string
        gen before_after_difference=`outcome'_after-`outcome'_before
        egen delta=rowmean(`delta_variable'_after `delta_variable'_before)
        reg before_after_difference delta
        local slope = round(_b[delta], 0.001)
        twoway ///
            (scatter before_after_difference delta if `delta_group_variable'!=0) ///
            (lfit before_after_difference delta if `delta_group_variable'!=0) ///
            (scatter before_after_difference delta if `delta_group_variable'==0, ///
            msymbol(X) msize(large)), ///
            legend(`legend') ylabel(`ylabel') xtitle(`xtitle') ytitle(`ytitle') ///
            title("Slope=`slope'", size(medium) pos(12) ring(0)) scheme(`scheme')
        graph export `saving', replace

    end

    program SelectionOnLevels
        syntax using, outcome(str) delta_group_variable(str) delta_variable(str) ///
            pre_period_start(str) pre_period_end(str) ///
            [legend(str)] [ylabel(str)] [xtitle(str)] [ytitle(str)] [scheme(str)] saving(str)

        use `using' if rel_yr_rit>=`pre_period_start' & rel_yr_rit<=`pre_period_end', clear
        collapse (mean) `delta_variable' `outcome' [fw=count], by(`delta_group_variable')
        reg `outcome' `delta_variable'
        local slope = round(_b[`delta_variable'], 0.001)
        twoway ///
            (scatter `outcome' `delta_variable' if `delta_group_variable'!=0) ///
            (lfit `outcome' `delta_variable' if `delta_group_variable'!=0), ///
            legend(`legend') ylabel(`ylabel') xtitle(`xtitle') ytitle(`ytitle') ///
            title("Slope=`slope'", size(medium) pos(12) ring(0)) scheme(`scheme')
        graph export `saving', replace

    end

program EventStudies

    EventStudy using "../external/Event Study/LnRBU/estimates", ///
        saving(../output/figures/LnRBU/EventStudy.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_EB/estimates", ///
        saving(../output/figures/LnRBU/EventStudy_EB.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_EB) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_all/estimates", ///
        saving(../output/figures/LnRBU/EventStudy_All.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_all) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_e/estimates", ///
        saving(../output/figures/LnRBU/BalancedPanelEarly.eps) ///
        xlabel(-1 (1) 7) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_e) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_m/estimates", ///
        saving(../output/figures/LnRBU/BalancedPanelMiddle.eps) ///
        xlabel(-4 (1) 4) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_m) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_l/estimates", ///
        saving(../output/figures/LnRBU/BalancedPanelLate.eps) ///
        xlabel(-7 (1) 1) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_l) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_up/estimates", ///
        saving(../output/figures/UpDown/Up.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_up) standard_error_reps(50)
    EventStudy using "../external/Event Study/LnRBU_down/estimates", ///
        saving(../output/figures/UpDown/Down.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings ///
        standard_error(../external/Event Study SE/LnRBU_down) standard_error_reps(50)
    EventStudy using "../external/Event Study/RBU/estimates", ///
        saving(../output/figures/RBU/EventStudy.eps) ///
        xlabel(-10 (1) 9) $EventStudy_RBU_Settings ///
        standard_error(../external/Event Study SE/RBU) standard_error_reps(50)
    EventStudy using "../external/Event Study/RBU_e/estimates", ///
        saving(../output/figures/RBU/BalancedPanelEarly.eps) ///
        xlabel(-1 (1) 7) $EventStudy_RBU_Settings ///
        standard_error(../external/Event Study SE/RBU_e) standard_error_reps(50)
    EventStudy using "../external/Event Study/RBU_m/estimates", ///
        saving(../output/figures/RBU/BalancedPanelMiddle.eps) ///
        xlabel(-4 (1) 4) $EventStudy_RBU_Settings ///
        standard_error(../external/Event Study SE/RBU_m) standard_error_reps(50)
    EventStudy using "../external/Event Study/RBU_l/estimates", ///
        saving(../output/figures/RBU/BalancedPanelLate.eps) ///
        xlabel(-7 (1) 1) $EventStudy_RBU_Settings ///
        standard_error(../external/Event Study SE/RBU_l) standard_error_reps(50)
    foreach hm in Lnchr Lnhcccom Lniez Lnnumcon {
        EventStudy using "../external/Event Study/`hm'/estimates", ///
            saving(../output/figures/HealthEventStudy/`hm'.eps) ///
            xlabel(-10 (1) 9) ytitle(${`hm'_title} (Coefficient)) $EventStudy_HM_Settings ///
            standard_error(../external/Event Study SE/`hm') standard_error_reps(50)
        EventStudy using "../external/Event Study/`hm'_down_e/estimates", ///
            saving(../output/figures/HealthEventStudy/`hm'DownEarly.eps) ///
            xlabel(-1 (1) 7) ytitle(${`hm'_title} (Coefficient)) $EventStudy_HM_Settings ///
            standard_error(../external/Event Study SE/`hm'_down_e) standard_error_reps(50)
        EventStudy using "../external/Event Study/`hm'_up_e/estimates", ///
            saving(../output/figures/HealthEventStudy/`hm'UpEarly.eps) ///
            xlabel(-1 (1) 7) ytitle(${`hm'_title} (Coefficient)) $EventStudy_HM_Settings ///
            standard_error(../external/Event Study SE/`hm'_up_e) standard_error_reps(50)
    }
    foreach subsample in age_q1_a age_q2_a age_q3_a age_q4_a nf nfac nonatr nondead nondh ///
        nonhmo xcr xs first_third second_third third_third {
        EventStudy using "../external/Event Study/LnRBU_`subsample'/estimates", ///
            saving(../output/figures/Subsamples/`subsample'.eps) ///
            xlabel(-10 (1) 9) $EventStudy_Settings ///
            standard_error(../external/Event Study SE/LnRBU_`subsample') standard_error_reps(50)
    }
    foreach third in first_third second_third third_third {
        EventStudy using "../external/Event Study/LnRBU_`third'/estimates", ///
            saving(../output/figures/Subsamples/`third'.eps) ///
            xlabel(-3 (1) 3) $EventStudy_Settings ///
            standard_error(../external/Event Study SE/LnRBU_`third') standard_error_reps(50)
    }
    foreach outcome in RBU_perc {
        EventStudy using "../external/Event Study/`outcome'/estimates", ///
            saving(../output/figures/OtherOutcomes/`outcome'.eps) ///
            xlabel(-10 (1) 9) ytitle(${`outcome'_title} (Coefficient)) ///
            $EventStudy_RBU_perc_Settings ///
            standard_error(../external/Event Study SE/`outcome') standard_error_reps(50)
    }
    foreach outcome in anyErRBU  any_Ip  anypcp Lndiag  LnEr_RBU  Lnimag  ///
        LnIp_RBU  Lnnum_doc  LnOp_RBU  LnOt_RBU  Lnprv_num  Spec {
        EventStudy using "../external/Event Study/`outcome'/estimates", ///
            saving(../output/figures/OtherOutcomes/`outcome'.eps) ///
            xlabel(-10 (1) 9) ytitle(${`outcome'_title} (Coefficient)) $Other_Settings ///
            standard_error(../external/Event Study SE/`outcome') standard_error_reps(50)
    }
    foreach level in hsa state {
        EventStudy using "../external/Event Study/`level'/estimates", ///
            saving(../output/figures/`level'/EventStudy.eps) ///
            xlabel(-10 (1) 9) $EventStudy_Settings ///
            standard_error(../external/Event Study SE/`level') standard_error_reps(50)
    }
    foreach cut in p50_rank p25_rank p10_rank p5_rank {
        EventStudy using "../external/Event Study/`cut'/estimates", ///
            saving(../output/figures/LnRBU/LnRBU_`cut'.eps) ///
            xlabel(-10 (1) 9) ytitle(Log Utilization (Coefficient)) scheme(s1mono) ///
            xline(0,lwidth(7) lcolor(gs11)) yline(-.75 (.25) 1.5, lwidth(vthin) lcolor(gray)) ///
            xtitle(Year Relative to Move) ylabel(-.75 (.25) 1.5) ///
            standard_error(../external/Event Study SE/LnRBU_`cut') standard_error_reps(50)
    }

    DoubleEventStudy using "../external/Event Study/LnRBU/estimates", ///
        saving(../output/figures/LnRBU/DoubleEventStudy_EB.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings label1("Standard Event Study") ///
        label2("EB Adjusted Event Study") ///
        standard_error(../external/Event Study SE/LnRBU) standard_error_reps(50) ///
        using2("../external/Event Study/LnRBU_EB/estimates") ///
        standard_error2(../external/Event Study SE/LnRBU_EB) standard_error_reps2(50)

    DoubleEventStudy using "../external/Event Study/LnRBU/estimates", ///
        using2("../external/Event Study/LnRBU_all/estimates") ///
        saving(../output/figures/LnRBU/DoubleEventStudy_All.eps) ///
        xlabel(-10 (1) 9) $EventStudy_Settings label1("Standard Event Study") ///
        label2("Include Non-Movers") standard_error(../external/Event Study SE/LnRBU) ///
        standard_error_reps(50)	standard_error2(../external/Event Study SE/LnRBU_all) ///
        standard_error_reps2(50)
end 

    program EventStudy
        syntax using, xlabel(str) ytitle(str) scheme(str) xline(str) yline(str) xtitle(str) ///
            ylabel(str) saving(str) [standard_error(str) standard_error_reps(str)]

        if "`standard_error'"!="" {
            use rel_yr_rit `using', clear
            forv i=1/`standard_error_reps' {
                merge 1:1 rel_yr_rit using "`standard_error'_`i'/estimates", ///
                    assert(3) keep(3) keepusing(*) nogen
                rename coefficient coefficient_`i'
            }
            egen standard_error=rowsd(coefficient_1-coefficient_`standard_error_reps')
            keep rel_yr_rit standard_error
            save ../temp/standard_error, replace
        }
        use `using', clear
        if "`standard_error'"!="" {
            merge 1:1 rel_yr_rit using ../temp/standard_error, assert(3) keep(3) keepusing(*) nogen
            gen confidence_interval_upper_bound = coefficient + 1.96*standard_error
            gen confidence_interval_lower_bound = coefficient - 1.96*standard_error
            twoway (connected coefficient rel_yr_rit) ///
                (line confidence_interval_lower_bound rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_lower_bound rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_upper_bound rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_upper_bound rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs10)), ///
                xlabel(`xlabel') ytitle(`ytitle') legend(off) ///
                scheme(`scheme') xline(`xline') yline(`yline') xtitle(`xtitle') ylabel(`ylabel')
        }
        else {
            twoway (connected coefficient rel_yr_rit), ///
                xlabel(`xlabel') ytitle(`ytitle') legend(off) ///
                scheme(`scheme') xline(`xline') yline(`yline') xtitle(`xtitle') ylabel(`ylabel')
        }
        graph export `saving', replace    

    end
	
	program DoubleEventStudy
        syntax using, using2(str) xlabel(str) ytitle(str) scheme(str) xline(str) yline(str) ///
            xtitle(str) ylabel(str) label1(str) label2(str) saving(str) [standard_error(str) ///
            standard_error_reps(str) standard_error2(str) standard_error_reps2(str)]

        if "`standard_error'"!="" {
            use rel_yr_rit `using', clear
            forv i=1/`standard_error_reps' {
                merge 1:1 rel_yr_rit using "`standard_error'_`i'/estimates", ///
                    assert(3) keep(3) keepusing(*) nogen
                rename coefficient coefficient1_`i'
            }
            forv i=1/`standard_error_reps2' {
                merge 1:1 rel_yr_rit using "`standard_error2'_`i'/estimates", ///
                    assert(3) keep(3) keepusing(*) nogen
                rename coefficient coefficient2_`i'
            }
            egen standard_error1=rowsd(coefficient1_1-coefficient1_`standard_error_reps')
            egen standard_error2=rowsd(coefficient2_1-coefficient2_`standard_error_reps')
            keep rel_yr_rit standard_error1 standard_error2
            save ../temp/standard_error, replace
        }
        use `using', clear
		rename coefficient coefficient1
		merge 1:1 rel_yr_rit using "`using2'", assert(3) keep(3) nogen
		rename coefficient coefficient2
        if "`standard_error'"!="" {
            merge 1:1 rel_yr_rit using ../temp/standard_error, assert(3) keep(3) keepusing(*) nogen
            forval n=1/2 {
                gen confidence_interval_upper_bound`n' = coefficient`n' + 1.96*standard_error`n'
                gen confidence_interval_lower_bound`n' = coefficient`n' - 1.96*standard_error`n'
            }
            twoway (connected coefficient1 rel_yr_rit, msymbol(circle) mcolor(gs10) ///
                lstyle(solid) lcolor(gs10)) (connected coefficient2 rel_yr_rit, ///
                msymbol(circle) mcolor(gs5) lstyle(solid) lcolor(gs2)) ///
                (line confidence_interval_lower_bound1 rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_lower_bound1 rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_upper_bound1 rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_upper_bound1 rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs10)) ///
                (line confidence_interval_lower_bound2 rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs5)) ///
                (line confidence_interval_lower_bound2 rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs5)) ///
                (line confidence_interval_upper_bound2 rel_yr_rit if rel_yr_rit<-1, ///
                lpattern(dash) lcolor(gs5)) ///
                (line confidence_interval_upper_bound2 rel_yr_rit if rel_yr_rit>0, ///
                lpattern(dash) lcolor(gs5)), xlabel(`xlabel') ytitle(`ytitle') ///
                legend(order(1 2) label(1 "`label1'") label(2 "`label2'")) ///
                scheme(`scheme') xline(`xline') yline(`yline') xtitle(`xtitle') ylabel(`ylabel')
        }
        else {
            twoway (connected coefficient1 rel_yr_rit) (connected coefficient2 rel_yr_rit), ///
                xlabel(`xlabel') ytitle(`ytitle') legend(label(1 "`label1'") ///
                label(2 "`label2'")) scheme(`scheme') xline(`xline') yline(`yline') ///
                xtitle(`xtitle') ylabel(`ylabel')
        }
        graph export `saving', replace    

    end
	
program UtilizationOverTime
    use ../external/ranks/rank_year_mean_p20, clear
    twoway (connected LnRBU year if LnRBU_p20_rank==1) ///
        (connected LnRBU year if LnRBU_p20_rank==2) (connected LnRBU year if LnRBU_p20_rank==3) ///
        (connected LnRBU year if LnRBU_p20_rank==4) (connected LnRBU year if LnRBU_p20_rank==5), ///
        legend(off) scheme(s1mono) ytitle("Mean Log Utilization") ///
        yline(6.5(.5)8, lcolor(gray) lwidth(vthin)) 
    graph export ../output/figures/UtilizationOverTime.eps, replace
end

program ClaimLocationFigures
    use bene_id year bs* using ../external_links/compiled/CompiledPatYrDataMoversAlt, clear
    merge 1:1 bene_id year using ../external/loc_share/claim_share_data_mover, ///
        assert(1 2 3) keep(3) keepusing(*) nogen
    save ../temp/data_loaded, replace
    foreach sample in bs bs_o bs_o_nsb bs_l bs_h {
        use ../temp/data_loaded if `sample'==1, clear
        collapse (mean) *orig* *dest*, by(rel_yr_rit)
        keep if rel_yr_rit!=.
        gen ClaimCnt_decomp=ClaimCnt0_frac_dest/(ClaimCnt0_frac_orig+ClaimCnt0_frac_dest)
        summ rel_yr_rit
        twoway connected ClaimCnt_decomp rel_yr_rit, ///
            xlabel(`r(min)' (1) `r(max)') ytitle("Share of Claims in Destination HRR") ///
            ylabel(0 (0.25) 1) yline(0 (.25) 1, lwidth(vthin) lcolor(gray)) ///
            xtitle("Year Relative to Move") scheme(s1mono)
         graph export ///
            ../output/figures/ClaimLocationFigures/ClaimLocationFigure_`sample'.eps, replace
    }
end

program LogUtilizationAroundMove
    use ../external/HealthCorr/mean_utilization_over_relative_years, clear
    tw (connected LnRBU_mover rel_yr_rit) (connected LnRBU_nonmover rel_yr_rit), ///
        scheme(s1mono) legend(rows(2)) ytitle(Log Utilization) xlabel(-10(1)9) ///
        yline(6.5(.5)8, lcolor(gray) lwidth(vthin))
    graph export ../output/figures/LogUtilizationAroundMove.eps, replace
    gen mover_nonmover_difference = LnRBU_mover-LnRBU_nonmover
    tw (connected mover_nonmover_difference rel_yr_rit), ///
        scheme(s1mono) legend(rows(2)) xlabel(-10(1)9) ///
        ytitle(Movers-Non-Movers Difference in Average Log Utilization)  ///
        yline(-.2(.2).4, lcolor(gray) lwidth(vthin))    
	graph export ../output/figures/MoverNonMoverDifferenceAroundMove.eps, replace
end

program DistanceHistogram
    use ../external/sample/baseline_sample, clear
    bys bene_id: keep if _n==1
    drop year
    merge 1:1 bene_id using ../external_links/chars/CharsPatient, ///   
        assert(2 3) keep(3) keepusing(hrr_orig hrr_dest mover) nogen
    keep if mover==1
    foreach loc in orig dest {
        rename hrr_`loc' hrrnum
        merge m:1 hrrnum using ../external/Location/hrr_latlon, ///
            assert(1 3) keep(1 3) keepusing(*) nogen
        rename lat lat_`loc'
        rename lon lon_`loc'
        rename hrrnum hrr_`loc'
    }
    vincenty lat_orig lon_orig lat_dest lon_dest, v(distance)
    sum distance, d
    global Mean=round(`r(mean)',0.1)
    global SD=round(`r(sd)',0.1)
    global Q1=round(`r(p25)',0.1)
    global Median=round(`r(p50)',0.1)
    global Q3=round(`r(p75)',0.1)
    histogram distance, fraction ytitle("Share of Movers") /// 
        xtitle(Distance Moved (Miles)) ///
        legend(on order(- "Mean: ${Mean}" "SD: ${SD}" " " "Q1: ${Q1}" ///
        "Median: ${Median}" "Q3: ${Q3}") pos(2) ring(0) region(lp(solid))) scheme(s1mono)
    graph export ../output/figures/DistanceHistogram.eps, replace
end

* Execute
main
