version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    AdditiveDecomp, outcome(LnRBU) saving(AdditiveDecomp)
    VarianceDecomp_Split, outcome(LnRBU) saving(VarianceDecomp_Split)
    OtherOutcomes
    Robustness
    AdditiveDecomp, outcome(RBU) saving(AdditiveDecomp_RBU)
    AdditionalRobustness
    Subsamples
    OtherOutcomes_RD
    AlternativeMoverDefinitions
    Health
    Percentiles
    SaturatedModel
    CensusDivisionMatrix
    PatientDemographics
    PatientHealth
    AdditiveDecomp_Exp, saving(AD_Exp)
end

program AdditiveDecomp
    syntax, outcome(str) saving(str)

	local rank_list "p50 p25 p10 p5 texas M"
    additive_decomposition using "../external/Model/`outcome'/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_`outcome') unit(hrrnum) rank_list(`rank_list') ///
        variables(y_bar_j gammatilde_j ctildebar_j)
	foreach rank in `rank_list' {
		matrix `saving' = nullmat(`saving'), (r(y_bar_j_diff_`rank') \ ///
        r(gammatilde_j_diff_`rank') \ r(ctildebar_j_diff_`rank') \ ///
		r(ctildebar_j_diff_`rank')/r(y_bar_j_diff_`rank'))
        matrix `saving'_place_share = nullmat(`saving'_place_share), ///
            (1-r(ctildebar_j_diff_`rank')/r(y_bar_j_diff_`rank'))
	}
    forv i=1/50 {
        cap matrix drop `saving'_iteration
        additive_decomposition using "../external/Model (`outcome') SE/`i'/hrr_fe", ///
            rank_file(../external/ranks/hrr_rank_`outcome') unit(hrrnum) rank_list(`rank_list') ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        foreach rank in `rank_list' {
            matrix `saving'_iteration = nullmat(`saving'_iteration), ///
                r(ctildebar_j_diff_`rank')/r(y_bar_j_diff_`rank') 
        }
        matrix `saving'_iterations = nullmat(`saving'_iterations) \ ///
            `saving'_iteration
    }
    clear
    matrix colnames `saving'_iterations = `rank_list'
    svmat `saving'_iterations, names(col)
    foreach var of varlist `rank_list' {
        sum `var'
        matrix `saving'_se = nullmat(`saving'_se), `r(sd)'
    }
    matrix `saving' = `saving' \ `saving'_se \ `saving'_place_share
    
    matrix_to_txt, saving(../output/tables/`saving'.txt) ///
        mat(`saving') format(%20.4f) title(<tab:`saving'>) replace

end
	
program VarianceDecomp_Split
    syntax, outcome(str) saving(str)

    use ../external/Model/LnRBU/hrr_fe, clear
    sum `outcome'_bar_j
	local `outcome'_var = r(sd)^2
	
	use gammatilde_j ctildebar_j hrrnum using ../external/Model/Split0/hrr_fe, clear
	rename gammatilde_j gammatilde_j_0
	rename ctildebar_j ctildebar_j_0
	merge 1:1 hrrnum using ../external/Model/Split1/hrr_fe, assert(3) keep(3) nogen
	corr gammatilde_j gammatilde_j_0, cov
	local gammatilde_j_var_split=r(cov_12)
	corr ctildebar_j ctildebar_j_0, cov
	local ctildebar_j_var_split=r(cov_12)
	
	corr ctildebar_j gammatilde_j_0, cov
	local cov_1=r(cov_12)
	corr gammatilde_j ctildebar_j_0, cov
	local cov_2=r(cov_12)
	local corr_cg_split = ///
	    ((`cov_1'+`cov_2')/2)/(sqrt(`gammatilde_j_var_split')*sqrt(`ctildebar_j_var_split'))
	
    forv i=1/50 {
        use "../external/Model (LnRBU Split) SE/`i'_0/hrr_fe", clear
        rename gammatilde_j gammatilde_j_0
	    rename ctildebar_j ctildebar_j_0
	    merge 1:1 hrrnum using "../external/Model (LnRBU Split) SE/`i'_1/hrr_fe", ///
		    assert(3) keep(3) nogen
        corr gammatilde_j gammatilde_j_0, cov
	    local gammatilde_j_var=r(cov_12)
	    corr ctildebar_j ctildebar_j_0, cov
	    local ctildebar_j_var=r(cov_12)
	
	    corr ctildebar_j gammatilde_j_0, cov
	    local cov_1=r(cov_12)
	    corr gammatilde_j ctildebar_j_0, cov
	    local cov_2=r(cov_12)
        local corr_cg = ///
	        ((`cov_1'+`cov_2')/2)/(sqrt(`gammatilde_j_var')*sqrt(`ctildebar_j_var'))		
        matrix VarianceDecomp_iterations = nullmat(VarianceDecomp_iterations) \ ///
            (1-(`ctildebar_j_var'/``outcome'_var')), ///
			(1 -(`gammatilde_j_var'/``outcome'_var')), `corr_cg'
    }
       
    clear
    matrix colnames VarianceDecomp_iterations = hrr_eq patient_eq corr_cg
    svmat VarianceDecomp_iterations, names(col)    
    foreach var of varlist hrr_eq patient_eq corr_cg {
        sum `var'
        local `var'_se=`r(sd)'
    }
	matrix `saving'=``outcome'_var' \ `gammatilde_j_var_split' \ ///
        `ctildebar_j_var_split' \ `corr_cg_split' \ `corr_cg_se' \ ///
        (1-(`ctildebar_j_var_split'/``outcome'_var')) \ `hrr_eq_se' \ ///
        (1-(`gammatilde_j_var_split'/``outcome'_var')) \ `patient_eq_se'
    matrix_to_txt, saving(../output/tables/`saving'.txt) ///
        mat(`saving') format(%20.4f) title(<tab:`saving'>) replace

end

program OtherOutcomes
    foreach outcome in LnRBU anypcp Spec any_Ip anyErRBU Lndiag Lnimag Lnprv_num Lnnum_doc ///
        LnIp_RBU LnOp_RBU LnEr_RBU LnOt_RBU {
		additive_decomposition using "../external/Model/`outcome'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`outcome') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix `outcome' = r(mean_y),r(y_bar_j_diff_p50),r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)
        forv i=1/50 {
            if "`outcome'"=="LnRBU" {
                additive_decomposition using "../external/Model (LnRBU) SE/`i'/hrr_fe", ///
                    rank_file(../external/ranks/hrr_rank_`outcome') unit(hrrnum) rank_list(p50) ///
                    variables(y_bar_j gammatilde_j ctildebar_j)
            }
            else {
                additive_decomposition using "../external/Model/`outcome'_`i'/hrr_fe", ///
                    rank_file(../external/ranks/hrr_rank_`outcome') unit(hrrnum) rank_list(p50) ///
                    variables(y_bar_j gammatilde_j ctildebar_j)
            }
            matrix `outcome'_iterations = nullmat(`outcome'_iterations) \ ///
                r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)
        }
        clear
        matrix colnames `outcome'_iterations = p50
        svmat `outcome'_iterations, names(col)
        sum p50
        matrix `outcome' = `outcome', `r(sd)'
        matrix OtherOutcomes = nullmat(OtherOutcomes) \ `outcome'
    }
    matrix_to_txt, saving(../output/tables/OtherOutcomes.txt) ///
        mat(OtherOutcomes) format(%20.4f) title(<tab:OtherOutcomes>) replace
end

program Robustness
    additive_decomposition using "../external/Model/LnRBU/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
        variables(y_bar_j gammatilde_j ctildebar_j)
    matrix Robustness = ///
        r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    foreach row in rd5 rd3 rd1 first_third second_third third_third fdfe ageq /// 
        nondead nonhmo nonatr state hsa xs xcr {
        if "`row'"=="fdfe" | "`row'"=="ageq" {
            additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
                rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
        else if "`row'"=="state" | "`row'"=="hsa" {
            additive_decomposition using "../external/Model/`row'/`row'_fe", ///
                rank_file(../external/ranks/`row'_rank_LnRBU) unit(`row') rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
        else {
            additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
                rank_file(../external/ranks/hrr_rank_LnRBU_`row') unit(hrrnum) rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
    
        matrix Robustness = Robustness \ ///
            r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
		matrix list Robustness
    }
    matrix_to_txt, saving(../output/tables/Robustness.txt) ///
        mat(Robustness) format(%20.4f) title(<tab:Robustness>) replace
end

program AdditionalRobustness
    additive_decomposition using "../external/Model/LnRBU/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
        variables(y_bar_j gammatilde_j ctildebar_j)
    matrix AdditionalRobustness= ///
        r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    foreach row in mover {
		additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix AdditionalRobustness = AdditionalRobustness \ ///
            r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    foreach row in age_omit ry_omit {
		additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix AdditionalRobustness = AdditionalRobustness \ ///
            r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    foreach row in LnTotExpn LnRBU_x01 LnRBU_x10 {
		additive_decomposition using "../external/Model/`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix AdditionalRobustness = AdditionalRobustness \ ///
            r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    foreach row in nf nfac te_move tm_move tl_move {
		additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix AdditionalRobustness = AdditionalRobustness \ ///
            r(size),r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    matrix_to_txt, saving(../output/tables/AdditionalRobustness.txt) ///
        mat(AdditionalRobustness) format(%20.4f) title(<tab:AdditionalRobustness>) replace
end

program Subsamples
    additive_decomposition using "../external/Model/LnRBU/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
        variables(y_bar_j gammatilde_j ctildebar_j)
    matrix Subsamples= ///
        r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)),r(size)
    foreach row in age_q1_a age_q2_a age_q3_a age_q4_a {
		additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix Subsamples = Subsamples \ ///
            r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)),r(size)
    }
    matrix_to_txt, saving(../output/tables/Subsamples.txt) ///
        mat(Subsamples) format(%20.4f) title(<tab:Subsamples>) replace
end

program OtherOutcomes_RD
    foreach row in LnRBU anypcp Spec any_Ip anyErRBU Lndiag Lnimag Lnprv_num Lnnum_doc ///
        LnIp_RBU LnOp_RBU LnEr_RBU LnOt_RBU {
		additive_decomposition using "../external/Model/`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix std = nullmat(std) \ (r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
		additive_decomposition using "../external/Model/`row'_rd1/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`row'_rd1) unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix rd = nullmat(rd) \ (r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    matrix OtherOutcomes_RD = std, rd
    matrix_to_txt, saving(../output/tables/OtherOutcomes_RD.txt) ///
        mat(OtherOutcomes_RD) format(%20.4f) title(<tab:OtherOutcomes_RD>) replace
end

program AlternativeMoverDefinitions
    foreach row in bs bs_l bs_h bs_o bs_adj multi {
        if "`row'"=="bs_o_adj" {
            additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
                rank_file(../external/ranks/hrr_rank_LnRBU_bs_o) unit(hrrnum) rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
        else if "`row'"=="bs_adj" {
            additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
                rank_file(../external/ranks/hrr_rank_LnRBU_bs) unit(hrrnum) rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
		else if "`row'"=="multi" {
		    additive_decomposition using "../external/Model/MultipleMovers/hrr_fe", ///
			    rank_file(../external/ranks/hrr_rank_LnRBU_with_multiple_movers) unit(hrrnum) ///
				rank_list(p50) variables(y_bar_j gammatilde_j ctildebar_j)
		}
        else {
            additive_decomposition using "../external/Model/LnRBU_`row'/hrr_fe", ///
                rank_file(../external/ranks/hrr_rank_LnRBU_`row') unit(hrrnum) rank_list(p50) ///
                variables(y_bar_j gammatilde_j ctildebar_j)
        }
        matrix AlternativeMoverDefinitions = nullmat(AlternativeMoverDefinitions) \ ///
            r(mean_y),r(y_bar_j_diff_p50),(r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50),r(size))
    }
    matrix_to_txt, saving(../output/tables/AlternativeMoverDefinitions.txt) format(%20.4f) ///
        mat(AlternativeMoverDefinitions) title(<tab:AlternativeMoverDefinitions>) replace
end

program Health
    foreach row in Lnhcccom Lnchr Lniez Lnnumcon {
		additive_decomposition using "../external/Model/`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix Health = nullmat(Health) \ r(mean_y),r(y_bar_j_diff_p50),r(ctildebar_j_diff_p50), ///
            r(gammatilde_j_diff_p50), (r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)), ///
            (r(gammatilde_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    matrix_to_txt, saving(../output/tables/Health.txt) ///
        mat(Health) format(%20.4f) title(<tab:Health>) replace
end

program Percentiles
    foreach row in RBU RBU_perc RBU_d3c RBU_d6c RBU_d9c RBU_d10c RBU_v20c {
		additive_decomposition using "../external/Model/`row'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_`row') unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j gammatilde_j ctildebar_j)
        matrix Percentiles = nullmat(Percentiles) \ ///
            r(mean_y), r(y_bar_j_diff_p50), (r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50))
    }
    matrix_to_txt, saving(../output/tables/Percentiles.txt) ///
        mat(Percentiles) format(%20.4f) title(<tab:Percentiles>) replace
end

program SaturatedModel
    foreach row in LnRBU SaturatedModel LnRBU_mover SaturatedModelMoversOnly { 
        estimates use ../external/Model/`row'/estimates
        matrix SaturatedModel = nullmat(SaturatedModel) \ e(r2_a)
    }
    matrix_to_txt, saving(../output/tables/SaturatedModel.txt) ///
        mat(SaturatedModel) format(%20.4f) title(<tab:SaturatedModel>) replace
end

program CensusDivisionMatrix
    use ../external/sample/baseline_sample, clear
    bys bene_id: keep if _n==1
    drop year
    merge 1:1 bene_id using ../external_links/chars/CharsPatient, ///   
        assert(2 3) keep(3) keepusing(state_orig state_dest mover) nogen
    keep if mover==1
    bys state_orig: egen state_orig_movers=total(mover)
    bys state_dest: egen state_dest_movers=total(mover)
    bys state_orig state_dest: gen N_state_orig_dest=_N
    bys state_orig state_dest: keep if _n==1
    drop bene_id mover
    foreach loc in orig dest {
        rename state_`loc' state_ssa
        merge m:1 state_ssa using ../external/geo/state_regions_crosswalk, ///
            assert(1 3) keep(3) keepusing(census_division state) nogen
        drop state_ssa
        rename state state_`loc'
        rename census_division census_division_`loc'
    }
    bys state_orig: replace state_orig_movers=. if _n!=1
    bys state_dest: replace state_dest_movers=. if _n!=1
    bys census_division_orig: egen cd_orig_movers=total(state_orig_movers)
    bys census_division_dest: egen cd_dest_movers=total(state_dest_movers)
    bys census_division_orig census_division_dest: egen N_cd_orig_dest=total(N_state_orig_dest)
    bys census_division_orig census_division_dest: keep if _n==1
    drop *state*
    foreach loc in orig dest {
        replace census_division_`loc'=subinstr(census_division_`loc'," ", "", 5)
        replace census_division_`loc'="MidAtlantic" if census_division_`loc'=="Mid-Atlantic"
        levelsof census_division_`loc', local(cd_list_`loc')
    }
	egen T=total(N_cd_orig_dest)
	sum T, meanonly
	global number_of_movers=`r(mean)'
	foreach cd_orig in `cd_list_orig' {
		foreach cd_dest in `cd_list_dest' {
			sum N_cd_orig_dest if census_division_orig=="`cd_orig'" ///
				& census_division_dest=="`cd_dest'"
			global pct=(`r(mean)'/${number_of_movers})*100
			matrix row_`cd_orig'_m=nullmat(row_`cd_orig'_m),${pct}
		}
		sum cd_orig_movers if census_division_orig=="`cd_orig'"
		global pct=(`r(mean)'/${number_of_movers})*100
		matrix CensusDivisionMatrix=nullmat(CensusDivisionMatrix) \ (row_`cd_orig'_m, ${pct})
	}
	foreach cd_dest in `cd_list_dest' {
		sum cd_dest_movers if census_division_dest=="`cd_dest'"
		global pct=(`r(mean)'/${number_of_movers})*100
		matrix row_dest_totals=nullmat(row_dest_totals),${pct}
	}
	matrix CensusDivisionMatrix=nullmat(CensusDivisionMatrix) \ (row_dest_totals, 100)
	
	matrix list CensusDivisionMatrix
	matrix_to_txt, saving(../output/tables/CensusDivisionMatrix.txt) ///
		mat(CensusDivisionMatrix) format(%20.4f) title(<tab:CensusDivisionMatrix>) replace
end

program PatientDemographics
    additive_decomposition using "../external/Model/LnRBU/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
        variables(y_bar_j ctildebar_j)
    local patient_share=r(ctildebar_j_diff_p50)/r(y_bar_j_diff_p50)
    foreach group in age race sex arsm{
		additive_decomposition using "../external/Pat Observables/`group'/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j ghat)
        matrix PatientDemographics = nullmat(PatientDemographics) \ ///
            (r(ghat_diff_p50)/r(y_bar_j_diff_p50)), ///
            (r(ghat_diff_p50)/r(y_bar_j_diff_p50))/`patient_share'
    }
	matrix_to_txt, saving(../output/tables/PatientDemographics.txt) ///
		mat(PatientDemographics) format(%20.4f) title(<tab:PatientDemographics>) replace
end

program PatientHealth
    additive_decomposition using "../external/Model/LnRBU/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
        variables(y_bar_j ctildebar_j)
    foreach var in Lnhcccom Lnchr Lniez Lnnumcon {
		additive_decomposition using "../external/Pat Observables/`var'_patobs/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j ghat)
        matrix PatientHealth_raw = nullmat(PatientHealth_raw) \ ///
            (r(ghat_diff_p50)/r(y_bar_j_diff_p50))
		additive_decomposition using "../external/Pat Observables/chat_`var'_patobs/hrr_fe", ///
			rank_file(../external/ranks/hrr_rank_LnRBU) unit(hrrnum) rank_list(p50) ///
            variables(y_bar_j ghat)
        matrix PatientHealth_patient_component = nullmat(PatientHealth_patient_component) \ ///
            (r(ghat_diff_p50)/r(y_bar_j_diff_p50))
    }
    matrix PatientHealth = PatientHealth_raw \ PatientHealth_patient_component
	matrix_to_txt, saving(../output/tables/PatientHealth.txt) ///
		mat(PatientHealth) format(%20.4f) title(<tab:PatientHealth>) replace
end

program AdditiveDecomp_Exp
	syntax, saving(str)

	local rank_list "p50 p25 p10 p5 texas M"
    additive_decomposition using "../external/Model/ExponentiatedModel/hrr_fe", ///
        rank_file(../external/ranks/hrr_rank_RBU) unit(hrrnum) rank_list(`rank_list') ///
        variables(yhat yhat_pateq yhat_pleq) 
	foreach rank in `rank_list' {
		matrix `saving' = nullmat(`saving'), (r(yhat_diff_`rank') \ ///
        r(yhat_pateq_diff_`rank') \ r(yhat_pleq_diff_`rank') \ ///
		(1-r(yhat_pateq_diff_`rank')/r(yhat_diff_`rank')))
        matrix `saving'_place_share = nullmat(`saving'_place_share), ///
            (1-r(yhat_pleq_diff_`rank')/r(yhat_diff_`rank'))
	}
    forv i=1/50 {
        cap matrix drop `saving'_pat_iteration
        cap matrix drop `saving'_pl_iteration
        additive_decomposition using ///
			"../external/Model (Exponentiated) SE/`i'/hrr_fe", ///
            rank_file(../external/ranks/hrr_rank_RBU) unit(hrrnum) rank_list(`rank_list') ///
            variables(yhat yhat_pateq yhat_pleq)
        foreach rank in `rank_list' {
            matrix `saving'_pat_iteration = nullmat(`saving'_pat_iteration), ///
                (1-r(yhat_pateq_diff_`rank')/r(yhat_diff_`rank'))
			matrix `saving'_pl_iteration = nullmat(`saving'_pl_iteration), ///
                (1-r(yhat_pleq_diff_`rank')/r(yhat_diff_`rank')) 
        }
        matrix `saving'_pat_iterations = nullmat(`saving'_pat_iterations) \ `saving'_pat_iteration
	    matrix `saving'_pl_iterations = nullmat(`saving'_pl_iterations) \ `saving'_pl_iteration
    }
	foreach effect in pl pat {
		clear
		matrix colnames `saving'_`effect'_iterations = `rank_list'
		svmat `saving'_`effect'_iterations, names(col)
		foreach var of varlist `rank_list' {
			sum `var'
			matrix `saving'_`effect'_se = nullmat(`saving'_`effect'_se), `r(sd)'
		}
	}
	matrix `saving' = `saving' \ `saving'_pat_se \ `saving'_place_share \ `saving'_pl_se
    
	matrix_to_txt, saving(../output/tables/`saving'.txt) ///
		mat(`saving') format(%20.4f) title(<tab:`saving'>) replace

end

* Execute
main
