version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    rank_correlation_across_periods
    claim_share_outside_residence
    nonmatching_zipcodes
end

program rank_correlation_across_periods
    use hrrnum period2 LnRBU_total using ../external/ranks/LnRBU_hrr_mean_periods, clear
    reshape wide LnRBU_total, i(hrrnum) j(period2)
    foreach period in 0 1 {
        sort LnRBU_total`period'
        gen rank`period'=_n
    }
    insert_tag HRR_period2_rank_corr, open
        di "Rank correlation of HRR avg utilization between the first and second half of the sample"
        spearman rank*
    insert_tag HRR_period2_rank_corr, close
end

program claim_share_outside_residence
    use bene_id year hrrnum baseline_samp mover using ///
        ../external_links/compiled/CompiledPatYrDataNonMovers.dta, clear
    append using ../external_links/compiled/CompiledPatYrDataMovers.dta, ///
        keep(bene_id year hrr_orig hrr_dest baseline_samp mover)
    keep if baseline_samp==1
    merge 1:m bene_id year using ../external_links/treat/TreatHrrPatientDocYear.dta, ///
        assert(1 2 3) keep(1 3) keepusing(phys_hrr ClaimCnt)
    replace ClaimCnt = 0 if _merge==1
    gen ClaimCnt_home = ClaimCnt if (mover==0 & hrrnum==phys_hrr) ///
        | (mover==1 & (hrr_orig==phys_hrr | hrr_dest==phys_hrr))
    replace ClaimCnt_home = 1 if _merge==1
    gen fwgt = 1
    replace fwgt = 4 if mover==0
    collapse (sum) ClaimCnt* [fw=fwgt]
    gen ClaimCnt_away_pct = 1 - ClaimCnt_home/ClaimCnt
    summ ClaimCnt_away_pct , meanonly
    local report = round(100*r(mean),.01)
    insert_tag claim_share_outside_residence, open
        di "Average % of claims outside of nonmovers' home HRR or "
        di "movers' origin or destination HRRs: `report'"
    insert_tag claim_share_outside_residence, close
end

program nonmatching_zipcodes
    use _merge using ../external_links/denom/denom_all_zipcodes, clear
    gen nonmatching_zipcodes = (_merge==1)
    insert_tag nonmatching_zipcodes, open
        tab nonmatching_zipcodes
    insert_tag nonmatching_zipcodes, close
end



* Execute
main

