version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global master_vars="researchid npi upin doflag birthdate birthcity birthstate birthcountry sex deadflag licprefstate licprefyear licgrpstate licgrpyear lichospstate lichospyear licaltoffstate licaltoffyear primarytop presentemployment primaryspecialty secondaryspecialty tops hospitalid hospitalhours praflag praexpiration groupid1 groupid2 medtrainflag medtrainfrom medtrainto medtrainyearin medtrainpostgrad medtrainspec1 medtrainspec2 medtraininginstitution medschoolid medschoolyog contactflag numberofoffices officestate officezipcode ustrained residencytraining medicalschoolstate omitflag yob yot"

program main
    create_ama_master
    create_AMA_Boards
    create_AMA_Specialties
    create_AMA_Country_Codes
    create_AMA_County_Codes
    create_AMA_Address_Type
    create_AMA_Foreign_School_Codes
    create_AMA_Hospital_Affiliation
    create_AMA_MSA
    create_AMA_MTI
    create_AMA_PMSA
    create_AMA_Schools
    create_AMA_Residency
    create_dea_crosswalk
    create_AMA_MPA
    create_AMA_Present_Employment
    create_AMA_Boards_2
    create_AMA_Present_Employment_2
    create_AMA_State_Codes
    create_AMA_MPA_2
    create_AMA_Primary_TOPS
    create_AMA_TOPS
    merge_ama_w_dea_crosswalk
end

program create_ama_master    
	use ../external/AMA/AMArawMaster_2014, clear
	rename zipcode zipcode2011
	rename v68 addtype2011
	rename v69 zipcode2012
	rename v70 addtype2012
	rename v71 zipcode2013
	rename v72 addtype2013
	rename v73 zipcode2014
	rename v74 addtype2014
	destring censusblockgroup, replace
	tostring licgrpstate, replace
	replace licgrpstate="" if licgrpstate=="."
	keep ${master_vars} zipcode* addtype*
	save ../temp/ama_temp2014, replace
	
	use ../external/AMA/AMArawMaster, clear
	foreach zipcode of varlist zipcode* {
	    cap tostring `zipcode', replace format(%05.0f)
	}
	keep zipcode* addtype* researchid
	save ../temp/ama_zip_pre2011, replace
	
	*start with the latest (2014) data, add older zipcodes from old ama data
	use ../temp/ama_temp2014, clear
	merge 1:1 researchid using ../temp/ama_zip_pre2011, assert(1 3) keep(1 3) nogen
   
    ** The following will try to compress the data to save space
    ds,has(type string)
    foreach var in `r(varlist)'{
       replace `var'=trim(`var')
    }
    compress

	*US Trained flag is incorrect
	recode ustrained (1=0) (0=1)

    ** Generate the training date
    split medtrainto,parse(" ")
    split medtrainto1,parse("/")
    drop medtrainto medtrainto2
	rename medtrainto1 medtrainto_orig

    destring medtrainto11,replace
    destring medtrainto12,replace
    destring medtrainto13,replace
    gen medtrainto=mdy(medtrainto11,medtrainto12,medtrainto13)
    format medtrainto %tdDmY
    drop medtrainto11 medtrainto12  medtrainto13
	
	label variable medtrainto "Medical training MDY format"
    label variable medtrainto_orig "Medical training Original"

    save_data ../output/ama.dta, replace key(researchid)
end

program create_AMA_Boards
 
    insheet using "../external/AMA/AMA_Boards.txt", clear
    replace boardname = boardname + ", " + v3 if v3!=""
    drop v3
    save_data "../output/AMA_Boards", replace key(boardid)

end

program create_AMA_Specialties
    *4 specialties in the 2014 AMA data are not in the AMA dictionary or classified by Dartmouth
	*3 identified through external files, 1 unidentified (CHD)
    clear
	set obs 3
	gen Specialty_Name="Critical Care Medicine (Emergency Medicine)" in 1 
	gen Specialty_Code="CCE" in 1
	replace Specialty_Name="Hospice & Palliative Medicine (Surgery)" in 2
	replace Specialty_Code="HPS" in 2
	replace Specialty_Name="Female Pelvic Medicine & Reconstructive Surgery (Urology)" in 3
	replace Specialty_Code="UPR" in 3

	save ../temp/specialty_add, replace
	
    insheet using "../external/AMA/AMA_Specialties.txt", clear
    drop in 1
    gen Specialty_Code=trim(v1)
	drop v1
    rename v2 Specialty_Name
    label variable Specialty_Code "Specialty Code"
    label variable Specialty_Name "Specialty Name"
    duplicates drop
	
	append using ../temp/specialty_add
	
	*classify specialties based on Dartmouth atlas
	gen ama_specialty = "Family Practice" if inlist(Specialty_Code,"AMF","FM","FP","FSM","GP")
    replace ama_specialty = "Internal Medicine" if inlist(Specialty_Code,"HPI","IFP","IM")
	replace ama_specialty = "Pediatrics" if inlist(Specialty_Code,"PD")
	replace ama_specialty = "Allergy/Immunology" if inlist(Specialty_Code,"A","AI","ALI","IG","PDA")
	replace ama_specialty = "Cardiology" if inlist(Specialty_Code,"CD","IC","ICE","NC")
	replace ama_specialty = "Critical Care" if ///
	    inlist(Specialty_Code,"CCA","CCM","CCS","IEC","NCC","OCC","PCC")
	replace ama_specialty = "Dermatology" if ///
	    inlist(Specialty_Code,"D","DDL","DS","IMD","PDD","PDM","PRD")
	replace ama_specialty = "Emergency Medicine" if ///
	    inlist(Specialty_Code,"EFM","EM","ESM","ETX","HPE","MEM","UCM","UME","CCE")
	replace ama_specialty = "Endocrinology" if inlist(Specialty_Code,"DIA","END")
	replace ama_specialty = "Gastroenterology" if inlist(Specialty_Code,"GE","HEP")
	replace ama_specialty = "Geriatrics" if inlist(Specialty_Code,"FPG","GER","IMG")
	replace ama_specialty = "Hematology/Oncology" if ///
	    inlist(Specialty_Code,"HEM","HO","ND","OMO","ON")
	replace ama_specialty = "Infectious Disease" if inlist(Specialty_Code,"ID")
	replace ama_specialty = "Nephrology" if inlist(Specialty_Code,"NEP")
	replace ama_specialty = "Neurology" if ///
	    inlist(Specialty_Code,"CHN","CN","MN","N","NDN","NMN","PMN","VN")
	replace ama_specialty = "Physical Medicine/Rehab" if ///
	    inlist(Specialty_Code,"MPM","NPR","PM","PMM","PMP","PRS","SCI")
	replace ama_specialty = "Pulmonology" if inlist(Specialty_Code,"PUD")
	replace ama_specialty = "Radiation Oncology" if inlist(Specialty_Code,"RO")
	replace ama_specialty = "Rheumatology" if inlist(Specialty_Code,"RHU")
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code,"ADM","AM", ///
	    "AMI","BE","CBG","CCG","CG","CMG","EP")
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code, ///
	    "GPM","HOS","HPM","HYP","IPM","ISM","LM","MDG","MDM")
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code, ///
	    "MG","MPH","NTR" "OM","OMM","OS","PA","PH","PHM")
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code,"PHP","PLM", ///
	    "PMD","PTX","PYM", "SM","SME","SMI","UM")
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code,"VM", "HPS")
	replace ama_specialty = "Anesthesiology" if inlist(Specialty_Code,"ACA","AN","APM","PAN","PME")
	replace ama_specialty = "Pathology" if inlist(Specialty_Code,"ATP","BBK","BLB","CLP","CMP", ///
	    "DLI","DMP","FOP","HMP")
	replace ama_specialty = "Pathology" if inlist(Specialty_Code,"ILI","IP","MGP","MM","NA", ///
	    "NP","PCH","PCP","PIP")
	replace ama_specialty = "Pathology" if inlist(Specialty_Code, "PLI","PP", ///
		"PTH","RIP","SP")
	replace ama_specialty = "Radiology" if inlist(Specialty_Code,"AR","CTR","DR","ESN","MSR", ///
	    "NM","NR","NRN","PDR")
	replace ama_specialty = "Radiology" if inlist(Specialty_Code,"R","RNR","RP","TR","VIR")
	replace ama_specialty = "Cardiovascular/Thoracic Surgery" if inlist(Specialty_Code,"CDS", ///
	    "CHS","CTS","PCS","TS")
	replace ama_specialty = "General Surgery" if inlist(Specialty_Code,"AS","ABS","CRS","GS","SO")
	replace ama_specialty = "Neurological Surgery" if inlist(Specialty_Code,"ES","NS","NSP")
	replace ama_specialty = "Obstetrics/Gynecology" if inlist(Specialty_Code,"GO","GYN","HPO", ///
	    "MFM","OBG","OBS","REN")
	replace ama_specialty = "Ophthalmology" if inlist(Specialty_Code,"OPH","PO")
	replace ama_specialty = "Orthopedic Surgery" if inlist(Specialty_Code,"HSO","OAR","OFA", ///
	    "OP","ORS","OSM","OSS","OTR")
	replace ama_specialty = "Otolaryngology" if inlist(Specialty_Code,"LAR","NO","OMF","OT", ///
	    "OTO","PDO","RHI")
	replace ama_specialty = "Plastic&Reconstructive Surgery" if inlist(Specialty_Code,"CS", ///
	    "FPS","PS","PSH")
	replace ama_specialty = "Urology" if inlist(Specialty_Code,"U","UP","UPR")
	replace ama_specialty = "Vascular Surgery" if inlist(Specialty_Code,"VS")
	replace ama_specialty = "Other Surgery" if inlist(Specialty_Code,"CFS","HNS","HS","HSP", ///
	    "HSS","MFS","PHL")
	replace ama_specialty = "Other Surgery" if inlist(Specialty_Code,"PRO","THP","TRS","TTS")
	replace ama_specialty = "Neonatology" if inlist(Specialty_Code,"NPM")
	replace ama_specialty = "Psychiatry" if inlist(Specialty_Code,"ADP","CHP","CPP","FPP","HPN", ///
	    "MP","NUP","P","PFP")
	replace ama_specialty = "Psychiatry" if inlist(Specialty_Code,"PPN","PYA","PYG","PYN","SMN")
	replace ama_specialty = "Pediatric Surgery" if inlist(Specialty_Code,"PDS","PMG","PPM")
	replace ama_specialty = "Other Pediatric Specialties" if inlist(Specialty_Code,"ADL","CCP", ///
	    "DBP","EMP","MPD","NDP","PDC","PDE","PDI")
	replace ama_specialty = "Other Pediatric Specialties" if inlist(Specialty_Code, ///
	    "PDP","PDT","PE","PEM","PG","PHO","PN","PNP","PPR")
	replace ama_specialty = "Other Pediatric Specialties" if inlist(Specialty_Code, ///
	    "PRM","PSM","RPM","SMP")
	replace ama_specialty = "Unspecified" if inlist(Specialty_Code, "US","FLX","TY")	
	
	*classify the 29 specialties not specified by Dartmouth
	replace ama_specialty = "Cardiology" if Specialty_Code == "AHF"
	replace ama_specialty = "Hematology/Oncology" if Specialty_Code == "ASO"
	replace ama_specialty = "Other Pediatric Specialties" if Specialty_Code == "CAP"
	replace ama_specialty = "Family Practice" if inlist(Specialty_Code,"FMP","HPF")
	replace ama_specialty = "Obstetrics/Gynecology" if Specialty_Code == "FPR"
	replace ama_specialty = "Anesthesiology" if inlist(Specialty_Code,"HPA","OAN")
	replace ama_specialty = "Radiology" if Specialty_Code == "HPD"
	replace ama_specialty = "Pediatrics" if Specialty_Code == "HPP"
	replace ama_specialty = "Physical Medicine/Rehab" if inlist(Specialty_Code,"HPR","NMP")
	replace ama_specialty = "Internal Medicine" if inlist(Specialty_Code,"INM","THI")
	replace ama_specialty = "Pathology" if Specialty_Code == "MGG"
	replace ama_specialty = "Plastic&Reconstructive Surgery" if ///
	    inlist(Specialty_Code,"OPR","PSI","PSO","PSP")
	replace ama_specialty = "Neurology" if inlist(Specialty_Code,"NNM","EPL","ENR")
	replace ama_specialty = "Pediatric Surgery" if inlist(Specialty_Code,"PTP")
	replace ama_specialty = "Cardiovascular/Thoracic Surgery" if Specialty_Code == "TSI"
	replace ama_specialty = "Otolaryngology" if Specialty_Code == "SMO"
	replace ama_specialty = "Other Medical Specialties" if inlist(Specialty_Code,"MBG","OM")
    replace ama_specialty = "Vascular Surgery" if inlist(Specialty_Code,"VSI")
    replace ama_specialty = "Critical Care" if inlist(Specialty_Code,"EMS")
	
    gen dartmouth_specialty = "Primary Physicians" if ///
	    inlist(ama_specialty,"Family Practice","Internal Medicine","Pediatrics")
	replace dartmouth_specialty = "Medical Specialists" if inlist(ama_specialty, ///
	    "Allergy/Immunology","Cardiology","Critical Care","Dermatology","Emergency Medicine", ///
		"Endocrinology", "Gastroenterology", "Geriatrics","Hematology/Oncology")
	replace dartmouth_specialty = "Medical Specialists" if inlist(ama_specialty, ///
	    "Infectious Disease","Nephrology","Neurology","Physical Medicine/Rehab","Pulmonology", ///
		"Radiation Oncology", "Rheumatology", "Other Medical Specialties")
	replace dartmouth_specialty = "Hospital-Based Physicians" if inlist(ama_specialty, ///
	    "Anesthesiology","Pathology","Radiology")
	replace dartmouth_specialty = "Surgeons" if inlist(ama_specialty, ///
	    "Cardiovascular/Thoracic Surgery", "General Surgery", "Neurological Surgery", ///
		"Obstetrics/Gynecology", "Ophthalmology","Orthopedic Surgery")
	replace dartmouth_specialty = "Surgeons" if inlist(ama_specialty,"Otolaryngology", ///
		"Plastic&Reconstructive Surgery","Urology","Vascular Surgery","Other Surgery")
	replace dartmouth_specialty = "Other" if inlist(ama_specialty, "Neonatology","Psychiatry", ///
	    "Pediatric Surgery","Other Pediatric Specialties")
    replace dartmouth_specialty = "Unspecified" if ama_specialty=="Unspecified"
	
	save_data "../output/AMA_Specialties", replace key(Specialty_Code)

end

program create_AMA_Country_Codes

    insheet using "../external/AMA/dbo_Country_Codes.txt", clear
    drop in 1
    rename v1 Country_Code
    rename v2 Country
    label variable Country_Code "Country Code"
    label variable Country "Country"
    duplicates drop
    drop if Country_Code=="BU1"&Country!="BULGARIA"
    drop if Country_Code=="LV2"&Country!="LATVIA"
    drop if Country_Code=="RU1"&Country!="RUSSIA"
    save_data "../output/AMA_Country_Codes", replace key(Country_Code)

end

program create_AMA_County_Codes

    insheet using "../external/AMA/dbo_County_Codes.txt", clear
    save_data "../output/AMA_County_Codes", replace key(countyid)

end

program create_AMA_Address_Type

    insheet using "../external/AMA/Dbo_LU_AMA_AddressType.txt", clear
    rename code addresstype
    label variable addresstype AddressType
    save_data "../output/AMA_Address_Type", replace key(addresstype)

end

program create_AMA_Foreign_School_Codes

    insheet using "../external/AMA/dbo_LU_AMA_Foreign_School_Codes.txt", clear
    save_data "../output/AMA_Foreign_School_Codes", replace key(countrycode)

end


program create_AMA_Hospital_Affiliation

    insheet using "../external/AMA/dbo_LU_AMA_HOSP_AFFIL.txt", clear
    tostring hospaffil, replace
    replace hospaffil="0"+hospaffil if length(hospaffil)<6
    rename hospaffil hospitalid
    save_data "../output/AMA_Hospital_Affiliation", replace key(hospitalid)

end

program create_AMA_MSA

    insheet using "../external/AMA/dbo_LU_AMA_MSA.txt", clear
    drop in 1
    rename v1 Code
    rename v2 Description
    label variable Code "Code"
    label variable Description "Description"
    rename Code msa
    save_data "../output/AMA_MSA", replace key(msa)

end

program create_AMA_MTI

    insheet using "../external/AMA/dbo_LU_AMA_MTI.txt", clear
    rename res_num medtraininginstitutioncode
    tostring medtraininginstitutioncode, replace
    replace medtraininginstitutioncode="0"+medtraininginstitutioncode ///
        if length(medtraininginstitutioncode)<6
    save_data "../output/AMA_MTI", replace key(medtraininginstitutioncode)

end

program create_AMA_PMSA

    insheet using "../external/AMA/dbo_LU_AMA_PMSA.txt", clear
    rename code pmsa_msa
    tostring pmsa_msa, replace
    replace pmsa_msa="0"+pmsa_msa if length(pmsa_msa)<4
    replace pmsa_msa="0"+pmsa_msa if length(pmsa_msa)<4
    save_data "../output/AMA_PMSA", replace key(pmsa_msa state)

end

program create_AMA_Schools

    insheet using "../external/AMA/Dbo_LU_AMA_Schools.txt", clear
    rename code medschoolid
    tostring medschoolid, replace
    replace medschoolid="0"+medschoolid if length(medschoolid)<5
    replace medschoolid="0"+medschoolid if length(medschoolid)<5
    save_data "../output/AMA_Schools", replace key(medschoolid)

end

program create_AMA_Residency

    insheet using "../external/AMA/Dbo_res_train.txt", clear
    rename res_num medtraininginstitutioncode
    tostring medtraininginstitutioncode, replace
    replace medtraininginstitutioncode="0"+medtraininginstitutioncode ///
        if length(medtraininginstitutioncode)<6
    save_data "../output/AMA_Residency", replace key(medtraininginstitutioncode)

end

program create_dea_crosswalk

    insheet using "../external/AMA/DEA_Crosswalk.txt", clear
    save_data "../output/DEA_Crosswalk.dta", replace key(researchid deanumber)

end

program create_AMA_MPA

    insheet using "../external/AMA/Major Professional Activity.txt", clear
    drop in 1
    gen Code=substr(v1,1,3)
    order Code
    rename v1 Activity
    replace Activity=subinstr(Activity,Code,"",1)
    label variable Code "Code"
    label variable Activity "Activity"
    save_data "../output/AMA_MPA", replace key(Code)

end

program create_AMA_Present_Employment

    insheet using "../external/AMA/PRESEMP.txt", clear
    rename pe_code presentemployment
    save_data "../output/AMA_Present_Employment", replace key(presentemployment)

end

program create_AMA_Boards_2

    import excel "../external/AMA/AMA_Boards_PRE_2004.xls", ///
	    sheet("dbo_LU_AMA_Boards") firstrow clear
    save_data "../output/AMA_Boards_2", replace key(Code)
    
end

program create_AMA_Present_Employment_2

    import excel "../external/AMA/AMA_PE_CODES.xls", sheet("PE") firstrow clear
    drop if Description==""
    rename Code presentemployment
    save_data "../output/AMA_Present_Employment_2", replace key(presentemployment)

end

program create_AMA_State_Codes

    import excel "../external/AMA/AMA ST CODES.xls", sheet("AMA_ST_CODES") firstrow clear
    save_data "../output/AMA_State_Codes", replace key(Code)

end

program create_AMA_MPA_2

    import excel "../external/AMA/MPA.xls", sheet("MPA") firstrow clear
    save_data "../output/AMA_MPA_2", replace key(MPA)

end

program create_AMA_Primary_TOPS

    import excel "../external/AMA/Primary TOPS.xls", sheet("Sheet1") firstrow clear
    destring Code, replace
    rename Code primarytop
    save_data "../output/AMA_Primary_TOPS", replace key(primarytop)

end

program create_AMA_TOPS

    import excel "../external/AMA/TOPS.xls", sheet("MPA") firstrow clear
    rename TOPS tops
    save_data "../output/AMA_TOPS", replace key(tops)

end

program merge_ama_w_dea_crosswalk

    use "../output/ama", clear
    merge 1:m researchid using "../output/DEA_Crosswalk.dta", ///
        assert(master using match) keep(master using match) keepusing(*) nogen
    tostring npi, replace
    replace npi="" if npi=="."
    save "../temp/AMA_w_DEA_Crosswalk", replace
    foreach id in npi upin deanumber {
        use researchid `id' using "../temp/AMA_w_DEA_Crosswalk", clear
        duplicates drop
        drop if `id'==""
        bys `id': keep if _n==1
        cap destring npi, replace force
        save_data "../output/`id'_crosswalk", replace key(`id')
    }  
 
end

** EXECUTE
main
