version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obs_no = "L"

program main
    global outcomes= "ClaimCnt"
	load_data, outcomes(${outcomes})
    generate_expense_fractions using ../temp/templ_mover, ///
        outcomes(${outcomes}) saving(../output/claim_share_data_mover)
end

program load_data
    syntax, outcomes(str)

        use bene_id year phys_hrr phys_id ${outcomes} ///
            using ../external_links/treat/TreatHrrPatientDocYear.dta, clear
        merge m:1 bene_id year using ../external_links/patient/CharsPatientYear, ///
			assert(1 2 3) keep(1 2 3) keepusing(rel_yr_rit)
        merge m:1 bene_id using ../external_links/patient/CharsPatient, ///
			assert(1 3) keep(1 3) keepusing(hrr_orig hrr_dest mover) nogen
        keep if mover==1
        foreach outcome in `outcomes' {
            replace `outcome' = 0 if _merge==2
        }
        drop _merge
        drop if phys_hrr==.
        gen hrr_type = .
        replace hrr_type = 1 if phys_hrr==hrr_orig
        replace hrr_type = 2 if phys_hrr==hrr_dest
        replace hrr_type = 3 if phys_hrr!=hrr_orig & phys_hrr!=hrr_dest
        assert hrr_type==1 | hrr_type==2 | hrr_type==3

        collapse (sum) `outcomes' (min) rel_yr_rit, by(bene_id year hrr_type)

        save ../temp/templ_mover, replace

end

program generate_expense_fractions
    syntax using [if], outcomes(str) saving(str)

    use `using', clear

    foreach outcome in `outcomes' {
        bys bene_id year: egen `outcome'_total_test = total(`outcome')
        replace `outcome' = ClaimCnt if `outcome'_total_test==0 | `outcome'_total_test==.
        bys bene_id year: egen `outcome'_total = total(`outcome')
        gen `outcome'_frac = `outcome'/`outcome'_total
        assert `outcome'==0 if `outcome'_total==0
        bys bene_id year: egen `outcome'_check = total(`outcome'_frac), missing
        assert abs(`outcome'_check - 1) < .001 | `outcome'_check==.
    }

    keep *_frac bene_id hrr_type year rel_yr_rit
    tostring hrr_type, replace
    collapse *_frac, by(bene_id hrr_type year rel_yr_rit)
    drop if (bene_id=="" | year==.)
    reshape wide *_frac, i(bene_id year rel_yr_rit) j(hrr_type) string
    foreach outcome in `outcomes' {
        rename `outcome'_frac1 `outcome'0_frac_orig
        rename `outcome'_frac2 `outcome'0_frac_dest
        rename `outcome'_frac3 `outcome'0_frac_other
        foreach type in orig dest other {
            replace `outcome'0_frac_`type' = 0 if `outcome'0_frac_`type'==.
        }
    }
	
    save_data `saving', replace key(bene_id year)

end

* EXECUTE
main
