version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)


program main
    load_data, ///
        outcome(LnRBU) ///
        variables(LnRBU bene_id year hrr* mover baseline_samp) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        delta_dataset(../external/fe/delta_LnRBU) ///
        delta_variable_in(delta_hrrnum_LnRBU_i) ///
        delta_variable_out(delta_i) ///
        matched_sample(../external/matched/MatchedPatientSample) ///
        loc(orig)
	
	foreach sample in base LnRBU_orig_above LnRBU_orig_below LnRBU_orig_q1 LnRBU_orig_q2 ///
		LnRBU_orig_q3 LnRBU_orig_q4 {
		use ../temp/delta_diff_data.dta if `sample'==1, clear
		create_delta_groups, nquantiles(20) delta_variable(delta_i) ///
			delta_group_variable(delta_group)
		gen count=1
		collapse (mean) delta_i LnRBU LnRBU_relative_to_nonmovers (sum) count, ///
			by(delta_group rel_yr_rit)
		save_data ../output/delta_bins_LnRBU_`sample', replace key(delta_group rel_yr_rit)
	}
end

program load_data
    syntax, outcome(str) variables(str) mover_dataset(str) nonmover_dataset(str) ///
    [keep_condition(str)] [drop_condition(str)] delta_dataset(str) delta_variable_in(str) ///
    delta_variable_out(str) matched_sample(str) loc(str)

    use `variables' using `nonmover_dataset', clear
    save ../temp/nonmover_temp, replace
    use rel_yr_rit `variables' using `mover_dataset', clear

    if "`keep_condition'"!="" {
        keep if `keep_condition'
    }
    if "`drop_condition'"!="" {
        drop if `drop_condition'
    }

    merge m:1 hrr_orig hrr_dest using `delta_dataset', ///
        assert(using match) keep(match) keepusing(*) nogen
    rename `delta_variable_in' `delta_variable_out'
    gen move_check_temp = (rel_yr_rit==-1 | rel_yr_rit==0) & `outcome'!=.
    bys bene_id: egen move_check = total(move_check_temp)
    keep if move_check>1 & move_check!=.
    drop move_check*

    merge_matched_nonmovers, outcome(`outcome') matched_sample(`matched_sample') loc(`loc')

    gen diff_`outcome'_mover=`outcome'_mover -`outcome'_nonmover_orig
    gen diff_`outcome'_nonmover_orig=`outcome'_nonmover_orig -`outcome'_nonmover_orig

    reshape long diff_`outcome' `outcome', i(bene_id year) j(status) string
    rename diff_`outcome' `outcome'_relative_to_nonmovers
    replace mover = 0 if status!="_mover"
    drop status
	
	rename hrrnum hrrnum_temp
	foreach type in orig {
		rename hrr_orig hrrnum
		merge m:1 hrrnum using ../external/fe/`outcome'_hrr_mean.dta, assert(using match) ///
			keep(match) keepusing(hrrnum `outcome'_total) nogen
		rename hrrnum hrr_`type'
		rename `outcome'_total `outcome'_`type'
	}
	rename hrrnum_temp hrrnum
	
	rename baseline_samp base
	xtile LnRBU_orig_median=LnRBU_orig, nq(2)
	xtile LnRBU_orig_quart=LnRBU_orig, nq(4)
	gen LnRBU_orig_above=LnRBU_orig_median==2
	gen LnRBU_orig_below=LnRBU_orig_median==1
	forvalues q=1/4{
		gen LnRBU_orig_q`q'=LnRBU_orig_quart==`q'
	}
	drop LnRBU_orig_median LnRBU_orig_quart
	
	save ../temp/delta_diff_data.dta, replace

end

    program merge_matched_nonmovers
        syntax, outcome(str) matched_sample(str) loc(str)

        rename bene_id bene_id_mover
        rename `outcome' `outcome'_mover
        merge 1:1 bene_id_mover year using `matched_sample', ///
                assert(1 2 3) keep(match) keepusing(bene_id_nonmover_`loc') nogen
        rename bene_id_nonmover_`loc' bene_id
        merge m:1 bene_id year using ../temp/nonmover_temp, ///
            assert (1 2 3 ) keep(1 3) keepusing(`outcome') nogen
        rename `outcome' `outcome'_nonmover_`loc'
        rename bene_id bene_id_nonmover_`loc'
        rename bene_id_mover bene_id

    end

program create_delta_groups
    syntax, nquantiles(str) delta_variable(str) delta_group_variable(str)

    replace `delta_variable' = 0 if mover==0
    replace bene_id = bene_id_nonmover_`loc' if mover==0
    xtile delta_group_temp = `delta_variable' if `delta_variable'!=0, nquantiles(`nquantiles')
    bys bene_id: egen `delta_group_variable' = min(delta_group_temp)
    drop delta_group_temp
    replace `delta_group_variable' = 0 if mover==0

end



* EXECUTE
main
