version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"

global outcomes1= "LnRBU RBU LnTotExpn"
global outcomes2= "anypcp Spec any_Ip anyErRBU Lndiag Lnimag Lnnum_doc Lnprv_num LnIp_RBU LnOp_RBU LnEr_RBU LnOt_RBU"
global outcomes3 = "diag imag num_doc prev_num Ip_RBU Op_RBU Er_RBU Ot_RBU"
global outcomes4 = "Amb doc_LnRBU doc_RBU LnIpDays LnIpDis prev_care Mam Clrtl FluShot"
global outcomes5 = "Lnhcccom Lnhccnew Lnnumcon hcc_com hcc_new any_cond num_cond"
global outcomes6 = "ami alzh alzhdmta atrialfb cataract chrnkidn copd chf diabetes glaucoma hipfrac ischmcht depressn osteoprs ra_oa strketia cncrbrst cncrclrc cncrprst cncrlung cncrendm anemia asthma hyperl hyperp hypert hypoth"
global outcomes7 = "LnRBU_x0 LnRBU_x01 LnRBU_x10"
global outcomes8 = "chr iez Lnchr Lniez"
global outcomes9 = "over_p50 over_p75 over_p90"
global outcomes10 = "RBU_v1c RBU_v2c RBU_v3c RBU_v4c RBU_v5c RBU_v6c RBU_v7c RBU_v8c RBU_v9c RBU_v10c RBU_v11c RBU_v12c RBU_v13c RBU_v14c RBU_v15c RBU_v16c RBU_v17c RBU_v18c RBU_v19c RBU_v20c"
global outcomes11 = "RBU_d1c RBU_d2c RBU_d3c RBU_d4c RBU_d5c RBU_d6c RBU_d7c RBU_d8c RBU_d9c RBU_d10c"
global outcomes12 = "RBU_perc"
global outcomes= "${outcomes5} ${outcomes8}"

program main
	load_data
	foreach yvar in ${outcomes} {
		output_hrr_mean, yvar(`yvar')
	}	
	calc_delta, fe_var(hrrnum)
	calc_hrr_ranks
end

program load_data
	syntax, [strata(str)]
    use bene_id mover year rel_yr_rit hrr* baseline_samp cc_samp female male ${outcomes} ///
        `strata' in 1/${obsno} using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
	append using "../external_links/compiled/CompiledPatYrDataNonMovers.dta", ///
		keep(bene_id mover year hrr* baseline_samp cc_samp female male ${outcomes} `strata')
	if "`strata'"!=""{
		keep if `strata'==1
	}
    gen awgt = 1
    replace awgt = 4 if mover==0
    save ../temp/patient_data, replace
end

program output_hrr_mean
    syntax, yvar(str) [strata(str)]
    
    use if rel_yr_rit!=0 using ../temp/patient_data, clear
	keep if ${`yvar'_samp}== 1 & rel_yr_rit!=0
	
    save ../temp/temp, replace
    gen `yvar'_mover = `yvar' if mover==1
    gen `yvar'_nonmover = `yvar' if mover==0
    collapse (mean) `yvar'_mover `yvar'_nonmover (sum) awgt, by(hrrnum year)
    save_data ../temp/`yvar'_hrr_mean, key(hrrnum year) replace
    use ../temp/temp, clear
    collapse (mean) `yvar'_total=`yvar' (semean) `yvar'_total_se=`yvar' [aw=awgt], by(hrrnum year)
    merge 1:1 hrrnum year using ../temp/`yvar'_hrr_mean, assert(3) nogen
    collapse (mean) `yvar'_total `yvar'_total_se `yvar'_nonmover `yvar'_mover, by(hrrnum)
	if "`strata'"!="" {
		save_data ../output/outcomes/`yvar'_hrr_mean_`strata', key(hrrnum) replace
	}
	else {
		save_data ../output/outcomes/`yvar'_hrr_mean, key(hrrnum) replace
	}

end

program calc_delta
    syntax, fe_var(str) [strata(str)]

    use hrr_orig hrr_dest using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    egen tag = tag(hrr_orig hrr_dest)
    keep if tag==1
    drop tag
    save ../temp/temp, replace
    levelsof hrr_orig, local(orig_groups)
    levelsof hrr_dest, local(dest_groups)
    foreach yvar in ${outcomes} {
        use ../temp/temp, clear
        foreach loc in orig dest {
            rename hrr_`loc' hrrnum
			if "`strata'"!="" {
				merge m:1 hrrnum using ../output/outcomes/`yvar'_hrr_mean_`strata', assert(1 3) ///
					keep(3) keepusing(`yvar'_total) nogen
			}
			else{
				merge m:1 hrrnum using ../output/outcomes/`yvar'_hrr_mean, assert(1 3) ///
					keep(3) keepusing(`yvar'_total) nogen
			}
            rename `yvar'_total `yvar'_total_`loc'
            rename hrrnum hrr_`loc'
        }
        gen delta_`fe_var'= `yvar'_total_dest - `yvar'_total_orig
        rename delta_`fe_var' delta_`fe_var'_`yvar'_i
     
        label variable delta_`fe_var'_`yvar'_i ///
            "diff in `fe_var' fixed effect of nonmovers from origin to destination, `yvar'"
        keep hrr_orig hrr_dest delta_*_*_i
		if "`strata'"!="" {
			save_data ../output/outcomes/delta_`yvar'_`strata', replace key(hrr_orig hrr_dest)
		}
		else {
			save_data ../output/outcomes/delta_`yvar', replace key(hrr_orig hrr_dest)
		}
     }
end

program calc_hrr_ranks
	syntax, [strata(str)]

    clear
    foreach outcome in ${outcomes} {
		if "`strata'"!="" {
			append using ../output/outcomes/`outcome'_hrr_mean_`strata'.dta, ///
				keep(`outcome'_total hrrnum )
		}
		else {
			append using ../output/outcomes/`outcome'_hrr_mean.dta, ///
				keep(`outcome'_total hrrnum )
		}
        rename `outcome'_total `outcome'
    }

    collapse (mean) ${outcomes}, by(hrrnum)
    save ../temp/temp, replace

    foreach outcome in ${outcomes} {
        use ../temp/temp, clear
        xtile `outcome'_p50_rank = `outcome', nquantiles(2)
        xtile `outcome'_p25_rank = `outcome', nquantiles(4)
        xtile `outcome'_p10_rank = `outcome', nquantiles(10)
        xtile `outcome'_p5_rank = `outcome', nquantiles(20)

        gen `outcome'_texas_rank = 1 if hrrnum==393
        replace `outcome'_texas_rank = 4 if hrrnum==402
        gen `outcome'_M_rank = 1 if hrrnum==251
        replace `outcome'_M_rank = 4 if hrrnum==127
        summ `outcome'
        gen `outcome'_maxmin_rank = 1 if `outcome'==r(min)
        replace `outcome'_maxmin_rank = 4 if `outcome'==r(max)

        keep hrrnum *rank*
		if "`strata'"!="" {
			save_data ../output/outcomes/hrr_rank_`outcome'_`strata', replace key(hrrnum)
		}
		else {
			save_data ../output/outcomes/hrr_rank_`outcome', replace key(hrrnum)		
		}
    }

end

* EXECUTE
main

