version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

global outcome = "LnRBU"
global strata "bs bs_o bs_o_nsb bs_l bs_h"

program main

    load_data
   
    foreach strata in none ${strata} {
        output_hrr_mean, yvar(${outcome}) strata(`strata')
    }
    calc_delta, strata(${strata}) fe_var(hrrnum) yvar(${outcome})
    calc_hrr_ranks, strata(${strata}) yvar(${outcome})
end

program load_data
    use bene_id mover year hrr* ${outcome} ${strata} rel_yr_rit ///
        using "../external_links/compiled/CompiledPatYrDataNonMoversAlt.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMoversAlt.dta", ///
        keep(bene_id mover year hrr* ${outcome} ${strata} rel_yr_rit)
    gen awgt = 1
    replace awgt = 4 if mover==0
	gen none=1
    save ../temp/patient_data, replace
end

program output_hrr_mean
    syntax, yvar(str) strata(str)
    
    use if rel_yr_rit!=0 using ../temp/patient_data, clear
	keep if `strata'==1
    save ../temp/temp, replace
    gen `yvar'_mover = `yvar' if mover==1
    gen `yvar'_nonmover = `yvar' if mover==0
    collapse (mean) `yvar'_total=`yvar' `yvar'_mover `yvar'_nonmover (semean) ///
		`yvar'_total_se=`yvar' [aw=awgt], by(hrrnum year) 
    collapse (mean) `yvar'*, by(hrrnum)
    save_data ../output/strata/`yvar'_hrr_mean_`strata', key(hrrnum) replace

end

program calc_delta
    syntax, strata(str) fe_var(str) yvar(str)

    use hrr_orig hrr_dest using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    egen tag = tag(hrr_orig hrr_dest)
    keep if tag==1
    drop tag
    save ../temp/temp, replace
    levelsof hrr_orig, local(orig_groups)
    levelsof hrr_dest, local(dest_groups)
    foreach strata in `strata' {
		use ../temp/temp, clear
        foreach loc in orig dest {
            rename hrr_`loc' hrrnum
            merge m:1 hrrnum using ../output/strata/`yvar'_hrr_mean_`strata', assert(1 3) keep(3) ///
                keepusing(`yvar'_total) nogen
            rename `yvar'_total `yvar'_`strata'_`loc'
            rename hrrnum hrr_`loc'
        }
        gen delta_`fe_var'= `yvar'_`strata'_dest - `yvar'_`strata'_orig
        rename delta_`fe_var' delta_`fe_var'_`yvar'_i

        label variable delta_`fe_var'_`yvar'_i ///
            "diff in `fe_var' fixed effect of nonmovers from origin to destination, `yvar'"
        keep hrr_orig hrr_dest delta_*_*_i
        save_data ../output/strata/delta_`yvar'_`strata', replace key(hrr_orig hrr_dest)
     }
end

program calc_hrr_ranks
	syntax, strata(str) yvar(str)
	
    foreach strata in `strata' {
        use ../output/strata/`yvar'_hrr_mean_`strata', clear
		cap rename `yvar'_total `yvar'_`strata'
        xtile `yvar'_p50_rank = `yvar'_`strata', nquantiles(2)
        xtile `yvar'_p25_rank = `yvar'_`strata', nquantiles(4)
        xtile `yvar'_p10_rank = `yvar'_`strata', nquantiles(10)
        xtile `yvar'_p5_rank = `yvar'_`strata', nquantiles(20)

        gen `yvar'_texas_rank = 1 if hrrnum==393
        replace `yvar'_texas_rank = 4 if hrrnum==402
        gen `yvar'_M_rank = 1 if hrrnum==251
        replace `yvar'_M_rank = 4 if hrrnum==127
        summ `yvar'_`strata'
        gen `yvar'_maxmin_rank = 1 if `yvar'_`strata'==r(min)
        replace `yvar'_maxmin_rank = 4 if `yvar'_`strata'==r(max)

        keep hrrnum *rank*
        save_data ../output/strata/hrr_rank_`yvar'_`strata', replace key(hrrnum)
    }

end

* EXECUTE
main

