version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

global outcomes = "LnRBU"

program main
    load_data
    foreach yvar in ${outcomes} {
        output_hrr_mean, yvar(`yvar')
   }
    calc_delta, fe_var(hrrnum)
    calc_hrr_ranks
	rank_time_series, rank(20) yvar(${outcomes})
end

program load_data
    use bene_id mover year hrr* ${outcomes} baseline_samp cc_samp sdod if baseline_samp==1 using ///
        "../external_links/compiled/CompiledPatYrDataNonMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMovers.dta", ///
        keep(bene_id mover year hrr* ${outcomes} baseline_samp cc_samp rel_yr_rit sdod)	
    keep if baseline_samp==1
    gen awgt = 1
    replace awgt = 4 if mover==0
    save ../temp/patient_data, replace
end

program output_hrr_mean
    syntax, yvar(str) [period2]
    
    use ../temp/patient_data, clear
    keep if ${`yvar'_samp}== 1 & rel_yr_rit!=0
    save ../temp/temp, replace
    gen `yvar'_mover = `yvar' if mover==1
    gen `yvar'_nonmover = `yvar' if mover==0
    collapse (mean) `yvar'_mover `yvar'_nonmover (sum) awgt, by(hrrnum year)
    save_data ../temp/`yvar'_hrr_mean, key(hrrnum year) replace
    use ../temp/temp, clear
    collapse (mean) `yvar'_total=`yvar' (semean) `yvar'_total_se=`yvar' [aw=awgt], by(hrrnum year)
    merge 1:1 hrrnum year using ../temp/`yvar'_hrr_mean, assert(3) nogen

    if "`period2'"=="period2" {
        gen period2=year>2003
        collapse (mean) `yvar'_total `yvar'_total_se `yvar'_nonmover `yvar'_mover, ///
            by(hrrnum period2)
        save_data ../output/`yvar'_hrr_mean_periods, key(hrrnum period2) replace
    }
    else {
        collapse (mean) `yvar'_total `yvar'_total_se `yvar'_nonmover `yvar'_mover, by(hrrnum)
        save_data ../output/`yvar'_hrr_mean, key(hrrnum) replace
    }

end

program calc_delta
    syntax, fe_var(str)

    use hrr_orig hrr_dest using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    egen tag = tag(hrr_orig hrr_dest)
    keep if tag==1
    drop tag
    save ../temp/temp, replace
    levelsof hrr_orig, local(orig_groups)
    levelsof hrr_dest, local(dest_groups)
    foreach yvar in ${outcomes} {
        use ../temp/temp, clear
        foreach loc in orig dest {
            rename hrr_`loc' hrrnum
            merge m:1 hrrnum using ../output/`yvar'_hrr_mean, assert(1 3) keep(3) ///
                keepusing(`yvar'_total) nogen
            rename `yvar'_total `yvar'_total_`loc'
            rename hrrnum hrr_`loc'
        }
        gen delta_`fe_var'= `yvar'_total_dest - `yvar'_total_orig
        rename delta_`fe_var' delta_`fe_var'_`yvar'_i
     
        label variable delta_`fe_var'_`yvar'_i ///
            "diff in `fe_var' fixed effect of nonmovers from origin to destination, `yvar'"
        keep hrr_orig hrr_dest delta_*_*_i
        save_data ../output/delta_`yvar', replace key(hrr_orig hrr_dest)
     }
end

program calc_hrr_ranks

    clear
    foreach outcome in ${outcomes} {
        append using ../output/`outcome'_hrr_mean.dta, keep(`outcome'_total hrrnum )
        rename `outcome'_total `outcome'
    }

    collapse (mean) ${outcomes}, by(hrrnum)
    save ../temp/temp, replace

    foreach outcome in ${outcomes} {
        use ../temp/temp, clear
        xtile `outcome'_p50_rank = `outcome', nquantiles(2)
        xtile `outcome'_p25_rank = `outcome', nquantiles(4)
        xtile `outcome'_p20_rank = `outcome', nquantiles(5)
        xtile `outcome'_p10_rank = `outcome', nquantiles(10)
        xtile `outcome'_p5_rank = `outcome', nquantiles(20)
        gen `outcome'_texas_rank = 1 if hrrnum==393
        replace `outcome'_texas_rank = 4 if hrrnum==402
        gen `outcome'_M_rank = 1 if hrrnum==251
        replace `outcome'_M_rank = 4 if hrrnum==127
        summ `outcome'
        gen `outcome'_maxmin_rank = 1 if `outcome'==r(min)
        replace `outcome'_maxmin_rank = 4 if `outcome'==r(max)
        keep hrrnum *rank*
        save_data ../output/hrr_rank_`outcome', replace key(hrrnum)
    }

end

program rank_time_series
    syntax, rank(str) yvar(str)

    use ../temp/patient_data if ${`yvar'_samp}== 1 & rel_yr_rit!=0, clear
    merge m:1 hrrnum using ../output/hrr_rank_`yvar', ///
        assert(3) keep(3) keepusing(`yvar'_p`rank'_rank)
    collapse (mean) `yvar', by(`yvar'_p`rank'_rank year)
    save_data ../output/rank_year_mean_p`rank', replace key(year `yvar'_p`rank'_rank)
    
end

* EXECUTE
main

