version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

global outcomes = "LnRBU"

program main
    load_data
    foreach yvar in ${outcomes} {
        output_state_mean, yvar(`yvar')
   }
    calc_delta, fe_var(state_de)
    calc_state_ranks
	
end

program load_data
    use bene_id mover year state* ${outcomes} baseline_samp sdod if baseline_samp==1 using ///
        "../external_links/compiled/CompiledPatYrDataNonMovers.dta", clear
    append using "../external_links/compiled/CompiledPatYrDataMovers.dta", ///
        keep(bene_id mover year state* ${outcomes} baseline_samp cc_samp rel_yr_rit sdod)	
    keep if baseline_samp==1
    gen awgt = 1
    replace awgt = 4 if mover==0
    save ../temp/patient_data, replace
end

program output_state_mean
    syntax, yvar(str)
    
    use ../temp/patient_data, clear
    keep if ${`yvar'_samp}== 1 & rel_yr_rit!=0
    save ../temp/temp, replace
    gen `yvar'_mover = `yvar' if mover==1
    gen `yvar'_nonmover = `yvar' if mover==0
    collapse (mean) `yvar'_mover `yvar'_nonmover (sum) awgt, by(state_de year)
    save_data ../temp/`yvar'_state_mean, key(state_de year) replace
    use ../temp/temp, clear
    collapse (mean) `yvar'_total=`yvar' (semean) `yvar'_total_se=`yvar' [aw=awgt], by(state_de year)
    merge 1:1 state_de year using ../temp/`yvar'_state_mean, assert(3) nogen

    collapse (mean) `yvar'_total `yvar'_total_se `yvar'_nonmover `yvar'_mover, by(state_de)
    save_data ../output/state/`yvar'_state_mean, key(state_de) replace

end

program calc_delta
    syntax, fe_var(str)

    use state_orig state_dest using "../external_links/compiled/CompiledPatYrDataMovers.dta", clear
    egen tag = tag(state_orig state_dest)
    keep if tag==1
    drop tag
    save ../temp/temp, replace
    levelsof state_orig, local(orig_groups)
    levelsof state_dest, local(dest_groups)
    foreach yvar in ${outcomes} {
        use ../temp/temp, clear
        foreach loc in orig dest {
            rename state_`loc' state_de
            merge m:1 state_de using ../output/state/`yvar'_state_mean, assert(1 3) keep(3) ///
                keepusing(`yvar'_total) nogen
            rename `yvar'_total `yvar'_total_`loc'
            rename state_de state_`loc'
        }
        gen delta_`fe_var'= `yvar'_total_dest - `yvar'_total_orig
        rename delta_`fe_var' delta_`fe_var'_`yvar'_i
     
        label variable delta_`fe_var'_`yvar'_i ///
            "diff in `fe_var' fixed effect of nonmovers from origin to destination, `yvar'"
        keep state_orig state_dest delta_*_*_i
        save_data ../output/state/delta_state_`yvar', replace key(state_orig state_dest)
     }
end

program calc_state_ranks

    clear
    foreach outcome in ${outcomes} {
        append using ../output/state/`outcome'_state_mean.dta, keep(`outcome'_total state_de)
        rename `outcome'_total `outcome'
    }

    collapse (mean) ${outcomes}, by(state_de)
    save ../temp/temp, replace

    foreach outcome in ${outcomes} {
        use ../temp/temp, clear
        xtile `outcome'_p50_rank = `outcome', nquantiles(2)
        xtile `outcome'_p25_rank = `outcome', nquantiles(4)
        xtile `outcome'_p20_rank = `outcome', nquantiles(5)
        xtile `outcome'_p10_rank = `outcome', nquantiles(10)
        xtile `outcome'_p5_rank = `outcome', nquantiles(20)
        summ `outcome'
        gen `outcome'_maxmin_rank = 1 if `outcome'==r(min)
        replace `outcome'_maxmin_rank = 4 if `outcome'==r(max)
        keep state_de *rank*
        save_data ../output/state/state_rank_`outcome', replace key(state_de)
    }

end

* EXECUTE
main

