version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    load_data
    output_mean, yvar(LnRBU) unit(hrr) unitnum(hrrnum)
    calc_delta, yvar(LnRBU) unit(hrr) unitnum(hrrnum)
    calc_ranks, yvar(LnRBU) unit(hrr) unitnum(hrrnum)
end

program load_data
    use bene_id mover year hrr* LnRBU ///
        using ../external_links/compiled/CompiledPatYrDataNonMoversAll, clear
    append using ../external_links/compiled/CompiledPatYrDataMoversAll, ///
        keep(bene_id mover year hrr* LnRBU rel_yr_rit)	
    merge 1:1 bene_id year using ../external_links/multiple/MultipleMovers_RelativeYears, ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    gen awgt = 1
    replace awgt = 4 if mover==0
    save ../temp/patient_data, replace
end

program output_mean
    syntax, yvar(str) unit(str) unitnum(str)
    
    use ../temp/patient_data, clear
    foreach var of varlist rel_yr_rit* {
        drop if `var'==0
    }
    save ../temp/temp, replace
    gen `yvar'_mover = `yvar' if mover==1
    gen `yvar'_nonmover = `yvar' if mover==0
    collapse (mean) `yvar'_mover `yvar'_nonmover (sum) awgt, by(`unitnum' year)
    save_data ../temp/`yvar'_`unit'_mean, key(`unitnum' year) replace
    use ../temp/temp, clear
    collapse (mean) `yvar'_total=`yvar' (semean) `yvar'_total_se=`yvar' [aw=awgt],by(`unitnum' year)
    merge 1:1 `unitnum' year using ../temp/`yvar'_`unit'_mean, assert(3) nogen
    collapse (mean) `yvar'_total `yvar'_total_se `yvar'_nonmover `yvar'_mover, by(`unitnum')
    save_data ../output/`yvar'_`unit'_mean_with_multiple_movers, key(`unitnum') replace

end

program calc_delta
    syntax, yvar(str) unit(str) unitnum(str)

    use bene_id `unit'_orig `unit'_dest ///
		using "../external_links/compiled/CompiledPatYrDataMoversAll.dta",clear
	gen count_temp=1
	bys `unit'_orig `unit'_dest: egen count=total(count_temp)
	bys bene_id: gen count_temp_patient=1 if _n==1
	bys `unit'_orig `unit'_dest: egen count_patient=total(count_temp_patient)
    egen tag = tag(`unit'_orig `unit'_dest)
    keep if tag==1
	bys `unit'_orig: egen `unit'_orig_count=total(count)
	bys `unit'_dest: egen `unit'_dest_count=total(count)
	bys `unit'_orig: egen `unit'_orig_count_patient=total(count_patient)
	bys `unit'_dest: egen `unit'_dest_count_patient=total(count_patient)
    drop tag count*
    foreach loc in orig dest {
        rename `unit'_`loc' `unitnum'
        merge m:1 `unitnum' using ../output/`yvar'_`unit'_mean_with_multiple_movers, ///
            assert(1 3) keep(3) keepusing(`yvar'_total) nogen
        rename `yvar'_total `yvar'_total_`loc'
        rename `unitnum' `unit'_`loc'
    }
    gen delta_`unit'_`yvar'_i= `yvar'_total_dest - `yvar'_total_orig
    label variable delta_`unit'_`yvar'_i ///
        "diff in `unit' fixed effect of nonmovers from origin to destination, `yvar'"
    keep `unit'_orig `unit'_dest delta_*_*_i delta_* *count*
    save_data ../output/delta_`unit'_`yvar'_with_multiple_movers, replace key(`unit'_orig `unit'_dest)

end

program calc_ranks
    syntax, yvar(str) unit(str) unitnum(str)

    use ../output/`yvar'_`unit'_mean_with_multiple_movers, clear
    rename `yvar'_total `yvar'
    collapse (mean) `yvar', by(`unitnum')
    save ../temp/temp, replace
    use ../temp/temp, clear
    xtile `yvar'_p50_rank = `yvar', nquantiles(2)
    xtile `yvar'_p25_rank = `yvar', nquantiles(4)
    xtile `yvar'_p20_rank = `yvar', nquantiles(5)
    xtile `yvar'_p10_rank = `yvar', nquantiles(10)
    xtile `yvar'_p5_rank = `yvar', nquantiles(20)
    gen `yvar'_texas_rank = 1 if hrrnum==393
    replace `yvar'_texas_rank = 4 if hrrnum==402
    gen `yvar'_M_rank = 1 if hrrnum==251
    replace `yvar'_M_rank = 4 if hrrnum==127
    summ `yvar'
    gen `yvar'_maxmin_rank = 1 if `yvar'==r(min)
    replace `yvar'_maxmin_rank = 4 if `yvar'==r(max)
    keep `unitnum' *rank*
    save_data ../output/`unit'_rank_`yvar'_with_multiple_movers, replace key(`unitnum')

end

* EXECUTE
main

