version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    process_AMA
	process_AHA
	insheet_dartmouthEOL
	insheet_HospitalCompare
end

program process_AMA
    use researchid primaryspecialty zipcode2011 using ../external/AMA/ama, clear
	rename zipcode2011 zipcode
	merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) ///
	    keepusing(hrrnum) nogen
	gen pcp=inlist(primaryspecialty,"AMF","FM","FP","FSM","GP","HPI","IFP","IM","PD")
	gen specialist=(pcp==0)
	collapse (sum) pcp specialist, by(hrrnum)
	merge 1:1 hrrnum using ../external/pop/HRRPop, assert(3) keep(3) keepusing(pop_avg) nogen
	gen pcp_pc=pcp/pop_avg*1000
	gen specialist_pc=specialist/pop_avg*1000
	keep pcp_pc specialist_pc hrrnum
	label variable pcp_pc "# of PCP per 1000 residents"
	label variable specialist_pc "# of specialists per 1000 residents"
	save_data ../output/HRRSpecPCPperCap, replace key(hrrnum)
end

program process_AHA
    forval year=1998/2008 {
	    use bdtot bdh mloczip cntrl using ../external/AHA/aha_extract`year', clear
		rename mloczip zipcode
		replace bdtot=bdh if bdh!=. //only include hospital beds (and exclude SNF beds)
		merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) ///
		    keepusing(hrrnum) nogen
		cap destring cntrl, replace force
		gen hosp_fp=inlist(cntrl,31,32,33)
		gen hosp_np=(hosp_fp==0)
		collapse (sum) hosp_fp hosp_np bdtot, by(hrrnum)
		gen year=`year'
        save ../temp/aha_hrr`year', replace
	}
	clear
    forval year=1998/2008 {
        append using ../temp/aha_hrr`year'
	}
	merge n:1 hrrnum using ../external/pop/HRRPop, assert(3) keep(3) keepusing(pop_avg) nogen
	gen hosp_fp_pct=hosp_fp/(hosp_fp+hosp_np)
	gen hosp_np_pct=1-hosp_fp_pct
	gen bed_pc=bdtot/pop_avg*1000
	label variable hosp_fp_pct "% for-profit hospitals"
	label variable hosp_np_pct "% non-profit hospitals"
	label variable bed_pc "# of hospital beds per 1000 residents"
    save_data ../output/HRRYearBedProfitperCap, replace	key(hrrnum year)
	collapse (mean) hosp_fp hosp_np bdtot pop_avg, by(hrrnum)
	gen hosp_fp_pct=hosp_fp/(hosp_fp+hosp_np)
	gen hosp_np_pct=1-hosp_fp_pct
	gen bed_pc=bdtot/pop_avg*1000
	label variable hosp_fp_pct "% for-profit hospitals"
	label variable hosp_np_pct "% non-profit hospitals"
	label variable bed_pc "# of hospital beds per 1000 residents"
    save_data ../output/HRRBedProfitperCap, replace	key(hrrnum)
end	
		
program insheet_dartmouthEOL
    foreach year in 01_05 03_07 {
        import excel "../external/dartmouth/DAP_hrr_`year'.xls", clear
		drop in 1/3
	    if "`year'"=="01_05" {
	        keep A T-W AB-AE AJ AK AN-AP AT AU AV AY AZ BF-BL
	        rename A hrrnum
	        rename T HospReimburseEOL
	        rename U HospDayEOL
	        rename V ReimbursePatDayEOL
	        rename W HospReimburseRatioEOL
	        rename AB PhysPayEOL
	        rename AC PhysVisitEOL
	        rename AD PayperPhysVisitEOL
	        rename AE PhysPayRatioEOL
	        rename AJ HospBedEOL
	        rename AK IntenseBedEOL
	        rename AN MedSurgBedEOL
	        rename AO SNFBedEOL
	        rename AP FTEPhysEOL
	        rename AT RNsEOL
	        rename AU HospDaysEOL
       	    rename AV IntenseDaysEOL
	        rename AY MedSurgDaysEOL
	        rename AZ SNFDaysEOL
	        rename BF PctInHospDeathEOL
	        rename BG PctICUDeathEOL
	        rename BH PctHospiceEOL
	        rename BI HospiceDaysEOL
	        rename BJ Pct10PhysEOL
	        rename BK NumPhysEOL
	        rename BL AvgCopayEOL
		}
		else if "`year'"=="03_07" {
		    keep A U-X AC-AF AK AL AO-AQ AU-AW AZ BA BG-BM
			rename A hrrnum
	        rename U HospReimburseEOL
	        rename V HospDayEOL
	        rename W ReimbursePatDayEOL
	        rename X HospReimburseRatioEOL
	        rename AC PhysPayEOL
	        rename AD PhysVisitEOL
	        rename AE PayperPhysVisitEOL
	        rename AF PhysPayRatioEOL
	        rename AK HospBedEOL
	        rename AL IntenseBedEOL
	        rename AO MedSurgBedEOL
	        rename AP SNFBedEOL
	        rename AQ FTEPhysEOL
	        rename AU RNsEOL
	        rename AV HospDaysEOL
       	    rename AW IntenseDaysEOL
	        rename AZ MedSurgDaysEOL
	        rename BA SNFDaysEOL
	        rename BG PctInHospDeathEOL
	        rename BH PctICUDeathEOL
	        rename BI PctHospiceEOL
	        rename BJ HospiceDaysEOL
	        rename BK Pct10PhysEOL
	        rename BL NumPhysEOL
	        rename BM AvgCopayEOL
		}
		destring *, replace
		gen year_range="`year'"
		save ../temp/DartmouthEOL`year', replace
	}
	use ../temp/DartmouthEOL01_05, clear
	append using ../temp/DartmouthEOL03_07
	save_data ../output/HRRYearDartmouthEOL, replace key(year_range hrrnum)
	drop year_range
	drop if hrrnum==999
	collapse HospReimburseEOL-AvgCopayEOL, by(hrrnum)
	
	label variable HospReimburseEOL ///
		"Hospital reimbursements per decedent last two years of life"
	label variable HospDayEOL "Hospital days per decedent last two years of life"
	label variable ReimbursePatDayEOL "Reimbursements per patient day last two years of life"
	label variable HospReimburseRatioEOL ///
		"Ratio to US average hospital reimbursements last two years of life"
	label variable PhysPayEOL ///
		"Payments for physicain visits per decedent last two years of life"
	label variable PhysVisitEOL "Physician visits per decedent last two years of life"
	label variable PayperPhysVisitEOL "Payments per physician visit last two years of life"
	label variable PhysPayRatioEOL ///
		"Ratio to US average physician visit payments last two years of life"
	label variable HospBedEOL "Hospital beds per 1000 decedents last two years of life"
	label variable IntenseBedEOL "Intensive care beds per 1000 decedents last two years of life"
	label variable MedSurgBedEOL  ///
		"Medical & surgical unit beds per 1000 decedents last two years of life"
	label variable SNFBedEOL ///
		"SNF beds per 1000 decedents last two years of life"
	label variable FTEPhysEOL "Standardized total FTE physician labor last two years of life"
	label variable RNsEOL "RNs required under proposed federal standards last two years of life"
	label variable HospDaysEOL "Hospital days per decedent during EOL"
	label variable IntenseDaysEOL "Intensive care days per decedent during EOL"
	label variable MedSurgDaysEOL "Medical & Surgical unit days per decedent during EOL"
	label variable SNFDaysEOL "SNF days per decedent during EOL"
	label variable PctInHospDeathEOL "Percent of deaths occurring in hospital"
	label variable PctICUDeathEOL "Percent of deaths that included an ICU admission"
	label variable PctHospiceEOL "Percent enrolled in hospice"
	label variable HospiceDaysEOL "Hospice days per decedent"
	label variable Pct10PhysEOL "Percent of patient seeing 10 or more different physicians"
	label variable NumPhysEOL "Number of different physicians seen per decedent"
	label variable AvgCopayEOL "Average copayment per decedent during last two years of life"
		
	save_data ../output/HRRDartmouthEOL, replace key(hrrnum)
end 

program insheet_HospitalCompare
    foreach year in 20050501 20050901 20051201 20060301 20060601 20061201 20070301 20070601 ///
	    20070901 20071201 20080401 20080801 20081001 20081201 {
		import excel "../external/HOS/HOS`year'.xlsx", first clear
		keep ZIPCode MeasureName Score
		rename ZIPCode zipcode
		merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) ///
	        keepusing(hrrnum) nogen
		destring Score, ignore("%") replace
		collapse (mean) HospScore=Score, by(hrrnum)
		gen year=substr("`year'",1,4)
		destring year, replace
		save ../temp/HOS`year', replace
	}
	clear
	foreach year in 20050501 20050901 20051201 20060301 20060601 20061201 20070301 20070601 ///
	    20070901 20071201 20080401 20080801 20081001 20081201 {
		append using ../temp/HOS`year'
	}
	collapse (mean) HospScore, by(hrrnum year)
	save_data ../output/HRRYearHospCompare, replace key(hrrnum year)
	collapse (mean) HospScore, by(hrrnum)
	save_data ../output/HRRHospCompare, replace key(hrrnum)
end
	 
*Execute
main
