version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    insheet_pop using "../external/census/Census2000_SF1/DEC_00_SF1_P007_with_ann.csv", ///
        zcta_var(v2) pop_var(v4) year(2000) 
    insheet_pop using "../external/ACS/ACS2007_2011/ACS_11_5YR_B02001_with_ann.csv", ///
        zcta_var(v2) pop_var(v4) year(2011) 
    pop_avg
    insheet_income using "../external/census/Census2000_SF3/DEC_00_SF3_P053_with_ann.csv", ///
        zcta_var(v2) income_var(v4) year(2000)
    insheet_income using "../external/ACS/ACS2007_2011/ACS_11_5YR_S1901_with_ann.csv", ///
        zcta_var(v2) income_var(v92) year(2011)
    insheet_urban using "../external/census/Census2000_SF1/DEC_00_SF1_P002_with_ann.csv", ///
        zcta_var(v2) pop_var(v4) urban_var(v5) year(2000)
    insheet_urban using "../external/census/Census2010_SF1/DEC_10_SF1_P2_with_ann.csv", ///
        zcta_var(v2) pop_var(v4) urban_var(v5) year(2010)
    urban_avg
    insheet_owner using "../external/census/Census2000_SF1/DEC_00_SF1_H004_with_ann.csv", ///
        zcta_var(v2) occupied_var(v4) owner_var(v5) year(2000)
    insheet_owner using "../external/census/Census2010_SF1/DEC_10_SF1_H4_with_ann.csv", ///
        zcta_var(v2) occupied_var(v4) owner_var(v5) owner_var2(v6) year(2010)
    owner_avg
    insheet_household using "../external/census/Census2000_SF1/DEC_00_SF1_P023_with_ann.csv", ///
        zcta_var(v2) household_var(v5) one_person_var(v6) year(2000)
    insheet_household using "../external/census/Census2010_SF1/DEC_10_SF1_P25_with_ann.csv", ///
        zcta_var(v2) household_var(v5) one_person_var(v6) year(2010)
    household_avg
    insheet_foreign using "../external/ACS/ACS2007_2011/ACS_11_5YR_B05001_with_ann.csv", ///
        zcta_var(v2) pop_var(v4) foreign_var1(v12) foreign_var2(v14) year(2011)
    insheet_education
    get_age_race_sex
    hrr_demographics
end

program insheet_pop
    syntax using, year(integer) zcta_var(str) pop_var(str)
	
    insheet `using', clear
    drop in 1/2
    drop if inlist(substr(v2,-2,.),"XX","HH") //these are water (or land!)
    rename `zcta_var' ZCTA5
    rename `pop_var' pop`year'
    destring pop`year', replace
    gen zipcode=ZCTA5
    *note that some master data exisits bc zipcode and zcta are not exactly the same
    *and that we are using a 1998 crosswalk
    merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) nogen ///
        keepusing(hrrnum)
    collapse (sum) pop`year', by(hrrnum)		
    save ../temp/pop`year', replace	
end
	
program pop_avg
    use ../temp/pop2011, replace
    merge 1:1 hrrnum using ../temp/pop2000, assert(3) keep(3) nogen
    gen pop_avg=(pop2000+pop2011)/2
    save_data ../output/HRRPop, replace key(hrrnum)
end

program insheet_income
    syntax using, year(integer) zcta_var(str) income_var(str)
	
    insheet `using', clear
	drop in 1/2
	rename `zcta_var' ZCTA5
	rename `income_var' medianHHincome`year'
	destring medianHHincome`year', replace force
	gen zipcode=ZCTA5
	merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) nogen ///
	    keepusing(hrrnum)
	*median HH income of HRR = median of median HH income of zipcodes in that HRR
	collapse (median) medianHHincome`year', by(hrrnum)
	save ../temp/income`year', replace
end

program insheet_urban
    syntax using, zcta_var(string) pop_var(string) urban_var(string) year(integer)

    insheet `using', clear
    drop in 1 / 2
    drop if inlist(substr(v2, -2, .), "XX", "HH")
    rename `zcta_var' ZCTA5
    generate zipcode = ZCTA5
    rename `pop_var' pop`year'
    destring pop`year', replace
    rename `urban_var' urban`year'
    destring urban`year', replace
    merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, ///
        assert(master match using) keep(match) keepusing(hrrnum) nogenerate
    collapse (sum) pop`year' (sum) urban`year', by(hrrnum)
    generate urban_pct_`year' = (urban`year' / pop`year')
    save ../temp/urban`year'.dta, replace
end

program urban_avg
    use ../temp/urban2010.dta, clear
    merge 1:1 hrrnum using ../temp/urban2000.dta, assert(match) keep(match) keepusing(*) nogenerate
    generate urban_pct = (urban_pct_2000 + urban_pct_2010) / 2
    keep hrrnum urban_pct
    save ../temp/hrr_urban.dta, replace
end

program insheet_owner
    syntax using, zcta_var(string) occupied_var(string) owner_var(string) year(integer) ///
        [owner_var2(string)]

    insheet `using', clear
    drop in 1 / 2
     drop if inlist(substr(v2, -2, .), "XX", "HH")
    rename `zcta_var' ZCTA5
    generate zipcode = ZCTA5
    rename `occupied_var' occupied`year'
    destring occupied`year', replace
    if ("`owner_var2'" == "") {
        rename `owner_var' owner`year'
        destring owner`year', replace
    }
    else {
        destring `owner_var', replace
        destring `owner_var2', replace
        generate owner`year' = `owner_var' + `owner_var2'
    }
    merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, ///
        assert(master match using) keep(match) keepusing(hrrnum) nogenerate
    collapse (sum) occupied`year' (sum) owner`year', by(hrrnum)
    generate owner_pct_`year' = (owner`year' / occupied`year')
    save ../temp/owner`year'.dta, replace
end

program owner_avg
    use ../temp/owner2010.dta, clear
    merge 1:1 hrrnum using ../temp/owner2000.dta, assert(match) keep(match) keepusing(*) nogenerate
    generate owner_pct = (owner_pct_2000 + owner_pct_2010) / 2
    keep hrrnum owner_pct
    save ../temp/hrr_owner.dta, replace
end

program insheet_household
    syntax using, zcta_var(string) household_var(string) one_person_var(string) year(integer)

    insheet `using', clear
    drop in 1 / 2
    drop if inlist(substr(v2, -2, .), "XX", "HH")
    rename `zcta_var' ZCTA5
    generate zipcode = ZCTA5
    rename `household_var' household`year'
    destring household`year', replace
    rename `one_person_var' one_person`year'
    destring one_person`year', replace
    merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, ///
        assert(master match using) keep(match) keepusing(hrrnum) nogenerate
    collapse (sum) household`year' (sum) one_person`year', by(hrrnum)
    generate one_person_pct_`year' = (one_person`year' / household`year')
    save ../temp/one_person`year'.dta, replace
end

program household_avg
    use ../temp/one_person2010.dta, clear
    merge 1:1 hrrnum using ../temp/one_person2000.dta, ///
        assert(match) keep(match) keepusing(*) nogenerate
    generate one_person_pct = (one_person_pct_2000 + one_person_pct_2010) / 2
    keep hrrnum one_person_pct
    save ../temp/hrr_one_person.dta, replace
end

program insheet_foreign
    syntax using, zcta_var(string) pop_var(string) foreign_var1(string) foreign_var2(string) ///
        year(integer)

    insheet `using', clear
    drop in 1 / 2
    rename `zcta_var' ZCTA5
    generate zipcode = ZCTA5
    rename `pop_var' pop
    destring pop, replace
    destring `foreign_var1', replace
    destring `foreign_var2', replace
    generate foreign = `foreign_var1' + `foreign_var2'
    merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, ///
        assert(master match using) keep(match) keepusing(hrrnum) nogenerate
    collapse (sum) pop (sum) foreign, by(hrrnum)
    generate foreign_born_pct = (foreign / pop)
    keep hrrnum foreign_born_pct
    save ../temp/hrr_foreign.dta, replace
end

program insheet_education
    insheet using "../external/census/Census2000_SF3/DEC_00_SF3_P037_with_ann.csv", clear
	drop in 1/2
	rename v2 ZCTA5
	foreach var in v4-v38 {
	    destring `var', replace force
	}
	rename v4 denom2000 //pop 25 and over
	gen hsgrad2000=v14+v15+v16+v17+v18+v19+v20+v21+v31+v32+v33+v34+v35+v36+v37+v38
	gen zipcode=ZCTA5
	merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) nogen ///
	    keepusing(hrrnum)
	collapse (sum) denom2000 hsgrad2000, by(hrrnum)
	gen hsgrad_pct2000=hsgrad2000/denom2000
	save ../temp/educ2000, replace
	
	insheet using "../external/ACS/ACS2007_2011/ACS_11_5YR_S1501_with_ann.csv", clear
	drop in 1/2
	keep v2 v34 v82
	rename v2 ZCTA5
	foreach var in v34 v82 {
	    destring `var', replace force
	}
	rename v34 denom2011 //pop 25 and over
	gen hsgrad2011=denom2011*v82/100
	gen zipcode=ZCTA5
	merge 1:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) nogen ///
	    keepusing(hrrnum)
	collapse (sum) denom2011 hsgrad2011, by(hrrnum)
	gen hsgrad_pct2011=hsgrad2011/denom2011
    save ../temp/educ2011, replace	
end

program get_age_race_sex
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest *_samp mover sex age) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)

    use ../temp/data_loaded.dta, clear
    keep if baseline_samp == 1
    keep if rel_yr_rit != 0
    generate fwgt = ${mover_weight}
    replace fwgt = ${nonmover_weight} if mover == 0

    merge 1:1 bene_id year using ../external_links/denom/denom_data.dta, ///
        assert(match using) keep(match) keepusing(race) nogenerate

    generate black = (race == 2)
    recode sex (0 = 1) (1 = 0)
    rename sex female

    collapse (mean) age black female [fw = fwgt], by(hrrnum year)
    collapse (mean) age black female, by(hrrnum)

    save ../temp/hrr_age_race_sex.dta, replace
end

program hrr_demographics
    use ../temp/income2000, clear
    merge 1:1 hrrnum using ../temp/income2011, assert(3) keep(3) nogen
    merge 1:1 hrrnum using ../temp/educ2000, assert(3) keep(3) nogen
    merge 1:1 hrrnum using ../temp/educ2011, assert(3) keep(3) nogen
    reshape long hsgrad_pct medianHHincome hsgrad denom, i(hrrnum) j(year)
    save ../temp/merge,replace
	
    keep hsgrad_pct medianHHincome hrrnum year
    save_data ../output/HRRYearDemographics, replace key(hrrnum year)
	
    use ../temp/merge, replace
    collapse (mean) medianHHincome denom hsgrad, by(hrrnum)
    generate hsgrad_pct = hsgrad/denom
    keep hsgrad_pct medianHHincome hrrnum

    merge 1:1 hrrnum using ../temp/hrr_urban.dta, assert(3) keep(3) nogenerate
    merge 1:1 hrrnum using ../temp/hrr_owner.dta, assert(3) keep(3) nogenerate
    merge 1:1 hrrnum using ../temp/hrr_one_person.dta, assert(3) keep(3) nogenerate
    merge 1:1 hrrnum using ../temp/hrr_foreign.dta, assert(3) keep(3) nogenerate
    merge 1:1 hrrnum using ../temp/hrr_age_race_sex.dta, assert(3) keep(3) nogenerate

    save_data ../output/HRRDemographics, replace key(hrrnum)
end

*Execute
main
