version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)

program main
    process_patient_health
end

program process_patient_health
    local patient_health = "num_cond hcc_com chr iez"
    load_data_main_model, ///
        mover_dataset(../external_links/compiled/CompiledPatYrDataMovers) ///
        nonmover_dataset(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        variables(bene_id year hrrnum hrr_orig hrr_dest `patient_health' *_samp mover) ///
        rhs(../external_links/rhs_matrix/rhs_matrix_noadj.dta) saving(../temp/data_loaded)
    use ../temp/data_loaded.dta, clear
    keep if rel_yr_rit != 0
    generate fwgt = ${mover_weight}
    replace fwgt = ${nonmover_weight} if mover == 0
    save ../temp/data_loaded_cleaned.dta, replace

    foreach health of local patient_health {
        use ../temp/data_loaded_cleaned.dta, clear
        keep if ${`health'_samp} == 1
        collapse (mean) `health' [fw = fwgt], by(hrrnum year)
        collapse (mean) `health', by(hrrnum)
        save ../temp/`health'.dta, replace
    }

    use ../temp/num_cond.dta, clear
    foreach health in hcc_com chr iez {
        merge 1:1 hrrnum using ../temp/`health'.dta, ///
            assert(match) keep(match) keepusing(`health') nogenerate
    }

    label variable hrrnum "HRR"
    label variable num_cond "Number of chronic conditions"
    label variable hcc_com "HCC score"
    label variable chr "Charlson Comorbidity Index"
    label variable iez "Number of Iezzoni chronic conditions"

    save_data ../output/HRRPatientHealth.dta, replace key(hrrnum)
end
	 
*Execute
main
