version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

set maxvar 32000

program main

    clean_1995
    clean_1996
    clean_1998
    clean_2000
    clean_2002
    clean_2004
    clean_2006
    clean_2008
    clean_2010
    clean_rand
    create_hrs

end

program clean_1995

    use hhidpn d88 d697 d698 d702m*  using "../external/HRS/ad95f2a", clear
    ren d88 move_ind
    ren d697 move_year
    ren d698 move_month
    ren d702m* move_reason*
    gen year=1995
    save "../temp/1995", replace

end

program clean_1996

    use hhidpn e88 e697 e698 e702m* using "../external/HRS/h96f4a.dta", clear
    ren e88 move_ind
    ren e697 move_year
    ren e698 move_month
    ren e702m* move_reason*
    gen year=1996
    save "../temp/1996", replace

end

program clean_1998

    use hhidpn f56 f1017 f1018 f1022m* using "../external/HRS/hd98f2b", clear
    ren f56 move_ind
    ren f1017 move_year
    ren f1018 move_month
    ren f1022m* move_reason*
	gen year=1998
    save "../temp/1998", replace

end

program clean_2000

    use hhidpn g56 g1104 g1105 g1109m* using "../external/HRS/h00f1c", clear
    ren g56 move_ind
    ren g1104 move_year
    ren g1105 move_month
    ren g1109m* move_reason*
	gen year=2000
    save "../temp/2000", replace

end

program clean_2002

    use hhidpn hx033 hb039 hb040 hb041m* using "../external/HRS/h02f2c", clear
    ren hx033 move_ind
    ren hb039 move_year
    ren hb040 move_month
    ren hb041m* move_reason*
	gen year=2002
    save "../temp/2002", replace

end

program clean_2004

    use hhidpn jx033 jb039 jb040 jb041m* using "../external/HRS/h04f1a", clear
    ren jx033 move_ind
	ren jb039 move_year
    ren jb040 move_month
    ren jb041m* move_reason*
	gen year=2004
    save "../temp/2004", replace

end

program clean_2006

    use hhidpn kx033 kb039 kb040 kb041m* using "../external/HRS/h06f2b", clear
    ren kx033 move_ind
    ren kb039 move_year
    ren kb040 move_month
    ren kb041m* move_reason*
	gen year=2006
    save "../temp/2006", replace

end

program clean_2008


    use hhidpn lx033 lb039 lb040 lb041m* using "../external/HRS/h08f1b", clear
    ren lx033 move_ind
    ren lb039 move_year
    ren lb040 move_month
    ren lb041m* move_reason*
	gen year=2008
    save "../temp/2008", replace

end

program clean_2010

    use hhidpn mx033 mb039 mb040 mb041m* using "../external/HRS/h10e1a", clear
    ren mx033 move_ind
    ren mb039 move_year
    ren mb040 move_month
    ren mb041m* move_reason*
	gen year=2010
    save "../temp/2010", replace

end

program clean_rand

    use hhidpn s*hhidpn inw* rawtsamp r*wthh r*wtresp s*wtresp r*agey_b s*agey_b ragender ///
        s*gender raracem s*racem rahispan s*hispan r*cenreg s*cenreg r*cendiv s*cendiv rabplace ///
        s*bplace raedyrs raeduc s*edyrs r*mstat s*mstat rarelig s*relig r*shlt s*shlt r*hltc ///
        s*hltc r*hosp s*hosp r*hsptim s*hsptim r*hspnit s*hspnit r*nrshom s*nrshom r*nrstim ///
        s*nrstim r*nrsnit s*nrsnit r*nhmliv s*nhmliv r*doctor s*doctor r*doctim s*doctim r*lbrf ///
        s*lbrf r*iearn s*iearn r*sayret s*sayret r*retemp s*retemp r*higov s*higov r*govmr ///
        s*govmr r*govmd s*govmd r*govva s*govva r*govot s*govot r*cholst r*flusht r*mammog ///
        r*breast r*papsm r*prost s*cholst s*flusht s*mammog s*breast s*papsm s*prost ///
        using "../external/HRS/rndhrs_l.dta", clear

    forvalues ind = 1/10 {

        foreach l in "r" "s" {

            foreach var in "wtresp" "agey_b" "cenreg" "cendiv" "mstat" "shlt" "hltc" ///
                "hosp" "hsptim" "hspnit" "nrshom" "nrstim" "nrsnit" "doctor" "doctim" "lbrf" ///
                "iearn" "sayret" "retemp" "higov" "govmr" "govmd" "govva" {

                 rename `l'`ind'`var' `l'`var'`ind'

            }

            if `ind' > 1 {

                rename `l'`ind'shltc `l'shltc`ind'

            }

            if `ind' > 2 {

                rename `l'`ind'nhmliv `l'nhmliv`ind'
                rename `l'`ind'cholst `l'cholst`ind'
                rename `l'`ind'flusht `l'flusht`ind'
                rename `l'`ind'mammog `l'mammog`ind'
                rename `l'`ind'breast `l'breast`ind'
                rename `l'`ind'papsm `l'papsm`ind'
                rename `l'`ind'prost `l'prost`ind'

            }

            if `ind' < 4 {

                rename `l'`ind'govot `l'govot`ind'

            }


        }

        foreach var in "hhidpn" "gender" "racem" "hispan" "bplace" "edyrs" "relig" {

            rename s`ind'`var' s`var'`ind'

        }

        rename r`ind'wthh rwthh`ind'

    }
            

    reshape long shhidpn inw rwthh rwtresp swtresp ragey_b sagey_b sgender ///
        sracem shispan rcenreg scenreg rcendiv scendiv sbplace ///
        sedyrs rmstat smstat srelig rshlt sshlt rhltc shltc rshltc sshltc rhosp shosp ///
        rhsptim shsptim rhspnit shspnit rnrshom snrshom rnrstim snrstim rnrsnit snrsnit ///
        rnhmliv snhmliv rdoctor sdoctor rdoctim sdoctim rlbrf slbrf riearn siearn ///
        rsayret ssayret rretemp sretemp rhigov shigov rgovmr sgovmr rgovmd sgovmd ///
        rgovva sgovva rgovot sgovot rcholst rflusht rmammog rbreast rpapsm rprost ///
        scholst sflusht smammog sbreast spapsm sprost, ///
        i(hhidpn rawtsamp raracem rahispan ragender rabplace rarelig raedyrs raeduc) j(wave)

    save "../temp/RAND", replace

end

program create_hrs

    clear

    foreach year in "1995" "1996" "1998" "2000" "2002" "2004" "2006" "2008" "2010" {

        append using "../temp/`year'"

    }


	gen wave = 1 if year == 1992
	replace wave = 2 if year == 1994 | year == 1993
	replace wave = 3 if year == 1995 | year == 1996
	replace wave = 4 if year == 1998
	replace wave = 5 if year == 2000
	replace wave = 6 if year == 2002
	replace wave = 7 if year == 2004
	replace wave = 8 if year == 2006
	replace wave = 9 if year == 2008
    replace wave = 10 if year == 2010

    drop year
    
	merge 1:1 hhidpn wave using "../temp/RAND", ///
        assert(match master using) keep(match master using) keepusing(*) nogen

    save_data ../output/HRS_for_restricted_analysis, replace key(hhidpn wave)

    drop if rcendiv==.|rcendiv==.m
	sort hhidpn wave
	gen moved = 0
	replace moved = 1 if rcendiv != rcendiv[_n-1] & hhidpn == hhidpn[_n-1]
    by hhidpn, sort: egen mover=max(moved)
    by hhidpn, sort: egen num_moves=total(moved)

    drop if num_moves>1 & num_moves !=.
    drop num_moves
    
    gen move_wave_temp=wave if moved==1
    by hhidpn, sort: egen move_wave=max(move_wave_temp)
    drop move_wave_temp
    gen relative_wave=.
    replace relative_wave=wave-move_wave if mover==1

    recode ragender 1=0 2=1, gen(Female)

    tab raracem, gen(race)
    rename race1 White
    rename race2 Black
    rename race3 Other
    rename rahispan Hispanic
    
    tab rarelig, gen(religion)
    rename religion1 Protestant
    rename religion2 Catholic
    rename religion3 Jewish
    rename religion4 None

    recode rmstat 2=1 3=1 5=4 6=4, gen(marriage_status_temp)
    tab marriage_status_temp, gen(marriage_status)
    drop marriage_status_temp
    rename marriage_status1 MarriedPartnered
    rename marriage_status2 SeparatedDivorced
    rename marriage_status3 Widowed
    rename marriage_status4 NeverMarried

    tab rcenreg, gen(region)
    rename region1 Northeast
    rename region2 Midwest
    rename region3 South
    rename region4 West

    tab rcendiv, gen(division)
    rename division1 NewEngland
    rename division2 MidAtlantic
    rename division3 ENCentral
    rename division4 WNCentral
    rename division5 SouthAtlantic
    rename division6 ESCentral
    rename division7 WSCentral
    rename division8 Mountain
    rename division9 Pacific

    tab rsayret, gen(retirement_status)
    rename retirement_status1 NotRetired
    rename retirement_status2 Retired
    rename retirement_status3 PartlyRetired

    gen Over79=ragey_b>79

    rename ragey_b Age
    rename riearn Earnings
    rename rshlt Health
    rename rshltc HealthChange
    rename rnhmliv LivesNursHome
    rename rdoctor VisitsDoctor
    rename rdoctim N_DoctorVisits
    rename rhosp HospStay
    rename rhsptim N_HospStay
    rename rhspnit T_HospNight
    rename rnrshom NursHomeStay
    rename rnrstim N_NursHomeStay
    rename rnrsnit T_NursHomeNight
    rename rhigov Some
    rename rgovmr Medicare
    rename rgovmd Medicaid
    rename rgovva ChampusVA
    rename rgovot OtherInsurance

    rename rcholst CholesterolTest
    rename rflusht FluShot
    rename rmammog Mammogram
    rename rbreast BreastCheck
    rename rpapsm PapSmear
    rename rprost ProstateExam

    gen Earnings_1000=Earnings/1000

    foreach n in "1" "2" {

        gen reason`n'=""
        replace reason`n'="Near/with children" if move_reason`n'==1
        replace reason`n'="Near/with relatives/friends" if move_reason`n'==2
        replace reason`n'="Health prob/services" if move_reason`n'==3
        replace reason`n'="Climate or weather" if move_reason`n'==4
        replace reason`n'="Leisure" if move_reason`n'==5
        replace reason`n'="Smaller/less expensive" if move_reason`n'==6
        replace reason`n'="Larger home/yard" if move_reason`n'==7
        replace reason`n'="Work/retirement" if move_reason`n'==8
        replace reason`n'="Marital status change" if move_reason`n'==9
        replace reason`n'="Public transportation" if move_reason`n'==10
        replace reason`n'="Closer to work" if move_reason`n'==11
        replace reason`n'="Shopping or consumption services" if move_reason`n'==12
        replace reason`n'="Old neighborhood or location bad" if move_reason`n'==20
        replace reason`n'="Dispossessed or forced to move" if move_reason`n'==21
        replace reason`n'="Old home too expensive" if move_reason`n'==22
        replace reason`n'="Moved into a house" if move_reason`n'==23
        replace reason`n'="Not happy in last location" if move_reason`n'==24
        replace reason`n'="Sold old home" if move_reason`n'==25
        replace reason`n'="Natural disaster" if move_reason`n'==26
        replace reason`n'="New neighborhood or location better" if move_reason`n'==30
        replace reason`n'="Cheaper area" if move_reason`n'==32
        replace reason`n'="Moved to retirement housing" if move_reason`n'==33
        replace reason`n'="Moved into area where had lives previously" if move_reason`n'==34
        replace reason`n'="New house or apartment has specific desirable features" if move_reason`n'==40
        replace reason`n'="Simpler house to take care of" if move_reason`n'==41
        replace reason`n'="Moved into previously owned property" if move_reason`n'==42
        replace reason`n'="Bought own or new home" if move_reason`n'==43
        replace reason`n'="Wanted to own instead of rent" if move_reason`n'==44
        replace reason`n'="In temporary housing" if move_reason`n'==45
        replace reason`n'="Moved into house where grew up" if move_reason`n'==46
        replace reason`n'="Desperation, nowhere else to go" if move_reason`n'==47
        replace reason`n'="Financial reasons" if move_reason`n'==48
        replace reason`n'="Family problems" if move_reason`n'==49
        replace reason`n'="Could not live by self" if move_reason`n'==50
        replace reason`n'="Wanted to live by self" if move_reason`n'==51
        replace reason`n'="Negative change in economic status" if move_reason`n'==52
        replace reason`n'="Positive change in economic status" if move_reason`n'==53
        replace reason`n'="Job change" if move_reason`n'==54
        replace reason`n'="Retirement" if move_reason`n'==55
        replace reason`n'="Retirement of spouse" if move_reason`n'==56
        replace reason`n'="To care for relative or family member" if move_reason`n'==57
        replace reason`n'="To move in with or nearby non-family member" if move_reason`n'==58
        replace reason`n'="Personal reasons" if move_reason`n'==59
        replace reason`n'="To get away from family members" if move_reason`n'==60
        replace reason`n'="To get away from non-family members" if move_reason`n'==61
        replace reason`n'="Positive change in health" if move_reason`n'==62
        replace reason`n'="Other" if move_reason`n'==97
        replace reason`n'="Don't know" if move_reason`n'==98
        replace reason`n'="Refused" if move_reason`n'==99    

    }

    save_data "../output/HRS", key(hhidpn wave) replace

end


** EXECUTE
main
