version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

global exp_vars "bene_id year LnRBU RBU LnTotExpn TotExpn"
global agesexv "f0_34  f35_44 f45_54 f55_59 f60_64 f65_69 f70_74 f75_79 f80_84 f85_89 f90_94 f95_gt m0_34  m35_44 m45_54 m55_59 m60_64 m65_69 m70_74 m75_79 m80_84 m85_89 m90_94 m95_gt"
global cmshcc "hcc1 hcc2 hcc5 hcc7 hcc8 hcc9 hcc10 hcc15 hcc16 hcc17 hcc18 hcc19 hcc21 hcc25 hcc26 hcc27 hcc31 hcc32 hcc33 hcc37 hcc38 hcc44 hcc45 hcc51 hcc52 hcc54 hcc55 hcc67 hcc68 hcc69 hcc70 hcc71 hcc72 hcc73 hcc74 hcc75 hcc77 hcc78 hcc79 hcc80 hcc81 hcc82 hcc83 hcc92 hcc95 hcc96 hcc100 hcc101 hcc104 hcc105 hcc107 hcc108 hcc111 hcc112 hcc119 hcc130 hcc131 hcc132 hcc148 hcc149 hcc150 hcc154 hcc155 hcc157 hcc158 hcc161 hcc164 hcc174 hcc176 hcc177"
global medicaid_and_disability "medicaid_female_aged medicaid_female_disabled medicaid_male_aged medicaid_male_disabled originallydisabled_female originallydisabled_male"
global condition_interactions "d_hcc5  d_hcc44  d_hcc51  d_hcc52  d_hcc107 dm_chf1  dm_cvd  chf_copd  copd_cvd_cad  rf_chf1  rf_chf_dm"
global cc "ami alzhdmta cataract copd diabetes hipfrac depressn ra_oa cncrbrst cncrprst cncrendm asthma hyperp hypoth alzh atrialfb chrnkidn chf glaucoma ischmcht osteoprs strketia cncrclrc cncrlung anemia hyperl hypert"
global cc_top5 "hypert hyperl ischmcht cataract ra_oa"
global cc_top10 "${cc_top5} anemia diabetes chf copd glaucoma"

program main
    use ${exp_vars} using ../external_links/compiled/CompiledPatYrDataMovers, clear
    append using ../external_links/compiled/CompiledPatYrDataNonMovers, keep(${exp_vars})
    merge 1:1 bene_id year using ../external/hcc/HCC , ///
        assert(2 3) keep(3) keepusing(*) nogen
    merge 1:1 bene_id year using ../external/sample/subsamples, ///
        assert(3) keep(3) keepusing(${cc}) nogen
    gen medicaid_female_aged = mcaid*(sex==2)*(1-disabl)
    gen medicaid_female_disabled = mcaid*(sex==2)*(disabl)
    gen medicaid_male_aged = mcaid*(sex==1)*(1-disabl)
    gen medicaid_male_disabled = mcaid*(sex==1)*(disabl)
    gen originallydisabled_female = origds*(sex==2)
    gen originallydisabled_male = origds*(sex==1)
    egen hcc_dm = rowmax(hcc15 hcc16 hcc17 hcc18 hcc19)
    gen hcc_chf = hcc80
    gen hcc_copd = hcc108
    egen hcc_cvd = rowmax(hcc95 hcc96 hcc100 hcc101)
    egen hcc_vd = rowmax(hcc104 hcc105) 
    egen hcc_cad = rowmax(hcc81 hcc82 hcc83)
    gen hcc_rf = hcc131
    gen dm_chf = hcc_dm*hcc_chf
    gen dm_cvd = hcc_dm*hcc_cvd
    gen chf_copd=hcc_chf*hcc_copd
    gen copd_cvd_cad = hcc_copd*hcc_cvd*hcc_cad
    gen rf_chf = hcc_rf*hcc_chf
    gen rf_chf_dm = hcc_rf*hcc_chf*hcc_dm
    gen dm_chf1=dm_chf*(rf_chf_dm==0)
    gen rf_chf1=rf_chf*(rf_chf_dm==0)
    gen d_hcc5 = disabl*hcc5
    gen d_hcc44 = disabl*hcc44
    gen d_hcc51 = disabl*hcc51
    gen d_hcc52 = disabl*hcc52
    gen d_hcc107 = disabl*hcc107
    egen num_cc = rowtotal(${cc})
    egen num_cc_top5 = rowtotal(${cc_top5})
    egen num_cc_top10 = rowtotal(${cc_top10})
    predict_score, ///
        lhs_variable(LnTotExpn) ///
        rhs_variables(${agesexv} ${cmshcc} ${medicaid_and_disability} ${condition_interactions}) ///
        score(sewd)
    predict_score, ///
        lhs_variable(TotExpn) ///
        rhs_variables(${agesexv} ${cmshcc} ${medicaid_and_disability} ${condition_interactions}) ///
        score(sewdl)
    predict_score, ///
        lhs_variable(LnTotExpn) ///
        rhs_variables(${cmshcc} dm_chf1  dm_cvd  chf_copd  copd_cvd_cad  rf_chf1  rf_chf_dm) ///
        score(send)
    predict_score, ///
        lhs_variable(TotExpn) ///
        rhs_variables(${cmshcc} dm_chf1  dm_cvd  chf_copd  copd_cvd_cad  rf_chf1  rf_chf_dm) ///
        score(sendl)
    predict_score, ///
        lhs_variable(TotExpn) ///
        rhs_variables(${cmshcc}) ///
        score(sendl2)
    predict_score, ///
        lhs_variable(LnRBU) ///
        rhs_variables (${cmshcc} dm_chf1  dm_cvd  chf_copd  copd_cvd_cad  rf_chf1  rf_chf_dm) ///
        score(sep)
    predict_score, ///
        lhs_variable(RBU) ///
        rhs_variables (${cmshcc} dm_chf1  dm_cvd  chf_copd  copd_cvd_cad  rf_chf1  rf_chf_dm) ///
        score(sepl)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(${cmshcc}) ///
        score(sep2)
    predict_score, lhs_variable(RBU) ///
        rhs_variables(${cmshcc}) ///
        score(sep2l)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(${cc}) ///
        score(secc)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(${cc_top5}) ///
        score(secc5)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(${cc_top10}) ///
        score(secc10)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(num_cc) ///
        score(sencc)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(num_cc_top5) ///
        score(sencc5)
    predict_score, lhs_variable(LnRBU) ///
        rhs_variables(num_cc_top10) ///
        score(sencc10)
    rename score_community sc
    gen lhcce=log(sewdl)
    gen lhcc=log(sendl)
    gen lhcc2=log(sendl2)
    egen num_hcc=rowtotal(${cmshcc})
    gen lnnhcc=log(num_hcc+1)
    save_data ../output/health_scores, replace key(bene_id year)
end

program predict_score
    syntax, lhs_variable(str) rhs_variables(str) score(str)

    cap drop predicted_spending mean_predicted_spending
    reg `lhs_variable' `rhs_variables'
    predict predicted_spending, xb
    sum predicted_spending, meanonly
    gen mean_predicted_spending = r(mean)
    gen `score' = predicted_spending/mean_predicted_spending
    cap drop predicted_spending mean_predicted_spending

end

**Execute
main
