/* These are macros that will generate annual data
 * Due to the way zip codes are defined in the denominator file, we need to define treatments
 * March - March.  The macros in this file will create claims files that are March-March */

%macro GenerateCarrierYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %CarrierVarNames(year=&year.);

    %if (&year. <= 2008 and &year. >= 1998) %then %do;
        data cartemp1 (&&keep&year. &&rename&year.);
            set carIn.carLNits&pct._&year. (OBS=&obs_num.);
            where &&c&year._from. > &startdate. and &&c&year._thru. <= &enddate.;
            year= &year.;
            run;
        data cartemp2 (&&keep&year2. &&rename&year2.);
            set carIn.carLNits&pct._&year2. (OBS=&obs_num.);
            where &&c&year2._from. > &startdate. and &&c&year2._thru. <= &enddate.;
            year= &year.;
            run;
        data cartemp;
            length upin $ &upin_length. npi $ &npi_length. provzip $ &zipcode_length.;
            set cartemp1 cartemp2;
            format upin $&upin_length.. npi $&npi_length..;
            run;
    %end;

%mend GenerateCarrierYear;

%macro GenerateOpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %OpClmsVarNames(year=&year.);

    /* Since we've merge two files, the current clm_id vars are no longer unique
     * I fix this below be generating a new, unique claim id */
        %if &year. <= 2008 and &year. >= 1998 %then %do;
        data opclmstemp;
            length upin $ &upin_length. npi $ &npi_length.;
            set opIn.opclms_&pct._&year. (&&keep&year. &&rename&year. obs=&obs_num.)
                opIn.opclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            year= &year.;
        run;
    %end;

%mend GenerateOpClmsYear;

%macro GenerateIpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %IpClmsVarNames(year=&year.);

    %if (&year. <= 2008 and &year. >= 1998) %then %do;
        data ipclmstemp;
            length upin $ &upin_length. npi $ &npi_length.;
            set ipIn.ipclms_&pct._&year. (&&keep&year. &&rename&year. obs=&obs_num.)
                ipIn.ipclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            year = &year.;
        run;
    %end;

%mend GenerateIpClmsYear;
