version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main

    generate_pat_location
    *generate_phys_location
    *generate_hrr_location

end

program generate_pat_location

    use bene_id year state_de hrrnum zipcode using ../external/denom/denom_data.dta, clear
    rename state_de pat_state
    rename zipcode pat_zipcode
    rename hrrnum pat_hrr
    gen census_reg4 = .
    replace census_reg4 = 1 if inlist(pat_state, 20, 22, 30, 47, 7, 41, 33, 39, 31)
    replace census_reg4 = 2 if inlist(pat_state, 49, 34, 42, 51, 21, 9, 8, 18, 44, 11, 10, 25, ///
                                                 1, 19, 45, 37, 4)
    replace census_reg4 = 3 if inlist(pat_state, 23, 36, 15, 14, 52, 24, 16, 26, 17, 28, 43, 35)
    replace census_reg4 = 4 if inlist(pat_state, 50, 38, 5, 29, 27, 13, 53, 6, 46, 3, 32, 2, 12)
    label define Lcensus_reg4 1 "Northeast" 2 "South" 3 "Midwest" 4 "West"
    label values census_reg4 Lcensus_reg4
    save_data "../output/PatientLocation.dta", replace key(bene_id year)

end

program generate_phys_location

    load_ssa_codes
    insheet using ../temp/physloc_all.csv, comma clear names
    merge m:1 phys_state using ../temp/ssa_codes.dta, ///
        assert(match master using) keep(master match) keepusing(*)
    replace phys_state = ssa if _merge==3
    drop _merge ssa
    replace phys_state = "" if phys_state=="AS"|phys_state=="GU"|phys_state=="CM"|phys_state=="VI"
    destring phys_state, replace
    save ../temp/temp1, replace
    
    sort phys_id year fileyear
    foreach loc in state hrr zipcode {
        bys phys_id year phys_`loc': gen `loc'_count = _N
        bys phys_id year: egen `loc'_count_max = max(`loc'_count)
        gen `loc'_tmp = phys_`loc' if `loc'_count==`loc'_count_max 
        bys phys_id year: egen `loc'_tmp2 = min(`loc'_tmp)
        replace phys_`loc' = `loc'_tmp2
        duplicates tag phys_id year, gen(tag1)
        duplicates tag phys_id year phys_`loc', gen(tag2)
        assert tag1==tag2
        drop *tmp* *tag* *count*
    }
    collapse (firstnm) phys_state phys_hrr phys_zipcode, by(phys_id year)
    
    save_data "../output/PhysicianLocation.dta", replace key(phys_id year)

end

    program load_ssa_codes
        use abbr ssa using ../external/state/msabea.dta, clear
        replace ssa = substr(ssa, 1, 2)
        destring ssa, replace
        collapse (firstnm) ssa, by(abbr)
        rename abbr phys_state
        tostring ssa, replace
        save ../temp/ssa_codes.dta, replace
    end

program generate_hrr_location

    load_latlon_data

    insheet using ../external/geo/ziphrrxwalk.csv, comma names clear
    keep zipcode hrrnum
    tostring zipcode, replace
    replace zipcode = "0" + zipcode if length(zipcode)==4
    merge 1:1 zipcode using ../temp/zipcode.dta, ///
        assert(match using master) keep(master match) keepusing(*)
    gen lat_wgt = lat*pop
    gen lon_wgt = lon*pop
    collapse (sum) lat_wgt lon_wgt pop, by(hrrnum)
    gen lat = lat_wgt/pop
    gen lon = lon_wgt/pop
    drop *wgt* pop
    save_data "../output/hrr_latlon.dta", replace key(hrrnum)

end

    program load_latlon_data 

        use ../external/state/zcta5.dta, clear
        duplicates tag zipcode, gen(tag)
        save ../temp/zipcode_dup, replace
        keep if tag == 0
        drop tag
        save ../temp/zipcode_nodup, replace
        use ../temp/zipcode_dup, clear
        keep if tag > 0
        collapse (sum) pop (mean) lat lon, by(zipcode)
        append using ../temp/zipcode_nodup
        save ../temp/zipcode, replace

    end

*EXECUTE
main
