options pagesize=200;
options nocenter;
** These options create detalied log files;
options mprint mlogic;
options spool;
options errorabend;
options msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options filelocks=none;

** load in the libraries with the data;
libname carIn "../external/carrier";
libname opIn "../external/outpatient";
libname ipIn "../external/inpatient";
libname pos "../external/pos";
libname zip "../external/zip";
libname cbsa "../external/cbsa";
libname bene "../external/bene";
libname drg "../external/rbu/DRG";
libname rvu "../external/rbu/RVU";
libname cmswi "../external/rbu/CMS_Wage_Indices";

** load in library to export data to;
libname out "../temp";

** load in additional macros that perform random data tasks;
%include "./SASmacros/SampleCreationMacros.sas";
%include "./SASmacros/LoadPhysCrosswalks.sas";
%include "./SASmacros/DataMacros.sas";
%include "./SASmacros/PhysMacros.sas";
%include "./SASmacros/VarNames.sas";

** load files with macros that process the annual files;
%include "./SASmacros/ProcessCarrier.sas";
%include "./SASmacros/ProcessOp.sas";
%include "./SASmacros/ProcessIp.sas";

** load files with macros that allow me to use macro arrays;
%include "../external/lib/sas/ARRAY.sas";
%include "../external/lib/sas/DO_OVER.SAS";
%include "../external/lib/sas/NUMLIST.SAS";
%include "../external/lib/sas/HASHMERGE.sas";

** Setting macros for variable names and lengths;
%let physid = phys_id;
%let rawid = bene_id;
%let obs_num = 200;
%let npi_length = 12;
%let upin_length = 8;
%let bene_id_length = 15;
%let phys_id_length = 19;
%let zipcode_length = 5;

* load physician crosswalks;
%LoadPhysCrosswalks();

%macro main(pct=, startyear=, endyear=);

    %do year = &startyear. %to &endyear.;

        %ProcessOutpatient(pct=&pct., year=&year.);
        %ProcessCarrier(pct=&pct., year=&year.);
        %ProcessInpatient(pct=&pct., year=&year.);

        data out.physloc_&year.;
            set opclmstemp (KEEP = &physid. year fileYear hrrnum state zipcode RENAME=(hrrnum=phys_hrr))
                ipclmstemp (KEEP = &physid. year fileYear hrrnum state zipcode RENAME=(hrrnum=phys_hrr))
                cartemp (KEEP = &physid. year fileYear hrrnum state zipcode RENAME=(hrrnum=phys_hrr));
        run;

        proc sort data=out.physloc_&year. nodupkey;
            by &physid. year fileYear phys_hrr state zipcode;
        run;

    %end;

    data out.physloc_all (RENAME=(state=phys_state zipcode=phys_zipcode));
        set %RepeatN(pfx=out.physloc_, Nlow=&startyear., Nhigh=&endyear.);
    run;

    proc sort data = out.physloc_all;
        by &physid. year;
    run;

    proc export data=out.physloc_all
        outfile="../temp/physloc_all.csv"
        dbms=csv
        replace;
    run;

%mend;

** EXECUTE;
%main(pct=20, startyear=1998, endyear=1998);

