version 12
clear all
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"


program main

    global Mover_hrrvars = "hrr_orig hrr_dest"
    global NonMover_hrrvars = "hrrnum"
    forvalues y = 1998/2008 {
        foreach mover in Mover NonMover {
            load_data, mover(`mover') year(`y')
        }
        merge_data, year(`y')
    }
    clear
    forvalues y = 1998/2008 {
        append using ../temp/matched`y'.dta
    }
    save_data ../output/MatchedPatientSample, key(bene_id_mover year) replace
end

program load_data
    syntax, year(real) mover(str)

    use bene_id year ${`mover'_hrrvars} age race sex ///
        if year==`year' in 1/${obsno} ///
        using "../external_links/output_local/CompiledPatYrData`mover's.dta", clear
    local mover = lower("`mover'")
    rename bene_id bene_id_`mover'
    gen white = (race==1)
    egen age_grp = cut(age), at(65, 70, 75, 80, 85, 90, 100)
    compress
    save ../temp/`mover's`year'.dta, replace

end

program merge_data
    syntax, year(real)

    use ../temp/movers`year'.dta, clear

    foreach type in orig dest {
        rename hrr_`type' hrrnum
        *The following joinby leaves a small number of movers unmatched with non-movers.
        *If we increase the number of nonmovers we keep from the raw data, this issue may
        *be resolved.
        joinby age_grp sex white hrrnum using ../temp/nonmovers`year'.dta, unm(master)
        rename bene_id_nonmover bene_id_nonmover_`type'
        sort bene_id_mover year
        set seed 11084353
        gen rand = 1000000*runiform()
        bys bene_id_mover: egen randmax = max(rand)
        keep if rand==randmax
        bys bene_id_mover: gen tag = (_n==1)
        keep if tag==1
        drop hrrnum rand* _merge tag
    }

    keep bene_id* year
    save ../temp/matched`year'.dta, replace
    
end


* EXECUTE
main

