version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries
global obsno = "L"

program main
	generate_baseline_sample
	generate_subsamples
end

program generate_baseline_sample

    use bene_id year a_mo_cnt b_mo_cnt age HMO rel_yr_rit in 1/${obsno} ///
        using ../external_links/chars/CharsPatientYear.dta, clear
    merge m:1 bene_id using ../external_links/chars/CharsPatient.dta, ///
        assert(3) keep(3) nogen keepusing(sex sdod sdob hmo mult_mover mover ///
        state_orig state_dest hrr_orig hrr_dest)
    merge 1:1 bene_id year using ../external_links/treat/TreatPatientYear.dta, ///
        assert(1 3) keep(1 3) keepusing(RBU* TotExpn LnTotExpn IpDays LnRBU) 
	foreach outcome in RBU TotExpn LnTotExpn IpDays LnRBU IpDays RBU_missing {
            replace `outcome' = 0 if _merge==1 & HMO!=1
    }
    save ../temp/data_prepped, replace

    gen_month_condition

    assert RBU_missing!=1
	
    recode hmo 1=0 0=1, gen(nonhmo)
    recode HMO 1=0 0=1, gen(nonhmo_yr)
    recode mult_mover 1=0 0=1, gen(non_mult_mover)
    gen over65 = age>= 65 & age!=.
    gen under99 = age<= 99 & age!=.

    keep bene_id year nonhmo nonhmo_yr non_mult_mover over65 ///
		under99 partA_pass partA_pass_yr partB_pass partB_pass_yr mover 

    label variable partA_pass ///
        "Has Part A in all months the patient is 65-99 years old"
	label variable partA_pass_yr ///
        "Has Part A in all months this year if the patient is 65-99 years old"
    label variable partB_pass ///
        "Has Part B in all months the patient is 65-99 years old"
    label variable partB_pass_yr ///
        "Has Part B in all months this year if the patient is 65-99 years old"
    label variable nonhmo "Never in an HMO"
    label variable nonhmo_yr "Not in an HMO this year"
    label variable non_mult_mover "Not a multiple mover"
    label variable over65 "At least 65 years old"
    label variable under99 "At most 99 years old"
    label variable mover "Mover"

    save  ../temp/sample_criteria_temp, replace

    keep if non_mult_mover & over65 & under99 & partA_pass_yr & partB_pass_yr & nonhmo_yr==1
    keep bene_id year

    save ../temp/temp_baseline, replace
    define_true_movers
    use ../temp/temp_baseline, clear
    merge m:1 bene_id using ../temp/true_false_list, assert(1 3) keep(1 3) keepusing(*)
    replace true=_merge==1|true==1
    replace true_l=_merge==1|true_l==1
    replace true_h=_merge==1|true_h==1
    drop _merge
    save  ../temp/sample_criteria_true_temp, replace
    keep if true==1
    keep bene_id year
    save_data ../output/baseline_sample, replace key(bene_id year)

    use ../temp/sample_criteria_temp, clear
    merge 1:1 bene_id year using ../temp/sample_criteria_true_temp, ///
        assert(1 3) keep(1 3) keepusing(*) nogen
    save_data ../output/sample_criteria, replace key(bene_id year)
    
end

    program gen_month_condition

        format sdod %td
        gen death_analysis_yr = year(sdod)
		replace death_analysis_yr=death_analysis_yr-1 if month(sdod)<=3
	    gen death_analysis_mo = month(sdod)-3
		replace death_analysis_mo=death_analysis_mo + 12 if month(sdod)<=3

        format sdob %td
        gen birth_analysis_yr = year(sdob)
		replace birth_analysis_yr=birth_analysis_yr-1 if month(sdob)<=3
        gen birth_analysis_mo = month(sdob)-3
		replace birth_analysis_mo=birth_analysis_mo+12 if month(sdob)<=3
			
        gen qual65_yr = birth_analysis_yr + 65
        assert year==qual65_yr if age==65
		
        gen partA_pass_yr = (a_mo_cnt== 12 | (a_mo_cnt>=death_analysis_mo & ///
			death_analysis_yr==year) | (a_mo_cnt>=(12-birth_analysis_mo) & qual65_yr==year))
        replace partA_pass_yr = . if age<65 | age>99
        bys bene_id: egen partA_pass = min(partA_pass_yr)
        bys bene_id: egen check = sd(partA_pass)
        assert check==0 | check==.
        drop check
		
        gen partB_pass_yr = (b_mo_cnt== 12|(b_mo_cnt>=death_analysis_mo & ///
			death_analysis_yr==year) | (b_mo_cnt>=(12-birth_analysis_mo) & qual65_yr==year))
        replace partB_pass_yr = . if age<65 | age>99
        bys bene_id: egen partB_pass = min(partB_pass_yr)
        bys bene_id: egen check = sd(partB_pass)
        assert check==0 | check==.
        drop check
		
    end

program define_true_movers
    merge 1:1 bene_id year using ../external/ClaimShare/claim_share_data_mover, ///
        assert(1 2 3) keep(3) keepusing(rel_yr_rit ClaimCnt*) nogen
    gen ClaimCnt_decomp=ClaimCnt0_frac_dest/(ClaimCnt0_frac_dest+ClaimCnt0_frac_orig)
    bys bene_id: egen avg_pre_orig_temp=total(ClaimCnt0_frac_orig) if rel_yr_rit<0
    bys bene_id: egen avg_pre_dest_temp=total(ClaimCnt0_frac_dest) if rel_yr_rit<0
    gen avg_pre_cs_temp=avg_pre_dest_temp/(avg_pre_orig_temp+avg_pre_dest_temp)
    bys bene_id: egen avg_post_orig_temp=total(ClaimCnt0_frac_orig) if rel_yr_rit>0
    bys bene_id: egen avg_post_dest_temp=total(ClaimCnt0_frac_dest) if rel_yr_rit>0
    gen avg_post_cs_temp=avg_post_dest_temp/(avg_post_orig_temp+avg_post_dest_temp)
    bys bene_id: egen avg_pre_cs=max(avg_pre_cs_temp)
    bys bene_id: egen avg_post_cs=max(avg_post_cs_temp)
    gen pre_post_cs_diff=avg_post_cs-avg_pre_cs
    keep bene_id year pre_post_cs_diff avg_pre_cs avg_post_cs
    gen true = ///
        (pre_post_cs_diff>=0.75& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    gen true_l = ///
        (pre_post_cs_diff>=0.6& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    gen true_h = ///
        (pre_post_cs_diff>=0.9& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    bys bene_id: keep if _n==1
    keep bene_id true true_l true_h
    save ../temp/true_false_list, replace
end

program generate_subsamples

    define_snowbirds

    use bene_id year age sex RBU* IpDays mover mult_mover *_orig *_dest ///
		LnRBU sdod rel_yr_rit using "../temp/data_prepped", clear
	merge 1:1 bene_id year using ../output/sample_criteria, assert(3) keep (3) ///
		keepusing(*) nogen
    merge 1:1 bene_id year using "../external_links/cc/ChronicCondition.dta", ///
        assert(1 3) keep(1 3) nogen keepusing(ami alzh atrialfb cataract chrnkidn copd ///
        chf diabetes glaucoma hipfrac ischmcht depressn osteoprs ra_oa strketia cncrbrst ///
		cncrclrc cncrprst cncrlung alzhdmta cncrendm anemia asthma hyperl hypert hyperp hypoth)

	merge 1:1 bene_id year using "../output/baseline_sample", assert(1 3) keep(3) keepusing(*)
	gen baseline_samp=(_merge==3)
	drop _merge

	*Make chronic condition flags
	gen_cc

    gen death_relyrT = rel_yr_rit if year(sdod)==year
	bys bene_id: egen death_relyr=min(death_relyrT)
	
    by bene_id: egen rel_yr_min=min(rel_yr_rit)
    by bene_id: egen rel_yr_max=max(rel_yr_rit)

	create_true_balanced_panel, before_year(-2) after_year(-1) varname(pre_move)
	create_true_balanced_panel, before_year(-7) after_year(1) varname(tl_move)
	create_true_balanced_panel, before_year(-4) after_year(4) varname(tm_move)
	create_true_balanced_panel, before_year(-1) after_year(7) varname(te_move)

    recode sex 1=0 0=1, gen(female)
    rename sex male

    gen cond_flag_temp=1 if any_cond==1 & rel_yr_rit<=-1 & rel_yr_rit>=-2
    bys bene_id: egen has_cc_p=min(cond_flag_temp) if pre_move==1
	bys bene_id: egen mean_num_cond=mean(num_cond)
	xtile cond_group=mean_num_cond, nq(2)
	gen blw_cc_a = cond_group==1
	gen abv_cc_a = cond_group==2
	xtile cc_q=mean_num_cond, nq(4)
	gen cc_q1 = cc_q==1
	gen cc_q2 = cc_q==2
	gen cc_q3 = cc_q==3
	gen cc_q4 = cc_q==4

    gen hosp_flag_temp=1 if (IpDays>=1 & IpDays!=. & rel_yr_rit==-2) | ///
        (IpDays>=1 & IpDays!=. & rel_yr_rit==-1) 
    bys bene_id: egen has_hp_p=min(hosp_flag_temp) if pre_move==1
	bys bene_id: egen mean_num_hosp=mean(IpDays)
	xtile hosp_group=mean_num_hosp, nq(2)
	gen blw_hp_a = hosp_group==1
	gen abv_hp_a = hosp_group==2
	
	replace has_cc_p=0 if has_cc_p==. & pre_move==1
    replace has_hp_p=0 if has_hp_p==. & pre_move==1	
	recode has_cc_p (1=0) (0=1), gen(no_cc_p)
	recode has_hp_p (1=0) (0=1), gen(no_hp_p)

    xtile age_groupT=age if mover==1 & pre_move==1 & rel_yr_rit==-1, nq(4)
    bys bene_id: egen age_group=min(age_groupT)
    gen age_q1_p=age_group==1 if pre_move==1
    gen age_q2_p=age_group==2 if pre_move==1
    gen age_q3_p=age_group==3 if pre_move==1
    gen age_q4_p=age_group==4 if pre_move==1
	bys bene_id: egen mean_age=mean(age)
	xtile mean_age_group=mean_age, nq(4)
	gen age_q1_a=mean_age_group==1
	gen age_q2_a=mean_age_group==2
	gen age_q3_a=mean_age_group==3
	gen age_q4_a=mean_age_group==4

    gen RBU_temp=RBU if rel_yr_rit==-2 | rel_yr_rit==-1
    bys bene_id: egen mean_RBU_temp=mean(RBU_temp)
    xtile RBU_groupT=mean_RBU_temp if pre_move==1, nq(2)
    bys bene_id: egen RBU_group=min(RBU_groupT)
    gen blw_RBU_p=RBU_group==1 if pre_move==1
    gen abv_RBU_p=RBU_group==2 if pre_move==1
	bys bene_id: egen mean_RBU=mean(RBU)
	xtile mean_RBU_group=mean_RBU, nq(2)
	gen blw_RBU_a=mean_RBU_group==1
	gen abv_RBU_a=mean_RBU_group==2
	
	drop cond_flag_temp mean_num_cond cond_group hosp_flag_temp age_groupT age_group ///
		RBU_temp mean_RBU_temp RBU_groupT RBU_group mean_num_hosp hosp_group mean_age ///
		mean_age_group

    merge m:1 bene_id using "../temp/PatientSnowbirds_pat.dta", ///
        assert(1 3) keep(1 3) nogen keepusing(*)

	gen nondead=sdod==.
	gen nosnowbird=snowbirdClaimCntp10==0
	gen nondh = nondead ==1 & nonhmo==1
	bys bene_id: egen min_year=min(year)
	bys bene_id: egen years_samp=count(year)
	gen nonatr=years_samp>=(2008-min_year+1)
	replace nonatr=0 if nonhmo==0 | partA_pass==0 | partB_pass==0 | nondead==0
	drop min_year years_samp partA_pass partB_pass
	
	gen cc_samp = year>1998
	
	gen first_half=year<=2003
	gen second_half=year>=2004
	gen includes_moveT=rel_yr_rit ==0
	bys bene_id first_half (year): egen includes_move=max(includes_moveT)
	replace first_half =0 if includes_move==0 & mover==1
	replace second_half =0 if includes_move==0 & mover==1
	gen half_samp = first_half==1 | second_half==1

    gen first_third=year<2002
    gen second_third=year>2001&year<2006
    gen third_third=year>2005
    gen third=.
    replace third=1 if first_third
    replace third=2 if second_third
    replace third=3 if third_third
    bys bene_id third (year): egen includes_move_third=max(includes_moveT)
    replace first_third =0 if includes_move_third==0 & mover==1
	replace second_third =0 if includes_move_third==0 & mover==1
	replace third_third =0 if includes_move_third==0 & mover==1
	gen third_samp = first_third==1 | second_third==1 | third_third==1
	
	foreach loc in orig dest {
        rename hrr_`loc' hrrnum
        merge m:1 hrrnum using ../external/Location/hrr_latlon, ///
            assert(1 3) keep(1 3) keepusing(*) nogen
        rename lat lat_`loc'
        rename lon lon_`loc'
        rename hrrnum hrr_`loc'
        rename state_`loc' ssa_code
        merge m:1 ssa_code using ../external/Geography/state_codes, ///
            assert(1 3) keep(1 3) keepusing(*) nogen
        merge m:1 state using ../external/Geography/state_regions_crosswalk, ///
            assert(1 3) keep(1 3) keepusing(*) nogen
        drop state
        rename ssa_code state_`loc'
        rename census_region census_region_`loc'
        rename census_division census_division_`loc'
        rename bea_region bea_region_`loc'
    }
	
    vincenty lat_orig lon_orig lat_dest lon_dest, v(distance)
    gen nf = state_dest!=10 | mover==0
    gen nfac = (state_dest!=10&state_dest!=3&state_dest!=5) | mover==0
	gen xs = state_orig!=state_dest | mover==0
    gen xcr = census_region_orig!=census_region_dest | mover==0
    gen xcd = census_division_orig!=census_division_dest | mover==0
    gen xbr = bea_region_orig!=bea_region_dest | mover==0
    gen ov100 = (distance>100&distance!=.) | mover==0
    gen ov300 = (distance>300&distance!=.) | mover==0
    gen ov1000 = (distance>1000&distance!=.) | mover==0

    gen rd1=(rel_yr_rit>-2 & rel_yr_rit<2 & rel_yr_rit!=.) | mover==0
    gen rd2=(rel_yr_rit>-3 & rel_yr_rit<3 & rel_yr_rit!=.) | mover==0
    gen rd3=(rel_yr_rit>-4 & rel_yr_rit<4 & rel_yr_rit!=.) | mover==0
    gen rd5=(rel_yr_rit>-6 & rel_yr_rit<6 & rel_yr_rit!=.) | mover==0
    
    label variable male ""
    label variable mover ""
    label variable female ""
	
	label variable has_cc_p "Has Chronic Condition in years -1 or -2"
	label variable no_cc_p "Has No Chronic Condition in years -1 or -2"
	label variable has_hp_p "Has Hospitalization in years -1 or -2"
	label variable no_hp_p "Has No Hospitalization in years -1 or -2"
	label variable age_q1_p "First Quartile of Age, Pre-Move"
	label variable age_q2_p "Second Quartile of Age, Pre-Move"
	label variable age_q3_p "Third Quartile of Age, Pre-Move"
	label variable age_q4_p "Fourth Quartile of Age, Pre-Move"
	label variable blw_RBU_p "Bottom Half of RBU, Pre-Move"
	label variable abv_RBU_p "Top Half of RBU, Pre-Move"
	
	label variable abv_cc_a "Top Half of Avg Num of Chronic Conditions"
	label variable blw_cc_a "Bottom Half of Avg Num of Chronic Conditions"
	label variable abv_hp_a "Top Half of Avg Num of Hospitalization"
	label variable blw_hp_a "Bottom Half of Avg Num Hospitalization"
	label variable age_q1_a "First Quartile of Age, Avg"
	label variable age_q2_a "Second Quartile of Age, Avg"
	label variable age_q3_a "Third Quartile of Age, Avg"
	label variable age_q4_a "Fourth Quartile of Age, Avg"
	label variable blw_RBU_a "Bottom Half of RBU, Avg"
	label variable abv_RBU_a "Top Half of RBU, Avg"

    label variable nf "Mover not to Florida or non-mover"
    label variable nfac "Mover not Florida, Arizona, or California or non-mover"
	label variable xs "Cross-state mover or non-mover"
    label variable xcr "Cross-census-region mover or non-mover"
    label variable xcd "Cross-census division mover or non-mover"
    label variable xbr "Cross-BEA-region mover or non-mover"
    label variable ov100 "Over-100-miles mover or non-mover"
    label variable ov300 "Over-300-miles mover or non-mover"
    label variable ov1000 "Over-1000-miles mover or non-mover"

    label variable rd1 "Relative years -1 to 1 or non-mover"
    label variable rd2 "Relative years -2 to 2 or non-mover"
    label variable rd3 "Relative years -3 to 3 or non-mover"
    label variable rd5 "Relative years -5 to 5 or non-mover"

    keep bene_id year rel_yr_rit mover male female age_q*  *_move has_cc_p no_cc_p ///
		has_hp_p no_hp_p abv_cc_a blw_cc_a abv_hp_a blw_hp_a snowbird* ov* x* any_cond ///
        num_cond ami-hypoth blw_RBU_* abv_RBU* nonhmo nondead nosnowbird nondh nonatr ///
        first_half second_half half_samp first_third second_third third_third third_samp cc_samp ///
        nf nfac rd* cc_q*

    save_data "../output/subsamples", replace key(bene_id year)

end

    program define_snowbirds
        load_data
        define_snowbird_pat, pcts(10 30)
    end

        program load_data
            use bene_id year age hrrnum rel_yr_rit ///
                using ../external_links/chars/CharsPatientYear.dta, clear
            merge 1:1 bene_id year using "../output/baseline_sample", ///
                assert(1 3) keep(3) nogen keepusing(*)
            merge m:1 bene_id using ../external_links/chars/CharsPatient.dta, ///
                assert(2 3) keep(3) nogen keepusing( *mover* hrr_orig hrr_dest)
            keep if mover==1 & mult_mover==0
            egen gbene_id = group(bene_id)
            xtset gbene_id year
            gen next_hrr = F.hrrnum
            gen prev_hrr = L.hrrnum
            drop gbene_id
            xtset, clear
            merge 1:m bene_id year using ../external_links/treat/TreatHrrPatientDocYear, ///
                assert(match using master) keep(master match) ///
                keepusing(ClaimCnt phys_hrr phys_id)
            
            replace ClaimCnt = 0 if _merge==1
            assert phys_hrr!=. if _merge!=1
            drop _merge

            compress
            save ../temp/merged_data, replace

        end

        program define_snowbird_pat
            syntax, pcts(str) [outcomes(str)]

            use ../temp/merged_data, clear

            foreach c in 1 3 {
                foreach metric in `outcomes' ClaimCnt {
                    gen before_`metric'`c' = `metric' if (rel_yr_rit<=-`c')
                    gen dest_before_`metric'`c' = ///
                        `metric' if (hrr_dest==phys_hrr & rel_yr_rit<=-`c')
                    gen after_`metric'`c' = `metric' if (rel_yr_rit>=`c')
                    gen orig_after_`metric'`c' = `metric' if (hrr_orig==phys_hrr & rel_yr_rit>=`c')
                }
            }

            collapse (sum) before_* after_* dest_before_* orig_after_*, by(bene_id)

            foreach c in 1 3 {
                foreach metric in `outcomes' ClaimCnt {
                    gen dest_before_frac_`metric'`c' = ///
                        100*(dest_before_`metric'`c'/before_`metric'`c')
                    gen orig_after_frac_`metric'`c' = ///
                        100*(orig_after_`metric'`c'/after_`metric'`c')
                }
                foreach pct in `pcts' {
                    foreach metric in `outcomes' ClaimCnt {
                        gen snowbird`metric'`c'p`pct' = ///
                            (dest_before_frac_`metric'`c'>`pct' ///
                                & dest_before_frac_`metric'`c'!=.)  | ///
                            (orig_after_frac_`metric'`c'>`pct' ///
                                & orig_after_frac_`metric'`c'!=.)
                        label variable snowbird`metric'`c'p`pct' ///
                            "Snowbird: `metric' >`pct'% in destination before move or in origin after move"
                    }
                }
            }

            foreach pct in `pcts' {
                foreach metric in `outcomes' ClaimCnt {
                    rename snowbird`metric'1p`pct' snowbird`metric'p`pct'
                }
            }

            keep bene_id snowbird*

            compress
            save ../temp/PatientSnowbirds_pat.dta, replace

        end

	program define create_true_balanced_panel
        syntax, before_year(real) after_year(real) varname(string)
		
		gen balanced_panel=0
        forvalues year = `before_year'/`after_year' {
			replace balanced_panel=1 if rel_yr_rit==`year' & baseline_samp==1
		}
		
		bys bene_id: egen total_balanced_panel = total(balanced_panel)
		by bene_id: gen `varname' = total_balanced_panel==`after_year'-`before_year'+1
		
		if "`varname'"!="pre_move" {
			replace `varname'=0 if rel_yr_rit<`before_year' | rel_yr_rit > `after_year'
			replace `varname'=1 if mover==0
		}
		
		cap drop balanced_panel
		cap drop total_balanced_panel
    end

*EXECUTE
main
