version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries


program main
    practice_styles_PCP
    practice_styles_cardiologist
    patient_preferences
    hrr_level_data
end

program practice_styles_PCP
    use Q1 Q9* Q14 Q30 Zip using ../external/skinner/stata/Private_National-PCP_data, clear
    *drop if have missing zipcode
    drop if Zip==""|Q1==9
    rename Zip zipcode
    merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(1 2 3) keep(3) nogen ///
        keepusing(hrrnum)
    *drop if only 1 doctor in an HRR
    bys hrrnum:egen num_pcp=count(hrr)
    drop if num_pcp==1
    *drop if missing answers to all intensive care/palliative care questions
    drop if (Q9c==9&Q9e==9&Q9d==9&Q9f==9)
    *cowboy if provide at least 1 of the 3 intensive care most of the time or always/almost always
    gen cowboy_pcp=(inlist(Q9c,1,2)|inlist(Q9d,1,2)|inlist(Q9e,1,2))
    *comforter if discuss palliative care always/almost always
    gen comforter_pcp=(Q9f==1|Q9f==2)
    *frequency of follow-up
    gen high_followup_pcp=Q14<3
    gen low_followup_pcp=Q14>6 
    sum high_followup_pcp low_followup_pcp cowboy_pcp comforter_pcp num_pcp
    bys hrrnum: gen n=_n
    collapse high_followup_pcp low_followup_pcp cowboy_pcp comforter_pcp num_pcp, by(hrrnum)
    save ../temp/pcp, replace
end

program practice_styles_cardiologist
    use Q1 Q10* Q11* Q14 Q30 Zip using ../external/skinner/stata/private_cardiologist_data, clear
    *drop if do not self identify as cardiologist, have missing zipcode, missing practice type
    drop if Q30!=4|Zip==""|Q1==9
    rename Zip zipcode
    merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(2 3) keep(3) nogen ///
        keepusing(hrrnum)
    *drop if only 1 doctor in an HRR
    bys hrrnum:egen num_card=count(hrr)
    drop if num_card==1
    *drop if missing answers to all intensive care/palliative care questions
    drop if (Q10a==9&Q10c==9&Q10d==9&Q10e==9&Q11c==9&Q11d==9&Q11e==9&Q11f==9)
    *this leaves us with 512 cardiologists while the Cutler-Skinner paper also has additional
    *(not clearly specified). Their sample is 509 cardiologists.
	
    *cowboy if provide at least 1 of the 3 intensive care to both patients
    gen cowboy_card=(inlist(Q10a,1,2)|inlist(Q10c,1,2)|inlist(Q10d,1,2))& ///
        (inlist(Q11c,1,2)|inlist(Q11d,1,2)|inlist(Q11e,1,2))
    *comforter if suggest palliative care always/almost always to both patients
    gen comforter_card=(Q11f==1|Q11f==2)&(Q10e==1|Q10e==2)
    *frequency of followups
    gen high_followup_card=Q14<4
    gen low_followup_card=Q14>12
    sum high_followup_card low_followup_card comforter_card cowboy_card num_card
    bys hrrnum: gen n=_n
    collapse high_followup_card low_followup_card comforter_card cowboy_card num_card, by(hrrnum)
    save ../temp/card, replace
end

program patient_preferences
    use B10 E3 E4 E12 E13 E14 zip2 using ../external/skinner/stata/PatientsData_Nationwide, clear
    recode E3 E4 E12 E13 E14 B10 (9=.)
    rename zip2 zipcode
    merge n:1 zipcode using ../external/xwalk/ziphrrxwalk, assert(2 3) keep(3) nogen ///
        keepusing(hrrnum)
    bys hrrnum:egen num_pat=count(hrr)
    gen want_pal_care=E12==1
    gen want_resp=E13==1|E14==1
    gen comf_patient=want_pal_care==1&want_resp==0
    gen ag_patient=want_pal_care==0&want_resp==1
    gen have_unneeded_tests=E3==1
    gen see_unneeded_card=E4==1
    sum comf_patient ag_patient have_unneeded_tests see_unneeded_card num_pat
    bys hrrnum: gen n=_n
    collapse comf_patient ag_patient have_unneeded_tests see_unneeded_card num_pat, by(hrrnum)
    save ../temp/patient, replace
end

program hrr_level_data
    use ../temp/patient, clear
    merge 1:1 hrrnum using ../temp/card, assert(1 2 3) keep(3) nogen
    merge 1:1 hrrnum using ../temp/pcp, assert(1 2 3) keep(3) nogen
    clean_variables
    save_data ../output/hrr_skinner, replace key(hrrnum)
end

    program clean_variables
        label variable comf_patient "Comfort Patient Preferences Ratio"
        label variable ag_patient "Aggressive Patient Preferences Ratio"
        label variable see_unneeded_card "See Unneeded Cardiologists"
        label variable have_unneeded_tests "Have Unneeded Tests"
        label variable num_pat "Number of Patients responded"
        label variable high_followup_card "High-Followup Cardiologists"
        label variable low_followup_card "Low-Followup Cardiologists"
        label variable comforter_card "Comforter Ratio Cardiologists"
        label variable cowboy_card "Cowboy Ratio Cardiologists"
        label variable num_card "Number of Cardiologists responded"
        label variable high_followup_pcp "High-Followup PCP"
        label variable low_followup_pcp "Low-Followup PCP"	
        label variable comforter_pcp "Comforter Ratio PCP"
        label variable cowboy_pcp "Cowboy Ratio PCP"
        label variable num_pcp "Number of PCPs responded"
    end

** EXECUTE
main
