version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"

program main
    use in 1/${obsno} using ../external/sample/baseline_sample, clear
    gen baseline_samp=1
    merge 1:1 bene_id year using ../external/sample/subsamples, ///
        assert(3) keep(3) keepusing(*) nogen
    merge 1:1 bene_id year using ../external_links/patient/CharsPatientYear, ///
        assert(1 2 3) keep(3) keepusing(*) nogen
    merge m:1 bene_id using ../external_links/patient/CharsPatient, ///
        assert(1 2 3 4) keep(3 4) nogen update ///
        keepusing(bene_id *_orig *_dest race sex mover hmo sdod)
	merge 1:1 bene_id year using ../external/hcc/HCC, assert(1 2 3) ///
	keep(3) keepusing(score_community score_new_enrollee) nogen
    merge 1:1 bene_id year using ../external_links/treat/TreatPatientYear, ///
        assert(1 2 3) keep(1 3) keepusing(*)
	replace baseline_samp=0 if baseline_samp==.
	foreach outcome in ${pat_numeric_outcomes} ${pat_prevcare_outcomes2} ///
		${pat_outcomes_main2} ${pat_proced_outcomes} pcp_cnt num_doc ///
		prev_care RBU_missing LnIpDis LnIpDays Lndiag Lnimag ///
		Lnnum_doc Ip_RBU Op_RBU Er_RBU Ot_RBU rare_proc {
		replace `outcome' = 0 if _merge==1 & HMO!=1
	}
    drop _merge
    rename score_community hcc_com
    rename score_new_enrollee hcc_new
    summ RBU if baseline_samp==1, det
	assert RBU_missing!=1
	drop RBU_missing
	rename diagtests diag
	rename imaging imag 
	gen Lnpcp=log(pcp_cnt+1)
	gen anypcp=pcp_cnt!=0
	gen anydoc=num_doc!=0
	gen anyIpRBU=LnIp_RBU!=0
	gen anyOpRBU=LnOp_RBU!=0
	gen anyErRBU=LnEr_RBU!=0
	gen anyOtRBU=LnOt_RBU!=0
	egen prev_num = rowtotal(Mam Amb Eye Hemo Lipids Cardio DiabMng Pap ///
		Pelvic BoneMass Clrtl FluShot Prostate)
	gen Lnprv_num=log(prev_num+1)	
	gen Lnhcccom = log(hcc_com)
    gen Lnhccnew = log(hcc_new)
	gen Lnnumcon = log(num_cond+1)
	gen LnRBU_x0=log(RBU)
	gen LnRBU_x01=log(RBU+0.1)
	gen LnRBU_x10=log(RBU+10)
    gen rRBU=round(RBU,1)
    merge 1:1 bene_id year using ../external/charlson/charlson, ///
        assert(1 2 3) keep(1 3) keepusing(wcharlsum) nogen
    merge 1:1 bene_id year using ../external/iezzoni/iezzoni, ///
        assert(1 2 3) keep(1 3) keepusing(iezzoni_index) nogen
    replace wcharlsum=0 if wcharlsum==.
    replace iezzoni=0 if iezzoni==.
    rename wcharlsum chr
    rename iezzoni iez
    gen Lnchr=log(chr+1)
    gen Lniez=log(iez+1)
    gen over_p50=0
    gen over_p75=0
    gen over_p90=0
    levelsof year, local(YRs)
    foreach year in `YRs' {
        summ RBU if year==`year', det
        foreach p in 50 75 90 {
            replace over_p`p'=1 if year==`year' & RBU>r(p`p')
        }
    }
	gen fwgt=1
	replace fwgt=4 if mover==0
	gen RBU_perc=.
    foreach year in `YRs' {
        xtile RBU_ventile_`year'=RBU if year==`year', nquantiles(20)
        xtile RBU_decile_`year'=RBU if year==`year', nquantiles(10)
		xtile RBU_perc_`year'=RBU if year==`year' [fw=fwgt], nq(100)
		replace RBU_perc=RBU_perc_`year' if year==`year'
		drop RBU_perc_`year'				
    }
    egen RBU_ventile=rowmax(RBU_ventile_*)
    egen RBU_decile=rowmax(RBU_decile_*)
    forv v=1/20 {
        gen RBU_v`v'=RBU_ventile==`v'
		gen RBU_v`v'c=RBU_ventile>=`v'
    }
    drop RBU_ventile_*
    forv d=1/10 {
        gen RBU_d`d'=RBU_decile==`d'
		gen RBU_d`d'c=RBU_decile>=`d'
    }
    drop RBU_decile_*
    summ age
    local max = `r(max)'+1
    egen age_5yr_bins = cut(age), at(`r(min)'(5)`max')
	replace race = (race==1)
    save ../temp/CompiledPatYrDataAll.dta, replace
    keep if mover==0
    drop rel_yr_rit
    summ baseline_samp
    save_data ../output_local/CompiledPatYrDataNonMovers, ///
        replace key(bene_id year) log("../output/data_file_manifest.log")
    use if mover==1 using ../temp/CompiledPatYrDataAll.dta, clear
    summ baseline_samp
    save_data ../output_local/CompiledPatYrDataMovers, ///
        replace key(bene_id year) log("../output/data_file_manifest.log")
end

* EXECUTE
main
