/***************************************************************************************************
 * The upin and npi list was generated in Crosswalks SAS
 **************************************************************************************************/
version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    clean_upin_npi, in(../external_links/xw_sas/UpinNpiList.csv) out(../temp/UpinNpi.dta)
    upin_npi_xwalk, in(../temp/UpinNpi.dta) out(../temp/UpinNpi.dta)
    physid_xwalk, in(../temp/UpinNpi.dta) out(../output_local/PhysId_UpinNpi)
    phys_id_specialty_xwalk, in(../temp/UpinNpi.dta) out(../output_local/PhysId_Specialty)
end

program clean_upin_npi
    syntax, in(string) out(string)
    insheet using `in', clear names

    *UPIns have one alphabetic character, followed by five numeric ones
    *NPIs have 10 numeric characters

    replace upin="" if length(upin)!=6
    replace npi="" if length(npi)!=10
    
    gen upin_error=(substr(upin, 1, 1)!="A" & substr(upin, 1, 1)!="B" & substr(upin, 1, 1)!="C" ///
        & substr(upin, 1, 1)!="D" & substr(upin, 1, 1)!="E" & substr(upin, 1, 1)!="F" ///
        & substr(upin, 1, 1)!="G" & substr(upin, 1, 1)!="H" & substr(upin, 1, 1)!="I" ///
        & substr(upin, 1, 1)!="J" & substr(upin, 1, 1)!="K" & substr(upin, 1, 1)!="L" ///
        & substr(upin, 1, 1)!="M" & substr(upin, 1, 1)!="N" & substr(upin, 1, 1)!="O" ///
        & substr(upin, 1, 1)!="P" & substr(upin, 1, 1)!="Q" & substr(upin, 1, 1)!="R" ///
        & substr(upin, 1, 1)!="S" & substr(upin, 1, 1)!="T" & substr(upin, 1, 1)!="U" ///
        & substr(upin, 1, 1)!="V" & substr(upin, 1, 1)!="W" & substr(upin, 1, 1)!="X" ///
        & substr(upin, 1, 1)!="Y" & substr(upin, 1, 1)!="Z" & upin!="")

    forvalues i = 2/6{
        replace upin_error=1 if (substr(upin, `i', 1)!="0" & substr(upin, `i', 1)!="1" & ///
        substr(upin, `i', 1)!="2" & substr(upin, `i', 1)!="3" & substr(upin, `i', 1)!="4" & ///
        substr(upin, `i', 1)!="5" & substr(upin, `i', 1)!="6" & substr(upin, `i', 1)!="7" & ///
        substr(upin, `i', 1)!="8" & substr(upin, `i', 1)!="9" & upin!="" )
    }

    gen npi_error=0
    forvalues i = 1/10{
        replace npi_error=1 if (substr(npi, `i', 1)!="0" & substr(npi, `i', 1)!="1" & ///
        substr(npi, `i', 1)!="2" & substr(npi, `i', 1)!="3" & substr(npi, `i', 1)!="4" & ///
        substr(npi, `i', 1)!="5" & substr(npi, `i', 1)!="6" & substr(npi, `i', 1)!="7" & ///
        substr(npi, `i', 1)!="8" & substr(npi, `i', 1)!="9" & npi!="" )
    }

	*Surrogate upins have a slightly different format, so these should not be errors
	foreach surrogate in INT000 RES000 PHS000 VAD000 RET000 SLF000 OTH000 AA000 ///
		CNA000 CNM000 CNS000 CP0000 CSW000 FOR000 MD0000 NP0000 OT0000 PA0000 ///
		PT0000 {
			replace upin_error=0 if upin=="`surrogate'"
		}

    replace upin="" if upin_error==1
    replace npi="" if npi_error==1

    foreach error in A00000 D00001 M00000 S00000 A12345 C12345 A99999 B99999 C99999 D99999 ///
        E99999 Z99999 N00001{
            replace upin="" if upin=="`error'"
    }

    foreach error in 1111111112 0000000000 9999999999 9999999996 9999999992 9999999991 9999999995 {
        replace npi="" if npi=="`error'"
    }

    drop if npi=="" & upin==""
    drop upin_error npi_error
    *Setting erroneous ids to blank strings generates some duplicates; drop these
    duplicates drop

    save `out', replace
end

program upin_npi_xwalk
    syntax, in(string) out(string)
    use `in', clear

    gen upin_original=upin
    gen npi_original=npi

    sort upin npi
    crosswalk_unique_match, byvar(upin) matchvar(npi)
    sort npi upin
    crosswalk_unique_match, byvar(npi) matchvar(upin)

    gen phys_id = upin + "_" + npi
    keep  upin_original npi_original phys_id hcfaspcl
    rename upin_original upin
    rename npi_original npi
    rename hcfaspcl spcl

    save `out', replace
end

    program crosswalk_unique_match
        syntax, byvar(varname) matchvar(varname)
        *Counts the number of unique, non-missing matchvars are associated
        *with each byvar. If a byvar has only one matchvar associated with it,
        *missing values of matchvar will be replaced with the associated matchvar.
        by `byvar' `matchvar': gen `matchvar'_vals=(_n==1 & `matchvar'!="")  
            // tags each unique byvar & matchvar combination, 
        by `byvar': replace `matchvar'_vals=sum(`matchvar'_vals)
            // sums the number of matchvars for each byvar
        by `byvar': replace `matchvar'_vals=`matchvar'_vals[_N]
            // applies the maximum number of matchvars to each observation within a byvar
        by `byvar': replace `matchvar'=`matchvar'[_N] if `matchvar'_vals==1
            // if a byvar has only one matchvar associated with it (matchvar_vals==1),
            //then replace all missing matchvars with that matchvar value
        drop `matchvar'_vals
    end

program phys_id_specialty_xwalk
    syntax, in(string) out(string)

    insheet using ../external/specialty/hcfa_provider_specialty_xwalk.csv, tab clear names
	replace spcl="0"+spcl if length(spcl)==1
    save ../temp/hcfa_provider_specialty_xwalk.dta, replace
 
    use `in', clear
    keep phys_id spcl

    *Drop phys_id observations with a missing specialty code
    **iff the phys_id has a specialty code associated with it in another observation
    sort phys_id spcl
    by phys_id: drop if spcl=="" & spcl[_N]!=""
    duplicates drop
	
    merge m:1 spcl using ../temp/hcfa_provider_specialty_xwalk.dta, nogen keepusing(specialist ///
        optometrist ambspcl radiologist surgeon internist) ///
        assert(master using match) keep(master match)

    sort phys_id spcl
    foreach var of varlist specialist - internist{
        replace `var'=0 if `var'==.
        by phys_id: egen `var'_max=max(`var')
        drop `var'
        rename `var'_max `var'
    }

    by phys_id: gen stub=_n
    reshape wide spcl, i(phys_id) j(stub)
    
    save_data "`out'.dta", replace key(phys_id) log("../output/data_file_manifest.log")
    save_data "`out'.csv", replace key(phys_id) outsheet comma log("../output/data_file_manifest.log")
end

program physid_xwalk
    syntax, in(string) out(string)

    use upin npi phys_id using `in', clear
    *The `in' dataset is at the specialty, upin, npi, phys_id level
    *we only need the latter three variables, which leaves duplicates
    duplicates drop

    generate_key
	order key phys_id upin npi

    save_data "`out'.dta", replace key(key) log("../output/data_file_manifest.log")
    save_data "`out'.csv", replace key(key) outsheet comma log("../output/data_file_manifest.log")
end

    program generate_key
        gen upin_temp = upin
        replace upin_temp = "missing" if upin==""
        gen npi_temp = npi
        replace npi_temp = "missing" if npi==""
        gen key = upin_temp + npi_temp
        drop *_temp
    end

* EXECUTE
main

