version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    append_denom_files, pct(20) startyear(1998) endyear(2009)
end

program append_denom_files,
    syntax, pct(string) startyear(real) endyear(real)

    forval year = `startyear'/`endyear'{

        insheet using "../external/denom`pct'/denom`pct'`year'_cnfm.csv", clear
		
        replace sex = 0 if sex == 2
        ** conform dates from 2002 - 2005
        if `year' >= 2002 & `year' <= 2005{
            gen b_day = mod(sdob,100)
            gen b_month = mod(int(sdob/100), 100)
            gen b_year = int(sdob/10000)

            gen d_day = mod(sdod,100)
            gen d_month = mod(int(sdod/100), 100)
            gen d_year = int(sdod/10000)

            drop sdod sdob

            gen sdob = mdy(b_month, b_day, b_year)
            gen sdod = mdy(d_month, d_day, d_year)
            drop b_day b_month b_year d_day d_month d_year
        }
        else{
            gen sdob_2 = date(sdob, "DMY")
            gen sdod_2 = date(sdod, "DMY")
            drop sdob sdod
            ren sdob_2 sdob
            ren sdod_2 sdod
        }

        ** duplicates of bene_id
        duplicates tag bene_id, gen(dup_tag)
        bys bene_id: egen dup_bene_id_flag=max(dup_tag)

        ** beneficiaries living abroad
        gen abroad = (state_de==40 | state_de==48 | state_de==54| ///
            (state_de >= 56 & state_de <= 66) | (state_de >= 97 & state_de !=.))
        bys bene_id: egen foreign_bene_id_flag=max(abroad)

        format zipcode %05.0f
        tostring zipcode, u replace
        duplicates drop bene_id, force

		gen mcaid = (buyin1=="C" | buyin1=="B")
		foreach var of varlist buyin2-buyin12 {
			replace mcaid=1 if `var'=="C" | `var'=="B" & mcaid==0
		}
		gen nemcaid=0
        save ../temp/denom_`year', replace
    }

    clear
	use ../temp/denom_2008
    merge 1:1 bene_id using ../temp/denom_2009, update replace keepusing(bene_id sdod) ///
        keep(1 3 4 5) nogen
    save ../temp/denom_2008, replace
    clear

    forval year = `startyear'/`endyear' {
        append using ../temp/denom_`year'
    }

    merge m:1 zipcode using ../external/hrrxw/ziphrrxwalk.dta, assert(1 2 3) keep(1 3)
    save_data ../output_local/denom_all_zipcodes, ///
        replace key(bene_id year) log("../output/data_file_manifest.log")

    gen dropped_post_1998_zip = (keep==0)
    gen dropped_nomatch_zip = (_merge==1)

    insert_tag post_1998_sample_drop, open
        tab dropped_post_1998_zip
    insert_tag post_1998_sample_drop, close
    insert_tag nomatch_zip_sample_drop, open
        tab dropped_nomatch_zip
    insert_tag nomatch_zip_sample_drop, close

    collapse (max) dropped_post_1998_zip dropped_nomatch_zip, by(bene_id)
    insert_tag post_1998_patient_drop, open
        tab dropped_post_1998_zip
    insert_tag post_1998_patient_drop, close
    insert_tag nomatch_zip_patient_drop, open
        tab dropped_nomatch_zip
    insert_tag nomatch_zip_patient_drop, close

    use if _merge!=2 using ../output_local/denom_all_zipcodes, clear
    unique bene_id
    local unique_total = r(sum)
    di "## of unique bene_ids before any drops: `unique_total'"
    drop if keep!=1

    ** gen nonstable bene_id flag
    bys bene_id: egen last_yr=max(year)
    replace last_yr=. if year==2009
    replace last_yr=. if year!=last_yr
    bys bene_id: gen chg_bene_id_flag=(sdod==. & last_yr!=.)

    ** sum flag variables
    insert_tag summ_flag, open
        summ *flag
    insert_tag summ_flag, close
    
	** recalculate a_mo_cnt b_mo_cnt and hmo_mo based on Apr-March years
	forval month = 1/12{
        gen pta_`month' = (buyin`month' == "1" | buyin`month' == "3" | ///
            buyin`month' == "A" | buyin`month' == "C")
        gen ptb_`month' = ( buyin`month' == "2" | buyin`month' == "3" | ///
            buyin`month' == "B" | buyin`month' == "C")
        gen phmo_`month' = (hmoind`month' != "0")
        
     }
         
    sort bene_id year
	
    foreach plan in pta ptb phmo{
        forval month = 1/3{
            replace `plan'_`month' = `plan'_`month'[_n+1] if bene_id[_n] == bene_id[_n+1]
            replace `plan'_`month' = 0 if bene_id[_n] != bene_id[_n+1]
        }
    }
    
	drop a_mo_cnt b_mo_cnt hmo_mo   
    egen a_mo_cnt = rowtotal(pta_*) 
    egen b_mo_cnt = rowtotal(ptb_*)
    egen hmo_mo = rowtotal(phmo_*) 

    drop if year == 2009
                 
    ** drop individuals who died in previous Apr-March year from current year  
    drop if month(sdod) <= 3 & year(sdod) == year
         
    keep bene_id ehic *state* *zip* *county* sex race *_mo* year *hrr* *hsa* sdo* orec *flag ///
		mcaid nemcaid
    save_data ../output_local/denom_data, replace key(bene_id year) /// 
        log("../output/data_file_manifest.log")
    outsheet using ../output_local/denom_data.csv, replace comma

end

** EXECUTE
main
