/* These are macros that will generate annual data
 * Due to the way zip codes are defined in the denominator file, we need to define treatments
 * March - March.  The macros in this file will create claims files that are March-March */

%macro GenerateCarrierYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %CarrierVarNames(year=&year.);

    %if (&year. <= 2008 and &year. >= 1998) and &year.~=2005 %then %do;
        data cartemp1 (&&keep&year. &&rename&year.);
            length clm_id_new $&clm_id_length.;
            set carIn.carLNits&pct._&year. (OBS=&obs_num.);
            where &&c&year._from. > &startdate. and &&c&year._thru. <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||&&claimid&year..;
            year= &year.;
            run;
        data cartemp2 (&&keep&year2. &&rename&year2.);
            length clm_id_new $&clm_id_length.;
            set carIn.carLNits&pct._&year2. (OBS=&obs_num.);
            where &&c&year2._from. > &startdate. and &&c&year2._thru. <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||&&claimid&year2..;
            year= &year.;
            run;
        data cartemp;
            length upin $ &upin_length. npi $ &npi_length. alowchrg &amt_length. lalowchg &amt_length.;
            set cartemp1 cartemp2;
            format upin $&upin_length.. npi $&npi_length..;
            run;
	%if &year. < 2005 %then %do;
	    %MergeEhicBeneId(data=cartemp, xwalk=bene.ehicbenex_unique);
	%end;

    %end;

    %if &year.= 2005 %then %do;
        data cartemp1 (&&keep&year. &&rename&year.);
            length clm_id_new $&clm_id_length.;
            set carIn.carLNits&pct._&year. (OBS=&obs_num.);
            where &&c&year._from.> &startdate. and &&c&year._thru. <= &enddate.;
            clm_id_new="Y"||PUT(fileYear,z4.)||"ID"||&&claimid&year..;
            year= &year.;
        run;
	%MergeEhicBeneId(data=cartemp1, xwalk=bene.ehicbenex_unique);

        data cartemp2 (&&keep&year2. &&rename&year2.);
            length clm_id_new $&clm_id_length.;
            set carIn.carLNits&pct._&year2. (OBS=&obs_num.);
            where &&c&year2._from. > &startdate. and &&c&year2._thru. <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||&&claimid&year2..;
            year= &year.;
            run;
        data cartemp;
            length upin $ &upin_length. npi $ &npi_length. alowchrg &amt_length. lalowchg &amt_length.;
            set cartemp1 cartemp2;
            format upin $&upin_length.. npi $&npi_length..;
        run;
    %end;
%mend GenerateCarrierYear;

%macro GenerateOpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %OpClmsVarNames(year=&year.);

    /* Since we've merge two files, the current clm_id vars are no longer unique
     * I fix this below be generating a new, unique claim id */
    %if &year. <= 2008 and &year. >= 1998 and &year.~=2005 %then %do;
        data opclmstemp (DROP= clm_id RENAME=clm_id_new=clm_id);
            length upin $ &upin_length. npi $ &npi_length. pmt_amt &amt_length.
                ptb_coin &amt_length. ptb_ded &amt_length. blddedam &amt_length. prpayamt &amt_length.
                clm_id_new $&clm_id_length.;
            set opIn.opclms_&pct._&year. (&&keep&year. &&rename&year. obs=&obs_num.)
                opIn.opclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||clm_id;
            year= &year.;
        run;
	%if &year. < 2005 %then %do;
	    %MergeEhicBeneId(data=opclmstemp, xwalk=bene.ehicbenex_unique);
	%end;
    %end;

    %if &year. = 2005 %then %do;
        ** If the year is 2005 then I need to merge the bene_id ehic xwalk;
        data opclmstemp1;
            set opIn.opclms_&pct._&year. (&&keep&year. &&rename&year. OBS=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
        run;

	%MergeEhicBeneId(data=opclmstemp1, xwalk=bene.ehicbenex_unique);

        data opclmstemp (DROP= clm_id RENAME=clm_id_new=clm_id);
            length upin $ &upin_length. npi $ &npi_length. pmt_amt &amt_length.
                ptb_coin &amt_length. ptb_ded &amt_length. blddedam &amt_length. prpayamt &amt_length.
                clm_id_new $&clm_id_length.;
            set opclmstemp1 opIn.opclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||clm_id;
            year= &year.;
        run;
    %end;

%mend GenerateOpClmsYear;

%macro GenerateIpClmsYear(year=, pct=);

    ** Define Constants Used to Restrict by Date;
    %let year2 = %eval(&year.+1);
    %let startdate = %sysfunc(MDY(3, 31, &year.));
    %let enddate = %sysfunc(MDY(3, 31, &year2.));
    %IpClmsVarNames(year=&year.);


    %if (&year. <= 2008 and &year. >= 1998) and &year.~=2005 %then %do;
        data ipclmstemp (DROP=clm_id RENAME=clm_id_new=clm_id);
            length upin $ &upin_length. npi $ &npi_length. outlrpmt &amt_length. pmt_amt &amt_length. prpayamt &amt_length.
                passthru &amt_length. util_day &amt_length. ded_amt &amt_length.  coin_amt &amt_length. blddedam &amt_length.
                clm_id_new $&clm_id_length.;;
            set ipIn.ipclms_&pct._&year. (&&keep&year. &&rename&year. obs=&obs_num.)
                ipIn.ipclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||clm_id;
            year = &year.;
        run;

	%if &year. < 2005 %then %do;
	    %MergeEhicBeneId(data=ipclmstemp, xwalk=bene.ehicbenex_unique);
	%end;
    %end;
    %if &year. = 2005 %then %do;
        ** If the year is 2005 then I need to merge the bene_id ehic xwalk;
        data ipclmstemp1;
            set ipIn.ipclms_&pct._&year. (&&keep&year. &&rename&year. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
        run;
	%MergeEhicBeneId(data=ipclmstemp1, xwalk=bene.ehicbenex_unique);

        data ipclmstemp (DROP=clm_id RENAME=clm_id_new=clm_id);
            length upin $ &upin_length. npi $ &npi_length. outlrpmt &amt_length. pmt_amt &amt_length. prpayamt &amt_length.
                passthru &amt_length. util_day &amt_length. ded_amt &amt_length.  coin_amt &amt_length. blddedam &amt_length.
                prcdrcd1-prcdrcd8 $ 5 clm_id $ 15 clm_id_new $&clm_id_length.;
            set ipclmstemp1 ipIn.ipclms_&pct._&year2. (&&keep&year2. &&rename&year2. obs=&obs_num.);
            where from_dt > &startdate. and from_dt <= &enddate.;
            clm_id_new = "Y"||PUT(fileYear,z4.)||"ID"||clm_id;
            year= &year.;
        run;
    %end;
%mend GenerateIpClmsYear;
