version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries

program main
    create_multiple_mover_data
    claim_share
    define_true_movers
    create_relative_years
end

program create_multiple_mover_data
    use bene_id mult_mover ///
        using ../external_links/patient/CharsPatient, clear
    merge 1:m bene_id using ../external_links/patient/CharsPatientYear, ///
        assert(3) keep(3) keepusing(hrrnum year age) nogen
    keep if mult_mover==1
    drop mult_mover
    sort bene_id year hrrnum
    gen move = (hrrnum != hrrnum[_n-1] & bene_id == bene_id[_n-1]) ///
        if age>=65 & age<=99 & age[_n-1]<=98
    bys bene_id: egen move_count=sum(move)
    bys bene_id: egen min_year=min(year)
    bys bene_id: egen max_year=max(year)
    gen hrr=hrrnum if year==min_year | year==max_year | move==1
    gen year_temp=year if year==min_year| year==max_year | move==1
    keep if hrr!=.
    sort bene_id year
    by bene_id: gen j=_n
    sum j
    local J=`r(max)'
    drop year age move hrrnum
    reshape wide hrr year_temp, i(bene_id) j(j)
    expand move_count
    gen hrr_orig=.
    gen hrr_dest=.
    gen year_start=.
    gen year_end=.
    bys bene_id: gen n=_n
    forv n=1/`J' {
        local n_minus1=`n'-1
        cap replace year_temp`n'=year_temp`n'+1 if year_temp`n'==max_year & hrr`n'==hrr`n_minus1'
    }
    sum n
    forv n=1/`r(max)' {
        local n_plus1=`n'+1
        local n_plus2=`n'+2
        replace hrr_orig=hrr`n' if n==`n'
        replace hrr_dest=hrr`n_plus1' if n==`n'
        replace year_start=year_temp`n' if n==`n'
        cap replace year_end=year_temp`n_plus2'-1 if n==`n'
    }
    replace year_end=max_year if year_end==.
    keep bene_id n hrr_orig hrr_dest year_start year_end
    order bene_id n hrr_orig hrr_dest year_start year_end
    gen number_of_years=year_end-year_start+1
    replace number_of_years=1 if number_of_years==.
    expand number_of_years
    sort bene_id n
    bys bene_id n: gen t=_n-1
    gen year=year_start+t
    keep bene_id n year hrr_orig hrr_dest year_start year_end
    order bene_id n year hrr_orig hrr_dest year_start year_end
    merge m:1 bene_id year using ../external_links/patient/CharsPatientYear, ///
        assert(1 2 3) keep(3) keepusing(hrrnum age) nogen
    sort bene_id n year
    gen move_year_temp = year if hrrnum != hrrnum[_n+1] & bene_id==bene_id[_n+1] & n==n[_n+1] ///
        & age>=65 & age<=98 & age[_n+1]<=99
    egen move_year = min(move_year_temp), by(bene_id n)
    gen rel_yr_rit = year - move_year - 1
    keep bene_id n year rel_yr_rit hrrnum hrr_orig hrr_dest
    save_data ../output_local/MultipleMovers, ///
        replace key(bene_id n year) log("../output/data_file_manifest.log")
end

program claim_share
    use ../output_local/MultipleMovers, clear
    bys bene_id: egen N=max(n)
    keep bene_id N
    bys bene_id: keep if _n==1
    merge 1:m bene_id using ../external_links/treat/TreatHrrPatientDocYear, ///
        assert(1 2 3) keep(1 3) keepusing(*) nogen
    expand N
    bys bene_id year phys_hrr phys_id: gen n=_n
    order bene_id n year
    merge m:1 bene_id n year using ../output_local/MultipleMovers, ///
        assert(1 2 3) keep(3) keepusing(rel_yr_rit hrr_orig hrr_dest) nogen
    gen hrr_type = .
    replace hrr_type = 1 if phys_hrr==hrr_orig
    replace hrr_type = 2 if phys_hrr==hrr_dest
    replace hrr_type = 3 if phys_hrr!=hrr_orig & phys_hrr!=hrr_dest
    collapse (sum) ClaimCnt (min) rel_yr_rit, by(bene_id n year hrr_type)
    bys bene_id n year: egen ClaimCnt_total = total(ClaimCnt)
    gen ClaimCnt_frac = ClaimCnt/ClaimCnt_total
    keep ClaimCnt_frac bene_id n hrr_type year rel_yr_rit
    tostring hrr_type, replace
    reshape wide ClaimCnt_frac, i(bene_id n year rel_yr_rit) j(hrr_type) string
    rename ClaimCnt_frac1 ClaimCnt0_frac_orig
    rename ClaimCnt_frac2 ClaimCnt0_frac_dest
    rename ClaimCnt_frac3 ClaimCnt0_frac_other
    merge 1:1 bene_id n year using ../output_local/MultipleMovers, ///
        assert(2 3) keep(2 3) keepusing(*) nogen
    foreach type in orig dest other {
        replace ClaimCnt0_frac_`type' = 0 if ClaimCnt0_frac_`type'==.
    } 
    save_data ../output_local/MultipleMovers_ClaimShares, ///
        replace key(bene_id n year) log("../output/data_file_manifest.log")    
end

program define_true_movers
    use ../output_local/MultipleMovers_ClaimShares, clear
    gen ClaimCnt_decomp=ClaimCnt0_frac_dest/(ClaimCnt0_frac_dest+ClaimCnt0_frac_orig)
    bys bene_id n: egen avg_pre_orig_temp=total(ClaimCnt0_frac_orig) if rel_yr_rit<0
    bys bene_id n: egen avg_pre_dest_temp=total(ClaimCnt0_frac_dest) if rel_yr_rit<0
    gen avg_pre_cs_temp=avg_pre_dest_temp/(avg_pre_orig_temp+avg_pre_dest_temp)
    bys bene_id n: egen avg_post_orig_temp=total(ClaimCnt0_frac_orig) if rel_yr_rit>0
    bys bene_id n: egen avg_post_dest_temp=total(ClaimCnt0_frac_dest) if rel_yr_rit>0
    gen avg_post_cs_temp=avg_post_dest_temp/(avg_post_orig_temp+avg_post_dest_temp)
    bys bene_id n: egen avg_pre_cs=max(avg_pre_cs_temp)
    bys bene_id n: egen avg_post_cs=max(avg_post_cs_temp)
    gen pre_post_cs_diff=avg_post_cs-avg_pre_cs
    keep bene_id n year pre_post_cs_diff avg_pre_cs avg_post_cs
    gen true = ///
        (pre_post_cs_diff>=0.75& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    gen true_l = ///
        (pre_post_cs_diff>=0.6& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    gen true_h = ///
        (pre_post_cs_diff>=0.9& pre_post_cs_diff<=1&pre_post_cs_diff!=.) | ///
        (avg_pre_cs==. & avg_post_cs>=0.95 & avg_post_cs!=.) | ///
        (avg_post_cs==. & avg_pre_cs<=0.05 & avg_pre_cs!=.)
    bys bene_id n: keep if _n==1
    keep bene_id n true true_l true_h
    save_data ../output_local/MultipleMovers_TrueFalse, ///
        replace key(bene_id n) log("../output/data_file_manifest.log")
    bys bene_id: egen number_of_true_moves=sum(true)
    bys bene_id: gen N=_N
    bys bene_id: keep if _n==1
    keep if number_of_true_moves==N
    keep bene_id
    save_data ../output_local/MultipleMovers_AlwaysTrueMovers, ///
        replace key(bene_id) log("../output/data_file_manifest.log")   
end

program create_relative_years
    use bene_id mult_mover ///
        using ../external_links/patient/CharsPatient, clear
    merge 1:m bene_id using ../external_links/patient/CharsPatientYear, ///
        assert(3) keep(3) keepusing(hrrnum year age) nogen
    keep if mult_mover==1
    drop mult_mover
    sort bene_id year hrrnum
    gen move_year = year ///
        if (hrrnum != hrrnum[_n-1] & bene_id == bene_id[_n-1]) & age>=65 & age<=99 & age[_n-1]<=98
    keep bene_id move_year
    keep if move_year!=.
    bys bene_id: gen j=_n
    reshape wide move_year, i(bene_id) j(j)
    merge 1:m bene_id using ../external_links/patient/CharsPatientYear, ///
        assert(2 3) keep(3) keepusing(year) nogen
    forv i=1/9 {
        gen rel_yr_rit_`i'=year-move_year`i'
    }
    keep bene_id year rel_yr_rit*
    save_data ../output_local/MultipleMovers_RelativeYears, ///
        replace key(bene_id year) log("../output/data_file_manifest.log")
end


* EXECUTE
main


