/* This file contains the macros to diagnose patients */
%macro InitializeIndicators(filetype=);
    %if &filetype. = carrier %then %do;
	Mam = 0;
	Amb = 0;
	EyeRet = 0;
	EyeNeg = 0;
	Lipids = 0;
	Hemo = 0;
	CardioScreen = 0; 
	DiabMng = 0;
	Pap = 0;
	Pelvic = 0;
	BoneMass = 0;
	Colorectal = 0;
	Prostate = 0;
	FluShot = 0;
	diagtests = 0;
	imaging = 0;
	EolExpn = 0;
    %end; 

    %if &filetype. = ipclm %then %do;
	Mam  = 0;
	EyeRet  = 0;
	EyeNeg  = 0;
	CardioScreen = 0; 
	Pap  = 0;
	Pelvic  = 0;
	Prostate  = 0;
	FluShot  = 0;
	IpDischarges  = 0;
	IpDays  = 0;
	SurgicalDischarge  = 0;
	HipFracture  = 0;
	AAA  = 0;
	ValveReplace  = 0;
	CarotidEnd  = 0;
	CoronaryAng  = 0;
	CABG  = 0;
	HipReplace = 0; 
	KneeReplace  = 0;
	LowerBypass  = 0;
	Mastectomy  = 0;
	PCI  = 0;
	Prostatectomy = 0; 
	Colectomy  = 0;
	Cholecystectomy = 0; 
	TURP  = 0;
	CardiacCath  = 0;
	BackSurgery = 0;
	EolExpn = 0;

	AAA_prcdr = 0;
	AAA_dgns = 0;	
	Hip_dgns = 0;
	Hip_prcdr = 0;
	LB_dgns = 0;
	LB_prcdr = 0; 	
	Mast_dgns = 0;
	Mast_prcdr = 0;
	Cole_dgns = 0;
	Cole_prcdr = 0;
	TURP_dgns = 0;
	TURP_prcdr = 0;	
	Back_ex = 0;
	Back_dgns = 0;
	Back_prcdr = 0;
	Back_prcdr2 = 0;
    %end; 

    %if &filetype. = revcntr %then %do;
	Mam  = 0;
	Hemo = 0;
	Lipids = 0;
	EyeRet  = 0;
	CardioScreen = 0; 
	DiabMng = 0;
	Pap  = 0;
	Pelvic  = 0;
	BoneMass = 0;
	Colorectal = 0;
	Prostate  = 0;
	FluShot  = 0;
    %end; 

    %if &filetype. = opclm %then %do;
	Mam = 0; 
	Amb  = 0;
	EyeRet  = 0;
	EyeNeg  = 0;
	CardioScreen = 0; 
	Pap  = 0;
	Pelvic	 = 0;    
	Prostate  = 0;
	FluShot  = 0;
	EolExpn = 0;
    %end; 

%mend InitializeIndicators;

%macro Process_ICD9(code=);
    /* I generate a numerical version of code, which is 5 digits long;
     * I have to add lagging zeros first, because there are up to 2 digits after a decimal place
     * but the Medicare data does not add them. */

    code_length = length(&code.);
    code_conform = &code.;
    if code_length = 3 then code_conform = CATT(code_conform,"00");
    if code_length = 4 then code_conform = CATT(code_conform,"0");
    code_num = input(code_conform, ??5.);
%mend Process_ICD9;

%macro Calculate_Expenditures(filetype=);
    %if &filetype. = outpatient %then %do;
        pay_med = pmt_amt;
        pay_bene = ptb_coin + ptb_ded + blddedam;
        pay_prim = prpayamt;
        pay_prov = pay_med + pay_bene + pay_prim;
    %end;

    %if &filetype. = inpatient %then %do;
        passthru_total = passthru*util_day;
        pay_prov = PMT_AMT + passthru_total + DED_AMT + COIN_AMT + BLDDEDAM + PRPAYAMT;
    %end;
%mend Calculate_Expenditures;

%macro Calculate_EolExpn(filetype=);
    %if &filetype. = carrier %then %do;
	daysbtwn = abs(sdod - expnsdt1);
	** 180 days or 6 month cut-off;
	if daysbtwn < 180 then EolExpn = lalowchg;
	if daysbtwn = . then EolExpn = 0;
    %end;

    %if &filetype. = outpatient %then %do;
	daysbtwn = abs(sdod - from_dt);
	** 180 days or 6 month cut-off;
	if daysbtwn < 180 then EolExpn = pay_prov; 
	if daysbtwn = . then EolExpn = 0;
    %end;

    %if &filetype. = inpatient %then %do;
	daysbtwn = abs(sdod - from_dt);
	** 180 days or 6 month cut-off;
	if daysbtwn < 180 then EolExpn = pay_prov; 
	if daysbtwn = . then EolExpn = 0;
    %end;
%mend Calculate_EolExpn;

%macro SpendingBreakdown(filetype=);
    %if &filetype. = carrier %then %do;
	if plcsrvc =21 then inpatient_RBU = car_RBU_mean;
	else if plcsrvc =22 | plcsrvc=11 then outpatient_RBU = car_RBU_mean;
	else if plcsrvc =23 | (hcpcs_num>=99281 & hcpcs_num<=99285)
        then er_RBU = car_RBU_mean;
	else other_RBU = car_RBU_mean;
    
    if inpatient_RBU = . then inpatient_RBU=0;
    if outpatient_RBU=. then outpatient_RBU=0;
    if er_RBU = . then er_RBU =0;
    if other_RBU = . then other_RBU=0;
    %end;

    %if &filetype. = outpatient %then %do;
    test=0;
    Er=0;
    if rev_cntr_num>=0450 & rev_cntr_num<=0459 | rev_cntr_num=0981
        then Er=1;
    %end;

    %if &filetype. = inpatient %then %do;
    test=0;
    Er=0;
    if rev_cntr_num>=0450 & rev_cntr_num<=0459 | rev_cntr_num=0981
        then Er=1;
    %end;

%mend SpendingBreakdown;

%macro Diagnose_Mammogram(table=, code=, codetype=);


    %if &codetype. = icd9 %then %do;
        if code_num = 8736 then Mam = 1;
        if code_num = 8737 then Mam = 1;
        if &code. = "V7611" then Mam = 1;
        if &code. = "V7612" then Mam = 1;
    %end;
    %if &codetype. = cpt %then %do;
        if &code. = "76090" then Mam = 1;
        if &code. = "76091" then Mam = 1;
        if &code. = "76092" then Mam = 1;
        if &code. = "76083" then Mam = 1;
        if &code. = "G0202" then Mam = 1;
    %end;
    %if &codetype. = rev_cntr %then %do;
        if &code. = "0403" then Mam=1;
    %end;
%mend Diagnose_Mammogram;

%macro Diagnose_Hemo(table=, code=, codetype=);

    %if &codetype. = cpt %then %do;
        if &code. = "83036" then Hemo = 1;
        if &code. = "83037" then Hemo = 1;
        if &code. = "3046F" then Hemo = 1;
        if &code. = "3047F" then Hemo = 1;
    %end;
%mend Diagnose_Hemo;

%macro Diagnose_Lipids(table=, code=, codetype=);

    %if &codetype. = cpt %then %do;
        if code_conform = "80061" then Lipids = 1;
        if code_conform = "83700" then Lipids = 1;
        if code_conform = "83701" then Lipids = 1;
        if code_conform = "83704" then Lipids = 1;
        if code_conform = "83715" then Lipids = 1;
        if code_conform = "83716" then Lipids = 1;
        if code_conform = "83721" then Lipids = 1;
        if &code. = "3048F" then Lipids = 1;
        if &code. = "3049F" then Lipids = 1;
        if &code. = "3050F" then Lipids = 1;
    %end;
%mend Diagnose_Lipids;

%macro Diagnose_CardioScreen(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if &code. = "V8100" then CardioScreen = 1;
        if &code. = "V8110" then CardioScreen = 1;
        if &code. = "V8120" then CardioScreen = 1;
    %end;
    %if &codetype. = cpt %then %do;
        if &code. = "80061" then CardioScreen = 1;
        if &code. = "82465" then CardioScreen = 1;
        if &code. = "83718" then CardioScreen = 1;
        if &code. = "84478" then CardioScreen = 1;
    %end;
%mend Diagnose_CardioScreen;

%macro Diagnose_DiabetesManage(table=, code=, codetype=);

    %if &codetype. = cpt %then %do;
        if &code. = "G0108" then DiabMng = 1;
        if &code. = "G0109" then DiabMng = 1;
    %end;
%mend Diagnose_DiabetesManage;

%macro Diagnose_BoneMass(table=, code=, codetype=);

    %if &codetype. = cpt %then %do;
        if &code. = "76977" then BoneMass = 1;
        if &code. = "77078" then BoneMass = 1;
        if &code. = "77079" then BoneMass = 1;
        if &code. = "77080" then BoneMass = 1;
        if &code. = "77081" then BoneMass = 1;
        if &code. = "G0130" then BoneMass = 1;
    %end;
%mend Diagnose_BoneMass;

%macro Diagnose_Colorectal(table=, code=, codetype=);

    %if &codetype. = cpt %then %do;
        if &code. = "82270" then Colorectal = 1;
        if &code. = "G0328" then Colorectal = 1;
    %end;
%mend Diagnose_Colorectal;

%macro Diagnose_PapTest(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if &code. = "V7620" then Pap = 1;
        if &code. = "V7647" then Pap = 1;
        if &code. = "V7649" then Pap = 1;
        if &code. = "V1589" then Pap = 1;
        if &code. = "V7231" then Pap = 1;
    %end;
    %if &codetype. = cpt %then %do;
        if &code. = "G0123" then Pap = 1;
        if &code. = "G0124" then Pap = 1;
        if &code. = "G0141" then Pap = 1;
        if &code. = "G0143" then Pap = 1;
        if &code. = "G0144" then Pap = 1;
        if &code. = "G0145" then Pap = 1;
        if &code. = "G0147" then Pap = 1;
        if &code. = "G0148" then Pap = 1;
        if &code. = "P3000" then Pap = 1;
        if &code. = "P3001" then Pap = 1;
        if &code. = "Q0091" then Pap = 1;
    %end;
%mend Diagnose_PapTest;

%macro Diagnose_PelvicExam(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if &code. = "V7620" then Pelvic = 1;
        if &code. = "V7647" then Pelvic = 1;
        if &code. = "V7649" then Pelvic = 1;
        if &code. = "V1589" then Pelvic = 1;
        if &code. = "V7231" then Pelvic = 1;
    %end;
    %if &codetype. = cpt %then %do;
        if &code. = "G0101" then Pelvic = 1;
    %end;
%mend Diagnose_PelvicExam;

%macro Diagnose_ProstateExam(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if &code. = "V7644" then Prostate = 1;
    %end;
    %if &codetype. = cpt %then %do;
        if &code. = "G0102" then Prostate = 1;
        if &code. = "G0103" then Prostate = 1;
    %end;

%mend Diagnose_ProstateExam;
 
%macro Diagnose_FluShot(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if &code. = "V0481" then FluShot = 1;
        if &code. = "V0660" then FluShot = 1;
    %end;

    %if &codetype. = cpt %then %do;
        if &code. = "90655" then FluShot = 1;
        if &code. = "90656" then FluShot = 1;
        if &code. = "90657" then FluShot = 1;
        if &code. = "90660" then FluShot = 1;
        if &code. = "90662" then FluShot = 1;
        if &code. = "Q2035" then FluShot = 1;
        if &code. = "Q2036" then FluShot = 1;
        if &code. = "Q2037" then FluShot = 1;
        if &code. = "Q2038" then FluShot = 1;
        if &code. = "Q2039" then FluShot = 1;
        if &code. = "G0008" then FluShot = 1;
    %end;

%mend Diagnose_FluShot;

%macro Diagnose_NegativeEye(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if Optometrist=1 and (code_num >= 25050 and code_num <= 25053) then EyeNeg = 1;
        if Optometrist=1 and (code_num >= 36201 and code_num <= 36207) then EyeNeg = 1;
    %end;
%mend;

%macro Diagnose_RetinalEye(table=, code=, codetype=);

    %if &codetype. = icd9 %then %do;
        if Optometrist = 1 and code_num >= 1410 and code_num <= 1459 then EyeRet=1;
        if Optometrist = 1 and code_num = 1490 then EyeRet=1;
        if Optometrist = 1 and code_num >= 9502 and code_num <= 9504 then EyeRet=1;
        if Optometrist = 1 and code_num >= 9511 and code_num <= 9512 then EyeRet=1;
        if Optometrist = 1 and code_num = 9516 then EyeRet=1;
    %end;

    %if &codetype. = cpt %then %do;
        if Optometrist = 1 and &code. = "67028" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67038" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67040" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67101" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67105" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67107" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67108" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67110" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67112" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67141" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67145" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67208" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67210" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67218" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67227" then EyeRet = 1;
        if Optometrist = 1 and &code. = "67228" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92002" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92004" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92012" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92014" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92018" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92019" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92225" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92226" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92230" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92235" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92240" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92250" then EyeRet = 1;
        if Optometrist = 1 and &code. = "92260" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99203" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99204" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99205" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99213" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99214" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99215" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99242" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99243" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99244" then EyeRet = 1;
        if Optometrist = 1 and &code. = "99245" then EyeRet = 1;
        if Optometrist = 1 and &code. = "2022F" then EyeRet = 1;
        if Optometrist = 1 and &code. = "2024F" then EyeRet = 1;
        if Optometrist = 1 and &code. = "2026F" then EyeRet = 1;
        if Optometrist = 1 and &code. = "3072F" then EyeRet = 1;
        if Optometrist = 1 and &code. = "S3000" then EyeRet = 1;
        if Optometrist = 1 and &code. = "S0625" then EyeRet = 1;

        if hcpcs_num >= 67038 and hcpcs_num <= 67040 and Optometrist = 1 then EyeRet = 1;
        if hcpcs_num >= 99203 and hcpcs_num <= 99205 and Optometrist = 1 then EyeRet = 1;
        if hcpcs_num >= 99213 and hcpcs_num <= 99215 and Optometrist = 1 then EyeRet = 1;
        if hcpcs_num >= 99242 and hcpcs_num <= 99245 and Optometrist = 1 then EyeRet = 1;
    %end;        

%mend Diagnose_RetinalEye;

%macro Count_Imaging_Tests();
    imaging = 0;
    if betos="I1A" then imaging = 1;
    if betos="I1B" then imaging = 1;
    if betos="I1C" then imaging = 1;
    if betos="I1D" then imaging = 1;
    if betos="I1E" then imaging = 1;
    if betos="I1F" then imaging = 1;
    if betos="I2A" then imaging = 1;
    if betos="I2B" then imaging = 1;
    if betos="I2C" then imaging = 1;
    if betos="I2D" then imaging = 1;
    if betos="I3A" then imaging = 1;
    if betos="I3B" then imaging = 1;
    if betos="I3C" then imaging = 1;
    if betos="I3D" then imaging = 1;
    if betos="I3E" then imaging = 1;
    if betos="I3F" then imaging = 1;
    if betos="I4A" then imaging = 1;
    if betos="I4B" then imaging = 1;
%mend Count_Imaging_Tests;


%macro Count_Diagnostic_Tests();
    diagtests = 0;
    if betos="T1A" then diagtests = 1;
    if betos="T1B" then diagtests = 1;
    if betos="T1C" then diagtests = 1;
    if betos="T1D" then diagtests = 1;
    if betos="T1E" then diagtests = 1;
    if betos="T1F" then diagtests = 1;
    if betos="T1G" then diagtests = 1;
    if betos="T1H" then diagtests = 1;
    if betos="T2A" then diagtests = 1;
    if betos="T2B" then diagtests = 1;
    if betos="T2C" then diagtests = 1;
    if betos="T2D" then diagtests = 1;
%mend Count_Diagnostic_Tests;

%macro Generate_ProvTypeInd();
    ProviderInd = 0;
    if plcsrvc="11" then ProviderInd = 1;
    if plcsrvc="22" then ProviderInd = 1;
    if plcsrvc="72" then ProviderInd = 1;
    if plcsrvc="50" then ProviderInd = 1;     
%mend Generate_ProvTypeInd; 

%macro Diagnose_AmbulatoryCare(table=, filetype=, spcl_ind=, prov_ind=);

    %if &filetype. = carrier %then %do;
        if hcpcs_num >= 99201 & hcpcs_num <= 99205 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
        if hcpcs_num >= 99211 & hcpcs_num <= 99215 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
        if hcpcs_num >= 99381 & hcpcs_num <= 99387 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
        if hcpcs_num >= 99391 & hcpcs_num <= 99397 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
        if hcpcs_num >= 99241 & hcpcs_num <= 99245 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
        if hcpcs_num >= 99271 & hcpcs_num <= 99275 and &spcl_ind. = 1 and &prov_ind. = 1 then Amb = 1;
    %end;
    %if &filetype. = outpatient %then %do;
        category = substr(provider, 3, 2);
        category4 = substr(provider, 3, 4);
        category4_num = input(category4_num, ??4.);

        ** RHC;        
        if category = "38" then Amb = 1;
        if category = "39" then Amb = 1;
        if category = "34" then Amb = 1;
        if category = "85" then Amb = 1;
        if category = "86" then Amb = 1;
        if category = "87" then Amb = 1;
        if category = "88" then Amb = 1;
        if category = "89" then Amb = 1;
    
        ** FQHC;
        if category4_num >= 1800 and category4_num<=1989 then Amb = 1;
    %end;
%mend Diagnose_AmbulatoryCare;


%macro Define_Specialties();

    if spcl&i. = "01" then Specialist = 0;
    if spcl&i. = "08" then Specialist = 0;
    if spcl&i. = "11" then Specialist = 0;
    if spcl&i. = "25" then Specialist = 0;
    if spcl&i. = "32" then Specialist = 0;
    if spcl&i. = "37" then Specialist = 0;
    if spcl&i. = "38" then Specialist = 0;
    if spcl&i. = "64" then Specialist = 0;
    if spcl&i. = "42" then Specialist = 0;
    if spcl&i. = "43" then Specialist = 0;
    if spcl&i. = "44" then Specialist = 0;
    if spcl&i. = "49" then Specialist = 0;
    if spcl&i. = "50" then Specialist = 0;
    if spcl&i. = "51" then Specialist = 0;
    if spcl&i. = "52" then Specialist = 0;
    if spcl&i. = "53" then Specialist = 0;
    if spcl&i. = "54" then Specialist = 0;
    if spcl&i. = "55" then Specialist = 0;
    if spcl&i. = "56" then Specialist = 0;
    if spcl&i. = "57" then Specialist = 0;
    if spcl&i. = "58" then Specialist = 0;
    if spcl&i. = "59" then Specialist = 0;
    if spcl&i. = "74" then Specialist = 0;
    if spcl&i. = "60" then Specialist = 0;
    if spcl&i. = "61" then Specialist = 0;
    if spcl&i. = "63" then Specialist = 0;
    if spcl&i. = "65" then Specialist = 0;
    if spcl&i. = "67" then Specialist = 0;
    if spcl&i. = "69" then Specialist = 0;
    if spcl&i. = "70" then Specialist = 0;
    if spcl&i. = "71" then Specialist = 0;
    if spcl&i. = "72" then Specialist = 0;
    if spcl&i. = "73" then Specialist = 0;
    if spcl&i. = "75" then Specialist = 0;
    if spcl&i. = "79" then Specialist = 0;
    if spcl&i. = "80" then Specialist = 0;
    if spcl&i. = "81" then Specialist = 0;
    if spcl&i. = "88" then Specialist = 0;
    if spcl&i. = "35" then Specialist = 0;
    if spcl&i. = "89" then Specialist = 0;
    if spcl&i. = "95" then Specialist = 0;
    if spcl&i. = "97" then Specialist = 0;
    if spcl&i. = "99" then Specialist = 0;
    if spcl&i. = "A0" then Specialist = 0;
    if spcl&i. = "A5" then Specialist = 0;
    if spcl&i. = "93" then Specialist = 0;

    if spcl&i. = "18" then Optometrist = 1;	
    if spcl&i. = "41" then Optometrist = 1;	

    if spcl&i. = "01" then AmbSpcl = 1;
    if spcl&i. = "08" then AmbSpcl = 1;
    if spcl&i. = "11" then AmbSpcl = 1;
    if spcl&i. = "37" then AmbSpcl = 1;
    if spcl&i. = "50" then AmbSpcl = 1;
    if spcl&i. = "97" then AmbSpcl = 1;
    if spcl&i. = "70" then AmbSpcl = 1;

%mend Define_Specialties;
