%macro LoadGeographyCrosswalks();

    proc sort data=Cmsxw.cbsatocountycrosswalk (drop=l y2005 y2011 y2012 y2013 ssacounty 
        rename=(fipscounty=cnty00)) out=pos.cms_cnty_xw;
        by cnty00;
    run; 

    data pos.cnty_pmsa;
        set pos.cms_cnty_xw (keep=cnty00 cbsa);
        where cbsa ~="";
    run;

    x st stata/se ../external/zip/zipcode.dta ../external/pos/zipcode.sas7bdat -y;
    data pos.zipcode (drop=zipcode cnty00 rename=(zipcode_char=zipcode cnty00_char=cnty00 ));
        length zipcode 5.;
        set pos.zipcode (keep=zipcode cnty00);
        zipcode_char=put(zipcode,z5.);
        cnty00_char = put(cnty00,z5.);
     run;

    %do y = 4 %to 7 ;
        x st ../external/cbsa/cbsa0&y..dta ../external/pos/cbsa200&y..sas7bdat -y;
        data pos.cbsa200&y.(keep=cbsa cnty00 fileYear);
            length fileYear 4.;
            set pos.cbsa200&y.(drop=cbsaname rename=(cnty00=cnty00_num cbsa0&y.=cbsa_num));
            cnty00 = put(cnty00_num, z5.);
            cbsa = put(cbsa_num, z5.);
            fileYear = 200&y.;
            format fileYear 4.;
         run;

        ** Update CBSA merge to include primary MSAs instead of consolidated MSAs;
        data pos.cbsa200&y.;
            update pos.cbsa200&y. pos.cnty_pmsa;
            by cnty00;
        run;
    %end;
    data pos.cbsa_all;
        set %RepeatN(pos.cbsa,2004, 2007);
        by cnty00;
    run;

    data pos.fips_msa;
        length state_fips $2. state_msa $4.;
        infile '../external/rbu/CMS_Wage_Indices/fips_msa.csv'
        dlm='2C0D'x dsd missover lrecl=10000 firstobs=2;

        input state_fips $ state_name $ state_msa $;
    run;

%mend;

%macro LoadCMSWageIndices;

    data cmswi.cbsa_fy1998_fy2008 (drop=year_char);
        infile '../external/rbu/CMS_Wage_Indices/IPPS Pricer CBSA Wage Index History File - 10-17-2007.txt';
        input cbsa $ 1-5
              large $ 6-6
              date $ 7-14
              wage_index 16-21
              wage_index2 23-28;
        length month $ 2. year 4. fyear 4. wage_index 5. wage_index2 5.;
        year_char = substr(date,1,4);
        year = put(year_char, 4.);
        month = substr(date,5,2);
        format month $ 2.;
        fyear = year+1;
        format wage_index 5.4 wage_index2 5.4;
        wage_index = wage_index/10000;
        wage_index2 = wage_index2/10000;
    run;
    proc import datafile='../external/rbu/CMS_Wage_Indices/fy2009_cbsa_wage_indices.txt'
        out=cmswi.cbsa_fy2009
        dbms=dlm
        replace;
        delimiter='090D'x;
    run;
    data cmswi.cbsa_fy2009 (DROP=CBSAGEO len);
        length month $ 2. year 4. fyear 4. cbsa $ 5. CBSAGEO 5. occ_mix_adjusted_wage_index 6.;
        set cmswi.cbsa_fy2009 (KEEP= CBSAGEO occ_mix_adjusted_wage_index);
        cbsa = put(CBSAGEO, $5.);
        cbsa = strip(cbsa);
        len = length(cbsa);
        if len=1 then do cbsa = '0'||cbsa; end;;
        rename occ_mix_adjusted_wage_index=wage_index;
        fyear=2009;
        year = 2008;
        month = '10';
        format month $2.;
    run;
    data cmswi.cbsa_all;
        set cmswi.cbsa_fy1998_fy2008 cmswi.cbsa_fy2009;
    run;

    data cmswi.msa_all (drop=year_char);
        infile '../external/rbu/CMS_Wage_Indices/wage_hist.txt';
        input msa $ 1-4
              large $ 5-5
              date $ 6-13
              wage_index 15-20
              wage_index2 22-27;
        length month $ 2. year 4. fyear 4. wage_index 5. wage_index2 5.;
        year_char = substr(date,1,4);
        year = put(year_char, $4.);
        month = substr(date,5,2);
        format month $ 2.;
        fyear = year+1;
        format wage_index 5.4 wage_index2 5.4;
        wage_index = wage_index/10000;
        wage_index2 = wage_index2/10000;
    run;

    proc sort data=cmswi.msa_all;
        by msa;
    run;

    ***For states that have no rural wage index (DC RI MA PR NJ), generate;
    ** one by taking the average of the wage index for urban areas;
    proc sort data=pos.cms_cnty_xw (keep=msa ssast) 
        out=cmswi.msa_st;
        where ssast="09" or ssast="22" or ssast="31" or ssast="40" or ssast="41";
        by msa;
    run;
    data cmswi.msa_extra;
       format wage_index 5.4;
       length ssast $4;
       merge cmswi.msa_all (in=orig) cmswi.msa_st (in=st);
           by msa;
       if orig and st;
    run;
    proc sort data=cmswi.msa_extra;
        by ssast fyear;
    run;
    proc means data=cmswi.msa_extra noprint;
        by ssast fyear;
        var wage_index;
        output out=cmswi.msa_extra (rename=(ssast=msa)) median(wage_index)=wage_index;
    run;
    proc append base=cmswi.msa_all data=cmswi.msa_extra force;
    run;


    proc sort data=pos.cms_cnty_xw (keep=cnty00 ssast) 
        out=cmswi.cbsa_st;
        where ssast="09" or ssast="22" or ssast="31" or ssast="40" or ssast="41";
        by cnty00;
    run;

    data cmswi.cbsa_extra (keep=ssast cbsa);
        length ssast $4.;
        merge pos.cbsa_all (in=orig) cmswi.cbsa_st (in=st);
        by cnty00;
        if orig and st;
    run;

    proc sort data=cmswi.cbsa_extra nodupkey;
        by cbsa ssast;
    run;
    proc sort data=cmswi.cbsa_all;
        by cbsa;
    run;

   data cmswi.cbsa_extra;
        merge cmswi.cbsa_extra (in=st) cmswi.cbsa_all (in=orig) ;
        by cbsa;
        if orig and st;
    run;
    proc sort data=cmswi.cbsa_extra;
        by ssast fyear;
    run;
    proc means data=cmswi.cbsa_extra noprint;
        by ssast fyear;
        var wage_index;
        output out=cmswi.cbsa_extra (rename=(ssast=cbsa)) median(wage_index)=wage_index;
    run;
    proc append base=cmswi.cbsa_all data=cmswi.cbsa_extra force;
    run;

%mend;

%macro LoadRVUInfo;

    data rvu.rvu_weights;
        set %RepeatN(rvu.RVU,1997, 2010);
        rename year= end_yr;
    run;

    proc sort data=rvu.rvu_weights;
        by hcpcs_cd end_yr modifier;
    run;

    data rvu.rvu_weights_nomod (drop=modifier mdfr_cd1);
        set rvu.rvu_weights;
        where modifier eq "";
    run;

%mend LoadRVUInfo;

%macro LoadDRGInfo;
*#########################################################;
*Format DRG MATRIX -- in wide format change to long format;
*#########################################################;

    proc import datafile= "../external/rbu/DRG/DRGhistory.csv"
        out=drg.DRGhistory
        dbms=dlm
        replace;
        delimiter=","  ;
        getnames=yes;

    run;

    %do y=1997 %to 2009;
        data drg.DRG&y.;
            length fyear 4.;
            set drg.DRGhistory   (keep=DRG FY&y.);
            fyear=&y.+1;
            rename FY&y.=DRGwght;
            drg_cd1=put(DRG,3.0);

            %do i=1 %to 9;
                if drg_cd1="  &i." then drg_cd1="00&i.";
                %end;
            %do i=10 %to 99;
                if drg_cd1=" &i." then drg_cd1="0&i.";
                %end;
            rename drg_cd1=drg_cd;

        run;
        %end;

    **assumed that large labor areas index >1;
    data drg.DRGlong;
        set %RepeatN(drg.DRG,1997,2009);
        DRGwght=DRGwght/10000;
        if fyear=1992 then do;
        **FULLUPDATE;
        *** HEIN LIBRARY FEDERAL REGISESTER - 1991 - Aug 30 1991 - pg 43249;
        * labor     large urban :: 2526.80   otherurban :: 2486.60   rural :: 2434.26;
        * non-labor large urban :: 1041.01   otherurban :: 1024.54   rural ::  816.50;

        *** HEIN LIBRARY FEDERAL REGISESTER - 1991 - Aug 30 1991 - pg 43249 - no cap reported;
            capital=.;
            labor=(2526.80+2486.60+2434.26)/3;
            nonlabor=(1041.01+1024.54+816.50)/3;
            end;
        if fyear=1993 then do;
        **FULLUPDATE;
        *** HEIN LIBRARY FEDERAL REGISESTER - 1992 - Sep 1,1992 - pg39845
        * labor     large urban :: 2588.38   otherurban :: 2547.40   rural :: 2623.30;
        * non-labor large urban :: 1066.39   otherurban :: 1049.51   rural ::  844.54;

        *** HEIN LIBRARY FEDERAL REGISESTER - 1992 - Sep 1,1992 - pg39845;
            capital=417.29;
            labor=(2855.38+2547.40+2623.30)/3;
            nonlabor=(1066.39+1049.51+844.54)/3;
            end;
        if fyear=1994 then do;
       **FULLUPDATE;
        *** HEIN LIBRARY FEDERAL REGISESTER - 1992 - Sep 1,1993 - pg46362;
        * labor     large urban :: 2646.19   otherurban :: 2604.30   rural :: 2698.19;
        * non-labor large urban :: 1090.21   otherurban :: 1072.95   rural ::  869.31;

        *** HEIN LIBRARY FEDERAL REGISESTER - 1992 - Sep 1,1993 - pg46362;
            capital=378.34;
            labor=(2646.19+2604.30+2698.19)/3;
            nonlabor=(1090.21+1072.95+869.31)/3;
            end;
        if fyear=1995 then do;
        **FULLUPDATE;
        ** 9/1/1994: text (270KB);
        * labor     <1 :: 2666.52        labor >=1 :: 2709.42  ;
        * non-labor <1 :: 1068.10   non-labor >=1 :: 1085.29 ;
            capital=376.83;
            labor=(2709.42+2666.52)/2;
            nonlabor=(1068.10+1085.29)/2;
            end;
        if fyear=1996 then do;
        **FULLUPDATE;
        ** 9/1/1995: text (270KB);
        * labor     <1 :: 2697.99        labor >=1 :: 2741.39  ;
        * non-labor <1 :: 1080.71   non-labor >=1 ::  1098.09 ;

        ** :: change to the way capital is updated - see final rule;
            capital=461.96;
            labor=(2697.99+2741.39)/2;
            nonlabor=(1080.71+1098.09)/2;
            end;
        if fyear=1997 then do;
        **FULLUPDATE;
        ** 8/30/1996: text (270KB);
        * labor     <1 :: 2738.79        labor >=1 :: 2782.84  ;
        * non-labor <1 :: 1107.83    non-labor >=1 :: 1125.64 ;

        ** :: change to the way capital is updated - see final rule;
            capital=438.92;
            labor=(2738.79+2782.84)/2;
            nonlabor=(1107.83+1125.64)/2;
            end;
        if fyear=1998 then do;
            labor=(2776.21+2732.26)/2;
            nonlabor=(1128.44+1110.58)/2;
            capital=371.51;
            end;
        if fyear=1999 then do;
            labor=(2783.42+2739.36)/2;
            nonlabor=(1313.41+1113.47)/2;
            capital= 378.05;
            end;
        if fyear=2000 then do;
            labor=(2809.18+2764.7)/2;
            nonlabor=(1141.85+1123.76)/2;
            capital= 377.03;
            end;
        if fyear=2001 then do;
            capital=382.03;
            labor=(2864.19+2818.85)/2;
            nonlabor=(1164.21+1145.78)/2;
            end;
        if fyear=2002 then do;
            capital=390.74;
            labor=(2955.44+2908.65)/2;
            nonlabor=(1201.30+1182.27)/2;
            end;
        if fyear=2003 then do;
        **FULLUPDATE;
        ** CMS-1470-CN: PDF Version (270KB);
        * labor     <1 :: 2974.75        labor >=1 :: 3022.6  ;
        * non-labor <1 :: 1209.15   non-labor >=1 :: 1228.6 ;

            capital=407.01;
            labor=(3022.6+2974.75)/2;
            nonlabor=(1209.15+1228.6)/2;
            end;

        if fyear=2004 then do;
                 **FULLUPDATE;
        ** CMS-1470-CN: PDF Version (270KB);
        * labor     <1 :: 3089.73        labor >=1 :: 3136.39  ;
        * non-labor <1 :: 1254.67   non-labor >=1 :: 1274.85 ;
            capital=414.18;
            labor=(3089.73+3136.39)/2;
            nonlabor=(1254.67+1274.85)/2;
            end;
        if fyear=2005 then do;
         **FULLUPDATE;
        ** CMS-1428-F2: PDF Version (1.9MB)
        ** http://www.gpo.gov/fdsys/pkg/FR-2005-05-04/pdf/05-8507.pdf -- pg 23483;
        * labor     <1 :: 2823.64        labor >=1 :: 3238.07  ;
        * non-labor <1 :: 1730.62   non-labor >=1 :: 1316.18 ;
            capital=416.53;
            labor=(3238.07+2823.64)/2;
            nonlabor=(1316.18+1730.62)/2;
            end;
        if fyear=2006 then do;
        **FULLUPDATE;
        ** http://www.gpo.gov/fdsys/pkg/FR-2005-05-04/pdf/05-8507.pdf -- pg 23483
        * labor     <1 :: 1428.55       labor >=1 :: 1791.58  ;
        * non-labor <1 :: 2923.11   non-labor >=1 :: 3286.14 ;
            labor=(3286.14+2923.11)/2;
            nonlabor=(1428.55+1791.58)/2;
            capital=419.90;
            end;
        if fyear=2007 then do;
        **FULLUPDATE;
        ** careful, CMS update the base payments several time. ;
        ** CMS-1488-N: PDF Version (989KB);
        * non-labor     <1 :: 1852.31        non-labor >=1 :: 1476.97   ;
        * labor         <1 :: 3022.18        labor     >=1 :: 3397.52 ;
            labor=(3397.52+3022.18)/2;
            nonlabor=(1852.31+1476.97)/2;
            capital=427.03;
            end;
        if fyear=2008 then do;
        **FULLUPDATE;
        ** careful, CMS update the base payments several time. ;
        ** CMS-1533-CN2: PDF Version (727KB)  ;
        * non-labor     <1 :: 1885.04        non-labor >=1 :: 1503.07   ;
        * labor <1 :: 3075.60   labor >=1 :: 3457.57 ;
            labor=(3457.57+3075.6)/2;
            nonlabor=(1885.04+1503.07)/2;
            capital=423.34;
            end;
        if fyear=2009 then do;
        **FULLUPDATE;
        * labor     <1 :: 1544.98       labor >=1 :: 3553.98 ;
        * non-labor <1 :: 1934.60   non-labor >=1 :: 3161.36 ;
            labor=(3553.98+3161.36)/2;
            nonlabor=(1544.98+1934.6)/2;
            capital=421.29;
            end;
        if fyear=2010 then do;
        **FULLUPDATE
        * labor     <1 :: 3179.71       labor >=1 :: 3441.26 ;
        * non-labor <1 :: 1948.85   non-labor >=1 :: 1687.30 ;
            labor=(3179.71+3441.26)/2;
            nonlabor=(1948.85+1687.30)/2;
            capital=420.67;
            end;
    run;

    proc sort data=drg.DRGlong;
        by fyear drg_cd;
    run;

%mend;

