*##############################################################;
*# THIS MACRO GENERATES RBU MEASURE FOR CARRIER YEAR DATA #####;
*##############################################################;
%macro ProcessCarrier(pct=, year=);

    ** Define what is to be sorted by and what is to define unique index;
    %let rawid=bene_id;
    %let physid=phys_id;

    /* The following macro generates cartemp
     * First I append the appropriate parts of two consecutive years together
     * If the file is using EHIC, I merge in BENE_ID */

    %GenerateCarrierYear(year=&year., pct=&pct.);

    /* In the current cartemp data set, physicians are identified by UPIN and
     * NPI. I need to make them all PHYS_ID to merge in the PHYS_ID - SPCL
     * Crosswalk. */

    %DefinePhysId(npiVar=npi, upinVar=upin, data=cartemp, physwalk=physid_upinnpi);

    %Carrier_RVU_Prep(yearin=&year.);

    ** With claims with 0 or missing RBUs, we use the national mean of claims with that HCPCS code.;
    **Therefore, the variable car_RBU_mean is our main carrier RBU measure and is renamed accordingly. 
    ** This is used to create the spending decomposition
    ** Alternates are dropped here, but were still generated in Carrier_RVU_Prep for futrure versatility;

    data cartemp (drop=provzip);
        length zipcode $ &zipcode_length.;
        set cartemp (drop=car_RBU car_RBU2 car_RBU2_mean);
        provzip = trim(provzip);
        zipcode = substr(provzip, 1, 5);
        hcpcs_num = input(hcpcs_cd, ?? 5.);

        %SpendingBreakdown(filetype=carrier);
   run;


    %DefinePhysHrr(data=cartemp, filetype=carrier);

    proc sort data=cartemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    proc means data=cartemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var lalowchg car_RBU_mean inpatient_RBU outpatient_RBU er_RBU other_RBU;
        output out=car_ind_&year. sum(lalowchg)=pay_prov sum(car_RBU_mean)=car_RBU_mean
            sum(inpatient_RBU)=inpatient_RBU sum(outpatient_RBU)=outpatient_RBU 
            sum(er_RBU)=er_RBU sum(other_RBU)=other_RBU;
    run;

    * Summing all expenditure variables to scale RBU variables to match total expenditures;
    proc means data=car_ind_&year.(WHERE=(car_RBU_mean~=.)) noprint;
        var pay_prov car_RBU_mean;
        output out=rvu.car_rbu_check_&year. mean(year)=year sum(pay_prov) = pay_prov_tot 
            sum(car_RBU_mean) = car_RBU_mean_tot;
    run;

    data car_ind_&year.;
        merge car_ind_&year. (in=clm) rvu.car_rbu_check_&year. (in=check keep=year pay_prov_tot car_RBU_mean_tot);
        by year;
        if clm and check;
    run;

    data car_ind_&year. (DROP= pay_prov_tot car_RBU_mean_tot RBU_mean_tmp ipRBU_tmp opRBU_tmp erRBU_tmp othRBU_tmp);
        set car_ind_&year. (RENAME= (car_RBU_mean=RBU_mean_tmp inpatient_RBU=ipRBU_tmp outpatient_RBU=opRBU_tmp
            er_RBU=erRBU_tmp other_RBU=othRBU_tmp));
        car_RBU_mean = RBU_mean_tmp*(pay_prov_tot/car_RBU_mean_tot);
        inpatient_RBU = ipRBU_tmp*(pay_prov_tot/car_RBU_mean_tot);
        outpatient_RBU = opRBU_tmp*(pay_prov_tot/car_RBU_mean_tot);
        er_RBU = erRBU_tmp*(pay_prov_tot/car_RBU_mean_tot);
        other_RBU = othRBU_tmp*(pay_prov_tot/car_RBU_mean_tot);
    run;

    proc means data=car_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var pay_prov car_RBU_mean inpatient_RBU outpatient_RBU er_RBU other_RBU;
        output out=out.car_ind_&year. sum(pay_prov)=pay_prov sum(car_RBU_mean)=car_RBU_mean
            sum(inpatient_RBU)=inpatient_RBU sum(outpatient_RBU)=outpatient_RBU 
            sum(er_RBU)=er_RBU sum(other_RBU)=other_RBU;
    run;
    data out.car_ind_&year. (drop=car_RBU_mean);
        set out.car_ind_&year.;
        RBU_missing = 0;
        if car_RBU_mean=. then RBU_missing=1;
        RBU=car_RBU_mean;
    run;

%mend;
