*#######################################################################;
*# THIS MACRO GENERATES RBU MEASURE FOR INPATIENT YEAR DATA ###;
*#######################################################################;
%macro ProcessInpatient(pct=, year=);

    ** Define what is to be sorted by and what is to define unique index;
    %let rawid=bene_id;
    %let physid=phys_id;

    /* The following macro generates cartemp
     * First I append the appropriate parts of two consecutive years together
     * If the file is using EHIC, I merge in BENE_ID */
    %GenerateIpClmsYear(year=&year., pct=&pct.);
    /* In the current cartemp data set, physicians are identified by UPIN and
     * NPI. I need to make them all PHYS_ID to merge in the PHYS_ID */

    %DefinePhysId(npiVar=npi, upinVar=upin, data=ipclmstemp, physwalk=physid_upinnpi);
    %IP_RBU(data = ipclmstemp);

    data ipclmstemp;
        length bene_id $&bene_id_length.;
        set ipclmstemp (drop=inpatient_Q);
        %Calculate_Expenditures(filetype=inpatient);
        test=0;
    run;

    %DefinePhysHrr(data=ipclmstemp, filetype=inpatient);

    proc sort data=ipclmstemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    data ip_clms_id;
        set ipclmstemp (KEEP=&rawid. &physid. clm_id phys_hrr);
    run;

    proc means data=ipclmstemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var pay_prov inpatient_RBU test;
        output out=ip_clm_ind_&year. sum(pay_prov)=pay_prov sum(inpatient_RBU)=inpatient_RBU max(test)=test;
    run;

    *********************************************;
    *** PROCESS REVENUE CENTER DATA;
    *********************************************;

    %GenerateIpRevCntrsYear(year=&year., pct=&pct.);

    proc sort data=ip_clms_id nodupkey; by &rawid. clm_id; run;
    proc sort data=iprevtemp; by &rawid. clm_id; run;

    data iprevtemp;
        merge iprevtemp (in=rev) ip_clms_id (in=clm keep=&rawid. &physid. clm_id phys_hrr);
        by &rawid. clm_id;
        if rev and clm;
    run;

    ** Tag ER Spending;
    data iprevtemp;
        set iprevtemp;
        rev_cntr_num = input(rev_cntr, ?? 4.);
        %SpendingBreakdown(filetype=inpatient);
    run;

    proc sort data=iprevtemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    proc means data=iprevtemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Er test;
        output out=ip_rev_ind_&year. max(Er)=Er max(test)=test;
    run;

    ************************************;
    *** MERGE DATA AND OUTPUT NOW AT CLAIM LEVEL;
    ************************************;
    data ip_ind_&year.;
         merge ip_clm_ind_&year. (in=clm) ip_rev_ind_&year. (in=rev);
         by &rawid. &physid. phys_hrr year clm_id;
    run;

    data ip_ind_&year.;
        set ip_ind_&year.(rename=(inpatient_RBU=RBU));
        if Er=1 then er_RBU=RBU;
        else inpatient_RBU=RBU;
        if inpatient_RBU = . then inpatient_RBU=0;
        if er_RBU = . then er_RBU =0;  
    run;

    * Summing all expenditure variables to scale RBU variables to match total expenditures;
    proc means data=ip_ind_&year. noprint;
        var pay_prov RBU year;
        output out=drg.ip_rbu_check_&year. mean(year)=year sum(pay_prov) = pay_prov_tot sum(RBU) = RBU_tot;
    run;

    data ip_ind_&year.;
        merge ip_ind_&year. (in=clm) drg.ip_rbu_check_&year. (in=check keep=year pay_prov_tot RBU_tot);
            by year;
        if clm and check;
    run;

    data ip_ind_&year. (DROP= pay_prov_tot RBU_tot RBU_tmp erRBU_tmp ipRBU_tmp);
        set ip_ind_&year.(RENAME= (RBU=RBU_tmp er_RBU=erRBU_tmp inpatient_RBU=ipRBU_tmp));
        RBU = RBU_tmp*(pay_prov_tot/RBU_tot);
        inpatient_RBU = ipRBU_tmp*(pay_prov_tot/RBU_tot);
        er_RBU = erRBU_tmp*(pay_prov_tot/RBU_tot);
    run;

    proc means data=ip_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var inpatient_RBU er_RBU RBU test;
        output out=ip_ind_&year. sum(inpatient_RBU)=inpatient_RBU sum(RBU)=RBU sum(er_RBU)=er_RBU max(test)=test;
    run;

    data out.ip_ind_&year.;
        set ip_ind_&year.;
        RBU_missing = 0;
        if RBU=. then RBU_missing=1;
    run;
%mend;



