********************************************************************;
** THIS MACRO GENERATES THE RBU MEASURE  FOR OUTPATIENT YEAR DATA **;
********************************************************************;
%macro ProcessOutpatient(pct=, year=);

    %let rawid=bene_id;
    %let physid=phys_id;

    /* The following macro generates opclmstemp
     * First I append the appropriate parts of two consecutive years together
     * If the file is using EHIC, I merge in BENE_ID */

    %GenerateOpClmsYear(year=&year., pct=&pct.);

    /* In the current cartemp data set, physicians are identified by UPIN and
     * NPI. I need to make them all PHYS_ID */

    %DefinePhysId(npiVar=npi, upinVar=upin, data=opclmstemp, physwalk=physid_upinnpi);

    %OP_RBU_Prep(data=opclmstemp);

    data opclmstemp;
        set opclmstemp (WHERE=(wage_index~=.)) opclmstemp_missingWI;
        %Calculate_Expenditures(filetype=outpatient);
        outpatient_RBU = pay_prov/(0.4 + 0.6*wage_index);
        test=0;
    run;

    %DefinePhysHrr(data=opclmstemp, filetype=outpatient);

    proc sort data=opclmstemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    data op_clms_id;
        set opclmstemp (KEEP=&rawid. &physid. clm_id phys_hrr);
    run;

    proc means data=opclmstemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var outpatient_RBU pay_prov test;
        output out=op_clm_ind_&year. sum(outpatient_RBU)=outpatient_RBU sum(pay_prov)=pay_prov max(test)=test;
    run;

   *********************************************;
    *** PROCESS REVENUE CENTER DATA;
    *********************************************;

    %GenerateOpRevCntrsYear(year=&year., pct=&pct.);

    proc sort data=op_clms_id nodupkey; by &rawid. clm_id; run;
    proc sort data=oprevtemp; by &rawid. clm_id; run;

    data oprevtemp;
        merge oprevtemp (in=rev) op_clms_id (in=clm keep=&rawid. &physid. clm_id phys_hrr);
        by &rawid. clm_id;
        if rev and clm;
    run;

    ** Tag ER Spending;
    data oprevtemp;
        set oprevtemp;
        rev_cntr_num = input(rev_cntr, ?? 4.);
        %SpendingBreakdown(filetype=outpatient);
    run;

    proc sort data=oprevtemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    proc means data=oprevtemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Er test;
        output out=op_rev_ind_&year. max(Er)=Er max(test)=test;
    run;

    ************************************;
    *** MERGE DATA AND OUTPUT NOW AT CLAIM LEVEL;
    ************************************;

    data op_ind_&year.;
         merge op_clm_ind_&year. (in=clm) op_rev_ind_&year. (in=rev);
         by &rawid. &physid. phys_hrr year clm_id;
    run;

    data op_ind_&year.;
        set op_ind_&year.(rename=(outpatient_RBU=RBU));
        if Er=1 then er_RBU=RBU;
        else outpatient_RBU=RBU;
        if outpatient_RBU = . then outpatient_RBU=0;
        if er_RBU = . then er_RBU =0;  
    run;

    * The total expenditures must be summed to scale the RBU measures so that the SUM(RBU)=SUM(TotExpn);
    proc means data=op_ind_&year. noprint;
        var pay_prov RBU year;
        output out=drg.op_rbu_check_&year. mean(year)=year sum(pay_prov) = pay_prov_tot sum(RBU) = RBU_tot;
    run;

    data op_ind_&year.;
        merge op_ind_&year. (in=clm) drg.op_rbu_check_&year. (in=check keep=year pay_prov_tot RBU_tot);
            by year;
        if clm and check;
    run;

    data op_ind_&year. (DROP= pay_prov_tot RBU_tot RBU_tmp erRBU_tmp opRBU_tmp);
        set op_ind_&year.(RENAME= (RBU=RBU_tmp er_RBU=erRBU_tmp outpatient_RBU=opRBU_tmp));
        RBU = RBU_tmp*(pay_prov_tot/RBU_tot);
        outpatient_RBU = opRBU_tmp*(pay_prov_tot/RBU_tot);
        er_RBU = erRBU_tmp*(pay_prov_tot/RBU_tot);
    run;

    proc means data=op_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var outpatient_RBU er_RBU RBU test;
        output out=op_ind_&year. sum(outpatient_RBU)=outpatient_RBU sum(RBU)=RBU sum(er_RBU)=er_RBU max(test)=test;
    run;

    data out.op_ind_&year.;
        set op_ind_&year.;
        RBU_missing = 0;
        if RBU=. then RBU_missing=1;

%mend;

