%macro Carrier_RVU_Prep(yearin=);

*** FROM CLAIMS PROCESSING IOM ;
** In addition to the major annual update, CMS also updates HCPCS codes quarterly to reflect ;
** additional changes or corrections that are emergency in nature.  Quarterly changes are ;
** issued by letter or memorandum for local implementation.;
** For this reason we use those reported in the last quarter;

*#########################################################################################;
**  LIMIT SAMPLE;
*#########################################################################################;
**SOURCE FOR OlD CONVERSION FACTORS;
** Medicare Claims Processing Manual;
** Chapter 12 - Physicians/Nonphysician Practitioners;
**     http://www.cms.gov/Regulations-and-Guidance/Guidance/Manuals/downloads/clm104c12.pdf;
**;
** updateThe national conversion factors are:;
** 2002 - $36.1992 ;
** 2001 - $38.2581 ;
** 2000 - $36.6137 ;
** 1999 - $34.7315 ;
** 1998 - $36.6873 ;
** 1997 - $40.9603 (Surgical) $33.8454 (Nonsurgical) $35.7671 (Primary Care);
** 1996 - $40.7986 (Surgical) $34.6296 (Nonsurgical) $35.4173 (Primary Care);
** 1995 - $39.447 (Surgical) $34.616 (Nonsurgical) $36.382 (Primary Care)   ;
** 1994 - $35.158 (Surgical) $32.905 (Nonsurgical) $33.718 (Primary Care)   ;
** 1993 - $31.926 (Surgical) $31,249 (Nonsurgical)                          ;
** 1992 - $31.001;
** For the years 1999 through 2002, payments attributable to practice expenses transitioned ;
** from charge-based amounts to resource-based practice expense RVUs.  The CMS used ;
** the following transition formula to calculate the practice expense RVUs.;
** 1999 -75 percent of charged-based RVUs and 25 percent of the resource-based ;
** RVUs.;
** 2000 - 50 percent of the charge-based RVUs and 50 percent of the resource-based ;
** RVUs.2001 - 25 percent of the charge-based RVUs and 75 percent of the resource-based ;
** RVUs.;
** 2002 - 100 percent of the resource-based RVUs;

    data rvu.cartemp_1 (drop=hcpcs_cd mdfr_cd1 rename=(hcpcs_cdsp=hcpcs_cd modifier=mdfr_cd1));
        length hcpcs_cd $7 modifier $4;
        set cartemp ;
/*      WHERE trim(clmstatus) ne "0";
We need to decide whether these "denied" claims are included in our sample.*/
        modifier=trim(mdfr_cd1);
        hcpcs_cdsp=trim(hcpcs_cd);

        FORMAT thru_dt DATE9.;
        ** Trying to ignore all other hcpcs modifiers because only these three are found in the ;
        ** RVU crosswalk files;
        convfact=.          ;
        cf_surg=.                            ;
        cf_primcare=.                            ;
        cf_other=.                            ;
        cf_anesth=.                            ;
        * BASED ON OIM MANUALS - SEE ABOVE;
        if year(thru_dt) = 1992 then do;
            convfact=31.001;
            end;
        * BASED ON OIM MANUALS - SEE ABOVE;
        if year(thru_dt) = 1993 then do;
            cf_anesth=.                            ;
            cf_surg=31.926                          ;
            cf_primcare=.               ;
            cf_other=31.249                            ;
            **WE DO NOT HAVE THE UPDATE CODE IN THE 92-94 PFS. USE AVERAGE ;
            convfact=(31.249+31.926)/2;
            end;
        * BASED ON OIM MANUALS - SEE ABOVE;
        if year(thru_dt) = 1998 then convfact=36.6873  ;
        ** seems low;
        if year(thru_dt) = 1999 then convfact=34.7315  ;
        if year(thru_dt) = 2000 then convfact=36.6137   ;
        if year(thru_dt) = 2001 then convfact=38.2581   ;
        if year(thru_dt) = 2002 then convfact=36.1992   ;
        if year(thru_dt) = 2003 then convfact=36.7856   ;
        if year(thru_dt) = 2004 then convfact=37.3374   ;
        if year(thru_dt) = 2005 then convfact=37.8975   ;
        if year(thru_dt) = 2006 then convfact=37.8975   ;
        if year(thru_dt) = 2007 then convfact=35.9848   ;
        * January to June30th because of rule pased    ;
        if year(thru_dt) = 2008 and month(thru_dt) <=6 then convfact=38.0870       ;
        * July30  to Dec31th                           ;
        if year(thru_dt) = 2008 and month(thru_dt) >=7 then convfact=34.0682       ;
        if year(thru_dt) = 2009 then convfact=36.0666 ;
        end_yr=year(thru_dt);
    run;


*#########################################################################################;
**  TAG OBERVATIONS WITH modifiers;
*#########################################################################################;
    ** These are the only 3 modifiers found in the RVU payment systems.;
    data rvu.addVar (drop= flag) rvu.addVarNonMod (drop=flag);
        set rvu.cartemp_1;
        end_yr=year(thru_dt);
        flag=0;
        if mdfr_cd1 = "26" then flag=1;
        if mdfr_cd1 = "53" then flag=1;
        if mdfr_cd1 = "TC" then flag=1;
        **BASED ON NOTE FROM FINAL RULE;
        if year(thru_dt) = 2003 and month(thru_dt) <= 3 then end_yr=2002;
        modifier=mdfr_cd1;
        flag2002=0;
        **BASED ON NOTE FROM FINAL RULE;
        if year(thru_dt) = 2003 and month(thru_dt) <= 3 then do ;
            end_yr=2002;
            flag2002=1;
        end;
        if flag=1 then output rvu.addVar;
        if flag=0 then output rvu.addVarNonMod;
    run;


    proc sort data=rvu.addVarNonMod;
        by hcpcs_cd end_yr;
    run;

    proc sort data=rvu.addVar;
        by hcpcs_cd end_yr modifier;
    run;

    ** MERGE BASED ON HCPCS_CD AND END_YR IN CASE WHERE MODIFIER IS NOT ONE OF THREE IDENTIFIED;
    data rvu.mergeInRVUsNonMod;
        merge rvu.addVarNonMod(in=nonmod) rvu.rvu_weights_nomod (in=inphyf) ;
        by hcpcs_cd end_yr ;
        innonMod=nonmod;
        inPhy=inphyf;
        if innonMod ;
    run;

    ** MERGE BASED ON HCPCS_CD AND END_YR AND MODIFIER ;
    data rvu.mergeInRVUsMod;
        merge rvu.addVar(in=nonmod) rvu.rvu_weights(in=inphyf drop=mdfr_cd1) ;
        by hcpcs_cd end_yr modifier;
        inMod=nonmod;
        inPhy=inphyf;
        if inMod ;
    run;



/*
    Note: Of those that merge, 26.41% of the claims (18.34% of costs) are associated with total RVU of 0.  These are largely associated with Status Codes indicating statutory exclusions, excluded from physician fee schedule by regulation, or that the carriers themselves are supposed to price the code.
Note: For this 26.41% of claims, we assign the RVU to be the mean Carrier Payment by HCPCS code, modifier and year, divided by the Conversion Factor for that year
*/

    data rvu.RVUcalcs rvu.missRVU;
        set rvu.mergeInRVUsNonMod (WHERE=(innonMod=1)) rvu.mergeInRVUsMod (WHERE=(inMod=1));
        *FACILITY/NON-FACILITY CODES FOUND HERE::;
        ** https://www.cms.gov/manuals/downloads/clm104c26.pdf;
        * FAcility;
        fac="O";
        if plcsrvc in("21","22","23","24","26","31","33","41","42","51",
                       "52","53","56","61") then fac="F";
        * Non-facility ;
        if plcsrvc in("01","03","04","09","11","12","13","14","15","16",
                      "17","20","25","32","33","49","50","54","57","60",
                      "62","65","71","72","81","91") then fac="N";
        **Facilty/non-facilty RVUwghts are handled in the import Stata script;
        RVUwght=0;
        if fac="F" then RVUwght=fac_total_rvu;
        if fac="N" or fac="O" then RVUwght=nonfac_total_rvu;
        cyear=end_yr;
        if modifier="" then modifier="MI";
        if RVUwght=0 or RVUwght= . then do;
            missingrvu=1;
            output rvu.missRVU;
        end;
        if RVUwght ne 0 and RVUwght ne . then do;
            missingrvu=0;
            output rvu.RVUcalcs;
        end;
        **could speed up by dropping observations;
    run;

    proc sort data = rvu.missRVU;
        by  hcpcs_cd modifier end_yr;
    run;
    proc means data=rvu.missRVU (keep=hcpcs_cd modifier end_yr lalowchg ) NWAY NOPRINT;
        by hcpcs_cd modifier end_yr;
        var lalowchg;
        output out=rvu.missRVUcollapse median(lalowchg)=medianHCPCScost mean(lalowchg)=meanHCPCScost;
    run;

   /* proc sort data=rvu.missRVU;
        by hcpcs_cd modifier end_yr;
    run;

    proc sort data=rvu.missRVUcollapse;
        by hcpcs_cd modifier end_yr;
    run;*/

    data rvu.collapseHCPCScostMissRVU;
        merge rvu.missRVU (in=inRVU) rvu.missRVUcollapse (in=inMed keep=hcpcs_cd modifier end_yr medianHCPCScost meanHCPCScost);
        by hcpcs_cd modifier end_yr;
        if inRVU and inMed;
    run;

        /* before 1997
        10. Update indicator. This column indicates whether the update for
surgical procedures, primary care services, or other nonsurgical
services applies to the HCPCS code in column 1. A ``0'' appears in this
field for codes that are deleted in 1995 or are not paid under the
physician fee schedule. A ``P'' in this column indicates that the
update and CF for primary care services applies to this code. An ``N''
in this column indicates that the update and CF for other nonsurgical
services applies to this code. An ``S'' in this column indicates that
the separate update and CF for surgical procedures applies.
Federal Register / Vol. 59, No. 235 / Thursday, December 8, 1994 / Rules
and Regulations

    3. Status indicator. This indicator shows whether the HCPCS code is
in the physician fee schedule and whether it is separately payable if
the service is covered.
    A=Active code. These codes are separately paid under the physician
fee schedule if covered. There will be RVUs for codes with this status.
The presence of an ``A'' indicator does not mean that Medicare has made
a national decision regarding the coverage of the service. Carriers
remain responsible for coverage decisions in the absence of a national
Medicare policy.
    B=Payment for covered services is always bundled into payment for
other services not specified. If RVUs are shown, they are not used for
Medicare payment. If these services are covered, payment for them is
subsumed by the payment for the services to which they are incident.
(An example is a telephone call from a hospital nurse regarding care of
a patient.)
    C=Carrier-priced codes. Carriers will establish RVUs and payment
amounts for these services, generally on a case-by-case basis following
review of documentation, such as an operative report.
    D=Deleted codes. These codes are deleted effective with the
beginning of the CY.
    E=Excluded from physician fee schedule by regulation. These codes
are for items or services that HCFA chose to exclude from the physician
fee schedule payment by regulation. No RVUs are shown, and no payment
may be made under the physician fee schedule for these codes. Payment
for them, if they are covered, continues under reasonable charge or
other payment procedures.
    G=Code not valid for Medicare purposes. Medicare does not recognize
codes assigned this status. Medicare uses another code for reporting
of, and payment for, these services.
    H=Deleted modifier. This code had TC and PC components in 1994. For
1995, these components are deleted.
    N=Noncovered service. These codes are noncovered services. Medicare
payment may not be made for these codes. If RVUs are shown, they are
not used for Medicare payment.
    P=Bundled or excluded codes. There are no RVUs for these services.
No separate payment should be made for them under the physician fee
schedule.
--If the item or service is covered as incident to a physician service
and is furnished on the same day as a physician service, payment for it
is bundled into the payment for the physician service to which it is
incident (an example is an elastic bandage furnished by a physician
incident to a physician service).
--If the item or service is covered as other than incident to a
physician service, it is excluded from the physician fee schedule (for
example, colostomy supplies) and is paid under the other payment
provisions of the Act.
    R=Restricted coverage. Special coverage instructions apply. If
covered and no RVUs are shown, the service is carrier-priced.
    T=Injections. There are RVUs for these services, but they are only
paid if there are no other services payable under the physician fee
schedule billed on the same date by the same provider. If any other
services payable under the physician fee schedule are billed on the
same date by the same provider, these services are bundled into the
service(s) for which payment is made.
    X=Exclusion by law. These codes represent an item or service that
is not within the definition of ``physician services'' for physician
fee schedule payment purposes. No RVUs are shown for these codes, and
no payment may be made under the physician fee schedule. (Examples are
ambulance services and clinical diagnostic laboratory services).

                        cf_anesth=15.32                            ;
            cf_surg=39.45                            ;
            cf_primcare=.                            ;
            cf_other=.                            ;

*/

    data rvu.cartemp_2;
        set rvu.collapseHCPCScostMissRVU rvu.RVUcalcs;
        RVUwght2 = RVUwght;
       if missingrvu=1 then do;
            RVUwght=medianHCPCScost/convfact;
            RVUwght2 = meanHCPCScost/convfact;
        end;
        RVUbase=convfact*(RVUwght);
        RVUbase2=convfact*(RVUwght2);
    run;

    proc sort data=rvu.cartemp_2;
        by end_yr;
    run;

    data rvu.ANNUAL_CALCS (keep=end_yr ratio ratio2);
        set rvu.cartemp_2 /*(keep=end_yr lalowchg convfact RVUwght RVUwght2)*/;
        by end_yr;
        retain totalPay totalRVU totalRVU2 totalConv;
        if first.end_yr then totalPay=0;
        if first.end_yr then  totalRVU=0;
        if first.end_yr then  totalRVU2=0;
        if first.end_yr then totalConv=0 ;

        totalPay=totalPay+lalowchg;
        totalConv=totalConv+convfact;
        totalRVU = RVUwght + totalRVU ;
        totalRVU2 = RVUwght2 + totalRVU2 ;

        if last.end_yr then ratio=totalPay/totalRVU;
        if last.end_yr then ratio2=totalPay/totalRVU2;
        if last.end_yr then output;
    run;

**RATIO TESTING;
    data cartemp;
        merge rvu.ANNUAL_CALCS (in=yeardta) rvu.cartemp_2 (in=clms);
        by end_yr;
        yeardtafl=yeardta;
        clmsfl=clms;

        if end_yr >= 1998 then do;
            car_RBU=RVUwght*convfact;
            car_RBU_mean=RVUwght2*convfact;
            end;
        else if end_yr = 1995 or end_yr = 1996 or end_yr = 1997 then do;
            if update ="P" then car_RBU=cf_primcare*(RVUwght);
            if update ="P" then car_RBU_mean=cf_primcare*(RVUwght2);
            if update ="N" then car_RBU=cf_other*(RVUwght);
            if update ="N" then car_RBU_mean=cf_other*(RVUwght2);
            if update ="S" then car_RBU=cf_surg*(RVUwght);
            if update ="S" then car_RBU_mean=cf_surg*(RVUwght2);
            end;
        car_RBU2=RVUwght*ratio;
        car_RBU2_mean=RVUwght2*ratio2;
        if flag2002=1 then end_yr=2003;

        LABEL
            car_RBU2= "Alternate Cost utilization measure : conversion factor estimated from data"
            car_RBU2_mean= "Alternate Cost utilization measure : conversion factor estimated from data - mean"
            car_RBU= "Recommended cost utilization measure: conversion factor from Final Rule"
            car_RBU_mean= "Recommended cost utilization measure: conversion factor from Final Rule - mean"
            end_yr= "Year of the claim end date, year(expensdt2)"
            mdfr_cd1= "First HCPCS modifier code-RAW"
            modifier="Modifier code used to merge in PFS, assigned MI code"
            plcsrvc = "Place of service code"
            RVUwght ="total RVU weight associated with HCPCS code"
            convfact ="Carrier conversion factor, $/RVU wght"
            flag2002="Half of fiscal year 2003 uses 2002 rates according to the final rule - flags these cases"
            missingrvu="RVU which are not in the PFS and median cost/conversion factor assigned as weight"
            ;

    run;

    /*TITLE "FINAL COST UTILIZATION COUNT";
    proc freq data=cartemp;
        table end_yr ;
    run;

    TITLE "MISSING PHYSICIAN Q";
    proc freq data=cartemp;
        WHERE physician_Q =.;
        table end_yr end_yr*update/ nocol norow nocel;
    run;
    TITLE "";

     proc corr data=cartemp;
        by year;
        var physician_Q_2 lalowchg;
    run;

    ***RATIO CORRLEATION;
    proc corr data=cartemp;
        by year;
        var physician_Q lalowchg;
    run;
*/
%mend;




