options pagesize=200;
options nocenter;
** These options create detalied log files;
options mprint mlogic;
options spool;
options errorabend;
options msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options filelocks=none;

** load in the libraries with the data;
libname carIn "../external/carrier";
libname opIn "../external/outpatient";
libname ipIn "../external/inpatient";
libname pos "../external/pos";
libname zip "../external/zip";
libname bene "../external/bene";
libname drg "../external/rbu/DRG";
libname rvu "../external/rbu/RVU";
libname cmswi "../external/rbu/CMS_Wage_Indices";
libname cmsxw "../external/rbu/geoxwalk";

** load in library to export data to;
libname out "../temp";

** the following macros contain the treatment definitions;
%include "./SASmacros/DiagnosisMacros.sas";
%include "./SASmacros/ProcedureMacros.sas";

** load in additional macros that perform random data tasks;
%include "./SASmacros/SampleCreationMacros.sas";
%include "./SASmacros/LoadPhysPatInfo.sas";
%include "./SASmacros/DataMacros.sas";
%include "./SASmacros/PhysMacros.sas";
%include "./SASmacros/VarNames.sas";

** load in macros that handle RBU measure tasks;
%include "./SASmacros/LoadRBUMacros.sas";
%include "./SASmacros/IP_RBU.sas";
%include "./SASmacros/OP_RBU.sas";
%include "./SASmacros/RVUMacros.sas";
%include "./SASmacros/MergeCMSIndices.sas";

** load files with macros that process the annual files;
%include "./SASmacros/ProcessCarrier.sas";
%include "./SASmacros/ProcessOp.sas";
%include "./SASmacros/ProcessIp.sas";

** load files with macros that allow me to use macro arrays;
%include "../external/lib/SASMacros/ARRAY.sas";
%include "../external/lib/SASMacros/DO_OVER.SAS";
%include "../external/lib/SASMacros/NUMLIST.SAS";
%include "../external/lib/SASMacros/HASHMERGE.sas";

** Setting macros for variable names and lengths;
%let physid = phys_id;
%let rawid = bene_id;
%let obs_num = 50000;
%let npi_length = 12;
%let upin_length = 8;
%let bene_id_length = 15;
%let phys_id_length = 19;
%let zipcode_length = 5;
%let amt_length = 8;
%let clm_id_length=22;

%LoadPhysCrosswalks();
%LoadPatInfo();

%LoadGeographyCrosswalks();
%LoadDRGInfo;
%LoadRVUInfo;
%LoadCMSWageIndices;

%macro main(pct=, startyear=, endyear=);

    %do year = &startyear. %to &endyear.;
        
        %ProcessCarrier(pct=&pct., year=&year.);

        %ProcessInpatient(pct=&pct., year=&year.);
        %ProcessOutpatient(pct=&pct., year=&year.);

        ** Merge Inpatient and Outpatient files;
        %MergeIndicatorFiles(file1=out.op_ind_&year., file2=out.ip_ind_&year., outFile=out.inst_ind_&year.,
            commonVars=RBU_missing, vars2= inpatient_RBU, vars1= outpatient_RBU, byVar=&rawid. &physid. phys_hrr year, 
            sum= RBU er_RBU, missing_check = RBU);

        ** Merge Insitutional and Carrier files;
        %MergeIndicatorFiles(file1=out.car_ind_&year., file2=out.inst_ind_&year., outFile=out.treat_ind_&year.,
            commonVars= RBU_missing, vars2=, vars1= other_RBU, byVar=&rawid. &physid. phys_hrr year, 
            sum= RBU inpatient_RBU outpatient_RBU er_RBU, missing_check= RBU);

    %end;

    **  output total RBU;
    data out.RBUHrrPatientDocYear;
        set %RepeatN(pfx=out.treat_ind_, Nlow=&startyear., Nhigh=&endyear.);
    run;

    proc sort data = out.RBUHrrPatientDocYear;
        by &rawid. &physid. phys_hrr year;
    run;

    proc export data=out.RBUHrrPatientDocYear
            outfile="../output_local/RBUHrrPatientDocYear.csv"
            dbms=csv
            replace;
    run;

%mend;

** EXECUTE;
%main(pct=20, startyear=1998, endyear=2008);
