version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries, loadglob(../external/lib/input_parameters/input_param.txt)
global obsno = "L"

program main

	load_data, ///
        compiled_mover(../external_links/compiled/CompiledPatYrDataMovers) ///
        compiled_nonmover(../external_links/compiled/CompiledPatYrDataNonMovers) ///
        saving(../temp/regression_data) ///
        vars(bene_id year hrrnum hrr_orig hrr_dest mover age race sex baseline_samp)
    gen_vars using ../temp/regression_data, ///
        saving_noadj(../output_local/rhs_matrix_noadj) saving(../temp/temp)
    gen_rhs_matrix using ../temp/temp, ///
        lambda(../external/loc_share/orig_dest_rit_mover) ///
        saving(../output_local/rhs_matrix_adj.dta)

    load_data, ///
        compiled_mover(../external_links/compiled/CompiledPatYrDataMovers) ///
        compiled_nonmover(../external_links/compiled/CompiledPatYrDataNonMovers) /// 
        keep0 saving(../temp/regression_data_fd) ///
        vars(bene_id year hrrnum hrr_orig hrr_dest mover age race sex baseline_samp)
    gen_vars using ../temp/regression_data_fd, ///
        saving_noadj(../output_local/rhs_matrix_noadj_fd) saving(../temp/temp_fd)
    gen_rhs_matrix using ../temp/temp_fd, ///
        lambda(../external/loc_share/orig_dest_rit_mover_fd) ///
        saving(../output_local/rhs_matrix_adj_fd.dta) fd

    load_data, ///
        compiled_mover(../external_links/compiled/CompiledPatYrDataMoversAlt) ///
        compiled_nonmover(../external_links/compiled/CompiledPatYrDataNonMoversAlt) ///
        alt saving(../temp/regression_data_alt) ///
        vars(bene_id year hrrnum hrr_orig hrr_dest mover age race sex bs*)
    gen_vars using ../temp/regression_data_alt, ///
        saving_noadj(../output_local/rhs_matrix_noadj_alt) saving(../temp/temp_alt)
    gen_rhs_matrix using ../temp/temp_alt, ///
        lambda(../external/loc_share/orig_dest_rit_mover) ///    
        saving(../output_local/rhs_matrix_adj_alt.dta)

end

program load_data
    syntax, [keep0] [alt] compiled_mover(str) compiled_nonmover(str) saving(str) vars(str)

    use  `vars' in 1/${obsno} using `compiled_nonmover', clear
    append using `compiled_mover', keep(`vars' rel_yr_rit)
    if "`keep0'"=="keep0" {
        keep if baseline_samp==1 
    }
    else if "`alt'"=="alt" {
        keep if (bs==1|bs_o==1|bs_l==1|bs_h==1) & rel_yr_rit!=0
    }
    else {
        keep if rel_yr_rit!=0 & baseline_samp==1
    }
    summ age
    local max = `r(max)'+1
    egen age_5yr_bins = cut(age), at(`r(min)'(5)`max')
    replace race = (race==1)
    save `saving', replace

end


program gen_vars
    syntax using, saving_noadj(str) saving(str)
    
    use `using', clear
    xi i.hrrnum, noomit
    xi i.year, noomit prefix(_Y)
    xi i.rel_yr_rit, noomit prefix(_RY)
    foreach var of varlist _RY* {
        replace `var' = 0 if mover==0
    }
    xi i.age_5yr_bins, noomit prefix(_A)
    egen ras = group(race age_5yr_bins sex)
    xi i.ras, noomit prefix(_RAS)
    egen ra = group(race age_5yr_bins)
    xi i.ra, noomit prefix(_RA)
    egen sa = group(sex age_5yr_bins)
    xi i.sa, noomit prefix(_SA)
    save `saving', replace
    keep bene_id year _I* _RY* _A* _RAS* _SA* _RA* _Y*
    save_data `saving_noadj', key(bene_id year) ///
        replace log("../output/data_file_manifest.log")

end

program gen_rhs_matrix 
    syntax using, saving(str) lambda(str) [fd]

    use `using', clear
    merge m:1 rel_yr_rit using `lambda', assert(master match) keep(master match) nogen
    levelsof hrrnum, local(hrrnum_levels)
    foreach H of local hrrnum_levels {
        replace _Ihrrnum_`H'=lambda_r if mover==1 & hrr_orig==`H' & rel_yr_rit<0
        replace _Ihrrnum_`H'=(1-lambda_r) if mover==1 & hrr_dest==`H' & rel_yr_rit<0
        replace _Ihrrnum_`H'=(1-lambda_r) if mover==1 & hrr_orig==`H' & rel_yr_rit>0 & rel_yr_rit<.
        replace _Ihrrnum_`H'=lambda_r if mover==1 & hrr_dest==`H' & rel_yr_rit>0 & rel_yr_rit<.
        if "`fd'"=="fd" {
            replace _Ihrrnum_`H'=lambda_r if mover==1 & hrr_orig==`H' & rel_yr_rit==0
            replace _Ihrrnum_`H'=lambda_r if mover==1 & hrr_dest==`H' & rel_yr_rit==0
        }
    }
    egen check = rowtotal(_Ihrrnum*)
    assert check==1
    drop check
    keep bene_id year _I* _RY* _A* _RAS* _SA* _RA* _Y*
    save_data `saving', key(bene_id year) replace log("../output/data_file_manifest.log")

end

* EXECUTE
main

