version 12
set more off
adopath + ../external/lib/stata/gslab_misc/ado
preliminaries
global obs_no = "L"

program main

    insheet_RBU, csv(../external_links/rbu/RBUHrrPatientDocYear.csv) ///
        out(../temp/RBUHrrPatientDocYear.dta)
    insheet_Treat, csv(../external_links/treat/TreatHrrPatientDocYear.csv) ///
		out(../temp/TreatHrrPatientDocYear.dta)
    merge_data
    generate_patientdocyear, in(../output_local/TreatHrrPatientDocYear)
    generate_patientyear, in(../temp/TreatPatientDocYear)

end

program insheet_RBU,
    syntax, csv(string) out(string)

    insheet using `csv', comma names clear

    rename rbu RBU
    rename rbu_missing RBU_missing
    rename inpatient_rbu Ip_RBU
    rename outpatient_rbu Op_RBU
	rename er_rbu Er_RBU
	rename other_rbu Ot_RBU

    ** If phys_id is empty, replace with a placeholder
    tostring phys_id, replace
    replace phys_id = "-99999" if phys_id == ""
    destring phys_hrr, replace
    replace phys_hrr = -99999 if phys_hrr == .

    save_data `out', replace key(bene_id phys_id phys_hrr year)

end

program insheet_Treat,
    syntax, csv(string) out(string)

    insheet using `csv', clear

    rename ipdischarges IpDis
    rename ipdays IpDays
    rename surgicaldischarge SurgDis
    rename hipfracture HipFrac
    rename aaa AAA
    rename valvereplace ValveRep
    rename carotidend CaroEnd
    rename coronaryang CorAng
    rename cabg CABG
    rename hipreplace HipRep
    rename kneereplace KneeRep
    rename lowerbypass LwrByps
    rename mastectomy Mastect
    rename pci PCI
    rename prostatectomy Prosect
    rename colectomy Colect
	rename turp TURP
    rename cardiaccath CardCath
    rename backsurgery BackSurg
    rename cholecystectomy Cholecys
    rename hemo Hemo
    rename lipids Lipids
    rename mam Mam
    rename eyeret EyeRet
    rename cardioscreen Cardio
    rename pap Pap
    rename pelvic Pelvic
    rename bonemass BoneMass
    rename prostate Prostate
    rename flushot FluShot
    rename colorectal Clrtl
    rename diabmng DiabMng
    rename amb Amb
    rename eyeneg EyeNeg
    rename specialist Spec
    rename pay_prov TotExpn
    rename claim_cnt ClaimCnt
    rename eolexpn EolExpn
    
    ** If phys_id is empty, replace with a placeholder
    replace phys_id = "-99999" if phys_id == ""
    replace phys_hrr = -99999 if phys_hrr == .

    save_data `out', replace key(bene_id phys_id phys_hrr year)

end

program merge_data

    use in 1/${obs_no} using ../temp/TreatHrrPatientDocYear.dta, clear
    merge 1:1 bene_id year phys_id phys_hrr using ../temp/RBUHrrPatientDocYear.dta, ///
        assert(1 2 3) nogen
    keep in 1/${obs_no}

    ** If phys_id is empty, replace with a placeholder
    replace phys_id = "-99999" if phys_id == ""
    replace phys_hrr = -99999 if phys_hrr == .

    save_data ../output_local/TreatHrrPatientDocYear.dta, replace ///
		key(bene_id phys_id phys_hrr year) log("../output/data_file_manifest.log")

end

program generate_patientdocyear,
    syntax, in(string)

    use `in', clear
    merge_HRR, xwalk(../external_links/denom/denom_data)
    * If expenditure is Negative, replace with 0
    replace TotExpn = 0 if TotExpn < 0
    replace EolExpn = 0 if EolExpn < 0
    replace RBU = 0 if RBU < 0

    gen num_doc = 1 if phys_id!= "-99999"

    collapse (sum) ClaimCnt TotExpn EolExpn IpDays IpDis diagtests imaging *RBU ///
    (max) Hemo Lipids Mam EyeRet Cardio Pap Pelvic BoneMass Prostate FluShot ///
    Clrtl HipFrac AAA ValveRep CaroEnd CorAng CABG HipRep KneeRep ///
    LwrByps Mastect PCI Prosect Colect TURP CardCath BackSurg Cholecys ///
    DiabMng Amb EyeNeg Spec RBU_missing num_doc, by(bene_id phys_id hrrnum year)

    replace phys_id = "-99999" if phys_id == ""
    gen any_Ip=(IpDays>=1 & IpDays!=.)
    save ../temp/TreatPatientDocYear, replace
    gen LnTotExpn = log(TotExpn + 1)
    gen LnEolExpn = log(EolExpn + 1)
    gen LnRBU = log(RBU + 1)
    gen LnIp_RBU=log(Ip_RBU+1)
    gen LnOp_RBU=log(Op_RBU+1)
    gen LnEr_RBU=log(Er_RBU+1)
    gen LnOt_RBU=log(Ot_RBU+1)
	egen prev_num = rowtotal(Mam Amb EyeRet Hemo Lipids Cardio DiabMng Pap ///
		Pelvic BoneMass Clrtl FluShot Prostate)

    save_data  ../output_local/TreatPatientDocYear, key(bene_id phys_id year) replace ///
		log("../output/data_file_manifest.log")
end

    program merge_HRR,
        syntax, xwalk(string)

        *This merge should only have matches and using observations. There are a small number
        *of master observations. According to Jean Roth, these observations should not be used.
        *only claims for patient-years found in the 20% decnominator file should be considered
        *part of the 20% sample.
        merge m:1 bene_id year using `xwalk', ///
            assert(match using master) keep(match) keepusing(hrrnum) nogen

    end

program generate_patientyear,
    syntax, in(string)

    use in 1/${obs_no} using `in', clear

    drop num_doc
    gen num_doc = 1 if phys_id!= "-99999"
    merge m:1 phys_id using ../external_links/xwalk/PhysId_Specialty, ///
        assert(match using master) keep(match master) keepusing(spcl*)
    gen pcp_cnt = 0
    ooo Defining Physician Specialty Using Medicare Specialty
    foreach var of varlist spcl* {
       replace pcp_cnt = 1 if inlist(`var', "01", "08", "11", "37")
    }
	
    collapse (sum) ClaimCnt TotExpn EolExpn IpDays IpDis diagtests imaging ///
		num_doc pcp_cnt *RBU (max) Hemo Lipids Mam EyeRet Cardio Pap Pelvic BoneMass Prostate ///
		FluShot ///
		Clrtl HipFrac AAA ValveRep CaroEnd CorAng CABG HipRep KneeRep ///
		LwrByps Mastect PCI Prosect Colect TURP CardCath BackSurg Cholecys ///
		DiabMng Amb EyeNeg Spec RBU_missing any_Ip, by(bene_id hrrnum year)

    * Maintaining missing RBU values for any collapsed group with at least 1 missing RBU
    replace RBU = . if RBU_missing==1
    gen LnTotExpn = log(TotExpn + 1)
    gen LnEolExpn = log(EolExpn + 1)
    gen LnRBU = log(RBU + 1)
    gen LnIp_RBU=log(Ip_RBU+1)
    gen LnOp_RBU=log(Op_RBU+1)
    gen LnEr_RBU=log(Er_RBU+1)
    gen LnOt_RBU=log(Ot_RBU+1)
	
    gen doc_RBU = RBU/num_doc
    gen Lndoc_RBU = log(doc_RBU+1)
    gen doc_LnRBU = LnRBU/num_doc
    gen LnIpDis = log(IpDis+1)
    gen LnIpDays = log(IpDays+1)
    gen Lndiag = log(diagtests+1)
    gen Lnimag = log(imaging+1)
    gen Lnnum_doc=log(num_doc+1)

    generate_treatment_indicators
    gen prev_care = (Mam == 1 | Amb == 1 | Eye == 1 | Hemo == 1 | Lipids == 1 | ///
        Cardio == 1 | DiabMng == 1 | Pap == 1 | Pelvic == 1 | BoneMass == 1 | ///
        Clrtl == 1 | FluShot == 1 | Prostate == 1 )
    gen rare_proc = (AAA == 1 | CaroEnd ==1 | HipFrac == 1 ///
        | ValveRep == 1 | CorAng ==1 )

    save_data ../output_local/TreatPatientYear, replace key(bene_id year) ///
		log("../output/data_file_manifest.log")

end

    program generate_treatment_indicators

        sort bene_id year
        ** Cardiovascular Disease Screening
        ** I want Cardio = 1 if treated within past 5 years
        ** I generate a temporary variable to keep track of actual treatment
        gen CarTemp = Cardio
        forval i = 1/4{
            replace CarTemp = 1 if CarTemp == 0 & bene_id == bene_id[_n-`i'] & year ///
			<= year[_n-`i'] + 5 & Cardio[_n-`i'] == 1
        }
        replace Cardio = CarTemp
        drop CarTemp

        ** Mammogram, Pap, Pelvic Test
        ** I want iTREAT = 1 if treated within past 2 years
        ** First, I generate a temporary variable to keep track of actual treatment
        foreach var in Mam Pap Pelvic{
            gen `var'Temp = `var'
            replace `var'Temp = 1 if `var'Temp == 0 & bene_id == bene_id[_n-1] & ///
				year == year[_n-1] + 1 & `var'[_n-1] == 1
            replace `var'=`var'Temp
            drop `var'Temp
        }

        gen Eye = 1 if EyeRet == 1 | (EyeNeg[_n-1] == 1 & bene_id==bene_id[_n-1] ///
			& year == year[_n-1]+ 1)
        replace Eye = 0 if Eye == .
        drop EyeRet EyeNeg

    end


** EXECUTE
main
