%macro RepeatN(pfx,Nlow,Nhigh);
%* Generate a numbered list of symbols starting with the value of pfx;
%* Ex: if pfx=Hello, Nlow=1, and Nhigh=3, then the macro generates;
%* Hello1 Hello2 Hello3;
    %do i=&Nlow. %to &Nhigh.;
        &pfx.&i.
            %end;
%mend;

%macro MergeEhicBeneId(data= , xwalk=bene.ehicbenex_unique_samp);

    %HASHMERGE(data=&data., data_a=&data., data_b=&xwalk., vars_b=bene_id, by=ehic, if=a); 

%mend;

%macro DefinePhysId(upinVar=, npiVar=, data=, year=, physwalk=);

    %HASHMERGE(data=&data., data_a=&data., data_b=&physwalk., vars_b=phys_id, by=upin npi, if=a);
    data &data.;
        set &data.;
        if phys_id = "                   " then phys_id= "-99999";
    run;
%mend DefinePhysId;

%macro MergePhysicianSpecialty(data=, xwalk=physid_specialty, indicators_only=1);
    %if &indicators_only=1 %then %do;
        %HASHMERGE(data=&data., data_a=&data., data_b=&xwalk., vars_b=phys_id Optometrist Specialist AmbSpcl,
            by=phys_id, if=a);
    %end;
    %if &indicators_only=0 %then %do;
        data &data.;
	    merge &data. (in=file)  &xwalk. (in=xwalk);
	    by phys_id;
	    if file;
	run;
    %end;
%mend MergePhysicianSpecialty;

%macro MergeDeathDates(data=, rawid=, xwalk=patient_char);
    data &xwalk.;
        length bene_id $&bene_id_length.;
        set &xwalk.;
    run;
    proc sort data = &data.; by bene_id year; run;
    data &data.;
	merge &data. (in=file)  &xwalk. (in=xwalk);
	by &rawid.;
	if file;
    run;
%mend MergeDeathDates;

%macro CheckVarExists(file=, var=, initVal=);
    %let tabid = %sysfunc(open(&file., i));
    %let varnum = %sysfunc(varnum(&tabid., &var.));
    %if &varnum. = 0 %then %do;
        &var. = &initVal.;
    %end;
%mend CheckVarExists;

%macro MergeIndicatorFiles(file1=, file2=, outFile=, commonVars=, vars1=, vars2=, byVar=, sum=);
    ** rename common variables from both files;
    data temp1;
        set &file1.;
        %array(varlist, values=&commonVars.);
        %do_over(varlist, phrase=rename ?=?_1;);
        %if &sum. ~= %then %do;
            %array(varlist, values=&sum.);
            %do_over(varlist, phrase=rename ? = ?_1;);
        %end;
    run;

    data temp2;
        set &file2.;
        %array(varlist, values=&commonVars.);
        %do_over(varlist, phrase=rename ?=?_2;);
        %if &sum. ~= %then %do;
            %array(varlist, values=&sum.);
            %do_over(varlist, phrase=rename ? = ?_2;);
        %end;
    run;

    proc sort data=temp1; by &byVar.; run;
    proc sort data=temp2; by &byVar.; run;

    data &outFile.;
        merge temp1 temp2;
        by &byVar.;
    run;

    data &outFile.;
        set &outFile.

        %array(varlist, values=&commonVars.);
        %do_over(varlist, phrase=if ?_1 =. then ?_1 = 0;);
        %do_over(varlist, phrase=if ?_2 =. then ?_2 = 0;);

        %if &sum. ~= %then %do;
            %array(varlist, values=&sum.);
	    %do_over(varlist, phrase=if ?_1 =. then ?_1 = 0;);
	    %do_over(varlist, phrase=if ?_2 =. then ?_2 = 0;);
	%end;
        %if &vars1. ~= %then %do;
            %array(varlist, values=&vars1.);
            %do_over(varlist, phrase=if ? =. then ? = 0;);
        %end;
        %if &vars2. ~= %then %do;
            %array(varlist, values=&vars2.);
            %do_over(varlist, phrase=if ? =. then ? = 0;);
        %end;

        %array(varlist, values=&commonVars.);
        %put %do_over(varlist);
        %do_over(varlist, phrase= ? = max(?_1, ?_2););

        * Do the variables need to be summed or maxed? The default is max, but some things;
        * like Expn are summed. The following code handles that.;

        %if &sum. ~= %then %do;
            %array(varlist, values=&sum.);
            %do_over(varlist, phrase= ? = ?_1 + ?_2;);
        %end;

        keep &byVar. &commonVars. &vars1. &vars2. &sum.;
    run;
%mend MergeIndicatorFiles;



%macro DefinePhysHRR(data=, filetype=);
    %if &filetype. = carrier %then %do;
        ** merge in HRR crosswalk to define HRR;
    	%HASHMERGE(data=&data., data_a=&data., data_b=ziphrrxwalk, vars_b=hrrnum, by=zipcode, if=a);
	data &data.;
	    set &data.;
	    rename hrrnum=phys_hrr;
	run;
    %end;
    %if &filetype. = outpatient or &filetype. = inpatient %then %do;
        ** merge in POS data to define provider zip code;
	%HASHMERGE(data=&data., data_a=&data., data_b=pos.posmaster, vars_b= zipcode, by=provider, if=a);
	%HASHMERGE(data=&data., data_a=&data., data_b=ziphrrxwalk, vars_b= hrrnum, by=zipcode, if=a);
	data &data.;
	    set &data.;
	    rename hrrnum=phys_hrr;
	run;
    %end;
%mend DefinePhysHRR;

%macro MergeMSACBSA;

    	%HASHMERGE(data=&data., data_a=&data., data_b=pos.posmaster, vars_b= zipcode, by=provider, if=a);
	%HASHMERGE(data=&data., data_a=&data., data_b=pos.zipcode, vars_b= cnty00, by=zipcode, if=a);
        %if &year.<2005 %then %do;
            %HASHMERGE(data=&data., data_a=&data., data_b=pos.cnty00, vars_b= msa, by=cnty00, if=a);
        %end;
        %if &year.>=2004 %then %do;
            %if &year.<2007 %then %do;
                %HASHMERGE(data=&data., data_a=&data., data_b=pos.cbsa_all, vars_b= cbsa, by=cnty00 fileYear, if=a);
            %end;
            %if &year.>=2007 %then %do;
                %HASHMERGE(data=&data., data_a=&data., data_b=pos.cbsa2007, vars_b= cbsa, by=cnty00, if=a);
            %end;
        %end;
%mend;

