%macro LoadPatInfo();

   data out.samp_list;
	infile "../external_links/pat_chars/samp_list.csv" delimiter="," dsd firstobs=2;
	input bene_id :$15. ;
   run;

   proc sort data=out.samp_list; by bene_id; run;

   data patient_char;
	infile "../external_links/pat_chars/sdod_list.csv" delimiter="," dsd firstobs=2;
	input bene_id :$15. sdod;
   run;
   data patient_char;
       set patient_char;
       sdod = MDY(1, 1, 1960) + sdod;
       format sdod date9.;
    run;

%mend;

%macro LoadBeneCrosswalk();

    proc sort data=bene.ehicbenex_unique out=bene.ehicbenex_unique_samp; by bene_id; run;

    data bene.ehicbenex_unique_samp;
	    merge bene.ehicbenex_unique_samp (DROP=hic_mtch sex_mtch dob_mtch in=xwalk) 
        out.samp_list (in=samp);
	    by bene_id;
	    if xwalk and samp;
    run;
    proc sort data=bene.ehicbenex_unique_samp; by ehic; run;

%mend;

%macro LoadPhysCrosswalks();

     data ziphrrxwalk;
	infile "../external/geo/ziphrrxwalk.csv" delimiter="," firstobs=2;
	informat zipcode $7.;
	informat hsanum 5.;
	informat hsacity $20.;
	informat hsastate $4.;
	informat hrrnum 3.;
	informat hrrcity $20.;
	informat hrrstate $4.;
      	informat keep 1.;

	format zipcode $7.;
	format hsanum 5.;
	format hsacity $20.;
	format hsastate $4.;
	format hrrnum 3.;
	format hrrcity $20.;
	format hrrstate $4.;
        format keep 1.;

	input zipcode $ hsanum hsacity $ hsastate $ hrrnum hrrcity $ hrrstate $ keep;
        zipcode = substr(zipcode, 2, &zipcode_length.);
    run;

    data ziphrrxwalk(DROP=keep);
        length zipcode $&zipcode_length..;
	set ziphrrxwalk(WHERE=(keep=1));
	hsacity = dequote(hsacity);
	hsastate = dequote(hsastate);
	hrrcity = dequote(hsacity);
	hrrstate = dequote(hsastate);
    run;

    data physid_upinnpi;
		infile "../external_links/xw/PhysId_UpinNpi.csv" delimiter="," MISSOVER DSD
			lrecl=32767 firstobs=2;
		informat key $18.;
		informat phys_id $19.;
        informat upin $8.;
        informat npi $12.;
        informat researchid $12.;
		format key $18.;
        format phys_id $19.;
        format upin $8.;
        format npi $12.;
        format researchid $12.;
        input key $ phys_id $ upin $ npi $ researchid $;

    run;

    data physid_upinnpi (drop=key researchid);
        set physid_upinnpi;
        phys_id = trim(phys_id);
        upin = trim(upin);
        npi = trim(npi);
    run;

    proc sort data=physid_upinnpi;
        by upin npi;
    run;

    data physid_specialty;
        infile "../external_links/xw/PhysId_Specialty.csv" delimiter="," MISSOVER DSD
			lrecl=32767 firstobs=2;
    	informat phys_id $19.;
		%do_over(values=1-27, phrase= informat spcl? $4.;);
		informat Specialist 1.;
		informat Optometrist 1.;
		informat AmbSpcl 1.;
		informat Radiologist 1.;
		informat Surgeon 1.;
        informat Internist 1.;

    	format phys_id $29.;
        %do_over(values=1-27, phrase= format spcl? $4.;)
		format Specialist 1.;
		format Optometrist 1.;
		format AmbSpcl 1.;
		format Radiologist 1.;
		format Surgeon 1.;
        format Internist 1.;

        input phys_id $
        %do_over(values=1-27, phrase= spcl? $)
		Specialist
		Optometrist
		AmbSpcl
		Radiologist
		Surgeon
        Internist;
    run;

    data physid_specialty;
        length phys_id $&phys_id_length..;
        set physid_specialty;
        phys_id = compress(phys_id,'"');
        %do_over(values=1-27, phrase= spcl? = dequote(spcl?););
        phys_id = trim(phys_id);
        %do_over(values=1-27, phrase= spcl? = trim(spcl?););
    run;


%mend LoadPhysCrosswalks;

