*#######################################################################;
*# THIS MACRO GENERATES TREATMENT INDICATORS FOR CARRIER YEAR DATA #####;
*#######################################################################;
%macro ProcessCarrier(pct=, year=);

    ** Define what is to be sorted by and what is to define unique index;
    %let rawid=bene_id;
    %let physid=phys_id;

    /* The following macro generates cartemp
     * First I append the appropriate parts of two consecutive years together
     * If the file is using EHIC, I merge in BENE_ID */

    %GenerateCarrierYear(year=&year., pct=&pct.);

    %DefinePhysId(npiVar=npi, upinVar=upin, data=cartemp, physwalk=physid_upinnpi);

    ** Merge in physician specialty to define Specialist treatment/Optmetrist;
    ** indicators_only=1 is a switch that only keeps the Specialist and Optometrist indicators;

    %MergePhysicianSpecialty(data=cartemp, xwalk=physid_specialty, indicators_only=1);
    %MergeDeathDates(data=cartemp, rawid=&rawid.,  xwalk=patient_char);

    data cartemp (drop=provzip);
        length zipcode $ &zipcode_length.;
        set cartemp ;
        provzip = trim(provzip);
        zipcode = substr(provzip, 1, 5);
	** Initialize all treatment outcomes to zero;
	%InitializeIndicators(filetype=carrier);

        ** Use betos codes to define diagnostic and imaging;
        %Count_Imaging_Tests();
        %Count_Diagnostic_Tests();
        %Calculate_EolExpn(filetype=carrier);

        %do i = 1 %to 4;

            %Process_ICD9(code=dgns_cd&i.);

            %Diagnose_Mammogram(code=dgns_cd&i., codetype=icd9);

            %Diagnose_RetinalEye(code=dgns_cd&i., codetype=icd9);

            %Diagnose_NegativeEye(code=dgns_cd&i., codetype=icd9);

            %Diagnose_CardioScreen(code=dgns_cd&i., codetype=icd9);

            %Diagnose_PapTest(code=dgns_cd&i., codetype=icd9);

            %Diagnose_PelvicExam(code=dgns_cd&i., codetype=icd9);

            %Diagnose_ProstateExam(code=dgns_cd&i., codetype=icd9);

            %Diagnose_FluShot(code=dgns_cd&i., codetype=icd9);

        %end;

	%if &year. >=2006 %then %do;

        %do i = 5 %to 8;

            %Process_ICD9(code=dgns_cd&i.);

            %Diagnose_Mammogram(code=dgns_cd&i., codetype=icd9);

            %Diagnose_RetinalEye(code=dgns_cd&i., codetype=icd9);

            %Diagnose_NegativeEye(code=dgns_cd&i., codetype=icd9);

            %Diagnose_CardioScreen(code=dgns_cd&i., codetype=icd9);

            %Diagnose_PapTest(code=dgns_cd&i., codetype=icd9);

            %Diagnose_PelvicExam(code=dgns_cd&i., codetype=icd9);

            %Diagnose_ProstateExam(code=dgns_cd&i., codetype=icd9);

            %Diagnose_FluShot(code=dgns_cd&i., codetype=icd9);

        %end;


	%end;


        ** Since there is only 1 HCPCS field, and 1 line to process, I didnt generate a separate macro;
        hcpcs_num = input(hcpcs_cd, ?? 5.);

        %Diagnose_Mammogram(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Hemo(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Lipids(code=hcpcs_cd, codetype=cpt);

        %Diagnose_RetinalEye(code=hcpcs_cd, codetype=cpt);

        %Diagnose_CardioScreen(code=hcpcs_cd, codetype=cpt);

        %Diagnose_DiabetesManage(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PapTest(code=hcpcs_cd, codetype=cpt);

        %Diagnose_FluShot(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PelvicExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_ProstateExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_BoneMass(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Colorectal(code=hcpcs_cd, codetype=cpt);

        ** Ambulatory Care depends on the Physician Specialty and Location;
        %Generate_ProvTypeInd();
        %Diagnose_AmbulatoryCare(filetype=carrier, spcl_ind=AmbSpcl, prov_ind=ProviderInd);
        claim_cnt = 1;

    run;
  

    %DefinePhysHrr(data=cartemp, filetype=carrier);


    proc sort data=cartemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    proc means data=cartemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Amb EyeRet EyeNeg Lipids Hemo Mam Specialist CardioScreen DiabMng Pap
            Pelvic BoneMass Colorectal Prostate FluShot lalowchg EolExpn diagtests imaging claim_cnt;
        output out=car_ind_&year. max(Amb)=Amb max(EyeRet)=EyeRet max(EyeNeg)=EyeNeg max(Lipids)=Lipids
            max(Hemo)=Hemo max(Mam)=Mam max(Specialist)=Specialist max(CardioScreen)=CardioScreen
            max(DiabMng)=DiabMng max(Pap)=Pap max(Pelvic)=Pelvic max(BoneMass)=BoneMass
            max(Colorectal)=Colorectal max(Prostate)=Prostate max(FluShot)=FluShot sum(lalowchg)=pay_prov
            sum(diagtests)=diagtests sum(imaging)=imaging sum(EolExpn)=EolExpn mean(claim_cnt)=claim_cnt;
    run;

    proc means data=car_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var Amb EyeRet EyeNeg Lipids Hemo Mam Specialist CardioScreen DiabMng Pap EolExpn
            Pelvic BoneMass Colorectal Prostate FluShot pay_prov diagtests imaging claim_cnt;
        output out=out.car_ind_&year. max(Amb)=Amb max(EyeRet)=EyeRet max(EyeNeg)=EyeNeg max(Lipids)=Lipids
            max(Hemo)=Hemo max(Mam)=Mam max(Specialist)=Specialist max(CardioScreen)=CardioScreen
            max(DiabMng)=DiabMng max(Pap)=Pap max(Pelvic)=Pelvic max(BoneMass)=BoneMass
            max(Colorectal)=Colorectal max(Prostate)=Prostate max(FluShot)=FluShot sum(pay_prov)=pay_prov
            sum(diagtests)=diagtests sum(imaging)=imaging sum(claim_cnt)=claim_cnt sum(EolExpn)=EolExpn;
    run;

%mend;

