*#######################################################################;
*# THIS MACRO GENERATES TREATMENT INDICATORS FOR INPATIENT YEAR DATA ###;
*#######################################################################;
%macro ProcessInpatient(pct=, year=);

    ** Define what is to be sorted by and what is to define unique index;
    %let rawid=bene_id;
    %let physid=phys_id;

    %GenerateIpClmsYear(year=&year., pct=&pct.);

    data ipclmstemp;
        length fyear 4.;
        set ipclmstemp;
        if month(from_dt)>=1 and month(from_dt)<=9 then fyear=year(from_dt);
        if month(from_dt)>=10 and month(from_dt)<=12 then fyear=year(from_dt)+1;
    run;

    /* In the current cartemp data set, physicians are identified by UPIN and
     * NPI. I need to make them all PHYS_ID to merge in the PHYS_ID - SPCL
     * Crosswalk. */

    %DefinePhysId(npiVar=npi, upinVar=upin, data=ipclmstemp, physwalk=physid_upinnpi);

    ****************************************;
    *** MERGE IN SPECIALTY CODE BY UPIN;
    ***************************************;
    ** Merge in physician specialty to define Specialist treatment/Optmetrist;
    ** indicators_only=1 is a switch that only keeps the Specialist and Optometrist indicators;

    %MergePhysicianSpecialty(data=ipclmstemp, xwalk=physid_specialty, indicators_only=1);
    %MergeDeathDates(data=ipclmstemp, rawid=&rawid.,  xwalk=patient_char);

    data ipclmstemp;
        length bene_id $&bene_id_length.;
        set ipclmstemp;

        ** Initialize all treatment outcomes to zero;
        %InitializeIndicators(filetype=ipclm);

        ** Pre-processing DRG Code - takes one line;
        drg_cd_num = input(drg_cd, ??3.);

        %Count_IpDischarges();
        %Calculate_IpDays();
        %Count_SurgicalDischarges();

        ** Generate Indicator for Surgical Discharge;

        %do i = 1 %to 10;

            ***************************;
            *** USE DIAGNOSIS CODES ***;
            ***************************;

            %Process_ICD9(code=dgnscd&i.);
            %Process_PRCDR(code=prcdrcd&i.);

            ** The following are for back surgery;
            dgns_cd1 = substr(dgnscd&i., 1, 1);
            dgns_cd2_4 = substr(dgnscd&i., 2, 4);
            dgns_cd2_4_num = input(dgns_cd2_4, ??3.);

            %Diagnose_Mammogram(code=dgnscd&i., codetype=icd9);

            %Diagnose_RetinalEye(code=dgnscd&i., codetype=icd9);

            %Diagnose_NegativeEye(code=dgnscd&i., codetype=icd9);

            %Diagnose_CardioScreen(code=dgnscd&i., codetype=icd9);

            %Diagnose_PapTest(code=dgnscd&i., codetype=icd9);

            %Diagnose_PelvicExam(code=dgnscd&i., codetype=icd9);

            %Diagnose_ProstateExam(code=dgnscd&i., codetype=icd9);

            %Diagnose_FluShot(code=dgnscd&i., codetype=icd9);

            %Diagnose_HipFracture(code=dgnscd&i., codetype=icd9);

            %Diagnose_AAA(code=dgnscd&i., codetype=icd9);
            %Diagnose_AAA(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_HipReplace(code=dgnscd&i., codetype=icd9);
            %Diagnose_HipReplace(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_LowerBypass(code=dgnscd&i., codetype=icd9);
            %Diagnose_LowerBypass(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_Mastectomy(code=dgnscd&i., codetype=icd9);
            %Diagnose_Mastectomy(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_Colectomy(code=dgnscd&i., codetype=icd9);
            %Diagnose_Colectomy(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_TURP(code=dgnscd&i., codetype=icd9);
            %Diagnose_TURP(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_ValveReplace(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_CarotidEnd(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_CoronaryAng(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_CABG(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_KneeReplace(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_PCI(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_Prostatectomy(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_Cholecystectomy(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_CardiacCath(code=prcdrcd&i., codetype=prcdr);

            %Diagnose_BackSurgery(code=dgnscd&i., codetype=icd9);
            %Diagnose_BackSurgery(code=prcdrcd&i., codetype=prcdr);

        %end;

        %Calculate_Expenditures(filetype=inpatient);
        %Calculate_EolExpn(filetype=inpatient);
        claim_cnt = 1;

    run;

    %DefinePhysHrr(data=ipclmstemp, filetype=inpatient);

    proc sort data=ipclmstemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    data ip_clms_id;
        set ipclmstemp (KEEP=&rawid. &physid. clm_id phys_hrr Optometrist AmbSpcl);
    run;

    proc means data=ipclmstemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Mam EyeRet EyeNeg Specialist CardioScreen Pap Pelvic Prostate FluShot pay_prov IpDischarges
            IpDays SurgicalDischarge HipFracture AAA ValveReplace CarotidEnd CoronaryAng CABG HipReplace
            KneeReplace LowerBypass Mastectomy PCI Prostatectomy Colectomy Cholecystectomy TURP
            CardiacCath BackSurgery EolExpn claim_cnt;

        output out=ip_clm_ind_&year. max(Mam)=Mam max(EyeRet)=EyeRet max(EyeNeg)=EyeNeg max(Specialist)=Specialist
                max(CardioScreen)=CardioScreen max(Pap)=Pap max(Pelvic)=Pelvic max(Prostate)=Prostate
                max(FluShot)=FluShot sum(pay_prov)=pay_prov sum(IpDischarges)=IpDischarges sum(IpDays)=IpDays
                max(SurgicalDischarge)=SurgicalDischarge max(HipFracture)=HipFracture max(AAA)=AAA
                max(ValveReplace) = ValveReplace max(CarotidEnd)=CarotidEnd max(CoronaryAng)=CoronaryAng
                max(CABG)=CABG max(HipReplace)=HipReplace max(KneeReplace)=KneeReplace max(LowerBypass)=LowerBypass
                max(Mastectomy)=Mastectomy max(PCI)=PCI max(Prostatectomy)=Prostatectomy max(Colectomy)=Colectomy
                max(TURP)=TURP max(CardiacCath)=CardiacCath max(BackSurgery)=BackSurgery
                max(Cholecystectomy) = Cholecystectomy sum(EolExpn) = EolExpn mean(claim_cnt) = claim_cnt;
    run;

    proc means data=ip_clm_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var Mam EyeRet EyeNeg Specialist CardioScreen Pap Pelvic Prostate FluShot pay_prov
            IpDischarges IpDays SurgicalDischarge HipFracture AAA ValveReplace CarotidEnd
            CoronaryAng CABG HipReplace KneeReplace LowerBypass Mastectomy PCI Prostatectomy
            Colectomy TURP CardiacCath BackSurgery Cholecystectomy claim_cnt EolExpn;

        output out=ip_clm_ind_&year. max(Mam)=Mam max(EyeRet)=EyeRet max(EyeNeg)=EyeNeg max(Specialist)=Specialist
                max(CardioScreen)=CardioScreen max(Pap)=Pap max(Pelvic)=Pelvic max(Prostate)=Prostate
                max(FluShot)=FluShot sum(pay_prov)=pay_prov sum(IpDischarges)=IpDischarges sum(IpDays)=IpDays
                max(SurgicalDischarge)=SurgicalDischarge max(HipFracture)=HipFracture max(AAA)=AAA
                max(ValveReplace) = ValveReplace max(CarotidEnd)=CarotidEnd max(CoronaryAng)=CoronaryAng
                max(CABG)=CABG max(HipReplace)=HipReplace max(KneeReplace)=KneeReplace max(LowerBypass)=LowerBypass
                max(Mastectomy)=Mastectomy max(PCI)=PCI max(Prostatectomy)=Prostatectomy max(Colectomy)=Colectomy
                max(TURP)=TURP max(CardiacCath)=CardiacCath max(BackSurgery)=BackSurgery max(Cholecystectomy) = Cholecystectomy
                sum(claim_cnt) = claim_cnt sum(EolExpn) = EolExpn;
    run;

    *********************************************;
    *** PROCESS REVENUE CENTER DATA;
    *********************************************;

    %GenerateIpRevCntrsYear(year=&year., pct=&pct.);

    proc sort data=ip_clms_id nodupkey; by &rawid. clm_id; run;
    proc sort data=iprevtemp; by &rawid. clm_id; run;

    data iprevtemp;
        merge iprevtemp (in=rev) ip_clms_id (in=clm keep=&rawid. &physid. clm_id phys_hrr Optometrist AmbSpcl);
        by &rawid. clm_id;
        if rev and clm;
    run;

    ** Generate Indicators for Revenue Center Data;
    data iprevtemp;
        length bene_id $&bene_id_length.;
        set iprevtemp;

        ** Initialize all treatment outcomes to zero;
        %InitializeIndicators(filetype=revcntr);

        rev_cntr3 = substr(rev_cntr, 1, 3);
        hcpcs_num = input(hcpcs_cd, ?? 5.);

        %Diagnose_Hemo(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Lipids(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Mammogram(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Mammogram(code=rev_cntr, codetype=rev_cntr);

        %Diagnose_RetinalEye(code=hcpcs_cd, codetype=cpt);

        %Diagnose_CardioScreen(code=hcpcs_cd, codetype=cpt);

        %Diagnose_DiabetesManage(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PapTest(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PelvicExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_BoneMass(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Colorectal(code=hcpcs_cd, codetype=cpt);

        %Diagnose_ProstateExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_FluShot(code=hcpcs_cd, codetype=cpt);

    run;

    proc sort data=iprevtemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;


    proc means data=iprevtemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Hemo Lipids Mam EyeRet CardioScreen DiabMng Pap Pelvic BoneMass Colorectal Prostate FluShot;
        output out=ip_rev_ind_&year. max=;
    run;

    proc means data=ip_rev_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var Hemo Lipids Mam EyeRet CardioScreen DiabMng Pap Pelvic BoneMass Colorectal Prostate FluShot;
        output out=ip_rev_ind_&year. max(Hemo)=Hemo max(Lipids)=Lipids max(Mam)=Mam max(EyeRet)=EyeRet
        max(CardioScreen)=CardioScreen max(DiabMng)=DiabMng max(Pap)=Pap max(Pelvic)=Pelvic
        max(BoneMass)=BoneMass max(Colorectal)=Colorectal max(Prostate)=Prostate max(FluShot)=FluShot;
    run;

    ************************************;
    *** MERGE DATA AND OUTPUT;
    ************************************;
    %MergeIndicatorFiles(file1=ip_rev_ind_&year., file2=ip_clm_ind_&year., outFile=out.ip_ind_&year.,
        commonVars= Mam EyeRet CardioScreen Pap Pelvic Prostate FluShot,
        vars1=Colorectal Lipids Hemo BoneMass DiabMng, vars2=pay_prov EolExpn
        claim_cnt Amb EyeNeg Specialist IpDischarges IpDays SurgicalDischarge HipFracture AAA
        ValveReplace CarotidEnd CoronaryAng CABG HipReplace KneeReplace LowerBypass Mastectomy
        PCI Prostatectomy Colectomy TURP CardiacCath BackSurgery Cholecystectomy,
        byVar=&rawid. &physid. phys_hrr year, sum=);

%mend;



