************************************************************************;
** THIS MACRO GENERATES TREATMENT INDICATORS FOR OUTPATIENT YEAR DATA **;
************************************************************************;
%macro ProcessOutpatient(pct=, year=);

    %let rawid=bene_id;
    %let physid=phys_id;

    /* The following macro generates cartemp
     * First I append the appropriate parts of two consecutive years together
     * If the file is using EHIC, I merge in BENE_ID */

    %GenerateOpClmsYear(year=&year., pct=&pct.);

    /* In the current cartemp data set, physicians are identified by UPIN and
     * NPI. I need to make them all PHYS_ID to merge in the PHYS_ID - SPCL
     * Crosswalk. */
    data opclmstemp;
        length fyear 4.;
        set opclmstemp;
        if month(from_dt)>=1 and month(from_dt)<=9 then fyear=year(from_dt);
        if month(from_dt)>=10 and month(from_dt)<=12 then fyear=year(from_dt)+1;
    run;

    %DefinePhysId(npiVar=npi, upinVar=upin, data=opclmstemp, physwalk=physid_upinnpi);

    ** Merge in physician specialty to define Specialist treatment/Optmetrist;
    ** indicators_only=1 is a switch that only keeps the Specialist and Optometrist indicators;
    %MergePhysicianSpecialty(data=opclmstemp, xwalk=physid_specialty, indicators_only=1);
    %MergeDeathDates(data=opclmstemp, rawid=&rawid.,  xwalk=patient_char);

    data opclmstemp;
        set opclmstemp;

        ** Initialize all treatment outcomes to zero;
        %InitializeIndicators(filetype=opclm);

        ** Ambulatory Care depends on the Physician Specialty and Location;
        %Generate_ProvTypeInd();
        %Diagnose_AmbulatoryCare(filetype=outpatient, spcl_ind=AmbSpcl, prov_ind=ProviderInd);
        %Calculate_Expenditures(filetype=outpatient);
        %Calculate_EolExpn(filetype=outpatient);

        %do i = 1 %to 10;
            %Process_ICD9(code=dgnscd&i.);

            %Diagnose_Mammogram(code=dgnscd&i., codetype=icd9);

            %Diagnose_RetinalEye(code=dgnscd&i., codetype=icd9);

            %Diagnose_NegativeEye(code=dgnscd&i., codetype=icd9);

            %Diagnose_CardioScreen(code=dgnscd&i., codetype=icd9);

            %Diagnose_PapTest(code=dgnscd&i., codetype=icd9);

            %Diagnose_PelvicExam(code=dgnscd&i., codetype=icd9);

            %Diagnose_ProstateExam(code=dgnscd&i., codetype=icd9);

            %Diagnose_FluShot(code=dgnscd&i., codetype=icd9);
            claim_cnt=1;
        %end;
    run;

    %DefinePhysHrr(data=opclmstemp, filetype=outpatient);

    proc sort data=opclmstemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    data op_clms_id;
        set opclmstemp (KEEP=&rawid. &physid. clm_id phys_hrr Optometrist AmbSpcl);
    run;

    proc means data=opclmstemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Mam Amb EyeRet EyeNeg Specialist CardioScreen Pap Pelvic Prostate FluShot pay_prov EolExpn
            claim_cnt;
        output out=op_clm_ind_&year. max(Mam)=Mam max(Amb)=Amb max(EyeRet)=EyeRet max(EyeNeg)= EyeNeg
            max(Specialist)=Specialist max(CardioScreen)=CardioScreen max(Pap)=Pap sum(EolExpn)=EolExpn
            max(Pelvic)=Pelvic max(Prostate)=Prostate max(FluShot)=FluShot sum(pay_prov)=pay_prov
            mean(claim_cnt)=claim_cnt;
    run;

    proc means data=op_clm_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var Mam Amb EyeRet EyeNeg Specialist CardioScreen Pap Pelvic Prostate FluShot pay_prov claim_cnt
	    EolExpn;
        output out=op_clm_ind_&year. max(Mam)=Mam max(Amb)=Amb max(EyeRet)=EyeRet max(EyeNeg)=EyeNeg
            max(Specialist)=Specialist max(CardioScreen)=CardioScreen max(Pap)=Pap max(Pelvic)=Pelvic
            max(Prostate)=Prostate max(FluShot)=FluShot sum(pay_prov)=pay_prov sum(claim_cnt)=claim_cnt
	    sum(EolExpn)=EolExpn;
    run;

    *********************************************;
    *** PROCESS REVENUE CENTER DATA;
    *********************************************;
    %GenerateOpRevCntrsYear(year=&year., pct=&pct.);

    proc sort data=op_clms_id nodupkey; by &rawid. clm_id; run;
    proc sort data=oprevtemp; by &rawid. clm_id; run;
    data oprevtemp;
        merge oprevtemp (in=rev) op_clms_id (in=clm keep=&rawid. &physid. clm_id phys_hrr Optometrist AmbSpcl);
        by &rawid. clm_id;
        if rev and clm;
    run;
    ** Generate Indicators for Revenue Center Data;


    data oprevtemp;
        set oprevtemp;

        ** Initialize all treatment outcomes to zero;
        %InitializeIndicators(filetype=revcntr);

        rev_cntr3 = substr(rev_cntr, 1, 3);
        hcpcs_num = input(hcpcs_cd, ?? 5.);

        %Diagnose_Hemo(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Lipids(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Mammogram(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Mammogram(code=rev_cntr, codetype=rev_cntr);

        %Diagnose_RetinalEye(code=hcpcs_cd, codetype=cpt);

        %Diagnose_CardioScreen(code=hcpcs_cd, codetype=cpt);

        %Diagnose_DiabetesManage(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PapTest(code=hcpcs_cd, codetype=cpt);

        %Diagnose_PelvicExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_BoneMass(code=hcpcs_cd, codetype=cpt);

        %Diagnose_Colorectal(code=hcpcs_cd, codetype=cpt);

        %Diagnose_ProstateExam(code=hcpcs_cd, codetype=cpt);

        %Diagnose_FluShot(code=hcpcs_cd, codetype=cpt);
    run;

    proc sort data=oprevtemp;
        by &rawid. &physid. phys_hrr year clm_id;
    run;

    proc means data=oprevtemp noprint;
        by &rawid. &physid. phys_hrr year clm_id;
        var Hemo Lipids Mam EyeRet CardioScreen DiabMng Pap Pelvic BoneMass Colorectal Prostate FluShot;
        output out=op_rev_ind_&year. max= ;
    run;

    proc means data=op_rev_ind_&year. noprint;
        by &rawid. &physid. phys_hrr year;
        var Hemo Lipids Mam EyeRet CardioScreen DiabMng Pap Pelvic BoneMass Colorectal Prostate FluShot;
        output out=op_rev_ind_&year. max=;
    run;

    ***********************************************;
    *** MERGE CLAIMS AND REV CENTER DATA AND OUTPUT;
    ***********************************************;
    ** Make sure YEAR is set;

    %MergeIndicatorFiles(file1=op_rev_ind_&year., file2=op_clm_ind_&year., outFile=out.op_ind_&year.,
        commonVars=Mam EyeRet CardioScreen Pap Pelvic Prostate FluShot,
        vars1=Colorectal Lipids Hemo BoneMass DiabMng, vars2=pay_prov EolExpn claim_cnt Amb EyeNeg Specialist,
        byVar=&rawid. &physid. phys_hrr year, sum=);

%mend;

