/* This file will load in macros to generate the TreatHrrPatientDocYear.sas file
 * Then another make.do will do the rest of the work and generate the remaining .dta
 * files. */

options pagesize=200;
options nocenter;
** These options create detalied log files;
options mprint mlogic;
options spool;
options errorabend;
options msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options filelocks=none;

** load in the libraries with the data;
libname carIn "../external/carrier";
libname opIn "../external/outpatient";
libname ipIn "../external/inpatient";
libname pos "../external/pos";
libname zip "../external/zip";
libname cbsa "../external/cbsa";
libname bene "../external/bene";

** load in library to export data to;
libname out "../temp";

** the following macros contain the treatment definitions;
%include "./SASmacros/DiagnosisMacros.sas";
%include "./SASmacros/ProcedureMacros.sas";

** load in additional macros that perform random data tasks;
%include "./SASmacros/SampleCreationMacros.sas";
%include "./SASmacros/LoadPhysPatInfo.sas";
%include "./SASmacros/DataMacros.sas";
%include "./SASmacros/VarNames.sas";

** load files with macros that process the annual files;
%include "./SASmacros/ProcessCarrier.sas";
%include "./SASmacros/ProcessOp.sas";
%include "./SASmacros/ProcessIp.sas";

** load files with macros that allow me to use macro arrays;
%include "../external/lib/SASMacros/ARRAY.sas";
%include "../external/lib/SASMacros/DO_OVER.SAS";
%include "../external/lib/SASMacros/NUMLIST.SAS";
%include "../external/lib/SASMacros/HASHMERGE.sas";

** Setting macros for variable names and lengths;
%let physid = phys_id;
%let rawid = bene_id;
%let obs_num = max;
%let npi_length = 12;
%let upin_length = 8;
%let bene_id_length = 15;
%let phys_id_length = 19;  
%let zipcode_length = 5;
%let clm_id_length=22;
%let amt_length = 8;

** load physician crosswalks;
%LoadPhysCrosswalks();
%LoadPatInfo();
%LoadBeneCrosswalk();

%macro main(pct=, startyear=, endyear=);

    %do year = &startyear. %to &endyear.;

        sasfile out.samp_list open;

       %ProcessCarrier(pct=&pct., year=&year.);
       %ProcessOutpatient(pct=&pct., year=&year.);
       %ProcessInpatient(pct=&pct., year=&year.); 

        sasfile out.samp_list close;


        ** Merge Inpatient and Outpatient files;
        %MergeIndicatorFiles(file1=out.op_ind_&year., file2=out.ip_ind_&year., outFile=out.inst_ind_&year.,
            commonVars=Hemo Lipids Mam EyeRet CardioScreen Pap Pelvic BoneMass Prostate FluShot Colorectal
            DiabMng Amb EyeNeg Specialist, vars2=IpDays IpDischarges SurgicalDischarge
            HipFracture AAA ValveReplace CarotidEnd CoronaryAng CABG HipReplace KneeReplace
            LowerBypass Mastectomy PCI Prostatectomy Colectomy TURP CardiacCath BackSurgery Cholecystectomy,
            vars1 = imaging diagtests, byVar=&rawid. &physid. phys_hrr year, sum=pay_prov claim_cnt EolExpn);

        ** Merge Insitutional and Carrier files;
        %MergeIndicatorFiles(file1=out.car_ind_&year., file2=out.inst_ind_&year., outFile=out.treat_ind_&year.,
            commonVars=Hemo Lipids Mam EyeRet CardioScreen Pap Pelvic BoneMass Prostate FluShot Colorectal
            DiabMng Amb EyeNeg Specialist, vars2=IpDays IpDischarges SurgicalDischarge
            HipFracture AAA ValveReplace CarotidEnd CoronaryAng CABG HipReplace KneeReplace
            LowerBypass Mastectomy PCI Prostatectomy Colectomy TURP CardiacCath BackSurgery Cholecystectomy,
            vars1 = imaging diagtests, byVar=&rawid. &physid. phys_hrr year, sum=pay_prov claim_cnt EolExpn);

    %end;

   data out.TreatHrrPatientDocYear;
        set %RepeatN(pfx=out.treat_ind_, Nlow=&startyear., Nhigh=&endyear.);
    run;

    proc sort data = out.TreatHrrPatientDocYear;
        by &rawid. &physid. phys_hrr year;
    run;

    proc export data=out.TreatHrrPatientDocYear
            outfile="../output_local/TreatHrrPatientDocYear.csv"
            dbms=csv
            replace;
    run;

%mend;

** EXECUTE;
%main(pct=20, startyear=2009, endyear=2009);

