cap program drop binned_scatter_plot
program binned_scatter_plot
	syntax, yvar(varname) xvar(varname) binvar(varname) name(str)  [xtitle(str)] ///
		[ytitle(str)] [weight] [count(varname)] [format(str)]

	if "`count'"=="" local count baseline_samp
	if "`format'"=="" local format %5.4f
	if "`ytitle'"=="" local ytitle "Mortality Rate"
	if "`xtitle'"=="" local xtitle "Log Utilization in Dest HRR"
	
	reg `yvar' `xvar' [fw=`count']
	local slope = string(round(_b[`xvar'], 0.0001), "`format'")
	local se = string(round(_se[`xvar'], 0.0001), "`format'")
	
	collapse (mean) `yvar' `xvar' (rawsum) `count' [fw=`count'], by(`binvar')
	
	if "`weight'"!="" {
		local msize 0.25
	}
	else {
		replace `count'=1
		local msize 1.1
	}
	twoway (scatter `yvar' `xvar' [aw=`count'], msize(`msize')) (lfit `yvar' `xvar' ///
		[aw=`count']), xtitle("`xtitle'") ytitle("`ytitle'")  title("Slope=`slope'", ///
		size(medium) pos(12) ring(0)) subtitle("SE=(`se')", size(small) pos(12) ///
		ring(0) margin(medlarge)) legend(off) scheme(s1mono)
	graph export ../output/figures/`name'.eps, replace
end
