*This program provides Empirical Bayes adjustments. The procedure here is based off of Morris (1983)
*Section 5 and Chandra et al. (2013), Appendix C (see http://economics.mit.edu/files/8500)

cap program drop ebayes

program define ebayes,
	syntax varlist [if], fe_se(name) groupfe(name) [absorb(name)] [factor(str)] ///
		GENerate(name) generate_se(name) 
	
	** This program will first estimate the variance of the prior distribution (a_hat).
	** Using A_hat, the program estimates the EB adjustment factor (b_hat) and the estimated mean
    ** towards which we shrinkg (theta_hat). 
	cap drop w temp_sum fe_var group_mean

	** Generate variables to contain the weights and the estimates
	gen w=1
	gen temp_sum=.

	** Deal with the if statement
	marksample touse
	
	** Create estimated variance by squaring standard errors.
	gen fe_var = (`fe_se')^2
	
	** Generate a variable to keep track of previous guess for a_hat
    local a_hat=0.5
	local a_hat_0 = 0

	local cnt=1

	while(abs(`a_hat'-`a_hat_0')>0.00001 & `cnt' < 50) {

        if "`absorb'"!="" {
            areg `varlist' `factor' if `touse' [aw=w], a(`absorb')
        }
        else {
            reg `varlist' `factor' if `touse' [aw=w]
        }
        cap drop theta_hat
        predict theta_hat
        replace theta_hat = . if `touse'==0
	
        ** generate k - number of observations
        local k = e(N)
        ** generate r - number of regressors
        local r = e(df_m)+1
	
		** generate a_hat and a_hat_0
		replace temp_sum = (`k'/(`k'-`r'))*(`groupfe'-theta_hat)^2 - fe_var
		sum temp_sum [aw=w], meanonly

		** if the estimated variance is less than 0 set it to zero
		if (r(mean)<=0){
			local a_hat_0=0
			local a_hat=0
		}
		else{
			local a_hat_0=`a_hat'
			local a_hat=r(mean)
		}

		** forward the counter
		disp `a_hat_0'
		disp `a_hat'	 
		disp `cnt'
		local cnt = `cnt'+1

		** generate new weights
		replace w = 1/(`a_hat'+fe_var)
	}

	local fail= (abs(`a_hat'-`a_hat_0')>0.001)

	if(!`fail'){
		gen a_hat=`a_hat' 
		gen b_hat = ((`k'-`r'-2)/(`k'-`r'))*(fe_var/(fe_var+`a_hat'))
	}
	else{
		gen a_hat=0
		gen b_hat=0
        disp "*************************************************************************************"
        disp "*** Outcome Failed to Converge "
        disp "*************************************************************************************"
	}

	** generate EB corrected fixed effects
	gen `generate'=(1-b_hat)*`groupfe'+b_hat*theta_hat 
    gen `generate_se'=sqrt(fe_var*(1-b_hat))

	** drop the variables we no longer need
	cap drop w 
    cap drop temp_sum 
    cap drop fe_var 
    cap drop theta_hat 
    cap drop a_hat 
    cap drop b_hat

end
