cap program drop run_main_model
program run_main_model
    syntax [if] [in], [y_it(str)] [x_it(str)] [fixed_effects(str)] ///
        [specification_name(str)] [lambda(str)] [absorb(str)] [keep_fe_estimates] [collapse(str)]

    marksample touse
    keep if `touse'

    cap mkdir ../output/`specification_name'/

    datasignature set, saving(../output/`specification_name'/datasignature, replace) reset

    areg `y_it' `x_it' `fixed_effects', a(`absorb')

    estimates save ../output/`specification_name'/estimates, replace
    estimates store estimates

    compute_hrr_fixed_effects, lambda(`lambda')
	
	if "`keep_fe_estimates'"=="keep_fe_estimates" {
		predict chat, d
		predict resid, residuals
        predict_list _RY* _A*, gen(xhat_it)
        replace chat = chat+xhat_it
		predict_list _Yyear*, gen(tau)
        gen cons=_b[_cons]
		keep bene_id year `y_it' mover gammatilde_j gammatilde_j_se hrrnum ///
			chat xhat_it tau cons resid
	}
    else {
		keep bene_id year `y_it' mover gammatilde_j hrrnum
    }
	
    gen fwgt = ${mover_weight}
    replace fwgt = ${nonmover_weight} if mover==0
	save ../temp/estimation_data_uncollapsed, replace
    	
	if "`collapse'"=="no" {
		exit
	}
		
	estimates restore estimates
	gen N=1
	collapse (mean) `y_it'_bar_jt=`y_it' gammatilde_j ///
		(semean) `y_it'_se=`y_it' (rawsum) N [fw=fwgt], by(hrrnum year)
	collapse (mean) `y_it'_bar_j=`y_it'_bar_jt `y_it'_se gammatilde_j ///
		(sum) N, by(hrrnum)
	gen ctildebar_j = `y_it'_bar_j - gammatilde_j

	save_data ../output/`specification_name'/hrr_fe, replace key(hrrnum)

end

    program compute_hrr_fixed_effects
    *This function computes HRR fixed effects from the regression above. If the option lambda 
    *is specified then it adjusts for fuzzy timing of move.
        syntax, [lambda(str)]

        if "`lambda'"!="" {
            gen gammatilde1_j = .
            gen gammatilde2_j = .
            gen gammatilde_j_se = .
            estimates restore estimates
            replace gammatilde2_j = 0 if mover==0
            levelsof hrrnum, local(hrrnum_levels)
            foreach H of local hrrnum_levels {
                replace gammatilde1_j = _b[_Ihrrnum_`H'] if mover==0 & hrrnum == `H'
                replace gammatilde1_j = _b[_Ihrrnum_`H'] if mover==1 & hrr_orig==`H' ///
                    & rel_yr_rit<0
                replace gammatilde1_j = _b[_Ihrrnum_`H'] if mover==1 & hrr_dest==`H' ///
                    & rel_yr_rit>0 & rel_yr_rit<.
                replace gammatilde2_j = _b[_Ihrrnum_`H'] if mover==1 & hrr_orig==`H' ///
                    & rel_yr_rit>0 & rel_yr_rit<.
                replace gammatilde2_j = _b[_Ihrrnum_`H'] if mover==1 & hrr_dest==`H' ///
                    & rel_yr_rit<0
				replace gammatilde_j_se = _se[_Ihrrnum_`H'] if hrrnum==`H'
            }
            gen gammatilde_j = ///
                `lambda'*gammatilde1_j + (1 - `lambda')*gammatilde2_j
        }
        else {
            predict_list _Ihrrnum*, gen(gammatilde_j)
        }

    end

