***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./decompressDenom.sas";
%include "&SASmac./ConformDenom.sas";
%include "&SASmac./breakFilename2parts.sas";

libname spip "&spip.";
libname spmed "&spmed.";
libname spden "&spden.";
libname spcar "&spcar.";
libname spop "&spop.";
libname denerz "&denerz.";
libname mederz "&mederz.";

libname here ".";
libname denex "&denExt.";
%let writeout = ~/Medicare/contents/sasout;

x "mkdir &writeout. -p";
***MEDPAR;
%macro contentmedpar(pct=,yearin=,yearout=);
    x "rm &spmed./medpar* -f";
    %do yr=&yearin. %to &yearout.;
        %decompressMedPar(yr=&yr.,pct=&pct.,libout=spmed,dirout=&spmed.);
        ods csv file="&writeout./medpar&yr.&pct..csv";
        proc contents data=spmed.medpar&pct._&yr._all;
        run;
        ods csv close;
        x "rm &spmed./medpar* -f";
        %end;
    %mend;

*** DENOM;

%macro contentdenom(pct=,yearin=,yearout=);
    x "rm &spden./* -f";
    %do yr=&yearin. %to &yearout.;
        %decompressDenom(yr=&yr.,pct=&pct.,outdir=&spden.,outlib=spden,dflag=0);
        ods csv file="&writeout./denom&yr.&pct..csv";
        proc contents data=spden.denom&pct._&yr._all;
        run;
        ods csv close;
        x "rm &spden./* -f";
        %end;
    %mend;


**CARRIER;
%macro contentcar(pct=,yearin=,yearout=);
    %do y=&yearin. %to &yearout.;

        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);
         ** The autocount data set contains the max number of files, this is generated by the;
         ** %decompress macro. It save it to a macro here  so it can be used globally  ;
       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
        %do z= 1 %to 1;
            %breakFilename2parts(ftype=car,pct=&pct.,z=&z.);
            %if &y. >= 2002  %then %do;
                %decompress_i(spaceDir=&spcar.,dataRoot=&dataRoot.,
                    ftype=car,pct=&pct.,year=&y.,subtype=clms,pctsuffix=&suffix.,indx=&part.);

                %decompress_i(spaceDir=&spcar.,dataRoot=&dataRoot.,
                    ftype=car,pct=&pct.,year=&y.,subtype=lnits,pctsuffix=&suffix.,indx=&part.);
                ods csv file="&writeout./car&y.&pct._lnits.csv";
                proc contents data=spcar.car&pct.&suffix._&y._lnits&part.;
                run;
                ods csv close;
                ods csv file="&writeout./car&y.&pct._clms.csv";
                proc contents data=spcar.car&pct.&suffix._&y._clms&part.;
                run;
                ods csv close;
                %end;
            %else %do;
                %decompress_i(spaceDir=&spcar.,dataRoot=&dataRoot.,
                    ftype=car,pct=&pct.,year=&y.,pctsuffix=&suffix.,indx=&part.);
                ods csv file="&writeout./car&y.&pct..csv";
                proc contents data=spcar.car&pct.&suffix._&y._&part.;
                run;
                ods csv close;
                %end;



            x "rm &spcar./car&pct.* -f";
                %end;
            %end;
    %mend;

***OUTPATIENT;
%macro contentop(pct=,yearin=,yearout=);
    %do y=&yearin. %to &yearout.;
        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.);
         ** The autocount data set contains the max number of files, this is generated by the;
         ** %decompress macro. It save it to a macro here  so it can be used globally  ;
       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
        %do z= 1 %to 1;
            %breakFilename2parts(ftype=op,pct=&pct.,z=&z.);
            * Decompress file or files to start;
            %if &y. >= 2001  %then %do;
                %decompress_i(spaceDir=&spop.,dataRoot=&dataRoot.,
                    ftype=op,pct=&pct.,year=&y.,subtype=clms,pctsuffix=&suffix.,indx=&part.);
                %decompress_i(spaceDir=&spop.,dataRoot=&dataRoot.,
                    ftype=op,pct=&pct.,year=&y.,subtype=revcntrs,pctsuffix=&suffix.,indx=&part.);
                            ** Make sure we are starting with an empty dataset to append files-appending;
                ods csv file="&writeout./op&y.&pct.clms.csv";
                proc contents data=spop.op&pct.&suffix._&y._clms&part.;
                run;
                ods csv close;

                ods csv file="&writeout./op&y.&pct.revcntrs.csv";
                proc contents data=spop.op&pct.&suffix._&y._revcntrs&part.;
                run;
                ods csv close;

                %end;
            %else %do;
                %decompress_i(spaceDir=&spop.,dataRoot=&dataRoot.,
                    ftype=op,pct=&pct.,year=&y.,pctsuffix=&suffix.,indx=&part.);

                ods csv file="&writeout./op&y.&pct..csv";
                proc contents data=spop.op&pct.&suffix._&y._&part.;
                run;
                ods csv close;

                %end;


            x "rm &spop./op&pct.* -f";
            %end;
        %end;
    %mend;


%macro contentip(pct=,yearin=,yearout=);
    x "rm &spip./ip&pct.* -f";
    %let part= 1 ;
    %do y=&yearin. %to &yearout.;
         ** The autocount data set contains the max number of files, this is generated by the;
         ** %decompress macro. It save it to a macro here  so it can be used globally  ;
       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
        %if &y. = 1997 or &y. >= 2002 %then %do;
            * Decompress file or files to start;
            %decompress_i(spaceDir=&spip.,dataRoot=&dataRoot.,
                ftype=ip,pct=&pct.,year=&y.,subtype=clms,pctsuffix=,indx=&part.);
            %decompress_i(spaceDir=&spip.,dataRoot=&dataRoot.,
                ftype=ip,pct=&pct.,year=&y.,subtype=revcntrs,pctsuffix=,indx=&part.);
            ** Make sure we are starting with an empty dataset to append files-appending;
            ods csv file="&writeout./ip&y.&pct.clms.csv";
            proc contents data=spip.ip&pct._&y._clms&part.;
            run;
            ods csv close;

            ods csv file="&writeout./ip&y.&pct.revcntrs.csv";
            proc contents data=spip.ip&pct._&y._revcntrs&part.;
            run;
            ods csv close;
            %end;
        %else %do;
            %decompress_i(spaceDir=&spip.,dataRoot=&dataRoot.,
                ftype=ip,pct=&pct.,year=&y.,pctsuffix=,indx=&part.);
            ods csv file="&writeout./ip&y.&pct..csv";
            proc contents data=spip.ip&pct._&y._&part.;
            run;
            ods csv close;
            %end;
        x "rm &spip./ip&pct.* -f";
        %end;
    %mend;

/*%contentmedpar(pct=05,yearin=1984,yearout=2010);
%contentmedpar(pct=20,yearin=1984,yearout=2010);
%contentmedpar(pct=100,yearin=1992,yearout=2010);
*/

%contentop(pct=05,yearin=2010,yearout=2010);
%contentop(pct=05,yearin=1984,yearout=2010);
%contentip(pct=05,yearin=1997,yearout=2010);
%contentcar(pct=05,yearin=1985,yearout=2010);


%contentop(pct=20,yearin=1984,yearout=2010);
%contentop(pct=100,yearin=1992,yearout=2010);


%contentcar(pct=20,yearin=1992,yearout=2010);
%contentcar(pct=100,yearin=1992,yearout=2010);

%contentip(pct=20,yearin=1997,yearout=2010);
%contentip(pct=100,yearin=1997,yearout=2010);


