*********************************************************************************************;
** SAS PROGRAM TO TAKE ALL PROVIDER NUMBER WHICH APPEAR IN THE MEDPAR FILE, MERGE THEM WITH THE;
** POS FILE : GET ADDRESS INFORMATION, MAKE A WJOLE SERIES OF EDITS THEN INTERPOLATE ADDRESS INFORMATION;

** THE CODE WAS ORIGNIALLY CREATED BY MATT FIEDLER AND THEN MODIFIED BY MAURICE DALTON.
** ALL ERRORS ARE MY OWN;
*********************************************************************************************;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./calcdistanceMacros.sas";
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinmedparxw;
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformMedPar.sas";

* Macro used for adress fixing;
%include "step1macrolib/StdzMacros.sas";
%include "step1macrolib/RifleShotAddressEdits.sas";
%include "step1macrolib/GenerateRawMedPARfiles.sas";
%include "step1macrolib/EditPOSAdressMacros.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname geoex "&geoex.";
libname inpos "&inpos.";
libname spmed "&spmed.";
libname carerz "&carerz.";
libname longEx "&longExt.";
libname bene "&inbenexw.";
libname gnislib "&ingnis.";

%let csvdir=/disk/aging/medicare/code/AuxData/providerGeoCodingPrj;
%let writeaddress=&programRoot./0PreProcessPrgms/providerGeoCodingPrj/excelFilesForHandCoding/POSAddresses.csv;
%macro wrapper_POSintoMedPAR(diag=, pct=,dgnPos=,start=,end=,identifier=);
**********************************************;
** Step 1 Extract Raw MedPAR files;
**********************************************;
    x "rm &spmed./* -f";
    %do year=&start. %to &end.;
       %if &pct.=100 and &year.<1992 %then %do;
           %decompressMedPar(yr=&year.,pct=20,fname=med,libout=spmed,dirout=&spmed.,dflag=1);
           %GenrateRawMedPARfiles(yr=&year.,diag=&diag.,pct=20,dgnPos=&dgnPos.
                                  ,identifier=&identifier.);
           %end;
       %else %do;
           %decompressMedPar(yr=&year.,pct=&pct.,fname=med,libout=spmed,dirout=&spmed.,dflag=1);
           %GenrateRawMedPARfiles(yr=&year.,diag=&diag.,pct=&pct.,dgnPos=&dgnPos.,identifier=&identifier.);
           %end;
       %end;

    data spmed.rawmedpar&pct. (keep=fileyear prvnumgrp dgnscd1 is_snf  flagami spclunit swing_bed);
        set  %RepeatN(rawmedpar,&start., &end.);
    run;

    *** tag provider id in the final indx event so we can prioritize;
    proc sort data=spmed.rawmedpar&pct.;
        by prvnumgrp swing_bed;
    run;

    proc freq data=spmed.rawmedpar&pct.;
        tables swing_bed /missing;
    run;

    data spmed.rawmedpar&pct._prov ;
        set spmed.rawmedpar&pct. ;
        WHERE swing_bed =0;
        by prvnumgrp ;
        **drop swing bed records here- not interested in these;
        if last.prvnumgrp  then output;
    run;

    proc sort data=spmed.rawmedpar&pct.;
        by prvnumgrp fileyear;
    run;

    proc summary nway data=spmed.rawmedpar&pct.;
        by prvnumgrp fileyear;
        var flagami;
        output out=spmed.rawmedpar_provYr (rename=(_FREQ_=totdis) drop=_TYPE_)
            sum(flagami) = / AUTONAME;
    run;

    proc contents data=spmed.rawmedpar_provYr;
    run;
   **********************************************;
   ** Step2: Merge MedPAR prov and POS FIle;
   **********************************************;
   ** File should have prvnumgrp IDs, plus number of;
   ** AMIs, also need to make sure snfs are not ;
   ** accounted for;


    proc contents data=inpos.posmaster;
    run;

    proc sort data=spmed.rawmedpar&pct._prov (keep=prvnumgrp  is_snf swing_bed)
        out=providerListMedpar nodupkey;
        by prvnumgrp;
    run;

**BRING THIS INTO POS IMPORT PROGRAM;
    proc sort data=inpos.posmaster
        (keep=provider name city category zipcode state ssastate address year)
        out=inpos.posmaster_nodupe NODUPKEY ;
        by provider year;
    run;

    **********************************************;
    ** Tag  POS prvnumgrp ID which occur in MedPAR files --drop at a later point;
    ** MedPAR files are kept at a later point;
    **********************************************;
    data geoex.ReducedPOS;
        merge inpos.posmaster_nodupe (in=inPOS rename=(year=fileyear provider=prvnumgrp) drop=state)
            providerListMedpar (in=inMed );
        by prvnumgrp;
        ** Only keep providers found in POS and MED. MEDPAR non matching numbers;
        ** are accounted for in the following datastep;
        if inPOS and inMed;
        ** FIX BY HAND;
        if prvnumgrp="440038" AND fileyear=1992 then city="MCMINNVILLE";
        if prvnumgrp="200066" then do;
            city="DOVER-FOXCROFT";
  	end;
    run;

    **********************************************;
    ** Identify POS files which Match provder-year ;
    ** from those whose year does not match;
    **********************************************;

    proc sort data=geoex.ReducedPOS;
        by prvnumgrp fileyear;
    run;

    data VolPOSCombined
        geoex.NoPOSMatch (keep=inPOS inMedPAR prvnumgrp fileyear);
        merge geoex.ReducedPOS(in=inPOSFlag )
              spmed.rawmedpar_provYr (  in= inMedPARFlag
                                    keep= prvnumgrp fileyear totdis  flagami_Sum);
        by prvnumgrp fileyear;
        inMedPAR = inMedPARFlag;
        inPOS = inPOSFlag;
        output VolPOSCombined;
        if inMedPAR and not inPOS then do;
            output geoex.NoPOSMatch;
            end;
    run;

    proc print data=VolPOSCombined;
	WHERE prvnumgrp = "200066";
	run;
    ***********************************************************************;
    * STEp3:Create absolute difference between medpar and pos fileyear nonmatches;
    ***********************************************************************;
    ** (M:1) Merge on provider ID {match<=>non-matching} being sure to keep file year;
    ** from the nonmatching while creating a distance metric of the mathcned nonmatched;
    proc sql;
        create table PatchMatch as
            select *, abs(N.fileyear-C.fileyear) as posDist
            from geoex.NoPOSMatch N, geoex.ReducedPOS  C
            where (N.prvnumgrp = C.prvnumgrp);
        quit;
    run;

    * restrict the approximate matches to be only those matches that are not too approximate;
    * and take the closest match for each year;
    proc sort data=PatchMatch;
        by prvnumgrp fileyear posDist;
    run;

    ** create patches by keeping firstyear in the sample if the distance is < 8.;
    ** only accounts for inbstance where POS and MEDPAR FILE are of by one years;
    data PatchMatch;
        set PatchMatch;
        by prvnumgrp fileyear posDist;
        if first.fileyear and posDist < 8;
    run;

    proc print data=PatchMatch;
        WHERE prvnumgrp = "050743";
    run;

    * match the approxiate matches back on to the master file;
    proc sort data=PatchMatch;
        by prvnumgrp fileyear;
    run;


   * Make a dataset containing all records for hospitals that ever are in the universe;
   * We will drop records corresponding to years where the hospital is not in the universe subsequently;
    proc sort data=VolPOSCombined;
        by prvnumgrp fileyear;
    run;

    data geoex.medparUniv&pct._clean;
        merge VolPOSCombined PatchMatch(in=inPatch);
        by prvnumgrp fileyear;
        inPach=inPatch;
        if inPatch then do;
            inPOS = posDist + 1;
            end;

        drop posDist;
        rename ssastate=statessa;
    run;

    proc print data=geoex.medparUniv&pct._clean;
        WHERE prvnumgrp = "050743";
    run;

    *%RunDiagnostics(pct=&pct.);


***!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*;
*** BEGIN FIXING FIX ADDRESS INFORMATION FOR THE REST OF THE CODE***;
***!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*;
*********************************************************************************;
*** Step 4a: Batch city renames from hand-written file;
*********************************************************************************;
    %BatchEdits(varname=city,newlen=28,pct=&pct.);
    *********************************************************************************;
    *** Step 4b: Apply changes/standards found in the Rifle-shot macro;
    *********************************************************************************;
    data geoex.medparUniv&pct._clean;
        set geoex.medparUniv&pct._clean ;
    * Fix various POS DATA ERRORS;
        %CorrectSSAStateCodes;
        %CorrectCityNames;
        %CorrectFullAddresses;

    * Standardize street addresses to successful interpolation;
    * This code strips PO BOX names, standardizes directions and street type abbreviations,;
    * and corrects various other issues;
        %StdzStrAddr(address);
    run;

    proc print data=geoex.medparUniv&pct._clean;
    WHERE prvnumgrp="010011";
    run;
    *********************************************************************************;
    *** Step 4c: Fix state alpha code inconsistencies en masse (using SSA state code);
    *********************************************************************************;
    * Import alpha codes;
    filename inAlpha "&csvdir./SSAtoAlpha.csv";

    data SSAtoAlpha;
        infile inAlpha delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;
        informat statessa $2.;
        informat statename $45.;
        informat statealpha $2.;

        input
            statessa $
            statename $
            statealpha $;
    run;

    proc sort data=SSAtoAlpha;
        by statessa;
    run;

    * Merge alpha codes onto address list and use to replace current code if there is a mismatch;
    * I checked by hand, and this appears to generate correct behavior;
    proc sort data=geoex.medparUniv&pct._clean;
        by statessa;
    run;

    data geoex.medparUniv&pct._clean;
        merge geoex.medparUniv&pct._clean(in=inAddr) SSAtoAlpha( drop=statename);
        by statessa;
        if inAddr;

        if statealpha ~= state then do;
            state = statealpha;
            end;
        *drop statealpha;
    run;

    proc freq data=geoex.medparUniv&pct._clean;
        tables state;
    run;

    ***********************************************************************;
    *** Step 4d: With the state codes corrected, standardize the city names;
    ***********************************************************************;
    %StdzCityName(geoex.medparUniv&pct._clean,city,state);
    ***********************************************************************;
    *** Step 4e: Interpolate addresses across years where valid address data is not available;
    ***********************************************************************;
    %InterpAddresses(fieldList=address city state zipcode  ,fieldLength=50 50 2 5,pct=&pct.);

    proc freq data=geoex.medparUniv&pct._clean;
        tables fileyear*(interpFlag extrapFlag) / nopercent norow nocol;
    run;
    *********************************************************;
    **** STEP 5: TAG ADDRESSES FOR GEOCODING AND EXPORT ****;
    *********************************************************;
    %TagUnique(fieldlist=address city state zipcode, suffix=pos,outfile=&writeaddress.,pct=&pct.);
    x "rm &spmed./* -f ";
    %mend;


***EXECUTE PROGRAM;
%wrapper_POSintoMedPAR(diag=ami, pct=100,dgnPos=1,start=1984,end=2008,identifier=bene_id);


