*********************************************************************************************;
** SAS PROGRAM TO TAKE ALL PROVIDER NUMBER WHICH APPEAR IN THE MEDPAR FILE, MERGE THEM WITH THE;
** POS FILE : GET ADDRESS INFORMATION, MAKE A WJOLE SERIES OF EDITS THEN INTERPOLATE ADDRESS INFORMATION;

** NOTE THEIR IS ONE CASE WHERE THE LAT-LON IS EQUAL TO ZERO;
** THAT OCCURS BECAUSE THE GNIS RECORD IS EMPTY. ITS A HOSPITAL FOUND IN THE PR ;
** THE CODE WAS ORIGNIALLY CREATED BY MATT FIEDLER AND THEN MODIFIED BY MAURICE DALTON.;
** ALL ERRORS ARE MY OWN;
*********************************************************************************************;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname geoex "&geoex.";
libname geoin "fors2_geoin";
libname ingnis "&ingnis.";

*FOUND LOCALLY ON THE NBER SERVERS;
%let csvinputfiles=/disk/aging/medicare/code/AuxData/providerGeoCodingPrj;
%let infiles=/disk/aging/medicare/code/AuxData/providerGeoCodingPrj/excelFileusedForHandCoding;



**** LOAD THE SPREADSHEETS OF GROUP A, B, C HOSPITAL DATA ****;

%macro ReadGroupResults;
    * read in the hand geocoding results for group A hospitals;
    filename grpAFile pipe "dos2unix < &infiles./GroupAHospitals-FINAL_EXPORT.csv";

    data GrpADat;
        infile grpAFile delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;

        informat prvnumgrpnum $6.;
        informat fileyear 4.;
        informat grpa_gnis_r3 10.;
        informat grpa_gnis_r4 10.;
        informat grpa_esri 10.;
        informat grpa_faa $4.;
        informat grpa_lat best16.;
        informat grpa_lon best16.;
        informat grpa_gnis_r1 10.;
        informat grpa_gnis_r2 10.;
        informat grpa_gnis_city 10.;

        input
            prvnumgrpnum $
            fileyear
            grpa_gnis_r3
            grpa_gnis_r4
            grpa_esri
            grpa_faa
            grpa_lat
            grpa_lon
            grpa_gnis_r1
            grpa_gnis_r2
            grpa_gnis_city;

        if length(prvnumgrpnum)=6 then prvnumgrp=prvnumgrpnum;
        if length(prvnumgrpnum)=5 then prvnumgrp="0" || prvnumgrpnum;
        drop prvnumgrpnum;
    run;


    proc sort data=GrpADat;
        by prvnumgrp fileyear;
    run;

    * read in the hand geocoding results for group B hospitals;
    filename grpBFile pipe "dos2unix < &infiles./GroupBHospitals-FINAL_EXPORT.csv";

    data GrpBDat;
        infile grpBFile delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;

        informat prvnumgrpnum $6.;
        informat fileyear 4.;
        informat stat_pos $1.;
        informat grpb_useyear 4.;
        informat grpb_badmatch 1.;
        informat grpb_gnis_r3 10.;
        informat grpb_gnis_r4 10.;
        informat grpb_faa $4.;
        informat grpb_esri 10.;
        informat grpb_gnis_r1 10.;
        informat grpb_gnis_r2 10.;
        informat grpb_lat best16.;
        informat grpb_lon best16.;

        input
            prvnumgrpnum $
            fileyear
            stat_pos $
            grpb_useyear
            grpb_badmatch
            grpb_gnis_r3
            grpb_gnis_r4
            grpb_faa $
            grpb_esri
            grpb_gnis_r1
            grpb_gnis_r2
            grpb_lat
            grpb_lon;

        drop stat_pos;
        if length(prvnumgrpnum)=5 then prvnumgrp="0" || prvnumgrpnum;
        if length(prvnumgrpnum)=6 then prvnumgrp=prvnumgrpnum;

        drop prvnumgrpnum;

    run;


    proc sort data=GrpBDat;
        by prvnumgrp fileyear;
    run;

        * read in the hand geocoding results for group B hospitals;
    filename grpCFile pipe "dos2unix < &infiles./GroupCHospitals-FINAL_EXPORT.csv";

    data GrpCDat;
        infile grpCFile delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;

        informat prvnumgrpnum $6.;
        informat fileyear 4.;
        informat stat_pos $1.;
        informat grpc_useyear 4.;
        informat grpc_badmatch 1.;
        informat grpc_gnis_r4 10.;
        informat grpc_gnis_r3 10.;
        informat grpc_faa $4.;
        informat grpc_esri 10.;
        informat grpc_gnis_r1 10.;
        informat grpc_gnis_r2 10.;
        informat grpc_lat best16.;
        informat grpc_lon best16.;

        input
            prvnumgrpnum $
            fileyear
            stat_pos $
            grpc_useyear
            grpc_badmatch
            grpc_gnis_r4
            grpc_gnis_r3
            grpc_faa $
            grpc_esri
            grpc_gnis_r1
            grpc_gnis_r2
            grpc_lat
            grpc_lon;

        **Working in OO converts provider numbers to strings and drops 0;
        if length(prvnumgrpnum)=5 then prvnumgrp="0"|| prvnumgrpnum;
        if length(prvnumgrpnum)=6 then prvnumgrp=prvnumgrpnum;
        drop stat_pos prvnumgrpnum;
    run;

    proc sort data=GrpCDat;
        by prvnumgrp fileyear;
    run;

    %mend;


%ReadGroupResults;

/*proc print data=GrpADat;
    WHERE prvnumgrp in("284003");
run;
proc print data=GrpBDat;
    WHERE prvnumgrp in("284003");
run;
proc print data=GrpCDat;
    WHERE prvnumgrp in("284003");
run;
*/
**** MATCH HAND-CODED DATA ONTO THE FULL DATA ****;

* get basic extract of the partially matched data;
data WorkingData;
    set geoex.medparuniv100_partcoord;
    keep prvnumgrp fileyear name address city state stat_pos stat_pos_d lat_pos lon_pos lat_pos_d lon_pos_d;
run;


proc sort data=WorkingData;
    by prvnumgrp fileyear;
run;

* merge on the hand-geocoded fields;
%macro MergeHandCode(grpLet);

    data WorkingData;
        merge WorkingData(in=inWork) Grp&grpLet.Dat(in=in&grpLet.);
        by prvnumgrp fileyear;

        inGrp&grpLet. = in&grpLet.;

        if not inWork then do;
            put "ERROR: Hand-coded hospital not in master database!";
            abort;
            end;
    run;

    %mend;

%MergeHandCode(A);
%MergeHandCode(B);
%MergeHandCode(C);

* confirm that all entres are in at most one group;
data _null_;
    set WorkingData;

    if (inGrpA + inGrpB + inGrpC > 1) then do;
        put "ERROR: Record in multiple hand-coding groups!";
        abort;
        end;
run;

* conslidate identifiers as appropriate;
data WorkingData;
    set WorkingData;

    if inGrpA then do;
        gnis_id_r4 = grpa_gnis_r4;
        gnis_id_r3 = grpa_gnis_r3;
        gnis_id_r2 = grpa_gnis_r2;
        gnis_id_r1 = grpa_gnis_r1;
        faa_id = grpa_faa;
        esri_id = grpa_esri;
        gnis_city_id = grpa_gnis_city;
        lat_man = grpa_lat;
        lon_man = grpa_lon;
        end;
    else if inGrpB then do;
        badmatch = grpb_badmatch;
        useyear = grpb_useyear;
        gnis_id_r4 = grpb_gnis_r4;
        gnis_id_r3 = grpb_gnis_r3;
        gnis_id_r2 = grpb_gnis_r2;
        gnis_id_r1 = grpb_gnis_r1;
        faa_id = grpb_faa;
        esri_id = grpb_esri;
        lat_man = grpb_lat;
        lon_man = grpb_lon;
        end;
    else if inGrpC then do;
        badmatch = grpc_badmatch;
        useyear = grpc_useyear;
        gnis_id_r4 = grpc_gnis_r4;
        gnis_id_r3 = grpc_gnis_r3;
        gnis_id_r2 = grpc_gnis_r2;
        gnis_id_r1 = grpc_gnis_r1;
        faa_id = grpc_faa;
        esri_id = grpc_esri;
        lat_man = grpc_lat;
        lon_man = grpc_lon;
        end;

    drop grpa_: grpb_: grpc_:;
run;


*** LOAD AND MERGE ON COORDINATES FROM THE FAA FILE ***;

* read in the FAA file;
filename faaFile pipe "dos2unix < &csvinputfiles./FAA/FAAHeliports-Processed.csv";

data FAAData;
    infile faaFile delimiter='09'x MISSOVER DSD LRECL=32767 FIRSTOBS=2;

    informat faa_id $4.;
    informat faa_state $2.;
    informat faa_county $20.;
    informat faa_city $34.;
    informat faa_facname $42.;
    informat faa_lat best16.;
    informat faa_lon best16.;

    input
        faa_id $
        faa_state $
        faa_county $
        faa_city $
        faa_facname $
        faa_lat
        faa_lon;
run;

* sort and merge;
proc sort data=FAAData;
    by faa_id;
run;

proc sort data=WorkingData;
    by faa_id;
run;

data WorkingData;
    merge WorkingData(in=inWork) FAAData(keep=faa_id faa_lat faa_lon);
    by faa_id;

    if inWork;
run;


*** LOAD AND MERGE ON COORDINATES FROM THE ESRI FILE ***;
***NO LONGER USING THE ESRI DATE;

*** LOAD AND MERGE ON COORDINATES FROM THE THREE GNIS FILES ***;
* The manual geocoding was done in three rounds, for which  ended up using different;
* versioins of the GNIS database.  Locations corresponding to a given GNIS ID can;
* change between versions of the database, so I match on the database for each;
* round as appropriate.;
* ;
* Date serials corresponding to the database for each round are as follows:;
* Round 1: 20101203;
* Round 2: 20110404;
* Round 3: 20111204;
* Round 4: 20120416;

%macro HandleGNISHospLocs(dateSrl, num);

    proc sort data=WorkingData;
        by gnis_id_r&num.;
    run;

    proc sort data=ingnis.HospCoords&dateSrl.;
        by feature_id;
    run;

    data WorkingData;
        merge WorkingData(in=inWork)
            ingnis.HospCoords&dateSrl.(keep=feature_id primary_lat_dec primary_long_dec
            rename=(feature_id=gnis_id_r&num. primary_lat_dec=gnis_r&num._lat primary_long_dec=gnis_r&num._lon));
        by gnis_id_r&num.;

        if inWork;
    run;

    %mend;

%HandleGNISHospLocs(20101203,1);
%HandleGNISHospLocs(20110404,2);
%HandleGNISHospLocs(20111204,3);
%HandleGNISHospLocs(20120416,4);

* handle the populated place file second;
proc sort data=WorkingData;
    by gnis_city_id;
run;

proc sort data=ingnis.ppdata20101203;
    by feature_id;
run;

data WorkingData;
    merge WorkingData(in=inWork)
        ingnis.ppdata20101203(keep=feature_id primary_lat_dec primary_long_dec
        rename=(feature_id=gnis_city_id primary_lat_dec=gnis_city_lat primary_long_dec=gnis_city_lon));
    by gnis_city_id;

    if inWork;
run;


*** HANDLE THE USE YEARS ***;
* extract the coordinates to rematch;
**HOSPITAL IN  PR - GNIS RECORD IS EMPTY;
proc print data=geoex.medparuniv100_partcoord;
    WHERE prvnumgrp in("400010");
run;

data UseSubset;
    set geoex.medparuniv100_partcoord;
    keep prvnumgrp fileyear lat_pos lon_pos;
    rename lat_pos=use_lat lon_pos=use_lon fileyear=useyear;
run;



* sort and merge;
proc sort data=UseSubset;
    by prvnumgrp useyear;
run;

proc sort data=WorkingData;
    by prvnumgrp useyear;
run;


data WorkingData;
    merge WorkingData(in=inWork) UseSubset;
    by prvnumgrp useyear;

    if inWork;
run;



*** COMBINE EVERYTHING ***;
proc sort data=WorkingData;
    by prvnumgrp fileyear;
run;

proc print data=WorkingData;
    WHERE prvnumgrp in("400010");
run;



data WorkingData;
    set Workingdata;

    length coordtype $ 20;

    if stat_pos in ("M", "T") and badmatch ~= 1 then do;
        lat_fin = lat_pos;
        lon_fin = lon_pos;
        coordtype = "Geocoded";
        end;
    else if stat_pos_d in ("M","T") and inGrpA ~= 1 and inGrpB ~= 1 and inGrpC ~= 1 then do;
        lat_fin = lat_pos_d;
        lon_fin = lon_pos_d;
        coordtype = "Rematched - auto";
        end;
    else if useyear ~= . then do;
        lat_fin = use_lat;
        lon_fin = use_lon;
        coordtype = "Rematched - manual";
        end;
    else if faa_id ~= "" then do;
        lat_fin = faa_lat;
        lon_fin = faa_lon;
        coordtype = "FAA";
        end;
    else if gnis_id_r4 ~= . then do;
        lat_fin = gnis_r4_lat;
        lon_fin = gnis_r4_lon;
        coordType = "GNIS R4 - Hospital";
        end;
    else if gnis_id_r3 ~= . then do;
        lat_fin = gnis_r3_lat;
        lon_fin = gnis_r3_lon;
        coordType = "GNIS R3 - Hospital";
        end;
    else if gnis_id_r2 ~= . then do;
        lat_fin = gnis_r2_lat;
        lon_fin = gnis_r2_lon;
        coordType = "GNIS R2 - Hospital";
        end;
    else if gnis_id_r1 ~= . then do;
        lat_fin = gnis_r1_lat;
        lon_fin = gnis_r1_lon;
        coordType = "GNIS R1 - Hospital";
        end;
    else if gnis_city_id ~= . then do;
        lat_fin = gnis_city_lat;
        lon_fin = gnis_city_lon;
        coordtype = "GNIS - City";
        end;
    else if lat_man ~= . and lon_man ~= . then do;
        lat_fin = lat_man;
        lon_fin = lon_man;
        coordtype = "Manual";
        end;

    validCoord = (lat_fin ~= .) and (lon_fin ~= .);
    flag0 = (lat_fin ~= .) and (lon_fin ~= .);
run;
**HOSPITAL IN  PR - GNIS RECORD IS EMPTY;
proc print data=WorkingData;
    WHERE prvnumgrp in("400010");
run;


proc freq data=WorkingData;
    tables validCoord*coordType / missing;
run;

proc print data=WorkingData(where=(validCoord = 0));
    var prvnumgrp fileyear coordType esri_id faa_id gnis_id_r: inGrpA inGrpB inGrpC;
run;

data geoex.medparuniv100_FinalCoords;
    set WorkingData;

    keep prvnumgrp fileyear name address city state coordtype lat_fin lon_fin;
    rename lat_fin=lat lon_fin=lon;
run;

**HOSPITAL IN  PR - GNIS RECORD IS EMPTY;
proc print data=geoex.medparuniv100_FinalCoords;
    WHERE prvnumgrp in("400010") or lat=. or lat=0;
run;

