** Sanity check will involve merging with the GNIS files based on city name and state and then calculdate the
** distance to the city center as suggested by matt fiedler;

***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./calcdistanceMacros.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname geoex "&geoex.";
libname ingnis "&ingnis.";


*** LOAD AND MERGE ON COORDINATES FROM THE THREE GNIS FILES ***;
* The manual geocoding was done in three rounds, for which  ended up using different;
* versioins of the GNIS database.  Locations corresponding to a given GNIS ID can;
* change between versions of the database, so I match on the database for each;
* round as appropriate.;
* ;
* Date serials corresponding to the database for each round are as follows:;
* Round 1: 20101203;
* Round 2: 20110404;
* Round 3: 20111204;

%macro MergeInGNISPopPlaces(gnisDate=, num=);
    proc sql;
        create table countgnis as
        select * , count(*) as repeatCity
            from ingnis.ppdata&gnisDate
        group by feature_name;
    run;

    proc freq data=countgnis;
        tables repeatCity;
    run;

    data gnis ;
        set countgnis;
        length city $50 state $2;
        city=UPCASE(feature_name);
        state=UPCASE(state_alpha);
        /*if repeatCity=1 then output gnis;
        if repeatCity>1 then output dupegnis;*/
        drop feature_name  state_alpha;
    run;

    proc sort data=geoex.medparuniv100_FinalCoords;
        by city state;
    run;

    proc sort data=gnis;
        by city state;
    run;

    /*proc print data=geoex.medparuniv100_FinalCoords (obs=100);
    run;*/

    proc sql;
        create table HospCityCoordMM as
            select *
            from geoex.medparuniv100_FinalCoords M, gnis G
            where M.city=G.city and M.state = G.state;
        quit;

    data HospCityCoordMMdist;
        set HospCityCoordMM;
       *Calc distnace between town center and hospitals;
        distTown_WP=%CalcDist_WP(lat1=primary_lat_dec ,long1=primary_long_dec ,
                                lat2=lat ,long2=lon );
    run;

    proc sql;
        create table geoex.HospCityCoordMMdist_min as
            select *, min (distTown_WP) as mindist, min(lat) as minlat,
                   min(lon) as minlon
            from HospCityCoordMMdist
            group by prvnumgrp ,city, state;
        quit;

    data geoex.g1zerolaton geoex.g2largedist geoex.g3else;
        set geoex.HospCityCoordMMdist_min;
        if minlat = 0  or minlon =0 then output geoex.g1zerolaton;
        else if mindist > 50 then output geoex.g2largedist;
        else output geoex.g3else;
    run;

    proc univariate data=geoex.HospCityCoordMMdist_min;
        var distTown_WP mindist;
    run;

    data geoex.HospCityCoord;
        merge geoex.medparuniv100_FinalCoords (in=inMedpar)
            gnis (in=inGNIS );
        by city state;
        if inMedpar;
        inmed=inMedpar;
        ingni=inGNIS;

       *Calc distnace between town center and hospitals;
        distTown_WP=%CalcDist_WP(lat1=primary_lat_dec ,long1=primary_long_dec ,
                                lat2=lat ,long2=lon );

        /*distTown_AC=%CalcDist_AC(lat1=primary_lat_dec ,long1=primary_long_dec ,
                                lat2=lat ,long2=lon );*/

    run;

    proc freq data=geoex.HospCityCoord;
        tables inmed*ingni state/ norow nocol;
    run;

    proc univariate data=geoex.HospCityCoord;
        WHERE ingni=1 and state ne "PR";
        var distTown_WP ;
    run;

    proc univariate data=geoex.HospCityCoord;
        WHERE ingni=1 ;
        var distTown_WP ;
    run;

    /*proc print data=geoex.HospCityCoord (keep=distTown_: city name address state primary_lat_dec primary_long_dec lat lon ingni);
        WHERE distTown_WP>150 and ingni=1 ;
    run;
    */
    %mend;

*%MergeInGNISPopPlaces(gnisDate= 20101203, num= 1);
*%MergeInGNISPopPlaces(gnisDate= 20110404, num= 2);
*%MergeInGNISPopPlaces(gnisDate= 20111204, num= 3);
%MergeInGNISPopPlaces(gnisDate= 20120416, num= 4);

