*********************************************************************************************;
** SAS PROGRAM TO TAKE ALL PROVIDER NUMBER WHICH APPEAR IN THE MEDPAR FILE, MERGE THEM WITH THE;
** POS FILE : GET ADDRESS INFORMATION, MAKE A WJOLE SERIES OF EDITS THEN INTERPOLATE ADDRESS INFORMATION;

** THE CODE WAS ORIGNIALLY CREATED BY MATT FIEDLER AND THEN MODIFIED BY MAURICE DALTON.
** ALL ERRORS ARE MY OWN;
*********************************************************************************************;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./calcdistanceMacros.sas";
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinmedparxw;
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformMedPar.sas";

* Macro used for adress fixing;
%include "step1macrolib/StdzMacros.sas";
%include "step1macrolib/RifleShotAddressEdits.sas";
%include "step1macrolib/GenerateRawMedPARfiles.sas";
%include "step1macrolib/EditPOSAdressMacros.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname inpos "&POSext.";
libname sppos "&sppos.";
libname spmed "&spmed.";
libname carerz "&carerz.";
libname longEx "&medparExt.";
libname bene "&inbenexw.";
***Used in one of the macos;
libname gnislib "&ingnis.";
libname inHRR "&inHRRzipxw.";

%let csvdir=&programRoot./0PreProcessPrgms/providerOfService/csvinputfiles;

%macro wrapper_POSintoMedPAR(diag=, pct=,dgnPos=,start=,end=,identifier=);
**********************************************;
** Step 1 Extract Raw MedPAR files;
**********************************************;

    %do year=&start. %to &end.;
        %rawVarXw(harVar=prvnumgrp,yr=&year.,outputvar=provider,filename=medparxw);
        %rawVarXw(harVar=spclunit,yr=&year. ,outputvar=ftypeVar,filename=medparxw);
        %rawVarXw(harVar=outlr_cd,yr=&year. ,outputvar=outlyer,filename=medparxw);
        %rawVarXw(harVar=dstntncd_ch,yr=&year. ,outputvar=dest_cd,filename=medparxw);
        %rawVarXw(harVar=drg_cd,yr=&year.   ,outputvar=drg_code,filename=medparxw);
        %rawVarXw(harVar=sslssnf,yr=&year.  ,outputvar=snfvar,filename=medparxw);

       %if &pct.=100 and &year.<1992 %then %do;
           %decompressMedPar(yr=&year.,pct=20,libout=spmed,dirout=&spmed.,dflag=1,dataroot=&dataRoot.);
           %GenrateRawMedPARfiles(yr=&year.,diag=&diag.,pct=20,dgnPos=&dgnPos.
                                  ,identifier=&identifier.);
           %end;
       %else %do;
           %decompressMedPar(yr=&year.,pct=&pct.,libout=spmed,dirout=&spmed.,dflag=1,dataroot=&dataroot.);
           %GenrateRawMedPARfiles(yr=&year.,diag=&diag.,pct=&pct.,dgnPos=&dgnPos.,identifier=&identifier.);
           %end;
       %end;

    data spmed.rawmedpar&pct. (keep=fileyear prvnumgrp dgnscd1 is_snf  flagami spclunit swing_bed);
        set  %RepeatN(rawmedpar,&start., &end.);
    run;

    *** tag provider id in the final indx event so we can prioritize;
    proc sort data=spmed.rawmedpar&pct.;
        by prvnumgrp;
    run;

    data spmed.rawmedpar&pct._prov ;
        set spmed.rawmedpar&pct. ;
        by prvnumgrp ;
        **drop swing bed records here- not interested in these;
        if last.prvnumgrp  then output;
    run;

    proc sort data=spmed.rawmedpar&pct.;
        by prvnumgrp fileyear;
    run;

    proc summary nway data=spmed.rawmedpar&pct.;
        by prvnumgrp fileyear;
        var flagami;
        output out=spmed.rawmedpar_provYr (rename=(_FREQ_=totdis) drop=_TYPE_)
            sum(flagami) = / AUTONAME;
    run;

    proc contents data=spmed.rawmedpar_provYr;
    run;
   **********************************************;
   ** Step2: Merge MedPAR prov and POS FIle;
   **********************************************;
   ** File should have prvnumgrp IDs, plus number of;
   ** AMIs, also need to make sure snfs are not ;
   ** accounted for;


    proc contents data=inpos.posmaster;
    run;

    proc sort data=spmed.rawmedpar&pct._prov (keep=prvnumgrp  is_snf swing_bed)
        out=providerListMedpar nodupkey;
        by prvnumgrp;
    run;

**BRING THIS INTO POS IMPORT PROGRAM;
    *        (keep=provider name city category zipcode state ssastate address year prv);

    proc sort data=inpos.posmaster
        out=sppos.posmaster_nodupe NODUPKEY ;
        by provider year;
    run;

    **********************************************;
    ** Tag  POS prvnumgrp ID which occur in MedPAR files --drop at a later point;
    ** MedPAR files are kept at a later point;
    **********************************************;
    data ReducedPOS;
        merge sppos.posmaster_nodupe (in=inp rename=(year=fileyear provider=prvnumgrp) drop=state)
            providerListMedpar (in=inMed );
        by prvnumgrp;
        ** Only keep providers found in POS and MED. MEDPAR non matching numbers;
        ** are accounted for in the following datastep;
        ***if inPOS and inMed;
        inmedpar=inMEd;
        inpos=inp;
        ** FIX BY HAND;
        if prvnumgrp="440038" AND fileyear=1992 then city="MCMINNVILLE";
        if prvnumgrp="200066" then do;
            city="DOVER-FOXCROFT";
  	end;
    run;

    proc freq data=ReducedPOS;
        table inmedpar*inpos fileyear /missing;
    run;

    proc freq data=ReducedPOS;
        WHERE fileyear=.;
        table fileyear /missing;
    run;

    **********************************************;
    ** Identify POS files which Match provder-year ;
    ** from those whose year does not match;
    **********************************************;

    proc sort data=ReducedPOS;
        by prvnumgrp fileyear;
    run;

    data VolPOSCombined
        NoPOSMatch (keep=inPOS inMedPAR prvnumgrp fileyear);
        merge ReducedPOS(in=inPOSFlag where=(inmedpar=1))
              spmed.rawmedpar_provYr (  in= inMedPARFlag
                                    keep= prvnumgrp fileyear totdis  flagami_Sum);
        by prvnumgrp fileyear;
        inMedPAR = inMedPARFlag;
        inPOS = inPOSFlag;
        output VolPOSCombined;
        if inMedPAR and not inPOS then do;
            output NoPOSMatch;
            end;
    run;
    proc freq data=VolPOSCombined;
        WHERE fileyear=.;
        table fileyear /missing;
    run;

    proc freq data=VolPOSCombined;
        table inPOS*inMedPAR;
    run;

     x "rm &spmed./* -f";

    proc print data=VolPOSCombined;
	WHERE prvnumgrp = "200066";
	run;
    ***********************************************************************;
    * STEp3:Create absolute difference between medpar and pos fileyear nonmatches;
    ***********************************************************************;
    ** (M:1) Merge on provider ID {match<=>non-matching} being sure to keep file year;
    ** from the nonmatching while creating a distance metric of the mathcned nonmatched;
    proc sql;
        create table PatchMatch as
            select *, abs(N.fileyear-C.fileyear) as posDist
            from NoPOSMatch (drop=inpos) N, ReducedPOS  C
            where (N.prvnumgrp = C.prvnumgrp);
        quit;
    run;

    * restrict the approximate matches to be only those matches that are not too approximate;
    * and take the closest match for each year;
    proc sort data=PatchMatch;
        by prvnumgrp fileyear posDist;
    run;

    ** create patches by keeping firstyear in the sample if the distance is < 8.;
    ** only accounts for inbstance where POS and MEDPAR FILE are of by one years;
    data PatchMatch;
        set PatchMatch;
        by prvnumgrp fileyear posDist;
        if first.fileyear and posDist < 8;
    run;

    proc print data=PatchMatch;
        WHERE prvnumgrp = "050743";
    run;

    * match the approxiate matches back on to the master file;
    proc sort data=PatchMatch;
        by prvnumgrp fileyear;
    run;


   * Make a dataset containing all records for hospitals that ever are in the universe;
   * We will drop records corresponding to years where the hospital is not in the universe subsequently;
    proc sort data=VolPOSCombined;
        by prvnumgrp fileyear;
    run;

    data posclean_medpar;
        merge VolPOSCombined PatchMatch(in=inPatch keep=prvnumgrp fileyear posDist);
        by prvnumgrp fileyear;
        inPach=inPatch;
        if inPatch then do;
            inPOS = posDist + 1;
            end;

        drop posDist;
        rename ssastate=statessa;
    run;

    proc freq data=posclean_medpar;
        WHERE fileyear=.;
        table fileyear /missing;
    run;

    **Add pos claims not found in medpar file;
    data inpos.posmaster_clean;
        set posclean_medpar
            ReducedPOS (where=(inmedpar=0));
        if prvnumgrp ne "";
    run;

    proc freq data=inpos.posmaster_clean;
        WHERE fileyear=.;
        table fileyear /missing;
    run;


    *%RunDiagnostics(pct=&pct.);


***!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*;
*** BEGIN FIXING FIX ADDRESS INFORMATION FOR THE REST OF THE CODE***;
***!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*;
*********************************************************************************;
*** Step 4a: Batch city renames from hand-written file;
*********************************************************************************;
    %BatchEdits(varname=city,newlen=28,pct=&pct.);
    *********************************************************************************;
    *** Step 4b: Apply changes/standards found in the Rifle-shot macro;
    *********************************************************************************;
    data inpos.posmaster_clean;
        set inpos.posmaster_clean ;
    * Fix various POS DATA ERRORS;
        %CorrectSSAStateCodes;
        %CorrectCityNames;
        %CorrectFullAddresses;

    * Standardize street addresses to successful interpolation;
    * This code strips PO BOX names, standardizes directions and street type abbreviations,;
    * and corrects various other issues;
        %StdzStrAddr(address);
    run;

    proc print data=inpos.posmaster_clean;
    WHERE prvnumgrp="010011";
    run;

    *********************************************************************************;
    *** Step 4c: Fix state alpha code inconsistencies en masse (using SSA state code);
    *********************************************************************************;
    * Import alpha codes;
    filename inAlpha "&csvdir./SSAtoAlpha.csv";

    data SSAtoAlpha;
        infile inAlpha delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;
        informat statessa $2.;
        informat statename $45.;
        informat statealpha $2.;

        input
            statessa $
            statename $
            statealpha $;
    run;

    proc sort data=SSAtoAlpha;
        by statessa;
    run;

    * Merge alpha codes onto address list and use to replace current code if there is a mismatch;
    * I checked by hand, and this appears to generate correct behavior;
    proc sort data=inpos.posmaster_clean;
        by statessa;
    run;

    data inpos.posmaster_clean;
        merge inpos.posmaster_clean (in=inAddr) SSAtoAlpha( drop=statename);
        by statessa;
        if inAddr;

        if statealpha ~= state then do;
            state = statealpha;
            end;
        *drop statealpha;
        zipcode_num=input(zipcode,8.);
    run;

    proc freq data=inpos.posmaster_clean;
        tables state;
    run;

    ***********************************************************************;
    *** Step 4d: With the state codes corrected, standardize the city names;
    ***********************************************************************;
    %StdzCityName(inpos.posmaster_clean,city,state);

    ***********************************************************************;
    *** Step 5: Add dartmouth crosswalks to the files;
    ***********************************************************************;
    proc sort data=inpos.posmaster_clean;
        by fileyear zipcode_num;
    run;
    proc sort data=inHRR.masterhrrcross;
        by year zipcode;
    run;

    proc contents data=inHRR.masterhrrcross;run;
    proc contents data=inpos.posmaster_clean;run;

    data inpos.posmaster_clean;
        merge inpos.posmaster_clean (in=inposc )
              inHRR.masterhrrcross (in=hrrxw
                                    rename=(year=fileyear zipcode=zipcode_num));
        by fileyear zipcode_num;

        inhrrxw=hrrxw;
        inposclean=inposc;
        **ONLY KEEP THOSE OBS FOUND IN THE POS;
        if inposclean;
        ** a small amount of providers with missing observations;
        if fileyear=. then delete;

    run;

    proc freq data=inpos.posmaster_clean;
        table inhrrxw*inposclean;
    run;

/**    x "rm &spmed./* -f";
    x "rm &sppos./* -f";
*/
    %mend;


***EXECUTE PROGRAM;
%wrapper_POSintoMedPAR(diag=ami, pct=100,dgnPos=1,start=1984,end=2011,identifier=bene_id);


