*** STEP 3: RUN SOME USEFUL DIAGNOSTICS ***;

%macro RunDiagnostics(pct=);
    *** CHECKS FOR WHETHER WE LEFT ANY OUT ***;
    ** Look at failed POS matches;
    * Tabluate how many provider number-year pairs did not match any record in the POS database;
    * RESULT: In the set of provider number-year pairs that report at least one admission, about 3700
    *do not match the POS file.;
    * 1) About 75 percent of the rest were rematched to another POS record, virtually all of these;
    *      within two years;
    * 2) Almost all of the rest either have trivial volume (these appear to be foreign hospitals and data
    *    errors) or else have special provider numbers that correspond to HCFA/CMS demonstration projects;

    TITLE "IN MEDPAR VS IN POS";
    proc freq data=VolPOSCombined;
        tables inMedPAR*inPOS  / missing;
    run;
    TITLE "";


    TITLE "NUMBER OF SWING BEDS TO DROP";
    proc freq data=VolPOSCombined;
        tables swing_bed*is_snf swing_bed*posAcuteCare  / missing;
    run;
    TITLE "";

    proc univariate data=VolPOSCombined;
        var countAMI;
    run;

    proc sort data=VolPOSCombined;
        by is_snf;
    run;

    proc univariate data=VolPOSCombined;
        by is_snf;
        var countAMI ;
    run;

    proc sort data=VolPOSCombined;
        by swing_bed;
    run;

    proc univariate data=VolPOSCombined;
        by swing_bed;
        var countAMI ;
    run;

    proc freq data=inpos.posmaster_clean;
        tables fileyear*inPOS fileyear*swing_bed fileyear*posAcuteCare inPach*inMedPAR inPach*inPOS / missing nocol norow ;
    run;

    %mend;



*** STEP 4: FIX ADDRESS INFORMATION ***;
*** Step 4a: Batch city renames from hand-written file;
%macro BatchEdits(fname=, varname=, newlen=,pct=);

    * Read in the edits;
    filename inEd "&csvdir./CityEdits.csv";

    data Edits;
        infile inEd delimiter="," MISSOVER DSD LRECL=32767 FIRSTOBS=2;

        informat prvnumgrp $6.;
        informat startyear 4.;
        informat endyear 4.;
        informat new&varname. $&newlen..;

        input
            prvnumgrp $
            startyear
            endyear
            new&varname. $;
    run;

    * Reshape them into long form;
    data Edits;
        set Edits;
        do i=startyear to endyear;
            fileyear = i;
            output;
            end;
        keep prvnumgrp fileyear new&varname.;
    run;


    * Sort and merge;
    proc sort data=Edits;
        by prvnumgrp fileyear;
    run;

    proc sort data=inpos.posmaster_clean;
        by prvnumgrp fileyear;
    run;

    data inpos.posmaster_clean;
        merge inpos.posmaster_clean(in=inAddr) Edits(in=inEds);
        by prvnumgrp fileyear;

        if inAddr;

        if inEds then do;
            &varname. = new&varname.;
            end;

        drop new&varname.;
    run;

    %mend;



*** Step 4e: Interpolate addresses across years where valid address data is not available;
%macro InterpAddresses(fieldList=,fieldLength=,pct=);
    * Step 4e(1): Transform the address data from long to wide form;
    proc sort data=inpos.posmaster_clean;
        by prvnumgrp fileyear;
    run;

    data WideUniv1;
        set inpos.posmaster_clean;
        by prvnumgrp;

        * set the list of variables to keep;
        %let keepList = prvnumgrp;

        * set up relevant arrays;
        %do i=1 %to %sysfunc(countw("&fieldList."));
            * basic variable setup;
            %let curField = %scan(&fieldList.,&i.);
            %let curLen = %scan(&fieldLength.,&i.);

            retain &curField.1984-&curField.2008;
            array &curField._ar {25} $ &curLen. &curField.1984-&curField.2008;

            %let keepList = &keepList. &curField.1984-&curField.2008;

            * if this is the first record for this hospital, then wipe the fields;
            if first.prvnumgrp then do;
                do j=1 to 25;;
                    &curField._ar{j} = "";
                    end;
                end;

            * take the current record into the proper place in the array;
            &curField._ar{fileyear-1983} = &curField.;

            %end;

        * if this is the last record for the hospital, then write the record;
        if last.prvnumgrp then do;
            output;
            end;

        keep &keepList.;
    run;

    * Step 4e(2): Interpolate addresses in two steps:;
    *               a) Identify blocks of blank addresses (often where the hospital reported only a PO BOX).;
    *                  Where those blocks are bookended by (identical) valid addresses, we interpolate.;
    *               b) In the early years, some hospitals reported a street name, but no street number.;
    *                  This code identifies these instances and projects the street number backward;

    data WideUniv;
        set WideUniv1;

        * Set up the data arrays for referring to the components of the address;
        %do i=1 %to %sysfunc(countw("&fieldList."));
            %let curField = %scan(&fieldlist.,&i.);
            array &curField._ar {25} &curField.1984-&curField.2008;
            %end;

        * Set up an array of flags that can be used to record where interpolation has occured;
        intFlag = 0;
        array interpFlag_ar {25} interpFlag1984-interpFlag2008;
        do i=1 to 25;
            interpFlag_ar{i} = 0;
            end;

        * Step 4e(2)(a): Interpolate blocks of blank addresses bookended by valid addreses;
        lastValid = -1;
        inBlankBlock = 0;
        intFlag = 0;

        do i=1 to 25;
            * check whether the current string is blank or not;
            * if not blank, then check for the end of a blank block and otherwise update the most recent valid address;
            if trim(address_ar{i}) ne "" then do;
                * handle the end of a blank block;
                if inBlankBlock then do;
                    * if the addresses on the two sides of the break match, then interpolate;
                    if address_ar{lastValid} = address_ar{i} then do;
                        do j = (lastValid + 1) to (i - 1);
                            address_ar{j} = address_ar{lastValid};
                            interpFlag_ar{j} = 1;
                            intFlag = 1;
                            end;
                        end;
                    end;
                * alternatively, update the location of the most recent valid address;
                else do;
                    lastValid = i;
                    end;
                end;
            * if blank, check whether we have ever seen a valid address and, if so, set that we are in a blank block;
            else if lastValid > 0 then do;
                inBlankBlock = 1;
                end;
            end;


        * Step 4e(2)(b): Extrapolate street numbers when prior records have the same street name, but no number;
        * In this step, we require city and state to match before we allow extrapolation;
        length stub $ 50;

        array extrapFlag_ar {25} extrapFlag1984-extrapFlag2008;
        do i=1 to 25;
            extrapFlag_ar{i} = 0;
            end;

        extFlag = 0;
        * extrapolate from present time backwards first;
        do i=2 to 25;

            * test the current address to see whether the current address has building number;
            * note that the regular expression returns the full string if there is no match;
            stub = prxchange("s/^[0-9]+ ([^\s].+)$/$1/",1,address_ar{i});

            * if there is a building number, extrapolate!;
            if trim(stub) ne trim(address_ar{i}) then do;
                do j=1 to i - 1;
                    * compare the current stub to a prior address;
                    * if it matches, replace the older address;
                    * if it does not match, then leave the loop;
                    if (trim(stub) = trim(address_ar{i-j})) and (city_ar{i} = city_ar{i-j}) and (state_ar{i}=state_ar{i-j}) then do;
                        address_ar{i-j} = address_ar{i};
                        extrapFlag_ar{i-j} = 1;
                        extFlag = 1;
                        end;
                    else leave;
                    end;
                end;
            end;


        * run forward extrapolation second;
        do i=1 to 24;

            * test the current address to see whether the current address has building number;
            * note that the regular expression returns the full string if there is no match;
            stub = prxchange("s/^[0-9]+ ([^\s].+)$/$1/",1,address_ar{i});

            * if there is a building number, extrapolate;
            if trim(stub) ne trim(address_ar{i}) then do;
                do j=i+1 to 25;

                    * compare the current stub to a prior address;
                    * if it matches, replace the older address;
                    * if it does not match, then leave the loop;
                    if (trim(stub) = trim(address_ar{j})) and (city_ar{i} = city_ar{j}) and (state_ar{i}=state_ar{j}) then do;
                        address_ar{j} = address_ar{i};
                        extrapFlag_ar{j} = 1;
                        extFlag = 1;
                        end;
                    else leave;

                    end;
                end;

            end;

        drop lastValid inBlankBlock i j;
    run;


    * Step 4e(3): Use interpolation results;

    * tabulate how many hospitals were affected by the edits;
    proc freq data=WideUniv;
        tables intFlag extFlag;
    run;

    * pull the provider number-year pairs that were affected;
    data AlteredRecords;
        set WideUniv;
        * set up data arrays to review street address and interpolation/extrapolation flags;
        %let fieldList = address interpFlag extrapFlag;

        %do i=1 %to %sysfunc(countw("&fieldList."));
            %let curField = %scan(&fieldlist.,&i.);
            array &curField._ar {25} &curField.1984-&curField.2008;
            %end;

        * dump the data into variables;
        do y=1 to 25;
            %do i=1 %to %sysfunc(countw("&fieldList."));
                %let curField = %scan(&fieldlist.,&i.);
                &curField. = &curField._ar{y};
                %end;

            fileyear = 1983 + y;

            * output if the record is relevant;
            if (extrapFlag = 1) or (interpFlag = 1) then output;
            end;

        keep prvnumgrp fileyear interpFlag extrapFlag address;
        rename address=address_new;
    run;

    * replace street addresses in the original data, making sure not to introduce records;
    * for years where no record exists for the hospital;
    proc sort data=inpos.posmaster_clean;
        by prvnumgrp fileyear;
    run;

    proc sort data=AlteredRecords;
        by prvnumgrp fileyear;
    run;

    data inpos.posmaster_clean;
        merge inpos.posmaster_clean(in=univMember) AlteredRecords(in=inIntExt);
        by prvnumgrp fileyear;

        if not inIntExt then do;
            interpFlag = 0;
            extrapFlag = 0;
            end;

        if interpFlag or extrapFlag then do;
            address = address_new;
            end;

        if univMember;
        drop address_new;
    run;

    %mend;


