** Correct various SSA state codes;
%macro CorrectSSAStateCodes;

    if prvnumgrp = "100025" and fileyear = 1987 then do;
        statessa = "10";
        end;
    if prvnumgrp = "010001" and (fileyear = 1991 or fileyear = 1992) then do;
        statessa = "01";
        end;

    if prvnumgrp = "100254" and fileyear = 1987 then do;
        statessa = "10";
        end;

    if prvnumgrp = "250025" and fileyear >= 1987 and fileyear <= 1990 then do;
        statessa = "25";
        end;

    %mend;


** Correct various city spelling issues;
%macro CorrectCityNames;

    * split (mispelled) WEST VIRGINA off the end of the city name;
    if prvnumgrp = "510086" and fileyear >= 1987 and fileyear <= 1988 then do;
        city = "WELCH";
        state = "WV";
        end;

    %mend;


** Correct various bits of innacurate address information;
%macro CorrectFullAddresses;


    * This hospital, St. Johns Regional Medical Center in Oxnard, CA, reports moving;
    * to an address across town for one year in the late 1980s.  This appears to be incorrect.;
    * Neither the AHA nor the local newspaper show such a move.  I correct it below;
    * Note that the newspaper does show the later significant move;
    * (MEDICAL CENTER DELAYS OPENING..., Los Angeles Daily News, 8/29/1992);
    if prvnumgrp="050082" and fileyear = 1989 then do;
        address = "333 NORTH F ST";
        city = "OXNARD";
        zipcode = "93030";
        end;

    * This hospital, Harbor View Medical Center, reports in the POS file moving;
    * from downtown San Diego, CA to El Centro, CA, which is about 40 miles away;
    * for the years 1991-1993, and then moves back.  Cross-checking with the ;
    * AHA files, it seems no such moved occured.  Based on local newpspaper stories,;
    * it is possible that the hospital operated a satellite mental health facility;
    * in El Centro during those years.;
    if prvnumgrp="050607" and fileyear >= 1991 and fileyear <= 1993 then do;
        address = "120 ELM ST";
        city = "SAN DIEGO";
        zipcode = "92101";
        end;

    * This hospital, Aurora Presbyterian Hospital (060100), merges with Aurora;
    * Regional Medical Center (060087) circa 1996 to form the Medical Center of Aurora.;
    * The first is the North campus and the second is the South campus.  Both report;
    * under provider number 060100.  Then in 1999, the North campus stops providing;
    * inpatient services (see HOSPITAL CAMPUS SET TO MOVE..., Rocky Mountain News, 5/18/1999).;
    * The upshot is this:;
    * 1) For 1997 and 1998, we have a two-campus hospital problem.;
    * 2) For 1999-2001, the address is the North campus address, but should really be;
    *    the South campus address.
    * I fix the second problem below, but the first is fixable in principle.;
    if prvnumgrp = "060100" and fileyear >= 1999 and fileyear <= 2001 then do;
        address = "1501 S POTOMAC ST";
        zipcode = "80012";
        end;

    * This hospital, Sun Coast Hospital (100015), erroneously has its address set to be the address;
    * of South Lake Memorial Hospital (100051), which is half way across the state, for 2000-2002.;
    * As a conseqeuence, the move of South Lake to its new facility in 2000 (see hospital website);
    * is not correctly recorded in the South Lake record.  I fix both addresses below;
    if prvnumgrp = "100015" and fileyear >= 1997 and fileyear <= 2002 then do;
        address = "2025 INDIAN ROCKS RD";
        city = "LARGO";
        zipcode = "33774";
        end;

    if prvnumgrp = "100051" and fileyear >= 2000 and fileyear <= 2002 then do;
        address = "1099 CITRUS TOWER BLVD";
        end;


    * This hospital, North Okaloosa Medical Center, incorrectly reports as its name and address;
    * the name and address of one of its outpatient clinic for 2000.  I correct this below;
    if prvnumgrp="100122" and fileyear = 2000 then do;
        name = "NORTH OKALOOSA MEDICAL CENTER";
        address = "151 REDSTONE AV SE";
        city = "CRESTVIEW";
        zipcode = "32536";
        end;


    * This hospital, Glenwood Regional Medical Center, appears to have erronesouly been;
    * overwritten by an ASC in 1999.  I correct this problem below.;
    if prvnumgrp = "190160" and fileyear = 1999 then do;
        name = "GLENWOOD REGIONAL MEDICAL CENTER";
        address = "503 MCMILLAN ROAD";
        city = "WEST MONROE";
        zipcode = "71291";
        end;

    * The provider number 190175 is complicated.  It starts as Chalmette General Hospital.;
    * After 1990, its volume falls off dramatically, such that it is not an AMI hospital;
    * as of 1994, when it merges with River Parishes Hospital (190193), which is about 10 miles away;
    * The combined hospital continues report under the 190175 provider number, but most of the volume;
    * (and almost all of the AMI volume) seems to be coming form the River Parishes campus starting;
    * in the 1995 reporting year. The address eventually changes, but it takes a year to do so. I;
    * fix that here. I also fix a typo from an earlier year.;
    * ;
    * For more information see RIVER PARISHES AND CHALMETTE HOSPITALS MERGE, Times-Picayune, 2/15/1994;
    if prvnumgrp = "190175" and fileyear = 1995 then do;
        address = "500 RUE DE SANTE";
        city = "LAPLACE";
        zipcode = "70068";
        end;

    * With the same hospital, I correct a little typo in the address;
    if prvnumgrp = "190175" and fileyear = 1985 then do;
        address = "801 VIRTUE ST";
        end;

    * The address for provider number 190218 appears to be screwed up.  This hospital appears;
    * as Northgate Hospital in 1992, then changes its name to Sabine Medical Center in 1995.;
    * This new hospital seems to capture all the volume of a pre-existing Sabine Medical Center;
    * (190047), which is 60 miles away in Many, LA.  In truth, it appears that Northgate was always;
    *  sending its general medical and surgical patients to Many, LA and was actually a psychiatric;
    * hospital.  Masquerading as a general hospital, however, allowed it to get additional Medicaid;
    * dollars from the state of Lousiana.  (See RULES OF THE GAME: MEDICAID MADNESS, Times-Picayune,;
    * 8/13/1995.);
    * ;
    * As a consequence, I change the address of Northgate to match the Sabine Medical Center address.;
    if prvnumgrp = "190218" and fileyear <= 1995 then do;
        address = "240 HIGHLAND DR";
        city = "MANY";
        zipcode = "71449";
        end;

    * A merger poses a problem for provider number 200021.  This is initially Bath Memorial Hospital;
    * in Bath, ME.  It merges with Regional Memorial Hospital in Brunswick, ME and begins joint;
    * reporting in 1992.  (See HOSPITAL PRESIDENT EXPLAINS..., Portland Press Herald, 7/10/1996.);
    * Both hospitals continue operating through mid-1997, at which point Bath Memorial closes.;
    * (See BATH HOSPITAL TAKES NEW ROLE..., Portland Press Herald, 5/29/1997.);
    * The upshot is this:;
    * 1) The address of Bath Memorial is incorrect for 1991, as it has already switched in the POS file;
    * 2) We have a multi-campus hospital problem for 1992-1997, which I have not dealt with at this point;
    * For now, I addres #1 only;
    if prvnumgrp = "200021" and fileyear = 1991 then do;
        name = "BATH MEMORIAL HOSPITAL";
        address = "23 WINSHIP ST";
        city = "BATH";
        zipcode = "04530";
        end;

    * Northern Cumberland Memorial Hospital, now Bridgton Hospital, which has provider number 200007,;
    * was acquried by Central Maine Medical Center (200024).  (See HOSPITALS IN BRIDGTON, LEWISTON...,;
    * Portland Press Herald, 8/4/1999.)  Though it continued to report separately, its address was;
    * incorrectly changed to the Lewiston addres of CMMC.  I correct this, and also reflect the hospitals;
    * new building as of 2002 (see New Bridgton Hospital..., Portland Press Herald, 1/31/2002.);
    * Note that old address is likely not geocodable, but article suggests that old building was only 50 yds away;
    if prvnumgrp = "200007" and fileyear >= 2000 and fileyear <= 2001 then do;
        address = "S HIGH ST";
        city = "BRIDGTON";
        zipcode = "04009";
        end;

    if prvnumgrp = "200007" and fileyear >= 2002 and fileyear <=2004 then do;
        address = "10 HOSPITAL DR";
        end;

    * Burbank Hospital (220001) and Leominster Hospital (220094) merged to form Health Alliance Hospital;
    * in 1994 according to the hospital website.  Local newspaper reports indicate that by sometime in;
    * 1997, Burbank had stopped providing most inpatient and emergency services  (see ER SYSTEM UNDER STRESS...,;
    * Worcester Telegram & Gazette, 7/20/1997).  It appears that Health Alliance consolidates all reporting under;
    * the Burbank provider number sometime in 1997.  The POS addresses do not, however, accord with this reality,;
    * as they subsequently bounce back and forth between the two hospital locations.  I correct this below,;
    * and ensure that all post-1997 records point to the old Leominster location;
    if prvnumgrp = "220001" and (fileyear=1997 or (fileyear >= 2004 and fileyear <= 2008)) then do;
        address = "60 HOSPITAL ROAD";
        city = "LEOMINSTER";
        zipcode = "01453";
        end;

    * There appears to have been a complicated series of mergers in Lynn and Salem, MA over the study period;
    * The three hospitals in question are Lynn Hospital, Union Hospital, and Salem Hospital.  There are two;
    * key events:;
    * 1) Beginning sometime around 1988, Lynn and Union Hospitals combine under the umbrella of AtlantiCare;
    *    Medical Center.  They report separately until the Lynn campus begins to shut down as a full-fledged;
    *    inpatient facility, likely in 1988.  Union then shifts to reporting under the Lynn provider number;
    *    The addresses of the two facilities, however, get switched for 1987, so I need to fix that;
    * 2) Beginning in 2004, the old Union hospital and Salem Hospital combine under the umbrella of North;
    *    Shore Medical Center and report as a single entity under the Union Hospital provider number. Since;
    *    both continue operating, there is a multi-campus hospital problem for these years that I cannot fix;
    * ;
    * The code below solves only the first problem;
    if prvnumgrp = "220005" and fileyear = 1987 then do;
        address = "500 LYNNFIELD ST";
        end;

    if prvnumgrp = "220035" and fileyear = 1987 then do;
        address = "212 BOSTON ST";
        end;

    * Milford-Whitinsville regional hospital reports changing its address for 1989-1993;
    * from its former (and current) address in Milford to an address in Franklin.  The;
    * address in Franklin appears not to exist (though it may be a mangled version of;
    * the address of the Franklin city hall).  The local newspaper and AHA surveys give;
    * no sign of any such move, so I act as if it did not occur.;
    if prvnumgrp = "220090" and fileyear >= 1989 and fileyear <= 1993 then do;
        address = "14 PROSPECT ST";
        city = "MILFORD";
        zipcode = "01757";
        end;

    * Provider number 220111, which started life as Goddard Memorial Hospital in Stoughton, MA,;
    * merges with Cardinal Cushing Medical Center in Brockton, MA in late 1993.  In 1994, there;
    * is a fire at the Brockston hospital, leading to its temporary closure.  Once renovations are;
    * completed in 1995, the Stoughton hospital closes permanently and both report under the old;
    * Goddard provider number.  However, the address on the old Goddard record does not change until;
    * 2000.  I fix that here.  For details on all the above, see GODDARD PLANNING A MOVING...,;
    * The Patriot Ledger, 1/5/1995.;
    if prvnumgrp = "220111" and fileyear >= 1995 and fileyear <=1999 then do;
        address = "235 N PEARL ST";
        city = "BROCKTON";
        zipcode = "02301";
        end;

    * Crittendon Hospital in Rochester, MI reports moving to Columbus, MI for 1996-2004,;
    * which is about 40 miles away.  This appears to be erroneous and no such move occurs;
    * in the AHA surveys;
    if prvnumgrp = "230254" and fileyear >= 1996 and fileyear <= 2004 then do;
        city = "ROCHESTER";
        end;

    * A merger poses a problem for provider number 330094.  This number is Columbia Memorial Hospital,;
    * which merges with and begins reporting jointly with Memorial Hospital of Greene County (330052);
    * in 1988.  Starting in 1988, the address for this hospital moves to the Greene County address,;
    * and remains there until 2004 despite the fact that the Greene County facility is smaller and;
    * has basically ceased providing relevant emergency services in 1992  (see COURT APPROVES HOSPITAL;
    * CONSOLIDATION, Albany Times-Union, 7/7/1992).  Thus there are two problems:;
    * 1) The address of the AMI-relevant emergency services is simply wrong for 1993 and later.;
    * 2) There is a multi-campus hospital problem for 1988-1992;
    * I make the address of the hospital remain at the original address straight through.  This;
    * obviously only solves problem 1.;
    if prvnumgrp = "330094" and fileyear >= 1988 and fileyear <= 2004 then do;
        address = "71 PROSPECT AVE";
        city = "HUDSON";
        zipcode = "12534";
        end;

    * Various issues affect provider number 330395.  This provider number appears to encompass two;
    * hospitals owned and operated by Episcopal Health Services of Long Island, one in Far Rockaway;
    * and one in Smithtown until the Smithtown hospital is sold early in 2000 (see EPISCOPAL HEALTH;
    * FILES FOR REORGANIZATION, NYT, 11/21/1999).  For most of the period, it reports an address in;
    * Hempstead, which appears to be the EHS corporate headquarters (see TRANSFER OF HOSPITAL EXEC;
    * STIRS PROTEST, Newday, 9/22/1988).  Thus, we have two problems:;
    * 1) In 2000, until it is fixed in 2005, the address should really be the Far Rockaway address,;
    *    not the corporate address.;
    * 2) For earlier years, we have a multi-campus hospital problem, and the address corresponds to;
    *    neither;
    * I set the address for all years to be the Far Rockaway address, but this is clearly not satisfactory.;
    if prvnumgrp = "330395" and fileyear >= 1985 and fileyear <= 2004 then do;
        address = "327 BEACH 19TH ST";
        city = "FAR ROCKAWAY";
        zipcode = "11691";
        end;

    * Provider number 490018 is another that poses problems.  This begins as Waynesboro Community Hospital.;
    * It merger with Kings Daughters Hospital in Staunton, VA (490029) in the late 1980s (see HOSPITALS THAT;
    * MERGE TO BECOME THE SOLE..., Modern Healthcare, 12/5/1994).  They begin joint reporting to HCFA early;
    * in 1990 under 490018, and in 1991 the address for 490018 shifts to the address for Kings Daughters.;
    *  In mid-1994, the old two hospitals are closed, replaced by a single new hospital in ;
    * Fishersville, VA (see AUGUSTA MEDICAL CENTER SETTLES IN, Charlottesville Business Journal, 4/1/1995).;
    * In practice, this generates a multi-campus hospital problem for years 1991-1993 (both hospitals have enough;
    * residual volume in 1990 to make both show up in that year).  In particular, Waynesboro CH is gone.;

    * Provider number 490028 gives a bad address for 1985 and 1986.  It reports 2908 Kensington Ave, which;
    * is out of date by at about 5 years (see HOSPITAL CELEBRATES SUCCESS, Richmond Times-Dispatch, 6/13/1990).;
    * I change the address to the correct one;
    if prvnumgrp = "490028" and fileyear >= 1985 and fileyear <= 1986 then do;
        address = "1401 JOHNSTON-WILLIS DR";
        zipcode = "23235";
        end;

    * Provider number 490042 has incorrect addresses for some years.  Radford Community Hospital is replaced by;
    * Carilion New River Valley Medical Center in March 1999, but address is not updated until 2005.  I correct;
    * that below.  See THE WEEK IN REVIEW, Roanoke Times & World News, 3/28/1999.;
    if prvnumgrp = "490042" and fileyear >= 1999 and fileyear <= 2004 then do;
        address = "2900 LAMB CIRCLE";
        city = "CHRISTIANSBURG";
        zipcode = "24073";
        end;

    * Provider number 490101, Fair Oaks Hospital, has a mispelled word in the address;
    if prvnumgrp = "490101" and fileyear >= 1987 and fileyear <= 2005 then do;
        address = prxchange("s/DIEWICK/SIEWICK/", 1, address);
        end;

    * Provider number 520138, St. Lukes Medical Center in Milwaukee, has an incorrect address for 1993-1996.;
    * This address corresponds to a hospital in Sheboygan (520035) that the same company appears to have;
    * acquired, but which seems to have continued to report volumes separately.  Note, however, that there;
    * does appear to be another multi-campus problem with another hospital acquired around the same time;
    * with provider number 520056.  I do not address that problem here.;
    if prvnumgrp = "520138" and fileyear >= 1993 and fileyear <= 1996 then do;
        address = "2900 W OKLAHOMA AVE";
        city = "MILWAUKEE";
        zipcode = "53215";
        end;

    %mend;
