*** SUMMARY ***;
* This file contains macros for standardizing various type of geographic information;

%macro StdzCityName(datasetname, cvar, svar);
* I take city names to their full versions since this seems to generate better geocoding;

    * Do formulaic standardizations;
    data &datasetname.;
        set &datasetname.;

        * standardize abbreviations;
        &cvar. = prxchange("s/\bST\b/SAINT/", 1, &cvar.);
        &cvar. = prxchange("s/\bSTE\b/SAINTE/", 1, &cvar.);
        &cvar. = prxchange("s/\bMT\b/MOUNT/", 1, &cvar.);
        &cvar. = prxchange("s/\bFT\b/FORT/", 1, &cvar.);
        &cvar. = prxchange("s/\bHTS\b/HEIGHTS/", 1, &cvar.);

        * standardize direction abbreviations;
        &cvar. = prxchange("s/^N\b/NORTH/", 1, &cvar.);
        &cvar. = prxchange("s/^S\b/SOUTH/", 1, &cvar.);
        &cvar. = prxchange("s/^E\b/EAST/", 1, &cvar.);
        &cvar. = prxchange("s/^W\b/WEST/", 1, &cvar.);

        * eliminate periods and apostrophes;
        &cvar. = prxchange("s/\.//", 1, &cvar.);
        &cvar. = prxchange("s/'/ /", 1, &cvar.);

        * get rid of duplicate spaces;
        &cvar. = prxchange("s/\s{2,}/ /", -1, &cvar.);

    run;

    proc sort data=&datasetname.;
        by &cvar. &svar.;
    run;

    proc sort data=gnislib.PrefixXwalk;
        by incorrect state;
    run;

     proc contents data=gnislib.PrefixXwalk;
    run;

    proc contents data=&datasetname.;
    run;

    data &datasetname.;
        merge &datasetname.(in=inDat) gnislib.PrefixXwalk(in=inXwalk rename=(incorrect=&cvar.));
        by &cvar. &svar.;

        inData=inDat;
        inGNIS=inXwalk;
        if inXwalk then do;
            &cvar. = correct;
            end;
        drop correct;
    run;

    proc freq data=&datasetname.;
        table  inData*inGNIS;
    run;

    data &datasetname.;
        set &datasetname.;
        if inData;
        drop inData inGNIS;
    %mend;

%macro StdzStrAddr(avar);

    * get rid of duplicate spaces;
    &avar. = prxchange("s/\s{2,}/ /", -1, &avar.);

    * standardize street types at end of address;
    &avar. = prxchange("s/\b(STREET|STREETS)\b/ST/", 1, &avar.);
    &avar. = prxchange("s/\b(AVENUE|AV)\b/AVE/", 1, &avar.);
    &avar. = prxchange("s/\bROAD\b/RD/", 1, &avar.);
    &avar. = prxchange("s/\bLANE\b/LN/", 1, &avar.);
    &avar. = prxchange("s/\bDRIVE\b/DR/", 1, &avar.);
    &avar. = prxchange("s/\bHIGHWAY\b/HWY/", 1, &avar.);
    &avar. = prxchange("s/\bBOULEVARD\b/BLVD/", 1, &avar.);
    &avar. = prxchange("s/\bRURAL\sROUTE\b/RR/", 1, &avar.);
    &avar. = prxchange("s/\bPLACE\b/PL/", 1, &avar.);

    * standardize street numbers;
    &avar. = prxchange("s/\bFIRST\b/1ST/", 1, &avar.);
    &avar. = prxchange("s/\bSECOND\b/2ND/", 1, &avar.);
    &avar. = prxchange("s/\bTHIRD\b/3RD/", 1, &avar.);
    &avar. = prxchange("s/\bFOURTH\b/4TH/", 1, &avar.);
    &avar. = prxchange("s/\bFIFTH\b/5TH/", 1, &avar.);
    &avar. = prxchange("s/\bSIXTH\b/6TH/", 1, &avar.);
    &avar. = prxchange("s/\bSEVENTH\b/7TH/", 1, &avar.);
    &avar. = prxchange("s/\bEIGHTH\b/8TH/", 1, &avar.);
    &avar. = prxchange("s/\bNINTH\b/9TH/", 1, &avar.);
    &avar. = prxchange("s/\bTENTH\b/10TH/", 1, &avar.);
    &avar. = prxchange("s/\bELEVENTH\b/11TH/", 1, &avar.);
    &avar. = prxchange("s/\bTWELTH\b/12TH/", 1, &avar.);

    * standardize direction abbreviations (where it is not a street name);
    if prxmatch("/\b(NORTH|SOUTH|EAST|WEST)(EAST|WEST)? (ST|AVE|RD|LN|DR|HWY|BLVD|PL)\b/", &avar.) = 0 then do;
        &avar. = prxchange("s/\b(?:(N)ORTH|(S)OUTH|(E)AST|(W)EST)(?:(E)AST|(W)EST)?\b/$1$2$3$4$5$6/",1, &avar.);
        end;

    * many addresses start with ONE or TWO spelled out rather than as a numeral;
    &avar. = prxchange("s/^ONE\b/1/",1,&avar.);
    &avar. = prxchange("s/^TWO\b/2/",1,&avar.);

    * correct US highway names;
    &avar. = prxchange("s/\bU S\b/US/",-1,&avar.);

    * standardize conjunction;
    &avar. = prxchange("s/\b(AND|AT)\b/&/", 1, &avar.);

    * some addresses start with a number sign;
    &avar. = prxchange("s/^#//",1,&avar.);

    * strip all variety of PO BOX and unit indicators;
    &avar. =
        prxchange("s/[\/,\-\(]? *(P\.? ?O\.? ?BOX|POST OFFICE BOX|BOX|SUITE|SLOT|DRAWER|P ?O DRAWER|POB|POX BX|POUCH|P O BX) [#0-9\-A-Z]+[,\)\-]? *//",
        1,&avar.);

    * take abbreviations of medical center to something matchable;
    &avar. = prxchange("s/(MED CENTER|MED CTR|MEDICAL CTR)/MEDICAL CENTER/", 1, &avar.);

    * make all plus signs into amphersands;
    &avar. = prxchange("s/\+/&/", 1, &avar.);

    * fix bizarre letters around street letter names;
    &avar. = prxchange("s/[\@'""]([A-Z])[\@'""]/ $1 /", 1, &avar.);

    * get rid of periods except when followed or preceeded by a number;
    &avar. = prxchange("s/([^0-9])\.([^0-9])/$1$2/", -1, &avar.);

    * get rid of curly braces;
    &avar. = prxchange("s/\{/ /", -1, &avar.);

    * get rid of duplicate spaces;
    &avar. = prxchange("s/\s{2,}/ /", -1, &avar.);

    * get rid of any leading spaces;
    &avar. = left(&avar.);

    %mend;

* Macro for standardizing hospital names;
%macro StdzHospName(hvar);

    * standardize various manglings of medical center and health center;
    &hvar. = prxchange(
        "s/\b(MEDICAL CENTER|MED CENTER|MEDICAL CTR|MEDICAL CENTE|MEDICAL CENT|MEDICAL CNTR|MED CNTR|MEDICAL CE)\b/MED CTR/", 1, &hvar.);

    &hvar. = prxchange(
        "s/\b(HEALTH CENTER|HLTH CENTER|HEALTH CTR|HEALTH CNTR|HLTH CNTR)\b/HLTH CTR/", 1, &hvar.);

    * standardize various commonly abbreviated words in hospital names;
    &hvar. = tranwrd(&hvar., "MEMORIAL", "MEM");
    &hvar. = tranwrd(&hvar., "HOSPITAL", "HOSP");
    &hvar. = tranwrd(&hvar., "REGIONAL", "REG");
    &hvar. = tranwrd(&hvar., "COMMUNITY", "COMM");
    &hvar. = tranwrd(&hvar., "DISTRICT", "DIST");
    &hvar. = tranwrd(&hvar., "SAINT", "ST");

    &hvar. = prxchange("s/\b(COUNTY|CO)\b/CNTY/",1,&hvar.);

    * standardize various conjuctions and prepositions;
    &hvar. = prxchange("s/\bAND\b/&/", -1, &hvar.);
    &hvar. = prxchange("s/\bOF\b//", -1, &hvar.);

    * strip THE from the hospital name in various forms;
    &hvar. = prxchange("s/^THE\s//",1,&hvar.);
    &hvar. = prxchange("s/[, ] *THE\s*$//",1,&hvar.);

    * strip various business form indicators from the end of a hospital name;
    &hvar. = prxchange("s/[, ] *(LLC|INC)\s*$//",1,&hvar.);
    &hvar. = prxchange("s/ - CAH\s*$//",1,&hvar.);

    * replace hyphens with spaces;
    &hvar. = prxchange("s/-/ /", -1, &hvar.);

    * eliminate apostrophes;
    &hvar. = prxchange("s/'//", -1, &hvar.);

    * strip repeat spaces;
    &hvar. = prxchange("s/\s{2,}/ /", -1, &hvar.);

    %mend;

