*********************************************************************************************;
** Programs to extract files from the HCRIS (cost report holdings);
** Thanks to Matt Fiedler for sharing his code;
** All errors below are my own;
** daltonm at nber dot org, April 15,2012;
*********************************************************************************************;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;



***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
libname inpos "&inPOS.";
libname sppos "&sppos.";
libname spmed "&spmed.";
libname carerz "&carerz.";
libname longEx "&longExt.";
libname bene "&inbenexw.";
***Used in one of the macos;
libname gnislib "&ingnis.";
libname inHRR "&inHRRzipxw.";
libname sphcris "&sphcris.";
libname exhcris "&exhcris.";



** COPY DATA OVER **;
%macro CopyData(ftypepfx, ftypesfx, startyear=2002, endyear=2010);

    %do y=&startyear. %to &endyear.;

        %let fileName = &ftypepfx.&y.&ftypesfx..sas7bdat;
        %if not %sysfunc(fileexist(&sphcris./&fileName.)) %then %do;
            x "cp /homes/nber/jroth/bulk/cost-reports/hosp/&fileName.  &sphcris.";
            %end;
        %end;
    %mend;



** EXTRACT DESIRED RECORDS FROM REPORT HEADER FILE **;
%macro Process_rpt(startyear=2002, endyear=2010);
    %do y=&startyear. %to &endyear.;
        data sphcris.tmp_rpt&y.;
            set sphcris.hosp_rpt&y.;
            fileyear = &y.;
            processYr=year(proc_dt);
            *keep prvdr_num prvdr_ctrl_type_cd rpt_stus_cd proc_dt rpt_rec_num fy_bgn_dt fy_end_dt fileyear;

        run;

        proc sort data=sphcris.tmp_rpt&y.;
            by rpt_rec_num;
        run;

        %end;
    %mend;




** EXTRACT DESIRED RECORDS FROM REPORT ALPHA, NMRC, AND ROLLUP FILE **;
%macro ProcessAlpha(startyear=2002, endyear=2010);

    %do y=&startyear. %to &endyear.;

        proc sort data=sphcris.hosp_alpha&y._long;
            by rpt_rec_num;
        run;

        data sphcris.wide_alpha&y.;
            set sphcris.hosp_alpha&y._long;
            by rpt_rec_num;

            length name street city state zipcode $ 45;
            retain name street city state zipcode "";

            if first.rpt_rec_num then do;
                name = "";
                street = "";
                city = "";
                state = "";
                zipcode = "";
                end;

            if wksht_cd="S200000" then do;
                if clmn_num="0100" and line_num="00200" then name=alphnmrc_itm_txt;
                if clmn_num="0100" and line_num="00100" then street=alphnmrc_itm_txt;
                if clmn_num="0100" and line_num="00101" then city=alphnmrc_itm_txt;
                if clmn_num="0200" and line_num="00101" then state=alphnmrc_itm_txt;
                if clmn_num="0300" and line_num="00101" then zipcode=alphnmrc_itm_txt;
                end;

            if last.rpt_rec_num then output;
            keep rpt_rec_num name street city state zipcode;
        run;

        proc sort data=sphcris.wide_alpha&y.;
            by rpt_rec_num;
        run;

        %end;

    %mend;

%macro ProcessNmrc(startyear=2002, endyear=2010);

    %do y=&startyear. %to &endyear.;

        proc sort data=sphcris.hosp_nmrc_rpt&y._long;
            by rpt_rec_num;
        run;

        data sphcris.wide_nmrc&y.;
            set sphcris.hosp_nmrc_rpt&y._long;
            by rpt_rec_num;

            retain tot1_bed tot5_bed tot12_bed
                micu_bed_n ccu_bed_n bicu_bed_n sicu_bed_n psyicu_bed_n pedicu_bed_n
                neoicu_bed_n trmicu_bed_n dtxicu_bed_n prmicu_bed_n .;

            if first.rpt_rec_num then do;
                tot1_bed = .;
                tot5_bed = .;
                tot12_bed = .;

                micu_bed_n = 0;
                ccu_bed_n = 0;
                bicu_bed_n = 0;
                sicu_bed_n = 0;
                psyicu_bed_n = 0;
                pedicu_bed_n = 0;
                neoicu_bed_n = 0;
                trmicu_bed_n = 0;
                dtxicu_bed_n = 0;
                prmicu_bed_n = 0;

                end;

            if wksht_cd = "S300001" and clmn_num = "0100" then do;
                if line_num = "00100" then tot1_bed = itm_val_num;
                if line_num = "00500" then tot5_bed = itm_val_num;
                if line_num = "01200" then tot12_bed = itm_val_num;

                if line_num >= "02600" and line_num <= "02619" then micu_bed_n = micu_bed_n + itm_val_num;
                if line_num >= "02700" and line_num <= "02719" then ccu_bed_n = ccu_bed_n + itm_val_num;
                if line_num >= "02800" and line_num <= "02819" then bicu_bed_n = bicu_bed_n + itm_val_num;
                if line_num >= "02900" and line_num <= "02919" then sicu_bed_n = sicu_bed_n + itm_val_num;
                if line_num >= "02140" and line_num <= "02159" then psyicu_bed_n = psyicu_bed_n + itm_val_num;
                if line_num >= "02080" and line_num <= "02099" then pedicu_bed_n = pedicu_bed_n + itm_val_num;
                if line_num >= "02060" and line_num <= "02079" then neoicu_bed_n = neoicu_bed_n + itm_val_num;
                if line_num >= "02180" and line_num <= "02199" then trmicu_bed_n = trmicu_bed_n + itm_val_num;
                if line_num >= "02040" and line_num <= "02059" then dtxicu_bed_n = dtxicu_bed_n + itm_val_num;
                if line_num >= "02120" and line_num <= "02139" then prmicu_bed_n = prmicu_bed_n + itm_val_num;

                end;

            if last.rpt_rec_num then output;

            keep rpt_rec_num tot1_bed tot5_bed tot12_bed
                micu_bed_n ccu_bed_n bicu_bed_n sicu_bed_n psyicu_bed_n pedicu_bed_n
                neoicu_bed_n trmicu_bed_n dtxicu_bed_n prmicu_bed_n;

        run;

        proc sort data=sphcris.wide_nmrc&y.;
            by rpt_rec_num;
        run;

        %end;

    %mend;

%macro ProcessRollup(startyear=2002, endyear=2010);

    %do y=2002 %to 2010;

        data sphcris.tmp_rollup&y.;
            set sphcris.hosp_rollup&y.(keep=rpt_rec_num S3_1_C1_6 S3_1_C1_7 S3_1_C1_8 S3_1_C1_9 S3_1_C1_10
                rename=(S3_1_C1_6=icu_bed_r S3_1_C1_7=ccu_bed_r S3_1_C1_8=bicu_bed_r S3_1_C1_9=sicu_bed_r S3_1_C1_10=osc_bed_r));

            if icu_bed_r = . then icu_bed_r = 0;
            if ccu_bed_r = . then ccu_bed_r = 0;
            if bicu_bed_r = . then bicu_bed_r = 0;
            if sicu_bed_r = . then sicu_bed_r = 0;
            if osc_bed_r = . then osc_bed_r = 0;

        run;

        proc sort data=sphcris.tmp_rollup&y.;
            by rpt_rec_num;
        run;

        %end;


    %mend;




** ASSEMBLE FINAL DATA SET **;

%macro GenerateHCRISExtract(startyear=2002, endyear=2006);
    x "rm &sphcris./* -f";
    **COPY FILES;
    %CopyData(hosp_nmrc_rpt, _long);
    %CopyData(hosp_alpha, _long);
    %CopyData(hosp_rpt, );
    %CopyData(hosp_rollup, );

    %Process_rpt(startyear=&startyear., endyear=&endyear.);
    %ProcessAlpha(startyear=&startyear., endyear=&endyear.);
    %ProcessNmrc(startyear=&startyear., endyear=&endyear.);
    %ProcessRollup(startyear=&startyear., endyear=&endyear.);


    %do y=&startyear. %to &endyear.;
        data sphcris.fin&y.;
            merge sphcris.tmp_rpt&y.(in=inrpt)
                sphcris.wide_alpha&y.(in=inalpha)
                sphcris.wide_nmrc&y.(in=innmrc)
                sphcris.tmp_rollup&y.(in=inrollup);
            by rpt_rec_num;

            in_rpt = inrpt;
            in_alpha = inalpha;
            in_nmrc = innmrc;
            in_rollup = inrollup;
            rename prvdr_num=provider prvdr_ctrl_type_cd=provOwnType;
            drop rpt_rec_num;
            fyear=year(fy_bgn_dt);
        run;
        %end;

        data exhcris.hcrisextract;
            set     %do y=&startyear. %to &endyear.;
            sphcris.fin&y.
            %end;;
        run;

        proc sort data=exhcris.hcrisextract;
            by provider fileyear provOwnType;
    run;

    data exhcris.hcrisextract;
        set exhcris.hcrisextract;
        by provider fileyear provOwnType;
        length lastownCode $3;
        retain lastownCode;
            if first.provider and first.fileyear and first.provOwnType then do;
                lastownCode=provOwnType;
            end;
    run;
    %mend;

%GenerateHCRISExtract(startyear=2002, endyear=2009);
/*

VALUE prvdr_ctrl_type_cd
       1     =  "Voluntary Nonprofit, Church"
       2     =  "Voluntary Nonprofit, Other"
       3     =  "Proprietary, Individual"
       4     =  "Proprietary, Corporation"
       5     =  "Proprietary, Partnership"
       6     =  "Proprietary, Other"
       7     =  "Governmental, Federal"
       8     =  "Governmental, City-County"
       9     =  "Governmental, County"
       10    =  "Governmental, State"
       11    =  "Governmental Hospital District"
       12    =  "Governmental, City"
       13    =  "Governmental, Other"



proc sort data=inPOS.posmaster;
    by provider6 year;
run;

data exhcris.mergetest;
    merge exhcris.hcrisextract(in=hcris)
          inPOS.posmaster (in=pos rename=(provider6=provider year=fileyear) drop=provider where=(category="01" ));
    by provider fileyear;
    inpos=pos;
    inhcris=hcris;
run;


proc freq data=exhcris.mergetest;
    table inhcris*inpos;
run;











