********************************************************;
** Flag candidate Index Events in the Carrier files **;
** *****************************************************;
**  Program uses the HCPCS codes found   ***;
**  Accompanying files to flag  potential index events.                          ***;
** Note this code processes one part of the code at a time;
** *****************************************************;
**
** Only use this file if you interested in pulling   ***;
** index events from the carrier files - other wise ignore ***;
***;
*** Instructions::;
*** Change HCPCS code to define cohort in the HCPCScohrtDef.sas file;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;

***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
x "mkdir &cartmp./xw";
libname here ".";

libname cartmp "&cartmp.";
libname spxw "&inbenexw.";
libname xwfile "&xwfile.";
libname carvw  "&carvw.";
libname carvwtm  "&carvw./tmp";


x "mkdir  &rawext./0001pct/car -p";
x "mkdir  &rawext./01pct/car   -p";
x "mkdir  &rawext./05pct/car   -p";
x "mkdir  &rawext./20pct/car   -p";
x "mkdir  &rawext./100pct/car  -p";


**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!**;
** BEGIN MACRO DEFINITIONS CALLED AT THE END IN THE WRAPPER PROGRAM;
**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!**;
***************************************************************************;
** Flags claims with code of interest (candidate index events);
***************************************************************************;
%macro TagcandidateIndxEventsCar(year=,pctsuffix= ,pct=,part=);

    libname carex  "&rawext./&pct.pct/car";


    ** proc append is faster then a set statement, place processed part into year file;
    proc append base = carex.car&pct._clmline_raw_&year.
                data = carvw.car&pct._&year._clmline_&year. force ;
    run;

    %mend;


**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro combine_raw_carrier(pct="",yearin=,yearout=,clmDTA=,crashStart=0,note=);
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());



***************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
        %do y=&yearin. %to &yearout.;
        x "rm &rawext./&pct.pct/car/car&pct._clmline_raw_&y.* -f";

       **************************************************************************;
       ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);
       **This macro creates the num_file macro which is used to loop through;
       *******************************************************************;
       ** define lib;
       **************************************************************************;
       ** FIles are no longer saved zipped and new 10g line no longer makes it important;
       ** to move files to scratch;
       ** change libname which views use to the year/type/file being processed;
       libname spcar "&dataRoot./&pct.pct/car/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART AND PULL CLMS RELEVANT FOR EACH COHORT ;
       **************************************************************************;
            **DEAL WITH DIFFENRT YEAR NAMING CONVENTIONS;
            %breakFilename2parts(ftype=car,pct=&pct.,z=1,year=&y.);
            %TagcandidateIndxEventsCar(year=&y.,pctsuffix=&suffix.,
                        pct=&pct.,part=&part.);
            %end;
        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE OLD FILES;
        %archiveoldLogfiles(pct=&pct.,cohrt=,dgnPos=,yearin=&yearin.,yearout=&yearout.,note=&note.);
        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
        x "rm &cartmp./xw/* -f";
        x "rm  &cartmp./* -rf &";
        %let tAfterRun=%sysfunc(datetime());
        %put &tAfterRun.-&tBeforeRun.;
        %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
        %put <TIMER> Process Years  ALL cohrt took &elapsedRun. minutes.;

    %mend;




********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%combine_raw_carrier;
********************************************************************************************;
/*%combine_raw_carrier(pct=&pct.,
          yearin=&yearin.,yearout=&yearout.,
          clmDTA=&clmDTA.);
*/

%combine_raw_carrier(pct=20,
          yearin=2005,yearout=2011,
          clmDTA=0);



