********************************************************;
** Flag candidate Index Events in the Inpatient sample**;
** *****************************************************;
**  Program uses the ICD9-CM and HCPCS codes found   ***;
**  Accompanying HCPCS and ICD9 SAS files to flag    ***;
**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the IP files - other wise ignore ***;
********************************************************;

*** Instructions::;
*** Change HCPCS and ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;



***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;

libname here ".";

libname iptmp "&iptmp.";
libname spxw "&inbenexw.";
libname ipvw  "&ipvw.";
libname ipvwtm  "&ipvw./tmp";



*import macros usedin the creations of sas views for doc;
%include "&SASmac./ConformOp.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinipxw;
%include "&SASmac./CreateXWmacro.sas";
*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";

x "mkdir  &rawext./0001pct/ip -p";
x "mkdir  &rawext./01pct/ip   -p" ;
x "mkdir  &rawext./05pct/ip   -p";
x "mkdir  &rawext./20pct/ip   -p";
x "mkdir  &rawext./100pct/ip  -p";


%macro candidateIndxIpFlag(year=,pct=,part=,filetype=);


    proc append base = ipex.ip&pct._clms_raw_&year.
                data = ipvw.ip&pct._clms_&year._&part. force ;
    run;

    proc append base = ipex.ip&pct._rev_raw_&year.
                data = ipvw.ip&pct._revcntr_&year._&part. force ;
    run;


    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro combine_raw_ip(pct=, yearin=, yearout=, clmDTA=0, crashStart=0);
  *For timing;
  %global tBeforeRun;
  %let tBeforeRun=%sysfunc(datetime());
  %put TIMER Begin run at time &SYSTIME.;


  libname ipex "&rawext./&pct.pct/ip";

  **************************************************************************;
  ********Deal with a crash if defined in the parameter - crashStart********;
  **************************************************************************;

    ****************************************************************;
    ** START LOOP THROUGH YEARs;
    **************************************************************************;
    %do y= &yearin. %to &yearout. ;
        x "rm &rawext./&pct.pct/ip/ip&pct._rev_raw_&y.* -f";
        x "rm &rawext./&pct.pct/ip/ip&pct._clms_raw_&y.* -f";
        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=ip,year=&y.);
         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spip "&dataRoot./&pct.pct/ip/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
       *For testing purposes set numfile =1 num_file;
        %do z=1 %to &num_file.;
                 **************************************************************************;
                 ** Loop through cohrts extracting cohort specific data from single     ***;
                 ** part, harmonize data                                                ***;
                 **************************************************************************;
                    %candidateIndxIpFlag(year=&y.,pct=&pct.,part=&z.
                                      );
                %end;
        %end;

        *******************************************************************;
        ** COMBINE ALL candidate INDX EVENTS;
        **************************************************************************;
        **#############################################################################;
        ** Copy log and lst files, gip for archiving ;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,dgnPos=,yearin=&yearin.,yearout=&yearout.);

        **clear space directory;
        x "rm &iptmp./* -f &";
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put TIMER END run at time &elapsedrun.;
    %mend;




%combine_raw_ip(pct=&pct.,
          yearin=&yearin.,yearout=&yearout.,
          clmDTA=&clmDTA.);
