********************************************************;
** Flag candidate Index Events in the MedPAR file**;
** *****************************************************;
**  Program uses the ICD9-CM found in the    ***;
**  accompanying HCPCS and ICD9 SAS files to flag    ***;
**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the medpar files - other wise ignore ***;
********************************************************;

*** Instructions::;
*** Change ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;
*!!!!WRAPPER MACRO FOUND AT THE END ;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
options symbolgen mlogic mprint mfile ;
*options FILELOCKS NONE;
%include "../../sasoptions.sas";

***********************************************************************
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
* load files with macros that conform the files of various years into a common format;
%include "&SASmac./ImportVariableXW.sas";
%readinmedparxw;
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
x "mkdir &medtmp./xw ";
x "mkdir -p &rawExt. ";
libname here "."            ;
libname medtmp "&medtmp."   ;
libname medvw  "&medvw.";
libname medvwtm  "&medvw./tmp";

libname xwfile "&xwfile.";
libname spxw "&inbenexw."   ;


x "mkdir  &rawext./0001pct/medpar -p";
x "mkdir  &rawext./01pct/medpar   -p";
x "mkdir  &rawext./05pct/medpar   -p";
x "mkdir  &rawext./20pct/medpar   -p";
x "mkdir  &rawext./100pct/medpar  -p";


%macro Extractdiag(yr=,  pct=,start=,end=,identifier=);


    ***********************************************************************************;
    *HARMONIZE FILE
    ***********************************************************************************;
    data medex.medpar&pct._raw_&yr. ;
        set medvw.medpar&pct._&yr. ;
    run;

  %mend;

**#############################################################################;
*** BEGIN  WRAPPER MACRO HERE**************************************************;
**#############################################################################;
%macro combine_raw_medpar(yearin=,yearout=,pct=,winyear=,dflag=1,clmDTA=,note=);
**#############################################################################;
*****---------TIMER CODE ----------;
**#############################################################################;
    libname medex  "&rawExt/&pct.pct/medpar/" ;

    %global tBeforeRun;
        %let tBeforeRun=%sysfunc(datetime());

**##################################################################;
***STEP 1: DECOMPRESS AND TAG candidateS;
**#############################################################################;
    *****************************************************************;
    ** BEGIN LOOPING THROUGH ALL YEARS OF INTEREST AND COHORTS   ****;
    *****************************************************************;
    %do y=&yearin. %to &yearout. ;
        x "rm &rawExt./&pct.pct/medpar/medpar&pct._raw_&y.* -f ";

        libname spmed "&dataRoot./&pct.pct/med/&y./";
       *************************************************************************;
       ** TAG ALL INDEX EVENT candidateS. MERGE ALL MEDPAR FILE ON LAST YEAR;
       *************************************************************************;
            %Extractdiag(yr=&y.,pct=&pct,start=&yearin.,end=&yearout);
           %end;


        **#############################################################################;
        *****---------TIMER CODE ----------;
        **#############################################################################;
            %let tAftercohrt=%sysfunc(datetime());
            %let elapsedcohrt=%sysevalf(%sysevalf((&tAftercohrt.-&tBeforeRun.)/60));
            %put <TIMER> FINAL  took &elapsedcohrt. minutes  ;
        **#############################################################################;
        *Copy log and lst files to archive folder with same name and attach date being run;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=,dgnPos=,yearin=&yearin.,
            yearout=&yearout.,note=&note.)               ;


    **#############################################################################;
    *Delete all temp files;
    **#############################################################################;
        x "rm &medtmp./* -f";
        x "rm &spmed./* -f";

        %let tAfterRun=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&tAfterRun.-&tBeforeRun.)/60));
        %put <TIMER> FINAL  took &elapsedrun. minutes  ;

    %mend;



***********************Call Wrapper Program Below-***********************;
*WRAPPER MACRO DOCUMENTATION --SAME AS DOC FOUND AT BEGINNING OF SCRIPT ---;
****************************************************************************************************;

%combine_raw_medpar(pct=&pct.,yearin=&yearin.,yearout=&yearout.,
                        dflag=1,clmDTA=&clmDTA.,note=&note.);


