********************************************************;
** Flag candidate Index Events in the Outpatient sample**;
** *****************************************************;
**  Program uses the ICD9-CM and HCPCS codes found   ***;

**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the OP files - other wise ignore ***;
***
*** Instructions::
*** Change HCPCS and ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;


*** NOTE ** IF YOU PLAN ON RUNNING THIS FOR THE 100% FILE PLEASE SEE EMAIL Maurice - daltonm@nber.org.;
**          100% files runs get stuck in the last year because file sizes are too large               ;


***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";

libname optmp "&optmp.";
* these libnames need to be defined in order for the sas views to work;
libname spxw "&inbenexw.";
libname opvw  "&opvw.";
libname opvwtm  "&opvw./tmp";


x "mkdir  &rawext./0001pct/op -p";
x "mkdir  &rawext./01pct/op   -p";
x "mkdir  &rawext./05pct/op   -p";
x "mkdir  &rawext./20pct/op   -p";
x "mkdir  &rawext./100pct/op  -p";


*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";


%macro candidateIndxFlag(year=,pctsuffix=,pct=,part=,file=,prcPos=,dgnPos=);

    proc append base = opex.op&pct._clms_raw_&year.
                data = opvw.op&pct._&year._clms_&part.  force ;
        run;

        proc append base = opex.op&pct._rev_raw_&year.
                    data = opvw.op&pct._&year._revcntrs_&part. force ;
        run;

    %mend;



**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro combine_raw_op(pct=,yearin=,yearout=,clmDTA=0,crashStart=0);
************************************************************************;
**          CATCH ERRORS IN PARAMETERS                    ;
************************************************************************;
  libname opex "&rawext./&pct.pct/op";

  *For timing;
  %global tBeforeRun;
  %let tBeforeRun=%sysfunc(datetime());
  %put TIMER Begin run at time &SYSTIME.;


    ****************************************************************;
    ** START LOOP THROUGH YEARs;
    **************************************************************************;
    %do y= &yearin. %to &yearout. ;
        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;
        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.,subtype=&stypem.,
                      pctsuffix=&suffix.);
         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spop "&dataRoot./&pct.pct/op/&y./";

         *******************************************************************;
         ** START LOOP THROUGH EACH FILE PART AND DISEASE COHORT;
         **************************************************************************;
         *For testing purposes set numfile =1 num_file ;
         x "rm &opext./op&pct._rev_raw_&y.*.sas* -f  & " ;
         x "rm &opext./op&pct._clms_raw_&y.*.sas* -f & " ;

         %do z=1 %to &num_file.;
                 **************************************************************************;
                 ** FLAG CANDITATE INDEX EVENTS FOR 1B programs  ***;
                 **************************************************************************;
                %candidateIndxFlag(year=&y.,pct=&pct.,part=&z.);
                %end;
        %end;
        *******************************************************************;
        ** COMBINE ALL candidate INDX EVENTS;
        **************************************************************************;

        **#############################################################################;
        ** Copy log and lst files, gip for archiving ;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=,dgnPos=,yearin=&yearin.,yearout=&yearout.);
        **clear space directory;
        x "rm &optmp./* -f &";
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put TIMER END run at time &elapsedrun.;
    %mend;





%combine_raw_op(pct=&pct.,
          yearin=&yearin., yearout=&yearout.,
          clmDTA=&clmDTA. );


