** PROGRAM GENERATES HARMONIZED FILES OF THE COMPLETE DATASET. SAVES THESE AS A VIEW.;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
x "mkdir -p &ipext./view/tmp ";
libname here ".";
libname ipex "&ipext.";
libname iptmp "&iptmp.";
libname spxw "&inbenexw.";
libname ipvw "&ipext./view";
libname ipvwtm "&ipext./view/tmp";


*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ConformIp.sas";
%include "&SASmac./ImportVariableXW.sas";

%readinipxw;
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./splitindxfiles.sas";

**NOTE CREATE A MACRO WHICH COUNTS THE NUMBER OF ELEMENTS IN A FOLDER.;


** This macro loops over all of the subfiles for a given year, selects;
** the desired observations;
%macro DecompressPartYear(spaceDir=,dataRoot=,year=,pct=,pctsuffix=,part=,revcenters=,claims=);
    * Decompress file or files to start;
    %if &year. > 2001  or &year. = 1997 %then %do;
        %if &claims.=yes %then %do;
            %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
                ftype=ip,pct=&pct.,year=&year.,subtype=clms,pctsuffix=&pctsuffix.,indx=&part.);
            %end;
        %if &revcenters.=yes %then %do;
            %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
                ftype=ip,pct=&pct.,year=&year.,subtype=revcntrs,pctsuffix=&pctsuffix.,indx=&part.);
            %end;
        %end;
    %else %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=ip,pct=&pct.,year=&year.,pctsuffix=&pctsuffix.,indx=&part.);
        %end;
    %mend;

%macro ProcessSQL(year=,pctsuffix=,cohrt=,pct=,part=,revcenters=,claims=, view=on);
    ************************************************************************;
    **           DEFINE RAW FILENAME TO READ IN LATER;
    ************************************************************************;
    %if &year. >= 2010  %then %do;
        %let rawip_clm = ipc&year.;
        %let rawip_rev = ipr&year.;
        %end;
    %else %if &year. = 2009  %then %do;
        %let rawip_clm = ipc_&year._&part.;
        %let rawip_rev = ipr_&year._&part.;
        %end;

    %else %if &year. >= 2002  or &year.=1997 %then %do;
        %let rawip_clm = ip&pct._&year._clms&part.;
        %let rawip_rev = ip&pct._&year._revcntrs&part.;
        %end;
    %else %do;
        %let rawip_clm = ip&pct._&year._&part.;
        %end;


    ************************************************************************;
    **           DEFINE VAR NAME BASED ON XW CSV FILE;
    ************************************************************************;
    %rawVarXw(harVar=from_dt,yr=&year.,outputvar=from_dt,pct=&pct.,pctsuffix=&pctsuffix.,filename=ipxw);
    %rawVarXw(harVar=thru_dt,yr=&year.,outputvar=thru_dt,pct=&pct.,pctsuffix=&pctsuffix.,filename=ipxw);
    %rawVarXw(harVar=clm_id,yr=&year.,outputvar=clmindx,pct=&pct.,pctsuffix=&pctsuffix.,filename=ipxw);
    %rawVarXw(harVar=revnum,yr=&year.,outputvar=numFields,pct=&pct.,pctsuffix=&pctsuffix.,filename=ipxw);
    ************************************************************************;
    **           CREATE MACRO VAR WHICH CONVERT DATES DO NUMERIC;
    ************************************************************************;
    %if &year. >= 1996 %then %do;
        %let clmStart=C.&from_dt.;
        %let clmEnd=C.&thru_dt.;
        %end;
    %else %if &year. >= 1986 and &year. <= 1995 %then %do;
        %let clmStart=input(put(C.&from_dt.,z8.0),yymmdd8.);
        %let clmEnd=input(put(C.&thru_dt.,z8.0),yymmdd8.);
        %end;
    %else %if &year. >= 1984 and &year. <= 1985 %then %do;
    * For years 1984 and 1985, claims have only an end date.  I treat all claims for;
    * these years as starting and ending on the same day.  A sizable;
    * majority of claims have the same start and end date in later years.;
    * The bulk of the others are just a few days long. Nonetheless, keep;
    * this in mind when working with those years.;
        %let clmStart=datejul(input(C.&from_dt.,5.0));
        %let clmEnd=datejul(input(C.&from_dt.,5.0));
        %end;
    ************************************************************************;
    **           DEFINE ID IN THE RAW DATA TO SORT AND MERGE BY;
    ************************************************************************;
    %if &year.>=2006 %then %do;
        %let rawid=bene_id;
        %end;
    %if &year.<=2005 %then %do;
        %let rawid=ehic;
        %end;

    ************************************************************************;
    **           GRAB WINDOW OF CLAIMS DATA;
    ************************************************************************;
    * Choose claims with expenses starting at most 365 days before &cohrt.;
    * and which have concluded by 365 days after &cohrt.;
    * making an exception for claims beginning on;
    * the date of &cohrt.;
    * NOTE: If either of the dates is missing, I do not select the record;
    * From spot-checking years, I have yet to find any missing dates, so;
    * it is not clear that this makes any difference at all;
    **********************************************************************;


    data ipvwtm.ip&pct.&pctsuffix._&year._indx_&part.
        %if &view. = on %then %do; /view= ipvwtm.ip&pct.&pctsuffix._&year._indx_&part.       ; %end;;
        set spip.&rawip_clm.
            (keep=
            %if &year. = 1998 or &year. = 1999 %then %do;
            &rawvarlist_rev. &rawvarlist_clm.
                %end;
            %else %if &year. >= 2000 and &year. <= 2001 %then %do;
                daily_dt clm_cntl sgmt_num sgmt_cnt   &rawvarlist_rev. &rawvarlist_clm.
                    %end;
                %else %if &year. >= 2002 or &year. = 1997 %then %do;
                    &rawvarlist_clm.
                        %end;
                    );

                %if &year. >= 1998 and &year. <= 2001   %then %do;
                    iprawrevindx=_N_;
                    iprawclmindx=_N_;

                    %end;
                %if &year. >= 2002 or  &year. <= 1997   %then %do;
                    iprawclmindx=_N_;
                    %end;
                part =&part.;
                %if &year.>= 2006 %then %do;
                    length ehic $15;
                    ehic="";
                    %end;
    run;

    proc sql;
        create  %if &view = on %then %do; view %end;
            %else %do; table %end;
            ipvwtm.ip&pct.&pctsuffix._&year._tmpclms_&part. as
            select C.*  %if &year.< 2006 %then %do; ,trim(M.bene_id) as bene_id %end;
            from  ipvwtm.ip&pct.&pctsuffix._&year._indx_&part. C
                %if &year.< 2006 %then %do;
                LEFT JOIN spxw.ehicbenex_unique&pct. (keep=ehic bene_id)  M
                    ON C.ehic=M.ehic
                    %end;
            %if &year. >= 2000 and &year. <= 2001 %then %do;
            order by daily_dt,link_num,clm_cntl,sgmt_num;
            %end;
            ;
        quit;
    run;


    ************************************************************************;
    **  CONFORM 2000 or BEFORE;
    ************************************************************************;
    %if &year. >= 1998 and &year. <=2001  %then %do;
        ************************************************************************;
        * For 1998-2001, a single claim can split across multiple records;
        * when there are more revenue centers on the claim than there are;
        * slots in a single record;
        * The documentation suggests that daily_dt and link_num together;
        * form a unique identifier for claims and then sgmt_num indexes over;
        * the segments of a single claim.  In practice, however, there seem;
        * multiple first segments for each link_num daily_dt claim that appear;
        * to simply be independent claims, as there is no reason for them to be;
        * split.  Using the claim control number in addition to daily_dt and link_num;
        * seems to generate an actual unique identifier that:;
        * a) keeps claims that ACTUALLY have multiple claims together;
        * b) splits up the many claims erroneously grouped together by link_num and daily_dt;
        * ;
        ************************************************************************;
       %if  &revcenters. = yes %then %do;
        *****************************************************************************;
        **      PRE-2001  REV CNTR;
        *****************************************************************************;
        data ipvwtm.ip&pct.&pctsuffix._revcntrnolabel_&year._&part.
             (keep= &finalvarlist_rev.)
             %if &view. = on %then %do;  / view = ipvwtm.ip&pct.&pctsuffix._revcntrnolabel_&year._&part. ; %end;;
            length &len_chnull_rev. &len_numnull_rev. &len_ch_rev. &len_num_rev. ;
            set ipvwtm.ip&pct.&pctsuffix._&year._tmpclms_&part. %ConvertStr2Num_setrenameIp(y=&year.,pct=&pct.,filevarin=rev);
            ** The clmindx_temp variable is - link_num - variable in 1999 and 2000. The ;
            ** convertstr2Num_setrenameIP macro rename the link_num variable to clmindx_temp;
            ** in order to change it from character to numeric;
            %if &year. >= 2000 and &year. <= 2001 %then %do;
                by daily_dt clmindx_temp  clm_cntl  sgmt_num;
                %end;
            retain clm_idnum 1;
            fileYear=&year.;
            ** CREATE EMPTY VARIABLES;
            &createvarCH_rev.;
            &createvarNum_rev.;


            clm_id=put(trim(clmindx_temp),15.);
            ************************************************************************;
            **           WRITE REVENUE CENTERS;
            ************************************************************************;
            * This macro iterates over the revenue center fields and outputs each to its;
            * own record in a common format For years where a field giving the total;
            * number of revenue centers does not exist for older files, this;
            * macro creates it;
            rename &renamevar_rev.;
            *since these claims are at the claim level-set rev center code equal to the ;
            * raw claim indx;
            iprawrevindx=iprawclmindx;
            %ConformIp_WriteRevcntrs(year=&year.,dir=iptmp,part=&part.);
        run;
        %end;

        *****************************************************************************;
        ** PREPARE PRE 2000 DATA FOR A CLMS FORMAT;
        *****************************************************************************;
    %if  &claims. = yes  %then %do;
            data ipvwtm.ip&pct.&pctsuffix._clmsnolabel_&year._&part (keep=&finalvarlist_clm.)
                %if &view. = on %then %do; / view = ipvwtm.ip&pct.&pctsuffix._clmsnolabel_&year._&part.  ; %end;;
                length &len_num_clm. &len_ch_clm. &len_chnull_clm. &len_numnull_clm.;
                    set ipvwtm.ip&pct.&pctsuffix._&year._tmpclms_&part.
                     %ConvertStr2Num_setrenameIp(y=&year.,pct=&pct.,filevarin=clm);
            ** The clmindx_temp variable is - link_num - variable in 1999 and 2000. The ;
            ** convertstr2Num_setrenameIP macro rename the link_num variable to clmindx_temp ;
            ** in order to change it from character to numeric;
            %if &year. >= 2000 and &year. <= 2001 %then %do;
                by daily_dt clmindx_temp  clm_cntl  sgmt_num ;
                %end;


                fileYear=&year.;
                **Write empty variables;
                &createvarCH_clm.;
                &createvarNum_clm.;

            ************************************************************************;
            **           WRITE CLAIMS;;
            ************************************************************************;
            * This takes the claim summary data, puts it in a common format, and writes;
            * it as a claim record;
            rename &renamevar_clm.;

            **Converts character to numeric;
            %ConformIp_ClmsChar2Numeric(year=&year.);
            * for 1999-2000, we only want to write out first-segment records;
            %if &year. >= 2000 and &year. <= 2001 %then %do;
                if sgmt_num eq 1 then do;
                    output  ;
                    end;
                %end;
            %else %do;
                output  ;
                %end;
            run;
            %end;
        %end;
    ************************************************************************;
    **           CONFORM FILES BETWEEN 2002 and 2009;
    ************************************************************************;
    %if &year. >= 2002  or &year. = 1997 %then %do;
        ***********************************************************************;
        * For records in years 2001 to 2005, select the revenue centers;
        * that correspond to the claims selected above;
        * Note that each claim record can appear twice in the extract: once for;
        * the lead-in period for each &cohrt. and once for the follow-up period for;
        * each &cohrt..  Thus, the claims-revenue centers match is a many-to-many merge;
        * that must use PROC SQL.;
        ************************************************************************;
        %if  &revcenters. = yes %then %do;
        ************************************************************************;
        **           strip claims file down to the relevant IDs;
        ************************************************************************;
            data ipvwtm.ip&pct.&pctsuffix._Tempclm_&year._&part.
                %if &view. = on %then %do; / view = ipvwtm.ip&pct.&pctsuffix._Tempclm_&year._&part.  ; %end;;
                set ipvwtm.ip&pct.&pctsuffix._&year._tmpclms_&part.;
                keep  &clmindx. bene_id ehic ;
            run;

        **Generate IP raw indx;
            data ipvwtm.ip&pct.&pctsuffix._TempRev_&year._&part.
                %if &view. = on %then %do; / view = ipvwtm.ip&pct.&pctsuffix._TempRev_&year._&part.  ; %end;;
                set spip.&rawip_rev. (keep=&rawid. &clmindx. &rawvarlist_rev.) ;
                iprawrevindx=_N_;
                part=&part.;
            run;


        ************************************************************************;
        **           MERGE IDS from clms into revenue center;
        ************************************************************************;
        * merge each revenue center onto each appripriate rawid;
        * note that ehic/bene_id should be unique within clm_id, but;
        * I add this as an additional criterion just to be safe;
            proc contents data=spip.&rawip_rev.;run;
            proc contents data=spip.&rawip_clm.;run;

            proc contents data=ipvwtm.ip&pct.&pctsuffix._Tempclm_&year._&part.;run;
            proc contents data=ipvwtm.ip&pct.&pctsuffix._TempRev_&year._&part.;run;

            data ipvwtm.ip&pct.&pctsuffix._&year._revcntrs_&part.
                 %if &view. = on %then %do; / view=ipvwtm.ip&pct.&pctsuffix._&year._revcntrs_&part. %end;;
                    merge ipvwtm.ip&pct.&pctsuffix._Tempclm_&year._&part.
                          ipvwtm.ip&pct.&pctsuffix._TempRev_&year._&part.  ;
                    by &rawid. &clmindx. ;
            run;

/*
            proc sql;
                create %if &view. = on %then %do; view %end; %else %do; table %end;
                    ipvwtm.ip&pct.&pctsuffix._&year._revcntrs_&part. as
                    select *
                    from ipvwtm.ip&pct.&pctsuffix._Tempclm_&year._&part. C,
                    ipvwtm.ip&pct.&pctsuffix._TempRev_&year._&part.  R
                    where (C.&clmindx. = R.&clmindx.) and (C.&rawid. = R.&rawid.);
                quit;
            run;
            */
        ************************************************************************;
        **           CONFORM CLAIMS AND REVENUE CETERS;
        ************************************************************************;

            data ipvwtm.ip&pct.&pctsuffix._revcntrnolabel_&year._&part (keep=&finalvarlist_rev.)
                %if &view. = on %then %do; / view = ipvwtm.ip&pct.&pctsuffix._revcntrnolabel_&year._&part; %end;;
                length &len_num_rev. &len_ch_rev. &len_chnull_rev. &len_numnull_rev.;
                set ipvwtm.ip&pct.&pctsuffix._&year._revcntrs_&part.
                    %ConvertStr2Num_setrenameIp(y=&year.,pct=&pct.,filevarin=rev);
                fileYear = &year.;
                &createvarCH_rev.;
                &createvarNum_rev.;
                rename &renamevar_rev.;
                %ConformIp_WriteRevcntrs(year=&year.,dir=iptmp,part=&part.);
            run;
            %end;


        %if  &claims. = yes %then %do;

            data ipvwtm.ip&pct.&pctsuffix._clmsnolabel_&year._&part. (keep=&finalvarlist_clm.)
                %if &view. = on %then %do; / view = ipvwtm.ip&pct.&pctsuffix._clmsnolabel_&year._&part.  ; %end;;
                length &len_num_clm. &len_ch_clm. &len_chnull_clm. &len_numnull_clm.;
                set ipvwtm.ip&pct.&pctsuffix._&year._tmpclms_&part.
                    %ConvertStr2Num_setrenameIp(y=&year.,pct=&pct.,filevarin=clm) ;
                fileYear = &year.;
                &createvarCH_clm.;
                &createvarNum_clm.;
                rename &renamevar_clm.;
                **Converts character to numeric;
                %ConformIp_ClmsChar2Numeric(year=&year.);

            run;
            %end;
        %end            ;

    %LabelVarsXw(outLabels=iprevLabels,filename=ipxw,filevarin=rev);
    data ipvw.ip&pct.&pctsuffix._revcntr_&year._&part
         / view= ipvw.ip&pct.&pctsuffix._revcntr_&year._&part ;
        set ipvwtm.ip&pct.&pctsuffix._revcntrnolabel_&year._&part;
        LABEL &iprevLabels.;
    run;

    %LabelVarsXw(outLabels=ipclmLabels,filename=ipxw,filevarin=clm);

    data ipvw.ip&pct.&pctsuffix._clms_&year._&part.
         / view= ipvw.ip&pct.&pctsuffix._clms_&year._&part. ;
        set ipvwtm.ip&pct.&pctsuffix._clmsnolabel_&year._&part.;
        LABEL &ipclmLabels.;
    run;
/*
    proc contents data=ipvw.ip&pct.&pctsuffix._clms_&year._&part. ;run;
    proc contents data=ipvw.ip&pct.&pctsuffix._revcntr_&year._&part ;run;

    proc print data=ipvw.ip&pct.&pctsuffix._clms_&year._&part. (obs=5 keep=clm_id);run;
    proc print data=ipvw.ip&pct.&pctsuffix._revcntr_&year._&part (obs=5 keep=clm_id);run;
        */
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;

%macro runprgIp(pct=, yearin=, yearout=, clmDTA=,  revcenters=, claims=, view=);
************************************************************************;
**          CATCH ERRORS IN PARAMETERS                    ;
************************************************************************;

  *For timing;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    %put TIMER Begin run at time &SYSTIME.;


    ****************************************************************;
    ** START LOIP THROUGH YEARs;
    **************************************************************************;
    %do y= &yearin. %to &yearout. ;
        x "rm &ipext./view/tmp/i*&pct.*&y.* -f";
        x "rm &ipext./view/i*&pct.*&y.* -f";

        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;
       *******************************************************************;
       ** GEN MACRO FROM XW WHICH HOLD VARIABLE NAME CHANGES ACROSS TIME;
       **************************************************************************;
        %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=rev,pct=&pct.,pctsuffix=&suffix.,filename=ipxw);
        %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=clm,pct=&pct.,pctsuffix=&suffix.,filename=ipxw);
        %GenerateAnnualVariableListFromXw(yr=&y.,pct=&pct.,pctsuffix=&suffix.,filename=ipxw);
            ** Generate macro name of the file name which resoolve to the raw variable name;
            ** for example &hcpcs_cd will resolve to ohcpcs in 1986;
        %genLineItemVarsToLoop(yr=&y.,pct=&pct.,filename=ipxw);

        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=ip,year=&y.,subtype=&stypem.,
            pctsuffix=&suffix.);

         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spip "&dataRoot./&pct.pct/ip/&y./";


       *******************************************************************;
       ** START LOIP THROUGH EACH FILE PART;
       **************************************************************************;
       *For testing purposes set numfile =1 num_file;
        %do z=1 %to &num_file.;
                 **************************************************************************;
                 ** Loip through cohrts extracting cohort specific data from single     ***;
                 ** part, harmonize data                                                ***;
                 **************************************************************************;
            %ProcessSQL(year=&y.,pctsuffix=,pct=&pct.,part=&z.,
                revcenters=&revcenters.,claims=&claims.,view=&view.);
            %end;
        %end;

    %archiveoldLogfiles(pct=&pct.,yearin=&yearin.,yearout=&yearout.);

    %let rundone=%sysfunc(datetime());
    %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
    %put TIMER END run at time &elapsedrun.;
    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgIp;
********************************************************************************************;
*** It has the following iptions;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
*** revcenters -- Indicates whether you want revenue centers to be extracted.;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;


*This run the program;
%runprgIp(pct=0001,
    yearin=1997,yearout=2012,
    revcenters=yes,
    claims = yes,
    clmDTA=0,
    view=on);


%runprgIp(pct=05,
    yearin=1997,yearout=2012,
    revcenters=yes,
    claims = yes,
    clmDTA=0,
    view=on);

%runprgIp(pct=20,
    yearin=1997,yearout=2011,
    revcenters=yes,
    claims = yes,
    clmDTA=0,
    view=on);

%runprgIp(pct=100,
    yearin=1997,yearout=2012,
    revcenters=yes,
    claims = yes,
    clmDTA=0,
    view=on);







