**Extract index events and corresponding claims from the inpatients and SNF claims (MEDPAR);
**Maurice Dalton, daltonm.at.nber.org,  based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.  All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several sas macros which are combined in a macro which sequences the;
** macros correctly.This wrapper macro is found at the end of the program and has several ;
** different parameters defined at the end of the program;
**;
*!!!!WRAPPER MACRO FOUND AT THE END ---%RunDefineIndexEvents!!!!!;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
/* %include "&SASmac./decompress_i_view.sas";*/
%include "&SASmac./DetermineMax.sas";
*Put final variable labels in this file;
%include "&SASmac./Labels.sas";
*Program which mergers in the crosswalk;
%include "&SASmac./applycrosswalk.sas";
* load files with macros that conform the files of various years into a common format;
%include "&SASmac./ImportVariableXW.sas";


%readinmedparxw;

%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformMedPar.sas";
%include "&SASmac./CreateReports.sas";
%include "&SASmac./archiveoldLogfiles.sas";
/*%include "&SASmac./decompressmedparview.sas";*/
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./errorCheckparameters.sas";


***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";
libname medex  "&medparExt.";
libname medtmp "&medtmp.";
libname spxw "&inbenexw.";
libname xwfile "&xwfile.";
x "mkdir &medparExt./view/tmp -p";
libname medvwtm "&medparExt./view/tmp";
libname medvw " &medparExt./view/";


%macro ExtractFinalClaims(start=,end=,pct=,y=);
        %GenerateAnnualVariableListFromXw(yr=&y.,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=prvnumgrp,yr=&y.,outputvar=provider,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=spclunit,yr=&y. ,outputvar=ftypeVar,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=outlr_cd_ch,yr=&y.,outputvar=outlyer,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=dstntncd_ch,yr=&y.,outputvar=dest_cd,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=drg_cd_ch,yr=&y.,outputvar=drg_code,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=sslssnf,yr=&y.,outputvar=snfvar,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=dschrgdt,yr=&y.,outputvar=dschrgdt,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=admsndt,yr=&y.,outputvar=admsndt,filename=medparxw,pct=&pct.);
        %rawVarXw(harVar=loscnt,yr=&y.,outputvar=loscnt,filename=medparxw,pct=&pct.);

    *********************************************************************************;
    **** PREP DATA FOR MERGING WITH CROSSWALK ADDED TO THE INITIAL EXTRACTS;
    *********************************************************************************;
        %if &y.>=2006 %then %do;
            %let rawid=bene_id;
            %let otherid=ehic;
            %end;
        %if &y.<=2005 %then %do;
            %let rawid=ehic;
            %let otherid=bene_id;
            %end;

** This macro extracts the discharge records for the desired years;
** Recall that the medparclaims file has already processed the part of the files which we are ;
** going to use. Therefore all of the appropriate bene_ids have been assigned to an ehic, even in ;
** cases where a bene_id has more than 1 ehic.;

*********************************************************************************************************;
* DATA STEP 1: GRAB FINAL INDX EVENTS FROM CANDIDATE CLAIMS- ENFORCE THE WINDOW ON BOTH SIDE OF INDEX EVENT;
*********************************************************************************************************;
        ** set the name of the discharge date variable;
        * Choose claims with admissions on or after the diag date;
        * that have a claim end date at most 365 days after diag;
        * making an exception for a hospitalization beginning on;
        * the data of diag;
        * ;
        * NOTE: Some SNF visits have a missing discharge date owing to cases;
        *       where the patient remains a patient past the end of the claim.;
        *       In those cases, I determine the claim end date from the admit;
        *       date and the length of stay variable;
        *****************************************************************************************;
    ***********************************************************************************;
    *DATA STEP : CONFORM MEDPAR CLAIMS DATA;
    ***********************************************************************************;
    * Merge in the crosswalk created in the prior datastep and also harmonizes the raw data after;
    * Choosing out claims which belong to the relevant individuals defined as potential index events;
/*    data _null_;
        set medvwtm .decompmed&y.;
    run;
*/

%if &y.>= 1999 %then %do ;
    %let file=med&y.;
    %end;
%if &y.<= 1998 %then %do ;
    %let file=med&pct._&y._1;
    %end;


    proc sql;
        create  view medvwtm.medtmp&pct._xw_&y. as
            select C.* %if &y.< 2006 %then %do; ,M.bene_id  %end;
            from  (SELECT * , MONOTONIC() AS medrawindx FROM
                             spmed.&file. ) C
                %if &y.< 2006 %then %do;
                LEFT JOIN spxw.ehicbenex_unique&pct. (keep=ehic bene_id)  M
                    ON trim(C.ehic)=trim(M.ehic)
                    %end;
                ;
                quit;


    data medvwtm.medtmp&pct._&y._all ( keep = &finalvarlist_. medrawindx)
         / view=medvwtm.medtmp&pct._&y._all;
        length &len_ch_. &len_num_. &len_chnull_. &len_numnull_.;
        set  medvwtm.medtmp&pct._xw_&y. (in=claims  %ConvertString2Num_setrename(y = &y.,pct = &pct.) );
        fileyear=&y.;
        &createvarNum_.;
        &createvarCH_.;
        dgn_year=.;
        dgn_date=.;
        diag_id=.;
        ep_indxNT=.;
        ambigOrder=.;
        if bene_id="" then bene_id=ehic;
        **MACRO WHICH MAKE SOME SMALL CHANGES TO HARMONIZE THE VARIABLES.;
        %ConformMedPAR(y=&y.,pct=&pct.);
        rename &renamevar_.;
    run;


    %LabelVarsXw(outLabels=medLabels,filename=medparxw);
    data medvw.medpar&pct._&y.
        / view=medvw.medpar&pct._&y.;
        set  medvwtm.medtmp&pct._&y._all ;
        label &medLabels. ;
        drop dgn_year dgn_date diag_id ep_indxNT ambigOrder;
    run;


    /*proc print data=medvw.medpar&pct._&y.(obs=10);run;*/


    %mend;




**#############################################################################;
*** BEGIN  WRAPPER MACRO HERE**************************************************;
**#############################################################################;
%macro PullMedParClaims(yearin=,yearout=,pct=,dflag=1,clmDTA=);
**#############################################################################;
*****---------TIMER CODE ----------;
**#############################################################################;
        %global tBeforeRun;
        %let tBeforeRun=%sysfunc(datetime());

**#############################################################################;
***STEP 1: PRELIMINARY ---COPY LARGE DATASETS TO SPACE DRIVES FOR FAST PROCESSING;
**#############################################################################;
    *Make Sure we are starting with an empty dataset;
    proc datasets lib=work nolist kill ; run;
    proc datasets lib=medtmp nolist kill ; run;

        %let txwcopy=%sysfunc(datetime());%let timexw=%sysevalf(%sysevalf((&txwcopy.-&tBeforeRun.)/60));
    %put <TIMER> COPY XW TOOK &timexw. minutes  ;

    **************************************************************************;
    ** THROW ERROR FOR BAD PARAMETERS ;
    **************************************************************************;

**##################################################################;
***STEP 2: DECOMPRESS AND EXTRACT INDEX EVENTS FROM MedPar File;
**#############################################################################;
       ****************************************************;
       ** BEGIN LOOPING THROUGH ALL YEARS OF INTEREST   ****;
       ****************************************************;
    %do y=&yearin. %to &yearout. ;
        x "rm &medparExt./view/tmp/*&pct.*&y.* -f ";
        x "rm &medparExt./view/*&pct.*&y.* -f ";
            libname spmed "&dataRoot./&pct.pct/med/&y./";
        *************************************************************************;
        *** GENERATE SAS VIEWS;
        *************************************************************************;
            %ExtractFinalClaims(start=&yearin.,end=&yearout.,pct=&pct.,
                y=&y.);
            **delete raw file after all cohorts have been processed;
    %end;
        **#############################################################################;
        *Copy log and lst files to folder with same name and attach date being run;
        **#############################################################################;
            %archiveoldLogfiles(pct=&pct.,cohrt=medparview,yearin=&yearin.,
                yearout=&yearout.)               ;
        **#############################################################################;
        *REMOVE FILES USED LOCALLY;
        **#############################################################################;


    **#############################################################################;
    *Delete all temp files;
    **#############################################################################;
        %let tAfterRun=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&tAfterRun.-&tBeforeRun.)/60));
        %put <TIMER> FINAL  took &elapsedrun. minutes  ;

    %mend;



***********************Call Wrapper Program Below-***********************;
*WRAPPER MACRO DOCUMENTATION ;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running several;
***            -- (4 plus)the efficiently of the program maybe impacted. ;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in. Use .01% for debugging where possible;
***;
*** dflag      -- Set equal to one if you want to delete raw files as you run the program;

*** clmDTA     -- Set equal to one if you want to convert the all files into a stata format (DTA)*;
***;
*** winYear     -- Set equal the window of claims you want to pull around index event;
****************************************************************************************************;

%PullMedParClaims(pct=05, yearin=1984,  yearout=2012,
                      dflag=1);

%PullMedParClaims(pct=0001, yearin=1984,  yearout=2012,
                      dflag=1);


%PullMedParClaims(pct=20, yearin=1984,  yearout=2011,
                      dflag=1);

%PullMedParClaims(pct=100, yearin=1992,  yearout=2012,
                      dflag=1);


