**Extract a 1 year window from OP files for the final list of index events generated ;
**in the 1B program. The script reshape the revenue center codes in the earlier years;
*of the claims from a wide format into a long format. These are easier to work with ;
*and match the current format used by CMS;
**Maurice Dalton, daltonm.at.nber.org   based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.;
**All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which sequences them correctly.;
** This wrapper macro is found at the end of the program and has several different parameters defined below. The;
** wrapper mAcro program is found at the end. The parameters are defined at the end of the program. ;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";
libname opex "&opext.";
libname optmp "&optmp.";
libname spxw "&inbenexw.";
x "mkdir -p &opext./view/tmp";
libname opvw  "&opext./view";
libname opvwtm  "&opext./view/tmp";

*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ConformOp.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinopxw;
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./archiveoldLogfiles.sas";


** This macro loops over all of the subfiles for a given year, selects;
** the desired observations;
%macro DecompressPartYear(spaceDir= ,dataRoot= ,year=, pct=, pctsuffix=, part=, revcenters=, claims=);
    * Decompress file or files to start;
    %if &year. >= 2001  %then %do;
        %if &claims.=yes %then %do;
            %decompress_i(spaceDir = &spaceDir., dataRoot = &dataRoot.,
                ftype = op, pct = &pct.,year = &year., subtype = clms, pctsuffix = &pctsuffix., indx = &part.);
            %end;
        %if &revcenters.=yes %then %do;
            %decompress_i(spaceDir = &spaceDir., dataRoot = &dataRoot.,
                ftype = op, pct = &pct., year = &year., subtype = revcntrs, pctsuffix = &pctsuffix., indx = &part.);
            %end;
        %end;
    %else %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype = op, pct = &pct., year = &year., pctsuffix = &pctsuffix., indx = &part.);
        %end;
    %mend;

%macro ProcessSQL(spaceDir=, year=,pctsuffix=,pct=,part=,revcenters=,claims=,winyear=,view=);
    ************************************************************************;
    **           DEFINE RAW FILENAME TO READ IN LATER;
    ************************************************************************;
        %put "pctsuffix : &pctsuffix.";
        %put "part : &part.";
        %put "year : &year.";

    %if &year. >= 2010  %then %do;
        %let rawop_clm = opc&year.;
        %let rawop_rev = opr&year.;
        %end;
    %else %if &year. = 2009  %then %do;
        %let rawop_clm = opc_&year._&part.;
        %let rawop_rev = opr_&year._&part.;
        %end;

    %else %if &year. >= 2001  %then %do;
        %let rawop_clm = op&pct._&year._clms&part.;
        %let rawop_rev = op&pct.&pctsuffix._&year._revcntrs&part.;
        %end;
    %else %do;
        %let rawop_clm = op&pct._&year._&part.;
        %end;
    ************************************************************************;
    **           DEFINE VAR NAME BASED ON XW CSV FILE;
    ************************************************************************;
    %rawVarXw(harVar=from_dt,yr=&year.,outputvar=from_dt,pct=&pct.,pctsuffix=&pctsuffix.,filename=opxw);
    %rawVarXw(harVar=thru_dt,yr=&year.,outputvar=thru_dt,pct=&pct.,pctsuffix=&pctsuffix.,filename=opxw);
    %rawVarXw(harVar=clm_id,yr=&year.,outputvar=clmindx,pct=&pct.,pctsuffix=&pctsuffix.,filename=opxw);
    %rawVarXw(harVar=revnum,yr=&year.,outputvar=numFields,pct=&pct.,pctsuffix=&pctsuffix.,filename=opxw);

    ************************************************************************;
    **           CREATE MACRO VAR WHICH CONVERT DATES DO NUMERIC;
    ************************************************************************;
    %if &year. >= 1996 %then %do;
        %let clmStart=C.&from_dt.;
        %let clmEnd=C.&thru_dt.;
        %end;
    %else %if &year. >= 1986 and &year. <= 1995 %then %do;
        %let clmStart=input(put(C.&from_dt.,z8.0),yymmdd8.);
        %let clmEnd=input(put(C.&thru_dt.,z8.0),yymmdd8.);
        %end;
    %else %if &year. >= 1984 and &year. <= 1985 %then %do;
    * For years 1984 and 1985, claims have only an end date.  I treat all claims for;
    * these years as starting and ending on the same day.  A sizable;
    * majority of claims have the same start and end date in later years.;
    * The bulk of the others are just a few days long. Nonetheless, keep;
    * this in mind when working with those years.;
        %let clmStart=datejul(input(C.&from_dt.,5.0));
        %let clmEnd=datejul(input(C.&from_dt.,5.0));
        %end;
    ************************************************************************;
    **           DEFINE ID IN THE RAW DATA TO SORT AND MERGE BY;
    ************************************************************************;
    %if &year.>=2006 %then %do;
        %let rawid=bene_id;
        %end;
    %if &year.<=2005 %then %do;
        %let rawid=ehic;
        %end;

    ************************************************************************;
    **           GRAB WINDOW OF CLAIMS DATA;
    ************************************************************************;
    * Choose claims with expenses starting at most 365 days before &cohrt.;
    * and which have concluded by 365 days after &cohrt.;
    * making an exception for claims beginning on;
    * the date of &cohrt.;
    * NOTE: If either of the dates is missing, I do not select the record;
    * From spot-checking years, I have yet to find any missing dates, so;
    * it is not clear that this makes any difference at all;
    **********************************************************************;
/*    proc contents data=spop.&rawop_clm.;run;*/
    **GENERATE A INDX OF THE RAW REVENUE CENTER CLAIMS -OPRAWINDX;
        data opvwtm.op&pct._rawindx_&year._&part.
        %if &view.=on %then %do; /view=opvwtm.op&pct._rawindx_&year._&part.       ;%end;;
            set spop.&rawop_clm.
                (keep=
                %if &year. <= 1998 %then %do;
                &rawvarlist_rev. &rawvarlist_clm.
                    %end;
                %else %if &year. >= 1999 and &year. <= 2000 %then %do;
                    daily_dt clm_cntl sgmt_num sgmt_cnt &rawvarlist_rev. &rawvarlist_clm.
                    %end;
               %else %if &year. > 2000 %then %do;
                    &rawvarlist_clm.
                    %end;
                );
                %if &year. <= 2000 %then %do;
                    oprevrawindx=_N_;
                    opclmrawindx=_N_;
                    %end;
                %if &year. >= 2001 %then %do;
                    opclmrawindx=_N_;
                    %end;
                diag_id=.;
                dgn_date=.;
                part =&part.;
                %if &year.>= 2006 %then %do;
                    length ehic $15;
                    ehic="";
                    %end;
    run;


    proc sql;
        create  %if &view = on %then %do; view %end;
            %else %do; table %end;
            opvwtm.op&pct._&year._clms_&part. as
            select C.*  %if &year.< 2006 %then %do; ,trim(M.bene_id) as bene_id %end;
            from  opvwtm.op&pct._rawindx_&year._&part. C
                %if &year.< 2006 %then %do;
                LEFT JOIN spxw.ehicbenex_unique&pct. (keep=ehic bene_id)  M
                    ON C.ehic=M.ehic
                    %end;
            %if &year. >= 1999 and &year. <= 2000 %then %do;
            order by daily_dt,link_num,clm_cntl,diag_id,sgmt_num;
            %end;
            ;
        quit;
    run;


    ************************************************************************;
    **  CONFORM 2000 or BEFORE;
    ************************************************************************;
    %if &year. <=2000  %then %do;
        ************************************************************************;
        * For 1999-2000, a single claim can split across multiple records;
        * when there are more revenue centers on the claim than there are;
        * slots in a single record;
        * The documentation suggests that daily_dt and link_num together;
        * form a unique identifier for claims and then sgmt_num indexes over;
        * the segments of a single claim.  In practice, however, there seem;
        * multiple first segments for each link_num daily_dt claim that appear;
        * to simply be independent claims, as there is no reason for them to be;
        * split.  Using the claim control number in addition to daily_dt and link_num;
        * seems to generate an actual unique identifier that:;
        * a) keeps claims that ACTUALLY have multiple claims together;
        * b) splits up the many claims erroneously grouped together by link_num and daily_dt;
        * ;
        * Note that sorting by diag_id is necessary since claims may get duplicated above;
        * since they may match to multiple &cohrt._ids (one in the lead-in, one in follow-up);
        ************************************************************************;
       %if  &revcenters. = yes %then %do;
        *****************************************************************************;
        **      PRE-2000  REV CNTR;
        *****************************************************************************;
        data opvwtm.op&pct._&year._revcntrs_cnfrm_&part.
             (keep= &finalvarlist_rev.)
            %if &view.=on %then %do;  / view = opvwtm.op&pct._&year._revcntrs_cnfrm_&part. ; %end;;
            length bene_id $15  &len_chnull_rev. &len_numnull_rev. &len_ch_rev. &len_num_rev. ;
            set opvwtm.op&pct._&year._clms_&part. %ConvertStr2Num_setrenameOp(y=&year.,pct=&pct.,filevarin=rev);
            ** The clmindx_temp variable is - link_num - variable in 1999 and 2000. The ;
            ** convertstr2Num_setrenameOP macro rename the link_num variable to clmindx_temp;
            ** in order to change it from character to numeric;
            %if &year. >= 1999 and &year. <= 2000 %then %do;
                by daily_dt clmindx_temp  clm_cntl diag_id sgmt_num;
                %end;

            fileyear=&year.;
            ** CREATE EMPTY VARIABLES;
            &createvarCH_rev.;
            &createvarNum_rev.;

            ************************************************************************;
            **           INCREMENT CLAIM INDEX;
            ************************************************************************;
            * For years 1999 to 2000, a single claim can have so many revenue centers that it;
            * is split across multiple records.  Thus, I increment the claim index as appropriate.;
            %if &year. >= 1999 and &year. <= 2000 %then %do;
                retain clm_idnum 1;
                if first.clm_cntl then do;
                    clm_idnum=clm_idnum + 1;
                    end;
                %end;
            %else %if &year. >= 1984 and &year. <= 1998 %then %do;
                clm_idnum = opclmrawindx;
                %end;
            **define it this way so that clm_id is unique across year;
            clm_id= "p&part.c" || put(trim(clm_idnum),15.);

            ************************************************************************;
            **           WRITE REVENUE CENTERS;
            ************************************************************************;
            * This macro iterates over the revenue center fields and outputs each to its;
            * own record in a common format For years where a field giving the total;
            * number of revenue centers does not exist for older files, this;
            * macro creates it;
            rename &renamevar_rev.;
            %ConformOp_WriteRevcntrs(year=&year.,cohrt=,dir=optmp,part=&part.);
        run;

        %LabelVarsXw(outLabels=oprevLabels,filename=opxw,filevarin=rev);
            data opvw.op&pct._&year._revcntrs_&part
                %if &view.=on %then %do; / view = opvw.op&pct._&year._revcntrs_&part   ;%end;;
                set opvwtm.op&pct._&year._revcntrs_cnfrm_&part.;
                LABEL &oprevLabels.;
                **bene id to ehic xw isnt perfect. use ehic if not beneid available;
                %if &year.<= 2005 %then %do;
                    if bene_id="" then bene_id=ehic;
                %end;

            run;

        %end;

        *****************************************************************************;
        ** PREPARE PRE 2000 DATA FOR A CLMS FORMAT;
        *****************************************************************************;
    %if  &claims. = yes  %then %do;
            data opvwtm.op&pct._&year._clms_cnfrm_&part. (keep=&finalvarlist_clm.)
                %if &view.=on %then %do;  / view = opvwtm.op&pct._&year._clms_cnfrm_&part.  ;%end;;
                length bene_id $15 &len_num_clm. &len_ch_clm. &len_chnull_clm. &len_numnull_clm.;
                set opvwtm.op&pct._&year._clms_&part.
                     %ConvertStr2Num_setrenameOp(y=&year.,pct=&pct.,filevarin=clm);
            ** The clmindx_temp variable is - link_num - variable in 1999 and 2000. The ;
            ** convertstr2Num_setrenameOP macro rename the link_num variable to clmindx_temp ;
            ** in order to change it from character to numeric;
            %if &year. >= 1999 and &year. <= 2000 %then %do;
                by daily_dt clmindx_temp  clm_cntl diag_id sgmt_num;
                %end;


                fileyear=&year.;
                **Write empty variables;
                &createvarCH_clm.;
                &createvarNum_clm.;

            ************************************************************************;
            **           INCREMENT CLAIM INDEX;
            ************************************************************************;
            * For years 1999 to 2000, a single claim can have so many revenue centers that it;
            * is split across multiple records.  Thus, I increment the claim index as appropriate.;
                %if &year. >= 1999 and &year. <= 2000 %then %do;
                    retain clm_idnum 1;
                    if first.clm_cntl then do;
                        clm_idnum=clm_idnum + 1;
                        end;
                    %end;
                %else %if &year. >= 1984 and &year. <= 1998 %then %do;
                    clm_idnum = opclmrawindx;;
                    %end;
            **define it this way so that clm_id is unique across year;
            clm_id= "p&part.c" || put(trim(clm_idnum),15.);

            ************************************************************************;
            **           WRITE CLAIMS;;
            ************************************************************************;
            * This takes the claim summary data, puts it in a common format, and writes;
            * it as a claim record;
            rename &renamevar_clm.;
            **bene id to ehic xw isnt perfect. use ehic if not beneid available;
            if bene_id="" then bene_id=ehic;

            **Conform Clm macro which generates a charge var;
            %ConformOp_ClmsGenChargeVar(year=&year. );
            **Converts character to numeric;
            %ConformOp_ClmsChar2Numeric(year=&year.);

            * for 1999-2000, we only want to write out first-segment records;
            %if &year. >= 1999 and &year. <= 2000 %then %do;
                if sgmt_num eq 1 then do;
                    output  ;
                    end;
                %end;
            %else %do;
                output  ;
                %end;
            run;

            %LabelVarsXw(outLabels=opclmLabels,filename=opxw,filevarin=clm);
            data opvw.op&pct._&year._clms_&part.
                %if &view.=on %then %do; / view = opvw.op&pct._&year._clms_&part.   ;%end;;
                length bene_id $15 ;
                set opvwtm.op&pct._&year._clms_cnfrm_&part.;
                LABEL &opclmLabels.;
                    **bene id to ehic xw isnt perfect. use ehic if not beneid available;
                %if &year.<= 2005 %then %do;
                    if bene_id="" then bene_id=ehic;
                %end;

                drop dgn_date diag_id ;
            run;

            %end;
        %end;
    ************************************************************************;
    **           CONFORM FILES BETWEEN 2001 and 2008;
    ************************************************************************;
    %if &year. >= 2001  %then %do;
        ***********************************************************************;
        * For records in years 2001 to 2005, select the revenue centers;
        * that correspond to the claims selected above;
        * Note that each claim record can appear twice in the extract: once for;
        * the lead-in period for each &cohrt. and once for the follow-up period for;
        * each &cohrt..  Thus, the claims-revenue centers match is a many-to-many merge;
        * that must use PROC SQL.;
        ************************************************************************;
       %if  &revcenters. = yes %then %do;
        ************************************************************************;
        **           strip claims file down to the relevant IDs;
        ************************************************************************;
        data opvwtm.op&pct._&year._clmid_&part.
             %if &view.=on %then %do; / view = opvwtm.op&pct._&year._clmid_&part.  ;%end;;
            set opvwtm.op&pct._&year._clms_&part.;
            keep diag_id dgn_date &clmindx. bene_id ehic ;
        run;
        ************************************************************************;
        **           MERGE IDS from clms into revenue center;
        ************************************************************************;
        * merge each revenue center onto each appropriate rawid;
        * note that ehic/bene_id should be unique within clm_id, but;
        * I add this as an additional criterion just to be safe;

        ** THIS IS DATASTEP IS SEPERATED FROM THE SQL STEP IN ORDER TO GENERATE THE OPRAWINDX VARIABLE;
        ** TO ALLOW FOR A LINK BETWEEN THE INDX AND CLAIMS FILES;
        data opvwtm.op&pct._&year._clmidrev_&part.
             %if &view.=on %then %do; / view = opvwtm.op&pct._&year._clmidrev_&part.  ;%end;;
            length bene_id $15 ;
            set spop.&rawop_rev.;
            oprevrawindx=_N_;
            part =&part.;
            keep &rawid. &clmindx. &rawvarlist_rev. oprevrawindx part;
        run;

*test;
/*
            creation of cross product slows this puppy down way too much
            proc sql;
            create  %if &view = on %then %do; view %end;
                    %else %do; table %end;
                 opvwtm.op&pct._&year._revcntrsid_&part. as
                select *
                from opvwtm.op&pct._&year._clmid_&part. C,
                     opvwtm.op&pct._&year._clmidrev_&part.  R
                where (C.&clmindx. = R.&clmindx.) and (C.&rawid. = R.&rawid.);
            quit;
        run;
        */

        data  opvwtm.op&pct._&year._revcntrsid_&part.
               %if &view = on %then %do; / view = opvwtm.op&pct._&year._revcntrsid_&part. %end;;
            merge  opvwtm.op&pct._&year._clmid_&part.
                   opvwtm.op&pct._&year._clmidrev_&part.;
                by  &rawid. &clmindx. ;
            run;

        ************************************************************************;
        **           CONFORM CLAIMS AND REVENUE CETERS;
        ************************************************************************;
        %LabelVarsXw(outLabels=oprevLabels,filename=opxw,filevarin=rev);
     data opvwtm.op&pct._&year._revcntrs_cnfrm_&part (keep=&finalvarlist_rev.)
            %if &view.=on %then %do; / view = opvwtm.op&pct._&year._revcntrs_cnfrm_&part ;%end;;
         length &len_num_rev. &len_ch_rev. &len_chnull_rev. &len_numnull_rev.;
         set opvwtm.op&pct._&year._revcntrsid_&part.
                    %ConvertStr2Num_setrenameOp(y=&year.,pct=&pct.,filevarin=rev);
            fileyear = &year.;
            &createvarCH_rev.;
            &createvarNum_rev.;
            rename &renamevar_rev.;
            %ConformOp_WriteRevcntrs(year=&year.,cohrt=,dir=optmp,part=&part.);
                **bene id to ehic xw isnt perfect. use ehic if not beneid available;
            %if &year.<= 2005 %then %do;
                if bene_id="" then bene_id=ehic;
                %end;
            run;

            data opvw.op&pct._&year._revcntrs_&part
                %if &view.=on %then %do; / view = opvw.op&pct._&year._revcntrs_&part   ;%end;;
                set opvwtm.op&pct._&year._revcntrs_cnfrm_&part;
                LABEL &oprevLabels.;
            run;

        %end;
    %if  &claims. = yes %then %do;

            %LabelVarsXw(outLabels=opclmLabels,filename=opxw,filevarin=clm);
            data opvwtm.op&pct.&year._clms_cnfrm_&part. (keep=&finalvarlist_clm.)
                %if &view.=on %then %do; / view = opvwtm.op&pct.&year._clms_cnfrm_&part.   ;%end;;
                length &len_num_clm. &len_ch_clm. &len_chnull_clm. &len_numnull_clm.;
                set opvwtm.op&pct._&year._clms_&part.
                     %ConvertStr2Num_setrenameOp(y=&year.,pct=&pct.,filevarin=clm) ;
                fileyear = &year.;
                &createvarCH_clm.;
                &createvarNum_clm.;
                rename &renamevar_clm.;
                **Conform Clm macro which generates a charge var;
                %ConformOp_ClmsGenChargeVar(year=&year. );
                **Converts character to numeric;
                %ConformOp_ClmsChar2Numeric(year=&year.);
                **bene id to ehic xw isnt perfect. use ehic if not beneid available;
                %if &year.<= 2005 %then %do;
                    if bene_id="" then bene_id=ehic;
                %end;
            run;

            data opvw.op&pct._&year._clms_&part.
                %if &view.=on %then %do; / view = opvw.op&pct._&year._clms_&part.   ;%end;;
                set opvwtm.op&pct.&year._clms_cnfrm_&part.;
                LABEL &opclmLabels.;
                drop dgn_date diag_id ;
            run;

        %end;
    %end;

    ************************************************************************;
    **           DELETE TEMP FILES;
    ************************************************************************;
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;

%macro runprgOp(pct =, yearin =, yearout =,
                clmDTA = 0,  revcenters = yes, claims = yes, winyear =, view= );
    ** Copy formatted xwfiles to local space drives for faster processing;
    x "rm &spxw./* -f ";
    x "cp &inbenexw./ehicbenex_unique_bene_indx&pct..* &spxw./ -f ";
    x "cp &inbenexw./ehicbenex_unique&pct..* &spxw./ -f ";
    x "bunzip2 &spxw./*&pct.*.*bz2  ";

************************************************************************;
**          CATCH ERRORS IN PARAMETERS                    ;
************************************************************************;
  *For timing;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    %put TIMER Begin run at time &SYSTIME.;

    ****************************************************************;
    ** START LOOP THROUGH YEARs;
    **************************************************************************;
    %do y= &yearin. %to &yearout. ;
        x "rm &opext./view/tmp/*&pct.*&y.* -f ";
        x "rm &opext./view/*&pct.*&y.* -f ";
        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;
       *******************************************************************;
       ** GEN MACRO FROM XW WHICH HOLD VARIABLE NAME CHANGES ACROSS TIME;
       **************************************************************************;
            %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=rev,pct=&pct.,pctsuffix=&suffix.,filename=opxw);
            %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=clm,pct=&pct.,pctsuffix=&suffix.,filename=opxw);
            %GenerateAnnualVariableListFromXw(yr=&y.,pct=&pct.,pctsuffix=&suffix.,filename=opxw);
            **Generate macro name of the file name which resoolve to the raw variable name;
            ** for example &hcpcs_cd will resolve to ohcpcs in 1986;
            %genLineItemVarsToLoop(yr=&y.,pct=&pct.,filename=opxw);

        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.,subtype=&stypem.,
                      pctsuffix=&suffix.);

         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spop "&dataRoot./&pct.pct/op/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
       *For testing purposes set numfile =1 num_file;
        %do z=1 %to &num_file.;
                 **************************************************************************;
                 ** Loop through cohrts extracting cohort specific data from single     ***;
                 ** part, harmonize data                                                ***;
                 **************************************************************************;
                %ProcessSQL(spaceDir=&spop., year = &y., pctsuffix =,  pct = &pct., part = &z.,
                            revcenters = &revcenters., claims = &claims., winyear = &winyear.,view=&view.);

            %end;

        %end;


        **#############################################################################;
        ** Copy log and lst files, gip for archiving ;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=,yearin=&yearin.,yearout=&yearout.);
        **clear space directory;
        x "rm &optmp./* -f &";
        x "rm &spxw./* -f ";
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put TIMER END run at time &elapsedrun.;
    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgOp;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
*** revcenters -- Indicates whether you want revenue centers to be extracted.;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;


*This run the program;


%runprgOp(pct=05,
          yearin=1984,yearout=2012,
          revcenters=yes,
          claims = yes,
          clmDTA=0,
          view=on           );


%runprgOp(pct=20,
          yearin=1986,yearout=2011,
          revcenters=yes,
          claims = yes,
          clmDTA=0,
          view=on
           );

%runprgOp(pct=100,
          yearin=1996,yearout=2012,
          revcenters=yes,
          claims = yes,
          clmDTA=0,
          view=on
           );

%runprgOp(pct=0001,
          yearin=1985,yearout=2012,
          revcenters=yes,
          claims = yes,
          clmDTA=0,
          view=on
           );
