** Extract a X year window of claims from the Carrier files for the given index events extracted in the
** CarrierExtract.sas. Use the index events defined in the 1B program to pull claims. ;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which
** sequences them correctly.This wrapper macro is found at the end of the program and has
**  several different parameters defined at the end of the code.;

** Maurice Dalton, daltonm.at.nber.org based on code initially written by Jean Roth and refined;
** by Matt Fiedler. All errors are my own.;
**;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformCarrier.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";
%readincarrierxw;

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spxw "&inbenexw.";
libname here ".";
libname indxex "&indxExt.";
libname carex  "&carext.";

x "mkdir &carext./view4extract/tmp -p";
libname carvw  "&carext./view4extract";
libname carvwtm  "&carext./view4extract/tmp";
libname cartmp "&cartmp.";
libname xwfile "&xwfile.";



%macro ProcessSQL(year=,pctsuffix= ,pct=,part=,view=,spaceDir=,dataRoot=);
   *******************************************************************;
   ** GEN MACRO FROM XW WHICH HOLD VARIABLE NAME CHANGES ACROSS TIME-BASED ON CSV FILE;
   **************************************************************************;
    %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=line,pct=&pct.,
        pctsuffix=&suffix.,filename=carrierxw);
    %GenerateAnnualVariableListFromXw(yr=&y.,filevarin=clm,pct=&pct.,
        pctsuffix=&suffix.,filename=carrierxw);
    %GenerateAnnualVariableListFromXw(yr=&y.,pct=&pct.,
        pctsuffix=&suffix.,filename=carrierxw);

    ** Specify date, clm_id and hcpcs_yr variables for these years;
    %rawVarXw(harVar=sexpndt1,yr=&year.,outputvar=expStart,
        pct=&pct.,pctsuffix=&pctsuffix.,filename=carrierxw);
    %rawVarXw(harVar=sexpndt2,yr=&year.,outputvar=expEnd,
        pct=&pct.,pctsuffix=&pctsuffix.,filename=carrierxw);
    %rawVarXw(harVar=clm_id,yr=&year,outputvar=clmindx,
        pct=&pct.,pctsuffix=&pctsuffix.,filename=carrierxw);
    %rawVarXw(harVar=hcpcs_yr,yr=&year,outputvar=hcpcsyr,
        pct=&pct.,pctsuffix=&pctsuffix.,filename=carrierxw);
    %rawVarXw(harVar=dgns_cd1,yr=&year,outputvar=dgns_cd1,
        pct=&pct.,pctsuffix=&pctsuffix.,filename=carrierxw);

    ***************************************************************************;
    ** 20% Carrier files before in 1998 and 1999 and between 2002 and 2005 are made up of 4;
    ** 5% samples (labeled as such with different pctsuffix). See readme file in the dataroot;
    ** for more explanation;
    ***************************************************************************;
    ** Specify name of the carrier line item file for this year;
    ** Need to use different names in 2008 because of the use of views;
        %put "pctsuffix : &pctsuffix.";
        %put "part : &part.";
        %put "year : &year.";

    %if &year. >= 2010  %then %do;
        %let rawcar_clms = carc&year.;
        %let rawcar_line = carl&year.;
        %let lineitemfile=carvwtm.car&pct._carclmlnitsraw&year._&part.;
        %end;
    %else %if &year.  = 2009  %then %do;
        %let rawcar_clms = carc_&year._&part.;
        %let rawcar_line = carl_&year._&part.;
        %let lineitemfile=carvwtm.car&pct._carclmlnitsraw&year._&part.;
        %end;
    %else %if &year. >=2002 and &year. < 2009  %then %do;
        %let rawcar_clms=car&pct.&pctsuffix._&year._clms&part.;
        %let rawcar_line = car&pct.&pctsuffix._&year._lnits&part.;
        %let lineitemfile=carvwtm.car&pct._carclmlnitsraw&year._&part.;
        %end;
    %else %do;
        %let rawcar_line = car&pct.&pctsuffix._&year._&part.;
        %let lineitemfile=carvwtm.car&pct.&pctsuffix._lnitsraw&year._&part.;
        %end;

   ** Define what is to be sorted by and what is to define unique index;
    %if &year.>=2006 %then %do;
        %let rawid=bene_id;
        %let otherid=ehic;
        %end;
    %if &year.<=2005 %then %do;
        %let rawid=ehic;
        %let otherid=bene_id;
        %end;

    ***************************************************************************;
    ** Grab line items associated with index event    **********;
    ***************************************************************************;
       ** Choose line items with expenses starting at most 365 days before cohrt;
       ** and which have concluded by 365 days after cohrt;
       ** ;
       ** Note that:;
       ** 1) Drop all records with a missing start or end date (which only affects;
       **    about 1 in a million line items in the 5%claims);
       ** 2) Make an exception for line items with expenses beginning on the index event date;

    proc sql _METHOD BUFFERSIZE=2097162;
        create
            %if &view = on %then %do; view %end;
            %else %do; table %end;
                carvwtm.car&pct.&pctsuffix._lnitsraw&year._&part. as

            select  C.*, J.diag_id, J.dgn_date , &part. as part %if &y.< 2006 %then %do;, J.bene_id ,J.ehicx as ehic %end;
                                                            %if &y.>= 2006 %then %do; ,J.ehic  %end;

                    from (SELECT *, MONOTONIC() AS carrawindx FROM spcar.&rawcar_line. (keep=
                                                              %if &year < 2002 %then %do;
                                                                   &rawvarlist_.
                                                              %end;
                                                              %else %if &year >= 2002 %then %do;
                                                                  &rawvarlist_line.
                                                              %end;)
                          )C ,
                  (SELECT S.diag_id, S.dgn_date, S.bene_id, %if &y.< 2006 %then %do; COALESCE(M.ehic,S.ehic)
                                                                                               as ehicx %end;
                                                            %if &y.>= 2006 %then %do; S.ehic %end;
                           FROM cartmp.indxfile S
                           %if &y.< 2006 %then %do;
                          LEFT JOIN spxw.ehicbenex_unique_bene_indx&pct. (keep=ehic bene_id)  M
                              ON trim(S.bene_id)=trim(M.bene_id)
                             %end;
                  ) J
                      %if &y.< 2006 %then %do;
                      WHERE J.ehicx=C.ehic
                          %end;
                      %else %do;
                      WHERE J.bene_id=C.bene_id
                          %end;
                     %if &year.>=2002 %then %do;
                      order by  &rawid. ,&clmindx.
                          %end;
                  ;
quit;

    ** For records in years 2002 and after, sort and then match on the actual claims files;
    %if &year. >= 2002 %then %do;
        ***************************************************************************;
        ** merge in info from clms into the line item levels for post 2002 files **;
        ***************************************************************************;
        data &lineitemfile.
            %if &view = on %then /view=&lineitemfile.       ;;
            merge carvwtm.car&pct.&pctsuffix._lnitsraw&year._&part.(in=inLnits)
                  spcar.&rawcar_clms. (keep=&rawid. &clmindx. &rawvarlist_clm. );
            by &rawid. &clmindx.;
            if inLnits;
        run;

        %end;

        ***************************************************************************;
        ** DEAL WITH CROSS YEAR DIFFERENCES: SIMILAR TO THE OLD CONFORM MACRO **;
        ***************************************************************************;

    data carvwtm.car&pct.&pctsuffix._&year._&part._nolab (keep=&finalvarlist_.)
          %if &view = on %then / view = carvwtm.car&pct.&pctsuffix._&year._&part._nolab; ;
        length &len_ch_. &len_num_. &len_chnull_. &len_numnull_.;
        set &lineitemfile.
            %ConvertStr2Num_setrenameCar(y=&year.,pct=&pct.);

        %conformCarrier(year=&year.,pct=&pct.);
        fileyear = &year.;
        * These variables list are created from a the macro GenerateAnnualVariableListFromXw;
        * which is based on the csv file.;
        &createvarCH_.;
        &createvarNum_.;

        rename &renamevar_.;
        **bene id to ehic xw isnt perfect. use ehic if not beneid available;
        if bene_id="" then bene_id=ehic;
    run;


    %LabelVarsXw(outLabels=carLabels,filename=carrierxw);
    data carvw.car&pct.&pctsuffix._clmline_&year._&part.
        %if &view = on %then / view = carvw.car&pct.&pctsuffix._clmline_&year._&part.; ;
        set carvwtm.car&pct.&pctsuffix._&year._&part._nolab;
        label &carLabels. ;
    run;


/*
    %if &part.=1 %then %do;
        proc print data=carvw.car&pct.&pctsuffix._clmline_&year._&part. (obs=10);run;
        %end;
*/
    %mend;



**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunCarExtraction(pct="",yearin=,yearout=,clmDTA=,view=);

**************************************************************************;
** THROW ERROR FOR BAD PARAMETERS ;
**************************************************************************;
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    **clear old datasets;
    x "cp &indxExt./ami05_indx.sas7bdat &cartmp./indxfile.sas7bdat -f";
**************************************************************************;
********Deal with a crash if defined in the parameter - crashStart********;
**************************************************************************;
****************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
    %do y=&yearin. %to &yearout.;


        x "rm &carext./view4extract/temp/*&pct.*&y.* -f";
        x "rm &carext./view4extract/*&pct.*&y.* -f";

       **************************************************************************;
       ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);
            **This macro creates the num_file macro which is used to loop through;
       *******************************************************************;
       ** define lib;
       **************************************************************************;
       ** FIles are no longer saved zipped and new 10g line no longer makes it important;
       ** to move files to scratch;
       ** change libname which views use to the year/type/file being processed;
       libname spcar "&dataRoot./&pct.pct/car/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART ;
       **************************************************************************;
        %do z= 1 %to &num_file.;
            %breakFilename2parts(ftype=car,pct=&pct.,z=&z.,year=&y.);
                 **************************************************************************;
                 ** Loop through cohrts extracting cohort specific data from single     ***;
                 ** part, harmonize data                                                ***;
                 **************************************************************************;
            %ProcessSQL(pct=&pct.,year = &y., pctsuffix = &suffix.,view=&view.,
                part = &part.,spaceDir = &spcar., dataRoot=&dataRoot.);
            %end;

        %end;
        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE LOG/LST FILE;
        %archiveoldLogfiles(pct=&pct.,cohrt=views,yearin=&yearin.,yearout=&yearout.);

        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
        %let tAfterRun=%sysfunc(datetime());
        %put &tAfterRun.-&tBeforeRun.;
        %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
        %put <TIMER> Process Years  ALL took &elapsedRun. minutes.;

        %mend;




********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%RunCarExtraction;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;

*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=N/A   -- This parameter is only used in the 1A and 1B programs ;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
**
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;
%RunCarExtraction(pct=05,
    yearin=1992,yearout=2012,
    clmDTA=0,view=on);


%RunCarExtraction(pct=0001,
    yearin=1992,yearout=2012,
    clmDTA=0,view=on);

%RunCarExtraction(pct=20,
    yearin=1998,yearout=2011,
    clmDTA=0,view=on);
