********************************************************;
** Flag candidate Index Events in the Inpatient sample**;
** *****************************************************;
**  Program uses the ICD9-CM and HCPCS codes found   ***;
**  Accompanying HCPCS and ICD9 SAS files to flag    ***;
**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the IP files - other wise ignore ***;
********************************************************;

*** Instructions::;
*** Change HCPCS and ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;



***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;

libname here ".";
libname ipex "&ipext.";
libname iptmp "&iptmp.";
libname spxw "&inbenexw.";
libname ipvw  "&ipvw.";
libname ipvwtm  "&ipvw./tmp";



*import macros usedin the creations of sas views for doc;
%include "&SASmac./ConformOp.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinipxw;
%include "&SASmac./CreateXWmacro.sas";
*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";
%include "ICD9cohrtDef.sas";
%include "HCPCScohrtDef.sas";


%macro candidateIndxIpFlag(year=,pctsuffix=,cohrt=,pct=,part=,dgnPos=,prcPos=,filetype=);

        %if &year<= 1991 and &dgnPos.>5 %then %do;
            %let  dgnPos = 5;
            %end;
        %if &year<= 1986 and &prcPos.>5 %then %do;
            %let  prcPos = 3 ;
            %end;


    data ip_clm_canidate;
        length   pICD9_indx $5 dICD9_indx $5;
        set ipvw.ip&pct._clms_&year._&part. ;

        **Creates a unique ID which allows the variable to be linked back to the raw data;
         ** GENERATE BLANKS;
        taghcpcs=0;
        prcIndxNum=0;
        dgnIndxNum=0;
        tagPrc1=0;
        tagDgn1=0;
        taghcpcs=0 ;
        phcpcs_indx = "";
        pICD9_indx  = "";
        dICD9_indx  = "";
        taghcpcsRevField=0;

        %ICD9cohrtDef(cohrt=&cohrt.,numProcCodes=&prcPos.,numDgnCodes=&dgnPos.,file=ip,
                          dgnsPfx=icd_dgns_cd,prcdPfx=icd_prcdr_cd);
    *** VARIABLE HARMONIZATION;
            dgn_date=from_dt;
            dgn_date2=thru_dt;

        *!!!!!!!!!!!   RESTRICT SAMPLE -  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
            if tagPrc1=1 %do i=1 %to &prcPos.; or tagPrc&i.=1 %end; or
            tagDgn1=1 %do i=1 %to &dgnPos.; or tagDgn&i.=1 %end;;
        *!!!!!!!!!!!   RESTRICT SAMPLE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
            zip_indx=zip_cd;
            file="ipclm";
            keep bene_id ehic fileyear file dICD9_indx pICD9_indx clm_id
                 dgn_date dgn_date2 prcIndxNum dgnIndxNum iprawclmindx zip_indx;

run;

    proc sort data=ip_clm_canidate;
        by clm_id;
    run;


    proc sort data=ipvw.ip&pct._revcntr_&year._&part. out=ip_rev_canidate;
        by clm_id;
    run;



    data ip_rev_canidate;
        length   phcpcs_indx $5;
        merge ip_rev_canidate ip_clm_canidate (in=canidateclm);
        by  clm_id ;

        %HCPCScohrtDef(cohrt=&cohrt.,hcpcs=hcpcs_cd);

        *!!!!!!!!!!!   RESTRICT SAMPLE - IF YOU WANT TO LOOK AT CLMS AND REV CNTR CONDITION DO IT BELOW!;
        if  taghcpcs=1 ;
        *!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
        if canidateclm =1 and taghcpcs=1 then file="ipboth";
        if file="" then file="iprev";

        ** HARMONIZE VARS;
        phcpcs_indx = hcpcs_cd;
        dgn_dte_rev = rev_dt;

        keep bene_id ehic fileyear file dICD9_indx pICD9_indx phcpcs_indx part clm_id
            dgn_date dgn_date2 prcIndxNum dgnIndxNum iprawrevindx iprawclmindx;
    run;

    data combine;
        set ip_rev_canidate ip_clm_canidate;
    run;

    ************************************************************************;
    **    COMBINE HARMONIZED PARTS - APPEND IS FASTEST;
    ************************************************************************;
       proc append base = iptmp.&cohrt.iprevindx_&year.
                    data = combine force ;
        run;

    %mend;

%macro CompileIndxEvents(cohrt=,pct= ,start= ,end= ,dgnPos= ,prcPos= ,clmDTA=0);
   ************************************************************************;
   ** Combine the CLMS  and dump the final extract to stata dta file;
   ************************************************************************;
    data ipex.&cohrt.&pct._d&dgnPos.p&prcPos._ipcandidates;
        set %RepeatN(iptmp.&cohrt.iprevindx_,&start.,&end.);
        LABEL
                bene_id = "Encrypted beneficiary identifier (individual unique identifier)"
                ehic = "Encrypted HIC  (OLD identifier)"
                fileyear = "Raw file year"
                file = "Type of file contributing claims"
                dICD9_indx = "Diagnostic ICD9-CM code defining the candidate"
                pICD9_indx = "Procedure ICD9-CM code defining the candidate"
                phcpcs_indx= "Procedure HCPCS code defining the candidate"
                dgn_date = "Claim index candidate START date"
                dgn_dte_rev  = "Revenue center candidate date"
                dgn_date2 = "Claim index candidate END date"
                prcIndxNum = "Procedure number generating the candidate indx event"
                dgnIndxNum = "Diagnostic number generating the candidate indx event"
                iprawindx = "Obs number in raw data. Combined with file/part/fileyear/bene_id/dgn_date generates unique match"
                part = "Raw file part for a given file/fileyear"
                zip_indx="Zip code on the claim generating the indx"
                ;

    run;

    x "rm &iptmp./&cohrt.ipindx_*.sas7bdat -f ";

    proc sql;
            select fileyear, count(fileyear) as clmCount
                from ipex.&cohrt.&pct._d&dgnPos.p&prcPos._ipcandidates
                group by fileyear;
        run;

   ************************************************************************;
   ** SEND TO STAT-TRANSFER;
   ************************************************************************;
    %if &clmDTA.=1 %then %do;
        x "st &ipext./&cohrt.&pct._&dgnPos._ipcandidates.sas7bdat
              &ipext./&cohrt.&pct._&dgnPos._ipcandidates.dta -y -od -v";
        %end;
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro FlagcandidateIPindx(pct=, cohrt1=, cohrt2=, cohrt3=, cohrt4=, cohrtN=,
                          dgnPos=, prcPos=,  yearin=, yearout=, clmDTA=0, crashStart=0,note=&note.);
  *For timing;
  %global tBeforeRun;
  %let tBeforeRun=%sysfunc(datetime());
  %put TIMER Begin run at time &SYSTIME.;


  **************************************************************************;
  ********Deal with a crash if defined in the parameter - crashStart********;
  **************************************************************************;
  %do j=1 %to &cohrtN.;
      %if &crashStart.=&yearin. or &crashStart.=0 %then %do;
            proc datasets lib=iptmp NOLIST KILL;
            run;
            %let beginLoop=&yearin.;
            %end;
        %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
            *Delete files no longer needed;
            proc datasets lib=iptmp;
                DELETE
                    %RepeatN(&&cohrt&j..iprevindx_,&crashStart.,&yearout.)
            run;
            %end;
        %end;
    ****************************************************************;
    ** START LOOP THROUGH YEARs;
    **************************************************************************;
    %do y= &beginLoop. %to &yearout. ;
        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=ip,year=&y.);
         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spip "&dataRoot./&pct.pct/ip/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART;
       **************************************************************************;
       *For testing purposes set numfile =1 num_file;
        %do z=1 %to &num_file.;
            %do j=1 %to &cohrtN.;
                 **************************************************************************;
                 ** Loop through cohrts extracting cohort specific data from single     ***;
                 ** part, harmonize data                                                ***;
                 **************************************************************************;
                    %candidateIndxIpFlag(year=&y.,cohrt=&&cohrt&j..,pct=&pct.,part=&z.,
                                      dgnPos=&dgnPos.,prcPos=&prcPos.);
                %end;
            %end;

        %end;

        *******************************************************************;
        ** COMBINE ALL candidate INDX EVENTS;
        **************************************************************************;
    %do j=1 %to &cohrtN.;
        %CompileIndxEvents(cohrt=&&cohrt&j..,pct=&pct.,start=&yearin.,end=&yearout.,prcPos=&prcPos.,dgnPos=&dgnPos.,clmDTA=&clmDTA.);
       **#############################################################################;
       *****---------TIMER CODE ----------;
       **#############################################################################;
        %let tAfterRunCht=%sysfunc(datetime());
        %let elapsedcohrt=%sysevalf(%sysevalf((&tAfterRunCht.-&tBeforeRun.)/60));
        %put <TIMER> Total  &&cohrt&j.. took &elapsedcohrt. minutes.;

        **#############################################################################;
        ** Copy log and lst files, gip for archiving ;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,dgnPos=&dgnPos.,yearin=&yearin.,yearout=&yearout.,note=&note.);
            %end;
        **clear space directory;
        x "rm &iptmp./* -f &";
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put TIMER END run at time &elapsedrun.;
    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgOp;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=1   -- Determine how many diagnosis variables (principal versus secondary) were used to;
***               create the index event data. Most of the time it will be equal to  1 (the ;
***               principle diagnosis).;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** id=        -- ehic or bene_id;
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
*** revcenters -- Indicates whether you want revenue centers to be extracted.;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;
%FlagcandidateIPindx(pct=&pct.,
          cohrt1=&cohrt.,
          cohrtN=1,
          yearin=&yearin.,yearout=&yearout.,
          dgnPos=&ip_dxn.,prcPos=&ip_proc.,
          clmDTA=&clmDTA.,note=&note.);



/*
*** To run this file only or for testing comment out the above lines and;
*** make sure you fill in the correct parameters below;

%FlagcandidateIPindx(pct=05,
          cohrt1=ami,
          cohrtN=1,
          yearin=1999,yearout=2011,
          dgnPos=1,prcPos=0,
          clmDTA=1);


