**Extract a 1 year window from IP files for the given index events generated ;
**by the 1B program.  The script reshapes the revenue center codes in the earlier years;
*of the claims from a wide format into a long format. These are easier to work with and;
* match the current format used by CMS;
**Maurice Dalton, daltonm.at.nber.org   based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.;
**All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which sequences them correctly.;
** This wrapper macro is found at the end of the program and has several different parameters defined below. The;
** wrapper mAcro program is found at the end. The parameters are defined at the end of the program. ;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";
libname spip "&spip.";
libname ipex "&ipext.";
libname iptmp "&iptmp.";
libname xwfile "&xwfile.";
libname spxw "&inbenexw.";
libname indxex "&indxExt.";
libname ipvw  "&ipvw.";
libname ipvwtm  "&ipvw./tmp";



*import useful simple utility macros;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ConformIp.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinipxw;
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./splitindxfiles.sas";
%include "&SASmac./read_sysparm.sas";

%macro code2manipulateclms(year=,pctsuffix=,cohrt=,pct=,part=,revcenters=,claims=,winyear=);
    %let winday=%sysevalf(&winyear.*365);
    **Pull winday window of clms assiciated with the index event date;
    proc sql;
        create table &cohrt.&pct._ip_clms as
            select *
            from iptmp.Samp&cohrt.&year. S, ipvw.ip&pct._clms_&year._&part.  C
            where (S.bene_id = C.bene_id) and
            (thru_dt ne .) and
            (from_dt ne .) and
            (from_dt >= S.dgn_date - &winday.) and
            ( (thru_dt - S.dgn_date) <= &winday. or (from_dt = S.dgn_date) )
        ;
        quit;

        %if  &revcenters. = yes %then %do;
        **Pull associated revenue centers for the clms pulled in the previous wave;
        proc sql;
            create table &cohrt.&pct._ip_revcntrs as
                select *
                from &cohrt.&pct._ip_clms (keep=diag_id dgn_date clm_id bene_id ehic) C,
                ipvw.ip&pct._revcntr_&year._&part.   R
                where (C.clm_id = R.clm_id) and (C.bene_id = R.bene_id);
            quit;
            %end;


    ************************************************************************;
    **    COMBINE HARMONIZED PARTS - APPEND IS FASTEST;
    ************************************************************************;
    %if  &revcenters. = yes %then %do;
        proc append base = iptmp.&cohrt.ip_revcntrs_&year.
                   data = &cohrt.&pct._ip_revcntrs force ;
        run;
        %end;

    %if  &claims. = yes %then %do;
        proc append base = iptmp.&cohrt.ip_clms_&year.
                    data = &cohrt.&pct._ip_clms force ;
        run;
        %end;
    %mend;


%macro appendYearFiles(cohrt=,pct=,start=,end=, clmDTA=0,revcenters=,claims=);
   ************************************************************************;
   ** Combine the CLMS  and dump the final extract to stata dta file;
   ************************************************************************;
    %if &claims. = yes %then %do;
        data ipex.&cohrt.&pct._ipclms;
            set %RepeatN(iptmp.&cohrt.ip_clms_,&start.,&end.);
        run;

        proc sql;
            select fileYear, count(fileYear) as clmCount
                from ipex.&cohrt.&pct._ipclms
                group by fileyear;
        run;
       %end;

   ************************************************************************;
   ** Combine the REVENUE CENTER and dump the final extract to stata dta file;
   ************************************************************************;
    %if &revcenters. = yes %then %do;
        data ipex.&cohrt.&pct._iprevcntrs;
            set %RepeatN(iptmp.&cohrt.ip_revcntrs_,&start.,&end.);
        run;

        proc sql;
            select fileyear, count(fileyear) as revCount
                from ipex.&cohrt.&pct._iprevcntrs
                group by fileyear;
        run;
        %end;

   ************************************************************************;
   ** SEND TO STAT-TRANSFER;
   ************************************************************************;
    %if &clmDTA.=1 %then %do;
        x "st &ipext./&cohrt.&pct._ipclms.sas7bdat
              &ipext./&cohrt.&pct._ipclms.dta -y -od -v &";
        x "st &ipext./&cohrt.&pct._iprevcntrs.sas7bdat
              &ipext./&cohrt.&pct._iprevcntrs.dta -y -od -v &";
        %end;
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;

%macro runprgIp(pct=, cohrt1=, cohrt2= ,cohrt3= ,cohrt4= ,cohrtN= , yearin=, yearout=, clmDTA=, crashStart=0, revcenters=, claims=, winyear=,note=);
*######################################################################;
*PRELIMINARIES:: PROGRAM SET UP;
*######################################################################;
    ** THROW ERROR FOR BAD PARAMETERS ;
    %errorCheckparameters(cohrt1=&cohrt1.,cohrtN=&cohrtN.,yearin=&yearin.,yearout=&yearout.,
        pct=&pct.,revcenters=&revcenters.,claims=&claims.,prgm=IP);

    ** Define macro variables for timing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());


    ********Deal with a crash if defined in the parameter - crashStart********;
    %do j=1 %to &cohrtN.;
    %if &crashStart.=&yearin. or &crashStart.=0 %then %do;
            proc datasets lib=iptmp NOLIST KILL;
            run;
            x "rm  &iptmp./* -f";
            %let beginLoop=&yearin.;
            %end;
        %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
    *Delete files no longer needed;
            proc datasets lib=iptmp;
                DELETE
                    %RepeatN(&&cohrt&j..ip_revcntrs_,&crashStart.,&yearout.)
                    %RepeatN(&&cohrt&j..ip_clms_,&crashStart.,&yearout.)
                    %RepeatN(Samp&&cohrt&j..,&crashStart.,&yearout.);
            run;
            %end;
        %end;

*######################################################################;
*BEGIN CALLING MACRO TO PROCESS CLAIMS;
*######################################################################;

    **---------------------------------------------------------------------------------------;
    ** 1:: BREAK UP THE INDEX FILE INTO SMALLER YEAR LEVEL DATA SETS USED TO IDENTIFY RELEVANT;
    **     BENEFICIARIES CLAIMS IN A LATER STEP;
    **---------------------------------------------------------------------------------------;
    %do j=1 %to &cohrtN.;
                %splitindxfiles(cohrt=&&cohrt&j..,begin=&yearin., end=&yearout.,
            pct=&pct.,outlib=iptmp,indxlib=indxex,winyear=&winyear.);

        %end;

    %do y= &beginLoop. %to &yearout. ;
        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;

         **---------------------------------------------------------------------------------------;
         ** 2:: CALL MACROS WHICH TELLS THE PROGRAM WHERE THE RAW DATA LIVES AND HOW MANY PARTS ;
         **     ARE FOUND IN THE DIRECTORY;
         **---------------------------------------------------------------------------------------;
         **This macro creates the num_file macro which is used to loop through each part below;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=ip,year=&y.,subtype=&stypem.,
                      pctsuffix=&suffix.);
         ** --- define libname for raw data :: directory differs by year and percent;
         ** ::: this directory is referenced by the sas views (data sets referenced by ipvw lib);
         libname spip "&dataRoot./&pct.pct/ip/&y./";

        %do z=1 %to &num_file.;
            %do j=1 %to &cohrtN.;
                **---------------------------------------------------------------------------------------;
                **3:: Extract window of claims for each beneficiaries index event  ;
                **---------------------------------------------------------------------------------------;
                %code2manipulateclms(year=&y.,pctsuffix=,cohrt=&&cohrt&j..,pct=&pct.,part=&z.,
                            revcenters=&revcenters.,claims=&claims.,winyear=&winyear.);
                %end;
            %end;
        %end;

        **---------------------------------------------------------------------------------------;
        **5:: Append temporary years files generated into a single file;
        **---------------------------------------------------------------------------------------;
        %do j=1 %to &cohrtN.;
             %appendYearFiles(cohrt = &&cohrt&j.., pct=&pct.,start=&yearin,end=&yearout.,
                              clmDTA=&clmDTA.,revcenters=&revcenters.,claims=&claims.);

             *****---------TIMER CODE ----------;
             %let tAfterRunCht=%sysfunc(datetime());
             %let elapsedcohrt=%sysevalf(%sysevalf((&tAfterRunCht.-&tBeforeRun.)/60));
             %put <TIMER> Total  &cohrt. took &elapsedcohrt. minutes.;

             ** Copy log and lst files, for archiving ;
             %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,yearin=&yearin.,yearout=&yearout.,note=&note.);
        %end;

        x "rm &iptmp./* -f &";

        ** ----------PRINT OUT FINAL RUN TIME-----------;
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put <TIMER> Process Years  ALL took &elapsedRun. minutes.;
    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgIp;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=N/A   -- This parameter is only used in the 1A and 1B programs ;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** winyear    -- Years to pull around indx event
*** clmDTA     -- Flag which pass SAS dataset to appendYearFilessfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
*** revcenters -- Indicates whether you want revenue centers to be extracted.;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;

         %runprgIp(pct=&pct.,
          cohrt1=&cohrt.,
          cohrtN=1,
          yearin=&yearin.,yearout=&yearout.,
          winyear=&winyear.,
          revcenters=yes,
          claims = yes,
          clmDTA=&clmDTA.,note=&note.        );


/*
********************************************************************************;
*** To run this file only or for testing comment out the above lines and;
*** make sure you fill in the correct parameters below;
********************************************************************************;

    %runprgIp(pct=05,
    cohrt1=chf428,
    cohrtN=1,
    yearin=2004,yearout=2011,
    revcenters=yes,
    claims = yes,
    clmDTA=1,winyear=1);

