**Extract index events and corresponding claims from the inpatients and SNF claims (MEDPAR);
**Maurice Dalton, daltonm.at.nber.org,  based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.  All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several sas macros which are combined in a macro which sequences the;
** macros correctly.This wrapper macro is found at the end of the program and has several ;
** different parameters defined at the end of the program;
**;
*!!!!WRAPPER MACRO FOUND AT THE END ---%RunDefineIndexEvents!!!!!;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./CreateXWmacro.sas";
%readinmedparxw;
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spden "&spden";
libname spxw "&inbenexw.";
libname medtmp "&medtmp.";
libname xwfile "&xwfile.";
libname here ".";
libname medex  "&medparExt.";
libname indxex "&indxExt.";
libname medvw  "&medvw4e.";
libname medvwtm  "&medvw4e./tmp";




%macro code2manipulateclms(start=,end=,cohrt=,pct=,winyear=,y=);
** This macro extracts the discharge records for the desired years;
** Recall that the medparclaims file has already processed the part of the files which we are ;
** going to use. Therefore all of the appropriate bene_ids have been assigned to an ehic, even in ;
** cases where a bene_id has more than 1 ehic.;

*********************************************************************************************************;
* DATA STEP 1: GRAB FINAL INDX EVENTS FROM CANDIDATE CLAIMS- ENFORCE THE WINDOW ON BOTH SIDE OF INDEX EVENT;
*********************************************************************************************************;
        ** set the name of the discharge date variable;
        * Choose claims with admissions on or after the diag date;
        * that have a claim end date at most 365 days after diag;
        * making an exception for a hospitalization beginning on;
        * the data of diag;
        * ;
        * NOTE: Some SNF visits have a missing discharge date owing to cases;
        *       where the patient remains a patient past the end of the claim.;
        *       In those cases, I determine the claim end date from the admit;
        *       date and the length of stay variable;
        *****************************************************************************************;
        %let windowdays=%sysevalf(&winyear.*365);
        %put CHECKDAY::&windowdays;

    proc sql _METHOD BUFFERSIZE=1048576 ;
            create table medtmp.claims&y. as
                select *
                from medvw.medpar&pct._&y. M
                where
                     (M.admsndt >= M.dgn_date - &windowdays.)
                     and (  ( (M.dschrgdt ne .) and ((M.dschrgdt - M.dgn_date) <= &windowdays.) )
                     or ( (M.dschrgdt = .) and
                        ((M.admsndt + M.loscnt - 1 - M.dgn_date) <= &windowdays.) )
                     or (M.admsndt = M.dgn_date) );
            quit;

    **************************************;
    **  COMBINE ALL YEARS;
    **************************************;
    %if &y. = &end. %then %do;
        %LabelVarsXw(outLabels=medLabels,filename=medparxw);
        data medtmp.&cohrt.&pct._medparclms;
            set %repeatN(medtmp.claims,&start.,&end);
            **Create place holders for variables defined within the program later;
            ep_indxNT=0;
            ambigOrder=0;
            label &medLabels. ;

        run;

        proc freq data=medtmp.&cohrt.&pct._medparclms;
            table fileyear dgn_year;
        run;

        x "rm &medtmp./claims* -f ";
        %end;
    %mend;


%macro FlagIndex_orderClaims(cohrt=,pct=,clmDTA=);
    ********************************************************************;
    **ORDER MEDPAR CLMS AND FLAG INDEX CLMS IN CLAIMS;
    ********************************************************************;
    ** Sorts files within diag episode in order to get them in chronological order;
    ** Sorting criteria are as follows, getting somewhat more speculative as numbers increase:;
    ** 1) Admit date;
    ** 2) Discharge date (with flag to ensure that missing discharge dates go at the end);
    ** 3) Admissions where the patient dies go after others;
    ** 4) Emergency admissions (identified one of two ways) go before non-emergency admissions;
    ** 5) Admissions where the source of admission is a transfer go after non-transfers.;
    ** 6) Admissions that have more procedure codes are assumed to come later;
    data medparclaim_flags2order;
        set medtmp.&cohrt.&pct._medparclms;
            **DEFINE FLAGS USED TO ORDER CLAIMS FILES;
            dschgMiss = (dschrgdt = .);
            transfer = (src_adms = "4");
            died = (dstntncd = "20");
            noEmerg1 = not (type_adm = "1");
            noEmerg2 = not (src_adms = "7");
            **NEED TO DROP THE PLACE HOLDER CREATED EARLIER IN THE CODE;
            drop ep_indxNT  ;

        * Want to be able to treat the discharge date as a claim end date;
        * so I replace the missing discharge dates using the length of stay;
        * variables;
        if dschrgdt = . then do;
            dschrgdt = admsndt + loscnt ;
            end;

        run;

    proc sort data=medparclaim_flags2order;
        by diag_id  admsndt  dschgMiss dschrgdt died noEmerg1 noEmerg2 transfer prcdrcnt;
    run;

    ******************************************************************;
    **First create flag for index events;
    ******************************************************************;
    proc sort data=medparclaim_flags2order;
        by diag_id medrawindx fileyear;
    run;

    proc sort data=indxex.&cohrt.&pct._indx (keep=diag_id medrawindx fileyear)
              out=indx4merge;
        by diag_id medrawindx fileyear;
    run;

    data medparclaim_indexclmsflag;
         merge medparclaim_flags2order (in=raw)
               indx4merge (in=indxfl ) ;
         by diag_id medrawindx fileyear;
         flagindx=indxfl;
         if raw;
         LABEL flagindx="Flag indicating the index event";
        run;

    ******************************************************************;
    **Next create sorted index events ;
    ******************************************************************;
    proc sort data=medparclaim_indexclmsflag;
        by diag_id  admsndt  dschgMiss dschrgdt died noEmerg1 noEmerg2 transfer prcdrcnt;
    run;

    ** Generate sorted index events;
    data medex.&cohrt.&pct._medparclms;
         set medparclaim_indexclmsflag;
        by diag_id  admsndt dschgMiss dschrgdt died noEmerg1 noEmerg2 transfer prcdrcnt;

       * nt stands for <<no ties>> (ties broken arbitrarily);
        retain ep_indx ep_indxNT 0;


        * flag ambiguous orderings;
        ambigOrder = 0;
        if not (first.prcdrcnt and last.prcdrcnt) then do;
            ambigOrder = 1;
            end;

        * flag orderings that are ambiguous if using only the dates and the death code;
        ambigOrder_dd = 0;
        if not (first.died and last.died) then do;
            ambigOrder_dd = 1;
            end;

        * impose orderings within diag episodes;
        if first.diag_id then do;
            ep_indx = 1;
            ep_indxNT = 1;
            end;
        else do;
            ep_indxNT = ep_indxNT + 1;
            if not ambigOrder then do;
                ep_indx = ep_indx + 1;
                end;
            end;

        drop dschgMiss transfer died noEmerg1 noEmerg2 ep_indx ambigOrder_dd;
    run;

    proc freq data=medex.&cohrt.&pct._medparclms;
        table fileyear dgn_year;
    run;

    %mend;

%macro DumpStatTransfer(cohrt=,pct=,clmDTA=);
    %if &clmDTA.=1 %then %do;
        x "st &medparExt./&cohrt.&pct._indx_coref.sas7bdat
              &medparExt./&cohrt.&pct._indx_corefdta -y -od &";

        x "st &medparExt./&cohrt.&pct._indx.sas7bdat
              &medparExt./&cohrt.&pct._indx.dta -y -od & ";

        x "st &medparExt./&cohrt.&pct._demo.sas7bdat
              &medparExt./&cohrt.&pct._demo.dta -y -od &";

        x "st &medparExt./&cohrt.&pct._medparclms.sas7bdat
              &medparExt./&cohrt.&pct._medparclms.dta -y -od &";

        x "st &medparExt./&cohrt.&pct._indxdemo.sas7bdat
              &medparExt./&cohrt.&pct._indxdemo.dta -y -od &";
        %end;
    %mend;



**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro PullMedParClaims(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrt6=,cohrt7=,
    cohrtN=,yearin=,yearout=,pct=,dflag=1,clmDTA=,winyear=,note=);
*######################################################################;
* PRELIMINARIES:: PROGRAM SET UP;
*######################################################################;
    ** THROW ERROR FOR BAD PARAMETERS ;
    %errorCheckparameters(cohrt1=&cohrt1.,cohrtN=&cohrtN.,yearin=&yearin.,yearout=&yearout.,
                          pct=&pct.,winyear=&winyear.,prgm=LongExtract);

    ** Define macro variables for timing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());

    *Make Sure we are starting with an empty dataset;
    x "rm &medtmp./* -f ";




*######################################################################;
* BEGIN CALLING MACRO TO PROCESS CLAIMS;
*######################################################################;
    %if &pct.<100 %then %do; sasfile spxw.ehicbenex_unique_bene_indx&pct. open; %end;
    %do y=&yearin. %to &yearout. ;
        %do j=1 %to &cohrtN.;
             **---------------------------------------------------------------------------------------;
             ** VIEWS READ IN INDEX FILES AND ONLY KEEP THOSE INDIVIDUALS. ;
             ** RENAME INDEX FILE SO THAT VIEW CAN FIND;
             ** variables needed in index file are  bene_id, dgn_date and diag_id (only bene_id is ;
             ** really needed) these are already defined;
             **---------------------------------------------------------------------------------------;
            **NOTE WE NEED TO INCLUDE ANY INDEX CLAIMS WHICH SHOW UP IN THE CLAIMS FILES MORE THEN 2 YEARS AFTER THEY WHERE BILLED.;
            ** SHOULD ONLY BE A PROBLEM FOR MEDPAR IN GENERAL.    ;
            data medtmp.indxfile (drop=fileyear);
                set indxex.&&cohrt&j..&pct._indx (keep=dgn_date bene_id diag_id ehic fileyear);
                WHERE ((year(dgn_date) >= %sysevalf(&y. - &winyear.)) and
                       (year(dgn_date) <= %sysevalf(&y. + &winyear.))) or
                       ( abs(year(dgn_date)-fileyear) >=2 )  ;
            run;

            **---------------------------------------------------------------------------------------;
            ** 1:: CALL MACRO WHICH AGGREGATES AND RENAMES THE MEDPAR FILE IN CASES WHERE THEIR ARE MANY PARTS;
            **---------------------------------------------------------------------------------------;
            libname spmed "&dataRoot./&pct.pct/med/&y./";

            **---------------------------------------------------------------------------------------;
            **2:: Extract window of claims for each beneficiaries index event  ;
            **---------------------------------------------------------------------------------------;
            %code2manipulateclms(start=&yearin.,end=&yearout.,cohrt=&&cohrt&j..,pct=&pct.,
                winyear=&winyear.,y=&y.);

            **delete raw file after all cohorts have been processed;
            %if &y.=&yearout. %then %do;
                ** flag index claim and cronologically order medpar clms;
                %FlagIndex_orderClaims(cohrt=&&cohrt&j..,pct=&pct.);
                ** convert to stat transfer at the end of loop;
                %DumpStatTransfer(cohrt=&&cohrt&j..,pct=&pct.,clmDTA=&clmDTA.);

            %end;
        %end;
    %end;
    %if &pct.<100 %then %do; sasfile spxw.ehicbenex_unique_bene_indx&pct. close; %end;
    *****---------TIMER CODE ----------;
    %let tAfterRun=%sysfunc(datetime());
    %let elapsedrun=%sysevalf(%sysevalf((&tAfterRun.-&tBeforeRun.)/60));
    %put <TIMER> FINAL  took &elapsedrun. minutes  ;

    *Copy log and lst files to folder with same name and attach date being run;
     %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&cohrtN..,yearin=&yearin.,
                yearout=&yearout.,note=&note.)               ;


     *REMOVE FILES USED LOCALLY;
     x "rm &medtmp./* -f ";
    %mend;



***********************Call Wrapper Program Below-***********************;
*WRAPPER MACRO DOCUMENTATION ;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running several;
***            -- (4 plus)the efficiently of the program maybe impacted. ;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in. Use .01% for debugging where possible;
***;
*** dflag      -- Set equal to one if you want to delete raw files as you run the program;

*** clmDTA     -- Set equal to one if you want to convert the all files into a stata format (DTA)*;
***;
*** winYear     -- Set equal the window of claims you want to pull around index event;
****************************************************************************************************;

%PullMedParClaims(cohrt1=&cohrt., cohrtN=1,   pct=&pct., yearin=&yearin.,  yearout=&yearout.,
                      clmDTA=&clmDTA., winyear=&winyear., dflag=1,note=&note.);



********************************************************************************;
*** To run this file only or for testing comment out the above lines and;
*** make sure you fill in the correct parameters below;
********************************************************************************;
/*
    %PullMedParClaims(pct=05,
    cohrt1=ami,
    cohrtN=1,
    yearin=1999,yearout=2011,
    clmDTA=1,winyear=1,dflag=1);

