**Extract a 1 year window from OP files for the final list of index events generated ;
**in the 1B program. The script reshape the revenue center codes in the earlier years;
*of the claims from a wide format into a long format. These are easier to work with ;
*and match the current format used by CMS;
**Maurice Dalton, daltonm.at.nber.org   based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.;
**All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which sequences them correctly.;
** This wrapper macro is found at the end of the program and has several different parameters defined below. The;
** wrapper mAcro program is found at the end. The parameters are defined at the end of the program. ;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
**ENABLEDIRECTIO USEDIRECTIO
* Defines local directories depending on which server currently running;
**ENABLEDIRECTIO USEDIRECTIO=yes TRANSFERSIZE=1M ;
libname here ".";
libname opex "&opext.";
libname optmp "&optmp.";
libname spxw "&inbenexw." ;
libname indxex "&indxExt.";
libname opvw  "&opvw4e.";
libname opvwtm  "&opvw4e./tmp";



*import macros usedin the creations of sas views for doc;
%include "&SASmac./ConformOp.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinopxw;
%include "&SASmac./CreateXWmacro.sas";
*macros used in the programs below;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "&SASmac./read_sysparm.sas";

** This macro loops over all of the subfiles for a given year, selects;
%macro code2manipulateclms(year=,pctsuffix=,cohrt=,pct=,part=,revcenters=,claims=,winyear=);
            x "rm &optmp./op_revcntrs_index.sas* -f";
            x "rm &optmp./op_clms_index.sas* -f";

    ************************************************************************;
    **           GRAB WINDOW OF CLAIMS DATA;
    ************************************************************************;
    **(obsbuf=100) options will speed view reading by sotring more in memory;
    **(bufsize=50K bufno=10);
    %let winday=%sysevalf(&winyear.*365);
    proc sql _METHOD BUFFERSIZE=2G ;
        create table optmp.op_clms_index   as
            select *
            from  opvw.op&pct._&year._clms_&part. C
            where
            (C.thru_dt ne .) and
            (C.from_dt ne .) and
            (C.from_dt >= C.dgn_date - &winday.) and
            ( (C.thru_dt - C.dgn_date) <= &winday. or (C.thru_dt = C.dgn_date) )
            ;
        quit;

    ************************************************************************;
    **    GRAB REVENUE CENTERS ASSOCAITED WITH CLAIMS PULLED IN 00BEFOREHAND;
    ************************************************************************;

    %if  &revcenters. = yes %then %do;
            proc sql _METHOD BUFFERSIZE=2G ;
            create view optmp.op_revcntrs_index  as
                select  C.diag_id , C.dgn_date, C.bene_id, C.ehic , R.*
                from opvw.op&pct._&year._revcntrs_&part.  (drop=bene_id ehic ) R,
                     optmp.op_clms_index C
                WHERE C.diag_id = R.diag_id and C.clm_id = R.clm_id and
                      C.fileyear = R.fileyear and C.part = R.part
                            ;
            quit;
        %end;
    ************************************************************************;
    **    COMBINE HARMONIZED PARTS - APPEND IS FASTEST;
    ************************************************************************;
    %if  &claims. = yes %then %do;
        proc append base = optmp.&cohrt.op_clms_&year.
                    data = optmp.op_clms_index  force ;
        run;

        %end;
    %if  &revcenters. = yes %then %do;
        **(obsbuf=100) options will speed view reading by sotring more in memory;
        proc append base = optmp.&cohrt.op_revcntrs_&year.
                   data = optmp.op_revcntrs_index  force ;
        run;

        %end;

            x "rm &optmp./op_revcntrs_index.sas* -f";
            x "rm &optmp./op_clms_index.sas* -f";
    %mend;


%macro appendYearFiles(cohrt=,pct=,start=,end=,clmDTA=0,revcenters=,claims=);
   ************************************************************************;
   ** Combine the CLMS  and dump the final extract to stata dta file;
   ************************************************************************;
    %if &claims. = yes %then %do;
        data opex.&cohrt.&pct._opclms;
            set %RepeatN(optmp.&cohrt.op_clms_,&start.,&end.);
        run;

        proc sql;
            select fileyear, count(fileyear) as clmCount
                from opex.&cohrt.&pct._opclms
                group by fileyear;
        run;

        %end;

   ************************************************************************;
   ** Combine the REVENUE CENTER and dump the final extract to stata dta file;
   ************************************************************************;
    %if &revcenters. = yes %then %do;
        data opex.&cohrt.&pct._oprevcntrs;
            set %RepeatN(optmp.&cohrt.op_revcntrs_,&start.,&end.);
        run;

        proc sql;
            select fileyear, count(fileyear) as revCount
                from opex.&cohrt.&pct._oprevcntrs
                group by fileyear;
        run;
        %end;

   ************************************************************************;
   ** SEND TO STAT-TRANSFER;
   ************************************************************************;
    %if &clmDTA.=1 %then %do;
        x "st &opext./&cohrt.&pct._opclms.sas7bdat
              &opext./&cohrt.&pct._opclms.dta -y -od -v &";
        x "st &opext./&cohrt.&pct._oprevcntrs.sas7bdat
              &opext./&cohrt.&pct._oprevcntrs.dta -y -od -v &";
        %end;
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro runprgOp(pct =, cohrt1 =, cohrt2 =, cohrt3 =, cohrt4 =, cohrtN =, yearin =, yearout =,
                clmDTA = 0, crashStart = 0, revcenters = yes, claims = yes, winyear =,note=);

*######################################################################;
* PRELIMINARIES:: PROGRAM SET UP;
*######################################################################;

    ** THROW ERROR FOR BAD PARAMETERS ;
    %errorCheckparameters(cohrt1=&cohrt1.,cohrtN=&cohrtN., yearin=&yearin.,yearout=&yearout.,
                          pct=&pct.,revcenters=&revcenters.,claims=&claims.,prgm=OP);
    ** Define macro variables for timing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());

    ********Deal with a crash if defined in the parameter - crashStart********;
    %do j=1 %to &cohrtN.;
        %if &crashStart.=&yearin. or &crashStart.=0 %then %do;

            proc datasets lib=optmp NOLIST KILL;
            run;

            x "rm &optmp./* -f" ;

            %let beginLoop=&yearin.;
            %end;
        %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
            ** Delete files no longer needed;
            proc datasets lib=optmp;
                DELETE
                    %RepeatN(&&cohrt&j..op_revcntrs_,&crashStart.,&yearout.)
                    %RepeatN(&&cohrt&j..op_clms_,&crashStart.,&yearout.)
            run;
            %end;
        %end;

*######################################################################;
* BEGIN CALLING MACRO TO PROCESS CLAIMS;
*######################################################################;
       **read sas file into memory;
    %if &pct.<100 %then %do; sasfile spxw.ehicbenex_unique_bene_indx&pct. open; %end;

    %do y= &beginLoop. %to &yearout. ;
        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;
        **---------------------------------------------------------------------------------------;
        ** 1:: CALL MACROS WHICH TELLS THE PROGRAM WHERE THE RAW DATA LIVES AND HOW MANY PARTS ;
        **     ARE FOUND IN THE DIRECTORY;
        **---------------------------------------------------------------------------------------;

        **This macro creates the num_file macro which is used to loop through each part below;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.,subtype=&stypem.,
                      pctsuffix=&suffix.);
         ** --- define libname for raw data :: directory differs by year and percent;
         ** ::: this directory is referenced by the sas views (data sets referenced by opvw lib);
          libname spop "&dataRoot./&pct.pct/op/&y./";

          %do j=1 %to &cohrtN.;

            data optmp.indxfile (drop=fileyear);
                set indxex.&&cohrt&j..&pct._indx (keep=dgn_date bene_id diag_id ehic fileyear);
                WHERE ((year(dgn_date) >= %sysevalf(&y. - &winyear.)) and
                      (year(dgn_date) <= %sysevalf(&y. + &winyear.))) or
                      ( abs(year(dgn_date)-fileyear) >=2 )  ;
            run;
            *read sas file into memory;
            sasfile optmp.indxfile open;
            %do z=1 %to &num_file.;

            **---------------------------------------------------------------------------------------;
            **2:: Extract window of claims for each beneficiaries index event  ;
            **---------------------------------------------------------------------------------------;
                **---------------------------------------------------------------------------------------;
                **     VIEWS READ IN INDEX FILES AND ONLY KEEP THOSE INDIVIDUALS. ;
                **     RENAME INDEX FILE SO THAT VIEW CAN FIND;
                **     variables needed in index file are  bene_id, dgn_date and diag_id (only bene_id;
                **     is really needed) these are already defined;
                **---------------------------------------------------------------------------------------;
                %code2manipulateclms(year = &y., pctsuffix =, cohrt = &&cohrt&j.., pct = &pct., part = &z.,
                            revcenters = &revcenters., claims = &claims., winyear = &winyear.);
                %end;
            *close sas file from memory;
            sasfile optmp.indxfile close;
            %end;
        %end;
    %if &pct.<100 %then %do; sasfile spxw.ehicbenex_unique_bene_indx&pct. close; %end;
    **---------------------------------------------------------------------------------------;
    **4:: Append temporary years files generated into a single file;
    **---------------------------------------------------------------------------------------;
    %do j=1 %to &cohrtN.;

        %appendYearFiles(cohrt = &&cohrt&j.., pct = &pct.,  start = &yearin, end = &yearout.,
            clmDTA = &clmDTA., revcenters = &revcenters., claims = &claims.);


       *****---------TIMER CODE ----------;
        %let tAfterRunCht=%sysfunc(datetime());
        %let elapsedcohrt=%sysevalf(%sysevalf((&tAfterRunCht.-&tBeforeRun.)/60));
        %put <TIMER> Total  &&cohrt&j.. took &elapsedcohrt. minutes.;

        ** Copy log and lst files, gip for archiving ;
        %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,yearin=&yearin.,yearout=&yearout.,note=&note.);
        %end;

    x "rm &optmp./* -f ";

    ** ----------PRINT OUT FINAL RUN TIME-----------;
    %let rundone=%sysfunc(datetime());
    %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
    %put TIMER END run at time &elapsedrun.;

    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgOp;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** clmDTA     -- Flag which pass SAS dataset to appendYearFilessfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
*** revcenters -- Indicates whether you want revenue centers to be extracted.;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;


*This runs the program;

%runprgOp(pct=&pct.,
          cohrt1=&cohrt.,
          cohrtN=1,
          yearin=&yearin.,yearout=&yearout.,
          revcenters=yes,
          claims = yes,
          clmDTA=&clmDTA.,
          winyear=&winyear.,note=&note. );



/*
********************************************************************************
*** To run this file only or for testing comment out the above lines and;
*** make sure you fill in the correct parameters below;
********************************************************************************;

    %runprgOp((pct=05,
    cohrt1=ami,
    cohrtN=1,
    yearin=1999,yearout=2011,
    revcenters=yes,
    claims = yes,
    clmDTA=1,winyear=1,dflag=1);


