/*
Reshape2CCS.sas;
The probgrams reshapes the inpatient data into a long format and applies the CCS categories to
the procedure codes. Finally the programs aggregates the claims upto the index CCS level.
*/

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

*****PRELIMINARIES************;
** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";


* define libraries;
* define libraries;
libname medEx  "&medparExt.";
libname indxex "&indxExt.";
libname spcar "&spcar.";
libname carEx   "&carExt.";
libname OpEx   "&OpExt.";
libname procs   "&proc.";
libname ccsext   "&ccsext.";
libname betoxw ".";

%macro readinCCSxw;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";

x "dos2unix -437   ./xwalks/single/$prref 2013.csv";
data singleCCScw;
        infile "./xwalks/single/$prref 2013.csv" MISSOVER DSD delimiter=","  LRECL=32767 FIRSTOBS=2  ;

        informat  icd9cm $4.
                  ccs  $3.
                  ccsdes  $50.
                  icd9des  $1.;

              input
                  icd9cm $
                  ccs  $
                  ccsdes  $
                  icd9des  $;
              drop icd9des;
    run;
    proc print data=singleCCScw (obs=10);run;

    x  "dos2unix  -437 ./xwalks/multi/ccs_multi_pr_tool_2013.csv ";
data multiCCScw;
        infile "./xwalks/multi/ccs_multi_pr_tool_2013.csv"  MISSOVER DSD delimiter=","  LRECL=32767 FIRSTOBS=2  ;

        informat  icd9cm $4.
                  ccs1  $5.
                  ccs1des  $50.
                  ccs2  $5.
                  ccs2des  $50.
                  ccs3  $5.
                  ccs3des  $50.;

              input
                  icd9cm $
                  ccs1  $
                  ccs1des  $
                  ccs2  $
                  ccs2des  $
                  ccs3  $
                  ccs3des  $;
    run;

    proc print data=multiCCScw (obs=10);run;
%mend;


%macro OutPatProcess(year=,cohrt=,pct=,sampleRule=,id=);
*The outpatient claims files need to be reshaped because they list several procedure per claim. Hence the first part of this macro ;
*goes through and basically creates a new dataset which tags any of the procedure we are interested in from a particular claim. These files can later;
*be used to identify which claims have a procedure of interests;


***********************************************;
*************OP-CLMS***************************;
***********************************************;

    data OPLongForCC (drop=dgnscd1-dgnscd10 prcdrcd1-prcdrcd6);
        length prcdrcd $4;
        set OpEx.&cohrt.&pct._opclms
             (keep =  bene_id dgn_date  dgn_date from_dt thru_dt  dgnscd: prcdrcd:  ) ;
        WHERE from_dt >= dgn_date  ;

        array dgnscdar{1:10} dgnscd1-dgnscd10;
        array prcdrcdar{1:6} prcdrcd1-prcdrcd6;
        length dgnscd $6 prcdrcd $4;
        do i=1 to 6;
            indx=i;
            dgnscd = dgnscdar{i};
            prcdrcd = prcdrcdar{i};
            * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
            prcdrcd=compress(prcdrcd,,'s');
            * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            prcdrcd=compbl(prcdrcd);
            *if dgnscd ne "" or prcdrcd ne "" then output;
            end;
        do i=7 to 10;
            indx=i;
            dgnscd = dgnscdar{i};
           * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
           * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            *if dgnscd ne "" or prcdrcd ne "" then output;
            end;
    run;

    proc sort data=OPLongForCC;
        by prcdrcd;
    run;

    proc sort data=singleCCScw;
        by icd9cm;
    run;

    data &cohrt.&pct._opcCCSsingl;
        merge singleCCScw OPLongForCC (rename=(prcdrcd=icd9cm) in=clms);
        by icd9cm;
        if clms;
        clm_year=year(from_dt);
    run;

    proc sort data=&cohrt.&pct._opcCCSsingl;
        by clm_year ccs;
    run;


    data ccsext.&cohrt.&pct._opc_ccs_singl_count (keep=ccs ccsdes countccs clm_year );
        set &cohrt.&pct._opcCCSsingl ;
        by clm_year ccs;
        retain countccs 0;
        if first.ccs  then countccs=0;
        countccs=countccs+1;
        if last.ccs then output;
    run;

    x "st &ccsext./&cohrt.&pct._opc_ccs_singl_count.sas7bdat &ccsext./&cohrt.&pct._opc_ccs_singl_count.dta -Y";

    proc sort data=multiCCScw;
        by icd9cm;
    run;

    proc contents data=OPLongForCC;
    run;
    proc contents data=multiCCScw;
    run;


    data &cohrt.&pct._opcCCSmult;
        merge multiCCScw(in=xw) OPLongForCC (rename=(prcdrcd=icd9cm) in=clms);
        by icd9cm ;
        if clms ;
        inclm=clm;
        inxw=xw;
        clm_year=year(from_dt);
    run;

    proc sort data=&cohrt.&pct._opcCCSmult;
        by clm_year ccs1;
    run;

    TITLE "BEFPRE AGG";
    proc freq data=&cohrt.&pct._opcCCSmult;
        table clm_year;
    run;


    data ccsext.&cohrt.&pct._opc_ccs_mult_count (keep=ccs1 ccs1des countccs1 clm_year );
        set &cohrt.&pct._opcCCSmult ;
        by clm_year ccs1;
        retain countccs1 0;
        if first.ccs1  then countccs1=0;
        countccs1=countccs1+1;
        if last.ccs1 then output;
    run;

    TITLE "AFTER AGG";
    proc print data=ccsext.&cohrt.&pct._opc_ccs_mult_count;
        where clm_year >2006;
    run;
    proc freq data=ccsext.&cohrt.&pct._opc_ccs_mult_count;
        table clm_year;
    run;

    x "st &ccsext./&cohrt.&pct._opc_ccs_mult_count.sas7bdat &ccsext./&cohrt.&pct._opc_ccs_mult_count.dta -Y";

    %mend;

*******CARRIER****************************************;
%macro CarProcess(year=,cohrt=,pct=,sampleRule=,id=);

    proc sort data=betoxw.betoxw;
        by betos ;
    run;

    proc sort data=betoxw.betos_names;
        by betos ;
    run;

    data betoxw;
    merge betoxw.betoxw  betoxw.betos_names;
    by betos;
    run;


    proc sort data=betoxw;
        by year hcpcs_cd;
    run;

    proc contents data=carEx.&cohrt.&pct._carlnits;run;

    data carclms;
        set carEx.&cohrt.&pct._carlnits (keep=fileyear clmstatus betos sexpndt1 sexpndt2 dgn_date bene_id hcpcs_cd lalowchg);
        clm_yr=year(sexpndt1);
        if trim(clmstatus) = "0" then delete;
    run;

    proc sort data=carclms;
        by clm_yr  hcpcs_cd;
    run;
/*
    proc sql;
    create table test as
        select *
        from carclms  S LEFT JOIN betoxw.betoxw  M
        ON  (S.clm_yr = M.clm_yr AND S.hcpcs_cd  = M.hcpcs_cd  );
    quit;
*/


    data  betogroup_aggregation  ;
        merge carclms ( in=carclms)
              betoxw (    in = xw
                             rename = (betos=betosxw year=clm_yr));
        by clm_yr hcpcs_cd;
        if carclms;
        incar=carclms;
        inxw=xw;
        if betos ="" then betos=betosxw;
        if substr(betos,1,1) ="M" then betosgroup="EvalManage";
        if substr(betos,1,1) ="P" then betosgroup="procedure";
        if substr(betos,1,1) ="I" then betosgroup="imaging";
        if substr(betos,1,1) ="T" then betosgroup="tests";
        if substr(betos,1,1) ="D" then betosgroup="DME";
        if substr(betos,1,1) ="O" then betosgroup="other";
        if substr(betos,1,1) ="Y" then betosgroup="unclass";
        if substr(betos,1,1) ="Z" then betosgroup="unclass";
        clm_yr=year(sexpndt1);
    run;

    proc freq data=betogroup_aggregation;
        WHERE incar=1 and inxw=0;
       table hcpcs_cd betos / missing;
    run;

    proc sql;
    create table betogroup_aggregation as
        select *, count(*) as countyear, sum(lalowchg) as costyear
        from betogroup_aggregation
        GROUP BY clm_yr;
    quit;

    proc freq data=betogroup_aggregation;
        table clm_yr*betosgroup /nopercent nocol norow missing;
    run;

    proc sort data=betogroup_aggregation;
        by clm_yr betosgroup ;
    run;


    data ccsext.&cohrt.&pct._betogroupaggAll (drop=sexpndt1 betos fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        by clm_yr betosgroup;
        retain countbetos betocost 0;
        if first.betosgroup then countbetos=0;
        if first.betosgroup then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;
        if last.betosgroup then output;
    run;

    data ccsext.&cohrt.&pct._betogroupagg30d (drop=sexpndt1 betos fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) <= 30 and (sexpndt1 - dgn_date) >=0;
        by clm_yr betosgroup;
        retain countbetos betocost 0;
        if first.betosgroup then countbetos=0;
        if first.betosgroup then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;
        if last.betosgroup then output;
    run;


    data ccsext.&cohrt.&pct._betogroupaggAfter (drop=sexpndt1 betos fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) >=0;
        by clm_yr betosgroup;
        retain countbetos betocost 0;
        if first.betosgroup then countbetos=0;
        if first.betosgroup then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;
        if last.betosgroup then output;
    run;

    data ccsext.&cohrt.&pct._betogroupaggBefore (drop=sexpndt1 betos fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) < 0;
        by clm_yr betosgroup;
        retain countbetos betocost 0;
        if first.betosgroup then countbetos=0;
        if first.betosgroup then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;
        if last.betosgroup then output;
    run;

        proc print data=ccsext.&cohrt.&pct._betogroupagg;run;
    x "st &ccsext./&cohrt.&pct._betogroupagg.sas7bdat &ccsext./&cohrt.&pct._betogroupagg.dta -Y";


    proc sort data=betogroup_aggregation;
        by bene_id sexpndt1 sexpndt2 betos ;
    run;

    data dedupe_betosday;
        set betogroup_aggregation ;
        WHERE  (sexpndt1 - dgn_date) >=0;
        by bene_id sexpndt1 sexpndt2 betos;
        retain costbucket 0;
        if first.betos then costbucket=0;
        if lalowchg ne . then costbucket=lalowchg+costbucket;
        if last.betos then output;
    run;

    proc print data=dedupe_betosday;
        where bene_id="mmmmmmmDUXsaWDU" and betos="I2B";
    run;

    proc sort data=dedupe_betosday;
        by bene_id betos;
    run;


    data ccsext.&cohrt.&pct._beto_bene_id (drop=sexpndt1 fileyear clmstatus   hcpcs_cd lalowchg costbucket);
        set dedupe_betosday;
        by bene_id betos;
        retain countbetos betocost 0;
        if first.betos then countbetos=0;
        if first.betos then betocost=0;
        if lalowchg ne . then betocost=costbucket+betocost;
        countbetos=countbetos+1;
        if last.betos then output;
    run;

    proc sort data=betogroup_aggregation;
        by clm_yr betos ;
    run;

    data ccsext.&cohrt.&pct._betoaggall (drop=sexpndt1 fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) <= 30 and (sexpndt1 - dgn_date) >=0;
        by clm_yr betos;
        retain countbetos betocost countyear costyear 0;
        if first.betos then countbetos=0;
        if first.betos then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;

        if last.betos then output;
    run;

    data ccsext.&cohrt.&pct._betoaggd30 (drop=sexpndt1 fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) <= 30 and (sexpndt1 - dgn_date) >=0;
        by clm_yr betos;
        retain countbetos betocost countyear costyear 0;
        if first.betos then countbetos=0;
        if first.betos then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;

        if last.betos then output;
    run;

    data ccsext.&cohrt.&pct._betoaggBefore (drop=sexpndt1 fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) < 0;
        by clm_yr betos;
        retain countbetos betocost countyear costyear 0;
        if first.betos then countbetos=0;
        if first.betos then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;

        if last.betos then output;
    run;

    data ccsext.&cohrt.&pct._betoaggAfter (drop=sexpndt1 fileyear clmstatus betos dgn_date bene_id hcpcs_cd);
        set betogroup_aggregation;
        WHERE (sexpndt1 - dgn_date) >= 0;
        by clm_yr betos;
        retain countbetos betocost countyear costyear 0;
        if first.betos then countbetos=0;
        if first.betos then betocost=0;
        if lalowchg ne . then betocost=lalowchg+betocost;
        countbetos=countbetos+1;

        if last.betos then output;
    run;



    proc print data=ccsext.&cohrt.&pct._betoagg;run;
    x "st &ccsext./&cohrt.&pct._betoagg.sas7bdat &ccsext./&cohrt.&pct._betoagg.dta -Y";


    %mend;


%macro MedparProcess(cohrt=,DGNMX=,pct=,sampleRule=,id=);

 *************MEDPAR***************************;
    ** Need to reshape the claim files from long to wide because there are several procedures reported per claims, however;
    ** first I need to make an index of every observation in the claims dataset so that it can be reshaped;


    data tempmed;
        set medex.&cohrt.&pct._medparclms;
        stayCost = drgprice + outlramt ;
        if dschrgdt<mdy(10,1,1988) then stayCost = stayCost + ime_amt ;
        if passthru ne . then stayCost = stayCost +  passthru;
    run;

    proc sql;
    create table medpar as
        select *, count(*) as countyear, sum(stayCost) as costyear
        from tempmed
        GROUP BY diag_year;
    quit;


    data LongForCC (drop=dgnscd1-dgnscd10 prcdrcd1-prcdrcd6);
        set medpar
             (keep = diag_year  bene_id dgn_date  dgn_date admsndt dschrgdt dgnscd: prcdrcd:  diag_year costyear countyear stayCost) ;
        WHERE admsndt >= dgn_date ;


        array dgnscdar{1:10} dgnscd1-dgnscd10;
        array prcdrcdar{1:6} prcdrcd1-prcdrcd6;
        length dgnscd $6 prcdrcd $4;
        do i=1 to 6;
            indx=i;
            dgnscd = dgnscdar{i};
            prcdrcd = prcdrcdar{i};
            * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
            prcdrcd=compress(prcdrcd,,'s');
            * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            prcdrcd=compbl(prcdrcd);
            clm_year=year(admsndt);
            if dgnscd ne "" or prcdrcd ne "" then output;
            end;
        do i=7 to 10;
            indx=i;
            dgnscd = dgnscdar{i};
           * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
           * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            clm_year=year(admsndt);
            if dgnscd ne "" or prcdrcd ne "" then output;
            end;
    run;

    proc sort data=singleCCScw;
        by icd9cm;
    run;

    proc sort data=LongForCC;
        by prcdrcd;
    run;

    proc contents data=singleCCScw; run;
    proc contents data=LongForCC; run;

    proc sql;
    create table &cohrt.&pct._mpcCCSsingl as
        select *
        from singleCCScw  S, LongForCC (rename=(prcdrcd=icd9cm) )  M
        WHERE S.icd9cm=M.icd9cm ;
    quit;


    proc sort data=&cohrt.&pct._mpcCCSsingl;
        by clm_year ccs;
    run;


    data ccsext.&cohrt.&pct._medpar_ccs_singl_count (keep=ccs ccsdes countccs clm_year costyear countyear countccs sumccscost);
        set &cohrt.&pct._mpcCCSsingl ;
        by clm_year ccs  ;
        retain countccs sumccscost 0;

        if first.ccs  then countccs=0;
        if first.ccs  then sumccscost=0;
        sumccscost=stayCost+sumccscost;
        countccs=countccs+1;
        if last.ccs   then output;
    run;


    x "st &ccsext./&cohrt.&pct._medpar_ccs_singl_count.sas7bdat &ccsext./&cohrt.&pct._medpar_ccs_singl_count.dta -Y";

*****************************************************************;

    proc sort data=multiCCScw;
        by icd9cm;
    run;

    data &cohrt.&pct._mpcCCSmult;
        merge multiCCScw (in=cw) LongForCC (rename=(prcdrcd=icd9cm) in=clms);
        by icd9cm;
        if clms and cw;
        clm_year=year(admsndt);
    run;

    proc sort data=&cohrt.&pct._mpcCCSmult;
        by clm_year ccs1;
    run;


    data ccsext.&cohrt.&pct._medpar_ccs_mult_count (keep=ccs1 ccs1des countccs1 clm_year costyear countyear countccs1 sumccscost);
        set &cohrt.&pct._mpcCCSmult ;
        by clm_year ccs1  ;
        retain countccs1 sumccscost 0;
        if first.ccs  then countccs=0;
        if first.ccs1  then sumccscost=0;
        sumccscost=stayCost+sumccscost;
        countccs1=countccs1+1;
        if last.ccs1   then output;
    run;

    proc sort data=&cohrt.&pct._mpcCCSmult;
        by clm_year ccs3;
    run;

    data ccsext.&cohrt.&pct._medpar_ccs3_mult_count (keep=ccs3 ccs3des countccs3 clm_year costyear countyear countccs3 sumccscost );
        set &cohrt.&pct._mpcCCSmult ;
        by clm_year ccs3  ;
        retain countccs3 sumccscost 0;
        if first.ccs3  then countccs3=0;
        if first.ccs3  then sumccscost=0;
        sumccscost=stayCost+sumccscost;
        countccs3=countccs3+1;
        if last.ccs3   then output;
    run;

    x "st &ccsext./&cohrt.&pct._medpar_ccs_singl_count.sas7bdat &ccsext./&cohrt.&pct._medpar_ccs_singl_count.dta -Y";
    %mend;

%macro MedparProviderType(cohrt=,DGNMX=,pct=,sampleRule=,id=);

 *************MEDPAR***************************;
    ** Need to reshape the claim files from long to wide because there are several procedures reported per claims, however;
    ** first I need to make an index of every observation in the claims dataset so that it can be reshaped;


    data tempmed;
        set medex.&cohrt.&pct._medparclms;
        stayCost = drgprice + outlramt ;
        if dschrgdt<mdy(10,1,1988) then stayCost = stayCost + ime_amt ;
        if passthru ne . then stayCost = stayCost +  passthru;
        hosptype="other";
        if is_cah=1 then hosptype="cah";
        if is_longhosp=1 then hosptype="long";
        if is_psychhosp=1 then hosptype="psych";
        if is_rehabhosp=1 then hosptype="rehab";
        if is_shorthosp=1 then hosptype="short";
        if is_snf=1 then hosptype="SNF";

    run;

    proc sql;
    create table medpar as
        select *, count(*) as countyear, sum(stayCost) as costyear
        from tempmed
        GROUP BY diag_year,hosptype;
    quit;

    proc contents data=medpar;run;
    data LongForCC (drop=dgnscd1-dgnscd10 prcdrcd1-prcdrcd6);
        set medpar
             (keep = diag_year  bene_id dgn_date  dgn_date admsndt dschrgdt dgnscd: prcdrcd:  diag_year costyear countyear stayCost hosptype is_cah  is_longhosp  is_psychhosp is_rehabhosp  is_shorthosp is_snf  ) ;
        WHERE admsndt >= dgn_date ;


        array dgnscdar{1:10} dgnscd1-dgnscd10;
        array prcdrcdar{1:6} prcdrcd1-prcdrcd6;
        length dgnscd $6 prcdrcd $4;
        do i=1 to 6;
            indx=i;
            dgnscd = dgnscdar{i};
            prcdrcd = prcdrcdar{i};
            * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
            prcdrcd=compress(prcdrcd,,'s');
            * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            prcdrcd=compbl(prcdrcd);
            clm_year=year(admsndt);
            if dgnscd ne "" or prcdrcd ne "" then output;
            end;
        do i=7 to 10;
            indx=i;
            dgnscd = dgnscdar{i};
           * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
           * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            clm_year=year(admsndt);
            if dgnscd ne "" or prcdrcd ne "" then output;
            end;
    run;

    proc sort data=singleCCScw;
        by icd9cm;
    run;

    proc sort data=LongForCC;
        by prcdrcd;
    run;

    proc contents data=singleCCScw; run;
    proc contents data=LongForCC; run;


*****************************************************************;

    proc sort data=multiCCScw;
        by icd9cm;
    run;

    data &cohrt.&pct._mpcCCSmult;
        merge multiCCScw (in=cw) LongForCC (rename=(prcdrcd=icd9cm) in=clms);
        by icd9cm;
        if clms and cw;
        clm_year=year(admsndt);
    run;

    proc sort data=&cohrt.&pct._mpcCCSmult;
        by clm_year hosptype ccs3;
    run;


    data ccsext.&cohrt.&pct._medpar_ccs3_prov (keep=ccs3 ccs3des countccs3 clm_year costyear countyear countccs3 sumccscost hosptype);
        set &cohrt.&pct._mpcCCSmult ;
        by clm_year hosptype ccs3  ;
        retain countccs3 sumccscost 0;
        if first.ccs3  then countccs3=0;
        if first.ccs3  then sumccscost=0;
        sumccscost=stayCost+sumccscost;
        countccs3=countccs3+1;
        if last.ccs3   then output;
    run;

    /*x "st &ccsext./&cohrt.&pct._medpar_ccs_singl_count.sas7bdat &ccsext./&cohrt.&pct._medpar_ccs_singl_count.dta -Y";*/
    %mend;


%macro RunProgram(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrtN=,pct=);
    %readinCCSxw;
    %do j=1 %to &cohrtN.;
        *%OutPatProcess(cohrt=&&cohrt&j..,pct=&pct.);
        *%MedparProcess(cohrt=&&cohrt&j..,pct=&pct.);
        %CarProcess(cohrt=&&cohrt&j..,pct=&pct.);


        %end;
    %mend;
/****************************************************************************************************************;
**********CALL THE PROGRAM BY DEFINING THE FOLLOWING WRAPPER PROGRAMS******************************************;
** cohrt1     = Defines the first cohort to loop through;
** cohrt2     = Defines the second cohort to loop through;
** ....

** cohrtN     = The number of cohorts defined.
*
** pct        = The percent of interest
***************************************************************************************************************;
***************************************************************************************************************;
*/
%RunProgram(cohrt1=ami,cohrt2=hip,cohrt3=chf428,cohrtN=3,pct=05);
*%RunProgram(cohrt1=ami,cohrtN=1,pct=05);

