************************************************************************************;
** COMORBIDITY CODING PROGRAM--hierarchical condition categories (CC);/*
***
*** The code below merges in the CCs with the diagnosis from the MedPAR file.
*** It then proceeds to code in and label the CCs. Then it aggregates the
*** CC following a paper by Krumholz(2007) available on-line at www.qualitynet.org. Note that in that
*** paper they use HCCs. However in a later revision (2008) they decided to use the CC
*** because they were risk adjusting mortality rates and the hierarchies are imposed to
*** help ensure we risk adjust for the most severe/costly comorbidity when applying the risk adjustment;
*** to costs, as CMS does. Currently the code runs the CCs however you simply need to include the  hierarchies
*** which are commented to convert them to HCCs
***
*** Maurice Dalton (dalton at nber) ***************************************
************************************************************************************;
    */

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";

* define libraries;
libname medex  "&medparExt.";
libname indxex "&indxExt.";
libname comorb   "&comorb.";
libname CCdir   "&CC.";
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./read_sysparm.sas";

%macro DefineComorid;
        *Define Cardiovascular Definitions;
        *Following the approach of Krumholz paper;
    card_amiG1=0;
    IF dgnscd IN ('4100','4101') THEN card_amiG1=1;

    card_amiG2=0;
    IF dgnscd IN ('4102','4103','4104','4105','4106') THEN card_amiG2=1;

        *Define heart failure;
    card_hf=0;
    IF CC80=1 then card_hf=1;

        *Define myocardial infarction;
    card_mi=0;
    IF CC81=1 then card_mi=1;

            *Define unstable angina;
    card_ua=0;
    IF CC82=1 then card_ua=1;

            *Define chronic atherosclerosis;
    card_cathero=0;
    IF CC83=1 or CC84=1 then card_cathero=1;

            *Define respiratory failure;
    card_respFal=0;
    IF CC79=1  then card_respFal=1;

            *Define hypertensive heart disease;
    card_hyperhd=0;
    IF CC90=1  then card_hyperhd=1;

            *Define Valvular heart disease;
    card_valve=0;
    IF CC86=1  then card_valve=1;

            *Define arrhythmia---CHECK;
    card_arrhythmia=0;
    IF CC92=1 or CC93=1  then card_arrhythmia=1;

***START DEFINING COMORBIDITIES;
                *Define hypertension;
    como_hyper=0;
    IF CC89=1 or CC91=1  then como_hyper=1;

    como_stroke=0;
    IF CC95=1 or CC96=1  then como_stroke=1;

*Cerebovascular disease;
    como_cervas=0;
    IF CC97=1 or CC98=1 or CC99=1 or CC103=1  then como_cervas=1;


*Renal Failure disease;
    como_renal=0;
    IF CC131=1  then como_renal=1;

*Dialysis;
    como_dialysis=0;
    IF CC130=1  then como_dialysis=1;


                *COPD;
    como_COPD=0;
    IF CC108=1  then como_COPD=1;

                *Pneumonia;
    como_pnuemo=0;
    IF CC111=1 or CC112=1 or CC113=1   then como_pnuemo=1;
                *Diabetes;
    como_diabetes=0;
    IF CC15=1 or CC16=1 or CC17=1 or CC18=1 or CC19=1 or CC20=1 or CC120=1   then como_diabetes=1;

    *Protein Calorie Malnutrition;
    como_protein=0;
    IF CC21=1  then como_protein=1;

    *dementia;
    como_dementia=0;
    IF CC49=1 or CC50=1  then como_dementia=1;

    *paralysis/FD;
    como_FDLsDis=0;
    IF CC100=1 or CC101=1 or CC102=1 or CC67=1
        or CC68=1 or CC69=1 or CC177=1 or CC178=1
        then como_FDLsDis=1;

                *Peripheral Vascular Disease;
    como_periph=0;
    IF CC104=1 or CC105=1  then como_periph=1;



                *Metastatic cancer;
    como_metaCancer=0;
    IF CC7=1 or CC8=1 then como_metaCancer=1;


                *trauma;
    como_trauma=0;
    IF CC154=1 or CC156=1 or CC158=1 or CC159=1
        or CC160=1 or CC161=1 or CC162=1 then como_trauma=1;


    como_subs= (CC51=1 or CC52=1  or CC53=1);

                *Major Psych disorder;
    como_mPsych=0;
    IF CC54=1 or CC55=1 or CC56=1 then como_mPsych=1;

                *Chronic Liver disease;
    como_cLiver=0;
    IF CC25=1 or CC26=1 or CC27=1 then como_cLiver=1;
    %mend;

%macro MedparProcess(cohrt=, pct=);
*****************************************MEDPAR***************************;
** Need to reshape the claim files from long to wide because there are several procedures reported per;
** claims, however first I need to make an index of every observation in the claims dataset so that it ;
** can be reshaped. This is an artifact of the way which the reshape proc statement works;
**;
** Note that there is a issue here with how we restrict our sample to looking for comorbidities. That ;
** is there are individuals who are in the data set twice because they have different two index events;
*****************************************MEDPAR***************************;
    data LongForCC (drop=dgnscd1-dgnscd25 );
        set medex.&cohrt.&pct._medparclms
             (keep = dgn_year  bene_id dgn_date  dgn_date admsndt dschrgdt dgnscd:   fileyear) ;
        WHERE dgn_date > admsndt >= dgn_date -365;

        array dgnscdar{1:25} dgnscd1-dgnscd25;
        *array prcdrcdar{1:25} prcdrcd1-prcdrcd25;
        *prcdrcd $4;
        length dgnscd $6 ;
        do i=1 to 6;
            indx=i;
            dgnscd = dgnscdar{i};
            *prcdrcd = prcdrcdar{i};
            * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
            /*prcdrcd=compress(prcdrcd,,'s');*/
            * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            /*prcdrcd=compbl(prcdrcd);*/
            output;
            end;
        do i=7 to 25;
            indx=i;
            dgnscd = dgnscdar{i};
           * Removes single white space;
            dgnscd=compress(dgnscd,,'s');
           * Removes multiple blanks;
            dgnscd=compbl(dgnscd);
            output;
            end;
    run;


    *Create a secondary index for the different dgnscd# from the proc transpose output variables.;
    proc contents  data= LongForCC;
    run;

    proc print data= LongForCC(obs=5);
    run;

    %mend;
*Define ICD9-CM coding regimes for different diagnosis-these are applied to the OP and MedPAR files;
%macro BringInCMSCode(cohrt=, pct=);

*Import all of the CC to ICD-9-CM code mappings, downloaded from the CMS page ... Got from excel file in zip file called Current model diagnosis codes-;
**Took the excel file and converted into a csv file. Website is at follows  https://www.cms.gov/MedicareAdvtgSpecRateStats/06_Risk_adjustment.asp  ;
** This file can be accessed with CCdir.CC2010;
        data CCdir.CC2010;
        infile "&CC./2010_ICD_9_Crosswalk.txt" dlm="," FIRSTOBS=4 DSD;
        length dgnscd $6 ;
        length CC 3;

        input dgnscd $  dgnsLabel $  CC CClabel $;

      *Removes single white space;
        dgnscd=compress(dgnscd," ");
    *Removes multiple blanks;
        dgnscd=compbl(dgnscd);
        dgnscdold=dgnscd;
        keep dgnscdold dgnscd CC ;
        zero="0";
        output;

        ** The raw data is not always merge perfectly with crosswalk because it either has an extra 0 (41000)
        ** or it maybe missing a padded 0 (4100 410). The following code goes through and creates all iterations;

        ** Their are a few instances where the padding creates ICD9 codes with a different label as;
        ** defined by the ICD9 crosswalk or in which case the padding assigns different CC categories ;
        ** (only happens for the following two instances)
        *7701,MECONIUM ASPIRATN SYNDRM,170,Serious Perinatal Problem Affecting Newborn;
        *77010,Fetal & newborn asp NOS,171,Other Perinatal Problems Affecting Newborn ;
        ** see the code;
        ** NOTE THAT THIS NEW CODE DOES NOT CHANGE ANY OF THE COMORBIDITY VARIABLES FROM BEFORE - I CHECKED IT;

        if dgnscd ne "27650" or dgnscd ne "2765" or dgnscd ne "28730" or dgnscd ne "2873" or dgnscd ne "28800" or
           dgnscd ne "2880" or dgnscd ne "33700" or dgnscd ne "3370" or dgnscd ne "52310" or dgnscd ne "5231" or
           dgnscd ne "52330" or dgnscd ne "5233" or dgnscd ne "52340" or dgnscd ne "5234" or
            dgnscd ne "77010" or dgnscd ne "7701" or dgnscd ne "77750" or dgnscd ne "7775" or
            dgnscd ne "78060" or dgnscd ne "7806" or dgnscd ne "79510" or dgnscd ne "7951" or
            dgnscd ne "99640" or dgnscd ne "9964" or dgnscd ne "E9270" or dgnscd ne "E927" or
            dgnscd ne "V1260" or  dgnscd ne "V126" or  dgnscd ne "V510" or dgnscd ne "V51" or
            dgnscd ne "V5830" or dgnscd ne "V583" or dgnscd ne "7701" then do;

        if length(dgnscd) <5 then do;
            if length(dgnscd) =3 then do;
                dgnscd=trim(dgnscd) || zero;
                output;
                dgnscd=trim(dgnscd) || zero;
                output;
                end;
            if length(dgnscd) =4 then do;
                dgnscd=trim(dgnscd) || zero;
                output;
                end;
            end;
        if substr(dgnscd,length(dgnscd),1) = "0" then do;
            dgnscd=substr(dgnscd,1,length(dgnscd)-1);
            output;
            if substr(dgnscd,length(dgnscd),1) = "0" then do;
                dgnscd=substr(dgnscd,1,length(dgnscd)-1);
                output;

                if substr(dgnscd,length(dgnscd),1) = "0" then do;
                    dgnscd=substr(dgnscd,1,length(dgnscd)-1);
                    output;

                    if substr(dgnscd,length(dgnscd),1) = "0" then do;
                        dgnscd=substr(dgnscd,1,length(dgnscd)-1);
                        output;
                        end;
                    end;
                end;
            end;
        end;
    run;



    proc print data=CCdir.CC2010;
        WHERE  dgnscdold="V8909";
    run;

    proc sort data=CCdir.CC2010 nodupkey;
        by dgnscd CC;
    run;

    proc sort data= LongForCC;
        by dgnscd;
    run;

    data LongCC;
        merge  LongForCC (in=inMedpar) CCdir.CC2010(in=inCC);
        by dgnscd;
        inM=inMedpar;
        inH=inCC;

        flag=0;
        if inM=1 and inH=1 then flag=1;
        *if flag=0 then delete;
    run;
/*
    TITLE "Note diagnosis codes not used in the CC";
    proc freq data=LongCC;
        WHERE inM =1 and inH = 0;
        tables dgnscd;
    run;

    proc freq data=LongCC;
        WHERE dgnscd ne "" ;
        tables fileyear*flag / nocol norow nocell;
    run;

*/

    proc freq data=LongCC;
        WHERE bene_id="mmmmmmmDDWfGXJf";
    run;

    proc sort data= LongCC out=ForCC;
        WHERE flag=1;
        by bene_id admsndt;
    run;

* Macro FROM CMS Risk Adjustment;
** MACRO V12H70H;
** Found on the web at https://www.cms.gov/MedicareAdvtgSpecRateStats/06_Risk_adjustment.asp;
** Look under the 20XX RxHCC model software;
    data LongCCret;
        set ForCC ;
        by  bene_id admsndt ;
       * Retain entire list of CC variables.;
        retain CC1-CC189 0;
        array  CCarray{189} CC1-CC189;
        DO k=1 TO 189;
         * How do we want to treat individuals who are second admission, say a year apart. ;
         * We do not deal with this special case;
            if first.bene_id then CCarray[k]=0;
            if CC=k and dgn_date>admsndt then CCarray[k]=1 ;
            END;
    run;

/*    proc sort data=LongCCret out=LongCCret dupout=test  nodup;
        by   bene_id dgn_date  ;
    run;
*/
    proc sort data=indxex.&cohrt.&pct._indx;
        by bene_id dgn_date;
    run;


/*    proc contents data=indxex.&cohrt.&pct._indx;  run;
    proc contents data=LongCCret;run;
*/

    data comorb.&cohrt.&pct._medpar_CC;
        merge indxex.&cohrt.&pct._indx LongCCret;
        by bene_id dgn_date;
     ** SAS MORTALITY PACK;
        IF dgnscd IN ('40403','40413','40493') THEN CC80=1;



** This code is taken from the CMS risk adjustment code to impose the hierarchies. The Krumholz group;
** recently updated the methodology of their mortality risk Adjustment strategy. They discontinued ;
** the use of the hierarchies because the HCCs intention was to  processes related conditions so that ;
** more severe manifestations of a disease cancel the effect of less serious ones. This approach reduces;
** the documented number of patients coding into certain HCCs relative to the number assigned to;
** related HCCs higher in the hierarchy **The code is commented out but the hierarchies included are taken;
**  from CMSs risk adjustment software.;

    array  CCarrayHIE{189} CC1-CC189;
 *imposing hierarchies;
 * Infection 5 ; if CC5   =1 then do i=112; CCarrayHIE(i)=0;end;
 * Neoplasm1 ;   if CC7   =1 then do i=8,9,10; CCarrayHIE(i)=0;end;
 * Neoplasm 2 ; if CC8   =1 then do i=9,10; CCarrayHIE(i)=0;end;
 * Neoplasm 3 ; if CC9   =1 then do i=10; CCarrayHIE(i)=0;end;
 * Diabetes 1 ; if CC15  =1 then do i=16,17,18,19; CCarrayHIE(i)=0;end;
 * Diabetes 2 ; if CC16  =1 then do i=17,18,19; CCarrayHIE(i)=0;end;
 * Diabetes 3 ; if CC17  =1 then do i=18,19; CCarrayHIE(i)=0;end;
 * Diabetes 4 ; if CC18  =1 then do i=19; CCarrayHIE(i)=0;end;
 * Liver 1  ;   if CC25  =1 then do i=26,27; CCarrayHIE(i)=0;end;
 * Liver 2  ;   if CC26  =1 then do i=27; CCarrayHIE(i)=0;end;
 * SA1  ;       if CC51  =1 then do i=52; CCarrayHIE(i)=0;end;
 * Psychiatric ;if CC54  =1 then do i=55; CCarrayHIE(i)=0;end;
 * Spinal 1  ;  if CC67  =1 then do i=68,69,100,101,157; CCarrayHIE(i)=0;end;
 * Spinal 2  ;  if CC68  =1 then do i=69,100,101,157; CCarrayHIE(i)=0;end;
 * Spinal 3  ;  if CC69  =1 then do i=157; CCarrayHIE(i)=0;end;
 * Arrest 1  ;  if CC77  =1 then do i=78,79; CCarrayHIE(i)=0;end;
 * Arrest 2  ;  if CC78  =1 then do i=79; CCarrayHIE(i)=0;end;
 * Heart 2  ;   if CC81  =1 then do i=82,83; CCarrayHIE(i)=0;end;
 * Heart 3  ;   if CC82  =1 then do i=83; CCarrayHIE(i)=0;end;
 * CVD 1   ;    if CC95  =1 then do i=96; CCarrayHIE(i)=0;end;
 * CVD6  ;      if CC100 =1 then do i=101; CCarrayHIE(i)=0;end;
 * Vascular 1 ; if CC104 =1 then do i=105,149; CCarrayHIE(i)=0;end;
 * Lung 1  ;    if CC107 =1 then do i=108; CCarrayHIE(i)=0;end;
 * Lung 5  ;    if CC111 =1 then do i=112; CCarrayHIE(i)=0;end;
 * Urinary 3 ;  if CC130 =1 then do i=131,132; CCarrayHIE(i)=0;end;
 * Urinary 4 ;  if CC131 =1 then do i=132; CCarrayHIE(i)=0;end;
 * Skin 1  ;    if CC148 =1 then do i=149; CCarrayHIE(i)=0;end;
 * Injury 1 ;   if CC154 =1 then do i=75,155; CCarrayHIE(i)=0;end;
 * Injury 8 ;   if CC161 =1 then do i=177; CCarrayHIE(i)=0;end;



            LABEL

                CC1   ='HIV/AIDS                                '
                CC2   ='Septicemia/Shock                        '
                CC3   ='Central Nervous System Infection        '
                CC4   ='Tuberculosis                            '
                CC5   ='Opportunistic Infections                '
                CC6   ='Other Infectious Diseases               '
                CC7   ='Metastatic Cancer and Acute Leukemia    '
                CC8   ='Lung, Upper Digestive Tract, and Other S'
                CC9   ='Lymphatic, Head and Neck, Brain, and Oth'
                CC10  ='Breast, Prostate, Colorectal and Other C'
                CC11  ='Other Respiratory and Heart Neoplasms   '
                CC12  ='Other Digestive and Urinary Neoplasms   '
                CC13  ='Other Neoplasms                         '
                CC14  ='Benign Neoplasms of Skin, Breast, Eye   '
                CC15  ='Diabetes with Renal Manifestation       '
                CC16  ='Diabetes with Neurologic or Peripheral C'
                CC17  ='Diabetes with Acute Complications       '
                CC18  ='Diabetes with Opthalmologic Manifestation'
                CC19  ='Diabetes with No or Unspecified Complications'
                CC20  ='Type I Diabetes Mellitus                '
                CC21  ='Protein-Calorie Malnutrition            '
                CC22  ='Other Significant Endocrine and Metabolic'
                CC23  ='Disorders of Fluid/Electrolyte/Acid-Base'
                CC24  ='Other Endocrine/Metabolic/Nutritional Di'
                CC25  ='End-Stage Liver Disease                 '
                CC26  ='Cirrhosis of Liver                      '
                CC27  ='Chronic Hepatitis                       '
                CC28  ='Acute Liver Failure/Disease             '
                CC29  ='Other Hepatitis and Liver Disease       '
                CC30  ='Gallbladder and Biliary Tract Disorders '
                CC31  ='Intestinal Obstruction/Perforation      '
                CC32  ='Pancreatic Disease                      '
                CC33  ='Inflammatory Bowel Disease              '
                CC34  ='Peptic Ulcer, Hemorrhage, Other Specified'
                CC35  ='Appendicitis                            '
                CC36  ='Other Gastrointestinal Disorders        '
                CC37  ='Bone/Joint/Muscle Infections/Necrosis   '
                CC38  ='Rheumatoid Arthritis and Inflammatory Co'
                CC39  ='Disorders of the Vertebrae and Spinal Di'
                CC40  ='Osteoarthritis of Hip or Knee           '
                CC41  ='Osteoporosis and Other Bone/Cartilage Di'
                CC42  ='Congenital/Developmental Skeletal and Co'
                CC43  ='Other Musculoskeletal and Connective Tis'
                CC44  ='Severe Hematological Disorders          '
                CC45  ='Disorders of Immunity                   '
                CC46  ='Coagulation Defects and Other Specified '
                CC47  ='Iron Deficiency and Other/Unspecified An'
                CC48  ='Delirium and Encephalopathy             '
                CC49  ='Dementia                                '
                CC50  ='Senility, Non-psychotic Organic Brain Syn'
                CC51  ='Drug/Alcohol Psychosis                  '
                CC52  ='Drug/Alcohol Dependence                 '
                CC53  ='Drug/Alcohol Abuse, Without Dependence  '
                CC54  ='Schizophrenia                           '
                CC55  ='Major Depressive, Bipolar, and Paranoid '
                CC56  ='Reactive and Unspecified Psychosis      '
                CC57  ='Personality Disorders                   '
                CC58  ='Depression                              '
                CC59  ='Anxiety Disorders                       '
                CC60  ='Other Psychiatric Disorders             '
                CC61  ='Profound Mental Retardation/Developmental'
                CC62  ='Severe Mental Retardation/Developmental '
                CC63  ='Moderate Mental Retardation/Development'
                CC64  ='Mild/Unspecified Mental Retardation/Deve'
                CC65  ='Other Developmental Disability          '
                CC66  ='Attention Deficit Disorder              '
                CC67  ='Quadriplegia, Other Extensive Paralysis '
                CC68  ='Paraplegia                              '
                CC69  ='Spinal Cord Disorders/Injuries          '
                CC70  ='Muscular Dystrophy                      '
                CC71  ='Polyneuropathy                          '
                CC72  ='Multiple Sclerosis                      '
                CC73  ="Parkinson's and Huntington's Diseases   "
                CC74  ='Seizure Disorders and Convulsions       '
                CC75  ='Coma, Brain Compression/Anoxic Damage   '
                CC76  ='Mononeuropathy, Other Neurological Condi'
                CC77  ='Respirator Dependence/Tracheostomy Statu'
                CC78  ='Respiratory Arrest                      '
                CC79  ='Cardio-Respiratory Failure and Shock    '
                CC80  ='Congestive Heart Failure                '
                CC81  ='Acute Myocardial Infarction             '
                CC82  ='Unstable Angina and Other Acute Ischemic'
                CC83  ='Angina Pectoris/Old Myocardial Infarction'
                CC84  ='Coronary Atherosclerosis/Other Chronic I'
                CC85  ='Heart Infection/Inflammation, Except Rhe'
                CC86  ='Valvular and Rheumatic Heart Disease    '
                CC87  ='Major Congenital Cardiac/Circulatory Def'
                CC88  ='Other Congenital Heart/Circulatory Disea'
                CC89  ='Hypertensive Heart and Renal Disease or '
                CC90  ='Hypertensive Heart Disease              '
                CC91  ='Hypertension                            '
                CC92  ='Specified Heart Arrhythmia             '
                CC93  ='Other Heart Rhythm and Conduction Disord'
                CC94  ='Other and Unspecified Heart Disease     '
                CC95  ='Cerebral Hemorrhage                     '
                CC96  ='Ischemic or Unspecified Stroke          '
                CC97  ='Precerebral Arterial Occlusion and Trans'
                CC98  ='Cerebral Atherosclerosis and Aneurysm   '
                CC99  ='Cerebrovascular Disease, Unspecified    '
                CC100 ='Hemiplegia/Hemiparesis                  '
                CC101 ='Diplegia (Upper), Monoplegia, and Other '
                CC102 ='Speech, Language, Cognitive, Perceptual '
                CC103 ='Cerebrovascular Disease Late Effects, Un'
                CC104 ='Vascular Disease with Complications     '
                CC105 ='Vascular Disease                        '
                CC106 ='Other Circulatory Disease               '
                CC107 ='Cystic Fibrosis                         '
                CC108 ='Chronic Obstructive Pulmonary Disease   '
                CC109 ='Fibrosis of Lung and Other Chronic Lung '
                CC110 ='Asthma                                  '
                CC111 ='Aspiration and Specified Bacterial Pneum'
                CC112 ='Pneumococcal Pneumonia, Empyema, Lung Ab'
                CC113 ='Viral and Unspecified Pneumonia, Pleuris'
                CC114 ='Pleural Effusion/Pneumothorax           '
                CC115 ='Other Lung Disorders                    '
                CC116 ='Legally Blind                           '
                CC117 ='Major Eye Infections/Inflammations      '
                CC118 ='Retinal Detachment                      '
                CC119 ='Proliferative Diabetic Retinopathy and V'
                CC120 ='Diabetic and Other Vascular Retinopathie'
                CC121 ='Retinal Disorders, Except Detachment and'
                CC122 ='Glaucoma                                '
                CC123 ='Cataract                                '
                CC124 ='Other Eye Disorders                     '
                CC125 ='Significant Ear, Nose, and Throat Disord'
                CC126 ='Hearing Loss                            '
                CC127 ='Other Ear, Nose, Throat, and Mouth Disor'
                CC128 ='Kidney Transplant Status                '
                CC129 ='End Stage Renal Disease                 '
                CC130 ='Dialysis Status                         '
                CC131 ='Renal Failure                           '
                CC132 ='Nephritis                               '
                CC133 ='Urinary Obstruction and Retention       '
                CC134 ='Incontinence                            '
                CC135 ='Urinary Tract Infection                 '
                CC136 ='Other Urinary Tract Disorders           '
                CC137 ='Female Infertility                      '
                CC138 ='Pelvic Inflammatory Disease and Other Sp'
                CC139 ='Other Female Genital Disorders          '
                CC140 ='Male Genital Disorders                  '
                CC141 ='Ectopic Pregnancy                       '
                CC142 ='Miscarriage/Abortion                    '
                CC143 ='Completed Pregnancy With Major Complicat'
                CC144 ='Completed Pregnancy With Complications  '
                CC145 ='Completed Pregnancy Without Complication'
                CC146 ='Uncompleted Pregnancy With Complications'
                CC147 ='Uncompleted Pregnancy With No or Minor C'
                CC148 ='Decubitus Ulcer of Skin                 '
                CC149 ='Chronic Ulcer of Skin, Except Decubitus '
                CC150 ='Extensive Third-Degree Burns            '
                CC151 ='Other Third-Degree and Extensive Burns  '
                CC152 ='Cellulitis, Local Skin Infection        '
                CC153 ='Other Dermatological Disorders          '
                CC154 ='Severe Head Injury                      '
                CC155 ='Major Head Injury                       '
                CC156 ='Concussion or Unspecified Head Injury   '
                CC157 ='Vertebral Fractures                     '
                CC158 ='Hip Fracture/Dislocation                '
                CC159 ='Major Fracture, Except of Skull, Vertebr'
                CC160 ='Internal Injuries                       '
                CC161 ='Traumatic Amputation                    '
                CC162 ='Other Injuries                          '
                CC163 ='Poisonings and Allergic Reactions        '
                CC164 ='Major Complications of Medical Care and '
                CC165 ='Other Complications of Medical Care     '
                CC166 ='Major Symptoms, Abnormalities           '
                CC167 ='Minor Symptoms, Signs, Findings         '
                CC168 ='Extremely Low Birth weight Neonates      '
                CC169 ='Very Low Birth weight Neonates           '
                CC170 ='Serious Perinatal Problem Affecting Newb'
                CC171 ='Other Perinatal Problems Affecting Newbo'
                CC172 ='Normal, Single Birth                    '
                CC173 ='Major Organ Transplant                  '
                CC174 ='Major Organ Transplant Status           '
                CC175 ='Other Organ Transplant/Replacement      '
                CC176 ='Artificial Openings for Feeding or Elimi'
                CC177 ='Amputation Status, Lower Limb/Amputation'
                CC178 ='Amputation Status, Upper Limb           '
                CC179 ='Post-Surgical States/Aftercare/Elective '
                CC180 ='Radiation Therapy                       '
                CC181 ='Chemotherapy                            '
                CC182 ='Rehabilitation                          '
                CC183 ='Screening/Observation/Special Exams     '
                CC184 ='History of Disease                      '
                CC185 ='Oxygen                                  '
                CC186 ='CPAP/IPPB/Nebulizers                    '
                CC187 ='Patient Lifts, Power Operated Vbene_idles, '
                CC188 ='Wheelchairs, Commodes                   '
                CC189 ='Walkers                                 ';

            %DefineComorid;
            drop CC: dgnscd:  inm inh flag  admsndt  indx;
            if last.dgn_date then output  ;

            LABEL
                card_amiG1="Cardiovascular dfn1 (4100 and 4101)-Krumholz paper"
                card_amiG2="Cardiovascular dfn2  (4102-4106)-Krumholz paper"
                card_hf="Heart failure"
                card_mi="Define myocardial infarction"
                card_ua="unstable angina"
                card_cathero="chronic atherosclerosis"
                card_respFal="respiratory failure"
                card_hyperhd="hypertensive heart disease"
                card_valve="Valvular heart disease"
                card_arrhythmia="arrhythmia"

                como_hyper="hypertension"
                como_stroke="stroke"
                como_cervas="Cerebovascular disease"
                como_renal="Renal Failure disease"
                como_dialysis="Dialysis"
                como_COPD="COPD"
                como_pnuemo="Pneumonia"
                como_diabetes="diabetes"
                como_protein="Protein Calorie Malnutrition"
                como_dementia="dementia"
                como_FDLsDis="paralysis/FD"
                como_periph="Peripheral Vascular Disease"
                como_metaCancer="Metastatic cancer"
                como_trauma="trauma"
                como_subs="substance abuse"
                como_mPsych="Major Psych disorder"
                como_cLiver="Chronic Liver disease";
    run;

    TITLE "COMORBIDITY --- &cohrt.";
    proc means data=comorb.&cohrt.&pct._medpar_cc;
        var como: card:;
    run;
    TITLE "";


    *Export to Stat/Transfer;
    x "st &comorb./&cohrt.&pct._medpar_cc.sas7bdat
          &comorb./&cohrt.&pct._medpar_cc.dta -y -od";

    %mend;




**BeginWrapperPrograms************************;
%macro ExtComorbidCC(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrtN=,pct=05);


    %do j=1 %to &cohrtN.;
        %MedparProcess(cohrt=&&cohrt&j..,pct=&pct.);
        %BringInCMSCode(cohrt=&&cohrt&j..,pct=&pct.);
        %end;
    %mend;
*****END WRAPPER********************************;





***CALL MACRO**********************************;
*sampleRule-- is equal to mn by default unless you decide create several differnt extract using different tags. ;
%ExtComorbidCC(cohrt1=&cohrt.,cohrtN=1,pct=&pct.);



********************************************************************************;
*** To run this file only or for testing comment out the above lines and;
*** make sure you fill in the correct parameters below;
********************************************************************************;
*%ExtComorbidCC(cohrt1=hipkne,cohrtN=1,pct=100);



