*******Create Cost Measure across claims files. *****************************;
******************************************************************************;
*** This program aggregates the costs utilization variables ;
*** into X days costs upto the index day level, using similar code as teh
*** CumulativeCostsPerIndx.sas file;
*Maurice Dalton,daltonm.at.nber.org;

***********************************************************************;
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";


* define libraries;
libname spcar "&spcar.";
libname medEx  "&medparExt.";
libname carEx   "&carExt.";
libname OpEx   "&OpExt.";
libname indxex "&indxExt.";
libname cost   "&costs.";
libname spcost   "&spcost.";
libname costutil "&costutil.";

* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./read_sysparm.sas";
* load files with macros that conform the files of various years into a common format;


**********************************************************************************;
***    MACROS USED WITHIN THE MEDPAR/CARRIER FILES;
**********************************************************************************;
%macro AssignMissingZero(Proc=,numDay=9,Days=);
    %do i=1 %to &numDay.;
      if costutil_&Proc._d%scan(&Days.,&i.)=. then costutil_&Proc._d%scan(&Days.,&i.)=0;
      %end;
%mend;
**********************************************************************************;
***    Sum costs into Variable  Macro     ;
**********************************************************************************;
%macro CreateCostVariables(days=,dNum=,pop=);

    *Flag claims which occur within XX days of index event;
    *Start summing at the day intervals defined in the macro;
    ** CASE 1: the claim fall completly before the day of interest. ie 7 day costs for ;
    ** a claim with los of 5 days, will simply include all costs;
    %do i=1 %to &dNum.;
        %let d=%scan(&days.,&i.);

    if (ClaimEnd - dgn_date)<=&d. and (ClaimEnd - dgn_date) >= 0 and stayCost ne .
            then &pop._cu_d&d.=stayCost+&pop._cu_d&d.;

    ** CASE 2: the length of stay on the claims falls completly after the day of interest. ie 7 day costs for ;
    ** a claim with los of 10 days would have reported zero costs. this bit of code will assume linear costs
    ** and the total costs occuring over 10 days and assign 70% of the costs to the 7 day cost variable. ;
    if (ClaimEnd - dgn_date)> &d. and stayCost ne .  and
        (ClaimStart - dgn_date)<= &d. then  do;
        pctDiff=(&d.+dgn_date -ClaimStart) / (ClaimEnd - ClaimStart) ;
        &pop._cu_d&d.=pctDiff*stayCost+&pop._cu_d&d.;
        end;
      %end;


  LABEL
      %do i=1 %to &dNum.;
            &pop._cu_d%scan(&days.,&i.)="Cost utilization measures aggregated costs occuring %scan(&days.,&i.) days after index event in &pop."
                %end; ;

    %mend;



**********************************************************************************;
***    Outpatient process Macro     ;
**********************************************************************************;
%macro OutPatProcess(cohrt=,pct=,daysO=,dNumO=,id=,contigious48=);

    proc contents data=costutil.&cohrt.&pct._OPPSq;
    run;

    proc sort data=costutil.&cohrt.&pct._OPPSq;
        by diag_id;
    run;

*OUTPATIENT;
    data  costutil.&cohrt.&pct._cu_op;
        set  costutil.&cohrt.&pct._OPPSq;
        by diag_id;
        where from_dt>=dgn_date ;
           diag_year=year(dgn_date);

            claimStart=from_dt;
            claimEnd=thru_dt;
        %if &contigious48. =1 %then %do;
            **only use contiguous 48 states not including washington dc.;
            if flagcontiguous48=1;
            %end;
     *drop procedure occuring before index events;
            StayCost = outpatient_QTcode;

             retain
                %do i=1 %to &dNumO.;
                    op_cu_d%scan(&daysO.,&i.)
                %end;
            0;

            *Drop first set of variables so we can sum acroos diag_id;
                  if first.diag_id  then do;
                %do i=1 %to &dNumO.;
                    op_cu_d%scan(&daysO.,&i.)=0;
                    %end;
                    end;

                %CreateCostVariables(days=&daysO.,dNum=&dNumO.,pop=op);

                outpat=1;
                op_basepayment=confact;
             keep outpat dgn_date  bene_id  op_cu_d: diag_id
                 op_basepayment;
             if last.diag_id then output;
    run;


    %mend;




**********************************************************************************;
***    Carrier process Macro     ;
**********************************************************************************;
%macro CarProcess(cohrt=,pct=,daysO=,dNumO= ,contigious48=);
    proc freq data=carEx.&cohrt.&pct._carlnits;
        table  pmtdnlcd pmtindcd;
    run;

    * The main file create a HCPCS to utilization xwalk. It however recodes all non 26,53,TC modifier codes to MI.;
    ** need to do the same in the raw file;
    data  spcost.carextract;
        set carEx.&cohrt.&pct._carlnits (keep=expnsdt1 expnsdt2 mdfr_cd1 lalowchg plcsrvc pmtdnlcd dgn_date diag_id hcpcs_cd bene_id prvstate);
        end_yr=year(expnsdt2);

        if expnsdt1>=dgn_date and trim(pmtdnlcd) ne "0" ;
        if mdfr_cd1 in("26","53","TC") = 0 then mdfr_cd1 = "MI";
        %if &contigious48. =1 %then %do;
        **only use contiguous 48 states not including washington dc.;
        if prvstate =54 or prvstate = 2 or prvstate = 9 or prvstate = 12 or (prvstate>=56 and prvstate<=66) or prvstate>=80 then delete;
        %end;

    run;

    proc freq data=spcost.carextract;
        table end_yr;
    run;

    proc contents data=costutil.&cohrt.&pct._hcpcs2costutil;
    run;

    proc sort data=spcost.carextract;
        by end_yr hcpcs_cd mdfr_cd1 plcsrvc;
    run;

    proc sort data=costutil.&cohrt.&pct._hcpcs2costutil;
        by end_yr hcpcs_cd mdfr_cd1 plcsrvc;
    run;

    **MAKE SURE WE ARE STARTING WITH AN EMPTY FILE;
    x "rm &spcost./bringincostutil_carrier.sas* -f";
    proc sql ;
    create table spcost.bringincostutil_carrier as
        select *
        from spcost.carextract C ,
            costutil.&cohrt.&pct._hcpcs2costutil  X
        WHERE C.end_yr = X.end_yr AND  C.hcpcs_cd = X.hcpcs_cd AND
              C.mdfr_cd1 = X.mdfr_cd1 AND  C.plcsrvc = X.plcsrvc;
    run;

    proc freq data=spcost.bringincostutil_carrier;
        table end_yr;
    run;

    proc sort data=spcost.bringincostutil_carrier;
        by diag_id;
    run;

    data  costutil.&cohrt.&pct._cu_car;
        set spcost.bringincostutil_carrier;
        *drop procedure occuring before index events;
        by diag_id;
        diag_year=year(dgn_date);
        *Need to aggregate lineitems to the claim levels prior to averging. This is done in the Createcost macro, sums lineitems to the diag_id level;
        stayCost=physician_Q;
        *stayCost=linepmt;

        claimStart=expnsdt1;
        claimEnd=expnsdt2;

        stdPlace = "";
        car_basepayment=convfact;

          retain
                %do i=1 %to &dNumO.;
                    car_cu_d%scan(&daysO.,&i.)
                %end;
            0;



            *Drop first set of variables so we can sum acroos diag_id;
            if first.diag_id then do;
                %do i=1 %to &dNumO.;
                    car_cu_d%scan(&daysO.,&i.)=0;
                    %end;
                    end;


        **************************************************************************;
        ***    CAll Sum costs Macro     ;
        **************************************************************************;
        %CreateCostVariables(days=&daysO.,dNum=&dNumO.,pop=car);
        **THESE GROUPING ARE NOT EXACTLY CORRECT --AMBULANCE-LABS-ER-ETC. GROUPED INTO OTHER;
        keep dgn_date bene_id  car_cu_d: diag_id car_basepayment;
        if last.diag_id then output ;
    run;

    %mend;



**********************************************************************************;
***    MedPAR process Macro :: ONLY DEFINED FOR SHORT TERM HOSPITAL     ;
**********************************************************************************;
%macro MedparProcess(cohrt=,pct=,sampleRule=,daysO=,dNumO=,contigious48=);
    proc sort data=costutil.&cohrt.&pct._claimsDRGQ;
        by diag_id;
    run;

    *Note we only look at costs occuring after the index event;
    data  costutil.&cohrt.&pct._cu_mpar;
        set costutil.&cohrt.&pct._claimsDRGQ;
        by diag_id;
            *drop procedure occuring before index events;
        where admsndt>=dgn_date ;
        %if &contigious48. =1 %then %do;
        **only use contiguous 48 states not including washington dc.;
        if flagcontiguous48=1;
        %end;
        claimStart=admsndt;
        claimEnd=dschrgdt;

        stayCost = inpatient_Q;
        mp_basepayment=opbase;
        mp_basepayment_cap=capbase;
            *DEfine variable to retian within do loop-any cost groupings-define here;
        retain
                %do i=1 %to &dNumO.;
                    shosp_cu_d%scan(&daysO.,&i.)
                %end;
            0;

            *Drop first set of variables so we can sum acroos diag_id;
               if first.diag_id  then do;
                %do i=1 %to &dNumO.;
                    shosp_cu_d%scan(&daysO.,&i.)=0;
                    %end;
                    end;

            *Create the variables with the stubs in pop;
             %CreateCostVariables(days=&daysO.,dNum=&dNumO.,pop=shosp);

                keep dgn_date bene_id shosp_cu_d: diag_id mp_basepayment mp_basepayment_cap;
                if last.diag_id  then output ;
                dif=ClaimStart-dgn_date;
    run;
    %mend;




%macro mergeAll(cohrt=,DGNMX=,pct=,sampleRule=,daysO=&dayW,dNumO=&dNumw.,id=,contigious48=);
    *************************************************************************;
    ***    Prep data for merge     ;
    *************************************************************************;
    proc sort data=indxex.&cohrt.&pct._indx;
        by bene_id dgn_date;
    run;
    %if &pct. ne 100 %then %do;
        proc sort data=costutil.&cohrt.&pct._cu_car;
            by bene_id dgn_date;
        run;
    %end;

    proc sort data=costutil.&cohrt.&pct._cu_mpar;
        by bene_id dgn_date;
    run;


    proc sort data=costutil.&cohrt.&pct._cu_op;
        by bene_id dgn_date;
    run;


    *************************************************************************;
    ***    Prep data for merge     ;
    *************************************************************************;
   data costutil.&cohrt.&pct._costutil;
        merge indxex.&cohrt.&pct._indx(keep=bene_id dgn_date diag_id)
            %if &pct. ne 100 %then %do;
            costutil.&cohrt.&pct._cu_car (in=car drop= diag_id)
                %end;
            costutil.&cohrt.&pct._cu_mpar (in=mpar drop= diag_id)
            costutil.&cohrt.&pct._cu_op (in=op drop= diag_id);
        by bene_id dgn_date;

        ** Uncomment this code if you want to assign a zero to missing values.;
      /*  %AssignMissingZero(Proc=hosp,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=snf,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=medpar,numDay=&dNumw.,Days=&daysO.);

        %AssignMissingZero(Proc=op,numDay=&dNumw.,Days=&daysO.);

        %AssignMissingZero(Proc=docof,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=docop,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=dochosp,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=car,numDay=&dNumw.,Days=&daysO.);
        %AssignMissingZero(Proc=other,numDay=&dNumw.,Days=&daysO.);
        */
        outside48=0;
        if car=0 and mpar=0 and op=0 and inex=1 then outside48=1;
        LABEL
            outside48="Flag; no cost utilization vars generated";

    run;


        proc means data=costutil.&cohrt.&pct._costutil;
        run;

       *************************************************************************;
       ***    Send to stata      ;
       *************************************************************************;
        x "st &costutil./&cohrt.&pct._costutil.sas7bdat  &costutil./&cohrt.&pct._costutil.dta -Y -od";


     proc datasets lib=costutil nolist;
           DELETE &cohrt.&pct._cu_car
                  &cohrt.&pct._cu_op
                  &cohrt.&pct._cu_mpar ;
    run;

    %mend;




**********************************************************************************;
****             START WRAPPER MACRO  ;
**********************************************************************************;

**********************************************************************************;
*WRAPPER MACRO DOCUMENTATION --SAME AS DOC FOUND AT BEGINING OF SCRIPT ---;
**********************************************************************************;
*** It has the following options;
*** cohrt1=    --These reference the ICD-9-CM codes in the code and define what these files will be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running several;
***             -- (4 plus)the efficiently of the program maybe impacted. ;
*** .....;
*** cohrtN=2   -- Define the total number of cohorts you are creating, must equal the number of the last cohorts defined  above;
***               Tells the program how many cohortX to loop through.;
*** pct=05    -- Define the percent extract you are interested in. Use .01% for debugging where possible;

*** win=1      -- Define the  window around the index event for the program to extract.;
***            -- In years.;
***;
***contigious48 -- drop claims occuring outside of the contigious 48 states from calcs.
***                They are most likely not reimbursed the same way although they only make up a small
***                number of claims;
**********************************************************************************;


%macro RunProgram(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrtN=,pct=,day=,dNum=,contigious48=);
    %do j=1 %to &cohrtN.;
        %OutPatProcess(cohrt=&&cohrt&j..,pct=&pct.,daysO=&day,dNumO=&dNum.,contigious48=&contigious48.);
        %MedparProcess(cohrt=&&cohrt&j..,pct=&pct.,daysO=&day,dNumO=&dNum,contigious48=&contigious48.);
        %if &pct.<100 %then %do;
        %CarProcess(cohrt=&&cohrt&j..,pct=&pct.,daysO=&day,dNumO=&dNum.,contigious48=&contigious48.);
        %end;
        %mergeAll(cohrt=&&cohrt&j..,pct=&pct.,daysO=&day,dNumO=&dNum.,contigious48=&contigious48.);

        %end;
%mend;

%RunProgram(cohrt1=&cohrt.,cohrtN=1,pct=&pct.,day=&day1. &day2. &day3. &day4. &day5. &day6. &day7. ,dNum=&dnum.,contigious48=&contigious48.);





