*#########################################################;
* Merges in drg weight and base payment amounts in order to generate a cost ;
* utilization --amount reimbursed without geographic or other costs;
**
** Note generates a fiscal year marker, drops claims not from the the 48 ;
** contiguos stataes.
*#########################################################;
%macro AcuteIPPScostUtil(yearin=,yearout=,cohrt=ami,pct=20);

    proc sort data=costutil.DRGlong;
        by fyear drg_cd;
    run;

    *#########################################################;
    * Subset data DROP SNF AND LONG-TERM HOSPITALS;
    *#########################################################;

    data fiscalYr;
        set medex.&cohrt.&pct._medparclms ;
        WHERE (fileYear>=&yearin. and fileYear<=&yearout.) and
               is_snf=0 and is_longhosp =0 ;


        **define fiscal year by discharge date 10/[FYEAR-1] -- 9[FYEAR];
        if month(dschrgdt)>=1 and month(dschrgdt)<=9 then fyear=year(dschrgdt);
        if month(dschrgdt)>=10 and month(dschrgdt)<=12 then fyear=year(dschrgdt)+1;
        ** drop bene_ids with out of statecodes --unsure about these;
        /*if state_mp="0{" then delete;*/
        flagcontiguous48=1;
        ** drop providers with out of state codes -iincluding hawaii, alaska and wash dc;
        if prvstate =54 or prvstate = 2 or prvstate = 9 or prvstate = 12 or (prvstate>=56 and prvstate<=66) or prvstate>=80 then flagcontiguous48=0;

        dyear=year(dschrgdt);
        ayear=year(dgn_date);
    run;

    proc sql;
        select fyear,SUM(drgprice) as totalDRGprice,SUM(ime_amt) as imeTot,
               SUM(pps_cptl) as ppscptlTOT, SUM(disp_shr) as DISPtot
            from fiscalYr
            group by fyear;
        quit;

    proc contents data=fiscalYr;run;
    proc contents data=medex.&cohrt.&pct._medparclms;run;
    *#########################################################;
    * MERGE IN DRG WEIGHTS;
    *#########################################################;
    proc sql;
        create table spcost.mergeVar_&pct. as
             select *
            from fiscalYr AS F LEFT JOIN costutil.DRGlong AS D
            ON F.drg_cd = D.drg_cd and F.fyear=D.fyear;
        quit;

    proc sort data=spcost.mergeVar_&pct.;
        by fyear ;
    run;

   *#########################################################;
   * Merge in ratio to dataset;
   *#########################################################;
    data costutil.&cohrt.&pct._claimsDRGQ ;
        set spcost.mergeVar_&pct. ;
        inpatient_Q=(labor+nonlabor)*DRGwght;
        allpay=drgprice;
        opbase=(labor+nonlabor);
        capbase=capital;

        if passthru ne . then  allpay=allpay+passthru;
        if outlramt ne . then  allpay=allpay+outlramt;
        **Subtract secondary payer amount since these are not included in the medicare;
        if prpayamt ne . then  allpay=allpay-prpayamt;

        LABEL
            inpatient_Q= "Cost utilization measure: base payment times specific drg wgt"
            fyear= "Fiscal year"
            allpay= "Total cost variable minus secondary payer amount (prpayamt) "
            opbase= "Operating base payment (labor+nonlabor) $ / DRG wght"
            capbase= "Capital base payment (capital) $ / DRG wght";
        keep inpatient_Q labor nonlabor DRGwght medrawindx diag_id is_snf is_shorthosp is_longhosp
             bene_id dgn_date admsndt dschrgdt fileyear allpay fyear  capbase opbase;

    run;


    proc sort data=costutil.&cohrt.&pct._claimsDRGQ;
        by fyear;
    run;

    *#########################################################;
    * Create correlation;
    *#########################################################;
    **Note that prpayamy (secondary payment amount are going to really impact this. ;
    ** there are a couple large outlier cases, so we subtract prpayamy;
    proc corr data=costutil.&cohrt.&pct._claimsDRGQ;
        by fyear;
        var inpatient_Q allpay;
    run;


    **Clear Space directory;
    x "rm &spcost./* -f";


    *##############################################################;
    * CODE NOT LONGER USED;
    **** Aggregate statistics --create ratio -;
    **** kept in case someone want to estimate;
    *##############################################################;
    /*data spcost.calcDRGdollar_&pct. (keep=fyear Total:  drgpricr_ratio ratio labor:
                                           nonlabor: capital stay_ratio );
        set spcost.mergeVar_&pct.;
        by fyear;
        retain TotalDRGwgt TotalPMT Totaldrgprice Totalstaycost  0;

        if first.fyear then TotalPMT=0;
        if first.fyear then Totaldrgprice=0;
        if first.fyear then TotalDRGwgt=0;
        if first.fyear then Totalstaycost=0;

        Totaldrgprice = Totaldrgprice+drgprice;
        TotalPMT      = TotalPMT+drgprice+passthru;
        TotalDRGwgt   = DRGwght+TotalDRGwgt;
        Totalstaycost = Totalstaycost+stayCost;


        if last.fyear then stay_ratio=Totalstaycost/TotalDRGwgt;
        if last.fyear then ratio=TotalPMT/TotalDRGwgt;
        if last.fyear then drgpricr_ratio=Totaldrgprice/TotalDRGwgt;
        if last.fyear then output;
    run;


    proc print data=spcost.calcDRGdollar_&pct.;
    run;
    */
    %mend;













