%macro OPPScostUtil(pct=,cohrt=,yearin=,yearout=,testlos=);
**#############################################################################;
***STEP 1: PRELIMINARY ---ADD ERROR CODE PROCESSING;
**#############################################################################;
    libname here ".";
        %if &pct. = "" or &cohrt. = "" or &yearin. = "" or &yearout. = ""
        %then %do;
        %PUT "!!!USER ERROR :: MISSING ID OR PCT PARAMTERS!!";
        ENDSAS ;
        %end;
        %if &yearin. < 2001  or &yearout. < &yearin. %then %do;
        %PUT "USER ERROR :: OPPS cost utilization is not defined before 2001. Change yearin parameter.";
        ENDSAS ;
        %end;

    *######################################### ;
    *## MERGE ADDENDUM B - HCPCS -->APC  DATA;
    *#########################################;
    proc sort data=spcost.&cohrt.merge_revclms;
        by cyear hcpcs_cd ;
    run;

    proc sort data=costutil.addendumb_apcwghts;
        by cyear hcpcs_cd ;
    run;

    **Rev cntr with 0001 are aggregated totals;
    data spcost.revclmsAPC_B  ;
        merge spcost.&cohrt.merge_revclms (in=clms
                                     drop= wageadj revpmt revdctbl revblood
                                          rev_fl rev_msp1 rev_msp2 rev_year clm_fl
                                          rdcdcoin
                                     where=(rev_cntr ne "0001" and
                                           (cyear >=&yearin. and cyear<=&yearout.))
                                    )
              costutil.addendumb_apcwghts (in=APCfl );
        by cyear hcpcs_cd ;
        inclm=clms;
        inAPC=APCfl;
        if inclm;

        ** drop providers with out of state codes ;
        flagcontiguous48=1;
        ** drop providers with out of state codes -iincluding hawaii, alaska and wash dc;
        if prstate =54 or prstate = 2 or prstate = 9 or prstate = 12 or (prstate>=56 and prstate<=66) or
           prstate>=80 then flagcontiguous48=0;

        ** According to the resdac documentation apchipps with a 0000 refer to ;
        ** packaged incidental service--no additional payment for this APC;
        **  payment included with line items for the APC. However looking at the ;
        ** claims shows that APCs with 0000 in some cases may have no HCPCS code ;
        ** and do have an associated payment with them. The APCHIPPS variable seems to be wrong,;
        ** in many cases when compared with the pmthd variable ;
        ** and  addendum B status indicators (correlation between the APC from using the addendum B and those found in;
        ** the claims was about ~60% (the correlation gets worse over time).;
        ** For this reason we decide to use the - pmtmthd1 - variable which is similar to the status code in;
        ** indicator with the exception that it also has numbers and changes from years to year.;
        ** see resdac for more info.;
        pmtmthd1=compress(pmtmthd);
        si_clms="";
        if costutiltype=. then do;
            if pmtmthd1 in("A","A2") then si_clms = "A";
            if pmtmthd1 in("C","B3") then si_clms = "C";
            if pmtmthd1 in("E","E3","Z3","W3") then si_clms = "C";
            if pmtmthd1 in("B2","2","3") then si_clms = "B";
            if pmtmthd1 in("F4","4") then si_clms = "F";
            if pmtmthd1 in("G5","5") then si_clms = "G";
            if pmtmthd1 in("H6","6") then si_clms = "H";
            if pmtmthd1 in("J7","7") then si_clms = "J";
            if pmtmthd1 in("N","N9","9") then si_clms = "N";
            if pmtmthd1 in("K1") then si_clms = "K";
            if pmtmthd1 in("1","S1") then si_clms = "S";
            if pmtmthd1 in("T1") then si_clms = "T";
            if pmtmthd1 in("W1") then si_clms = "W";
            if pmtmthd1 in("X1") then si_clms = "X";
        end;
    if si_clms in("A","C","B") then costutiltype = 0;
    if si_clms in("F","G","H","J","K") then costutiltype = 3;
    **Packaged incidental service;
    ** These claims costs are for the most part packaged into other claims, however for a small amount of;
    ** revenue cneters between 2000-2005, the rev cntrs 250,270 and 272 among other claims where ;
    ** used without hcpcs_cd and were reimbresed. These rev_cntrs fall under general drug category ;
    ** These claims should be treated as is, although addendum B has no weights associated with all N;
    ** status indicators. ;
    if si_clms in("N") or packagePay=1 then costutiltype = 4;
    ** These codes have an inconsitency in that the CLMS/REV files say they are covered by
    ** OPPS in the (pmtmthd1) but they are not matched to ADDEN B.;
    ** Closer inspection of the HCPCS codes shows that they are mostly;
    ** C and G codes. The C codes are temporary HCPCS codes and the G codes;
    ** are for voluntary reporting of quality codes;
    ** These are codes with no HCPCS codes matched to the ADDEN B. I simply flag these;
    ** since we have no weights for them but they do have associated costs;
    if si_clms in("S","T","W","X") then costutiltype = 5;
    ** Partial Hospitalization reimbursement is another program which is not entirely clear how;
    ** CMS  reimburses. There appears to be considerable packaging of these claims together based on some;
    ** discussion about G0176 in CYEAR 2008 final rule. The weights drop out for these individals from teh addendum B;
    ** starting in 2008.;
    ** Looking at the raw claims themselves show that much of the time no costs are associated with these;
    ** claims. When these claims  are paid they are paid a flat per diem amount. Assign these to group 5 and use the straight costs;
    if si in("P") then costutiltype = 5;
    ** No match to status indicator in the clms files or in ADDEN B, likely not covered by OPPS.;
    if costutiltype=. then costutiltype = 6;
    ** All costutil measure should have a weight or payment amount - if not set to group 6 and use cost.;
    if costutiltype=1 and (payrate = . and APCwgt = .) then costutiltype = 6;
    run;

    proc print data=spcost.revclmsAPC_B  (obs=100) ;
        WHERE hcpcs_cd="G0176";
    run;

    proc freq data=spcost.revclmsAPC_B;
        table inAPC;
    run;

    *************************************************************************** ;
    ** DEAL WITH DISCOUNT CLAIMS (SI=T);
    ***************************************************************************;
    proc sql;
        create table revclmsAPC_siT as
        select *, count(si) as CountSI, max(APCwgt) as maxweight, max(rev_dt) as maxrev_dt
        from spcost.revclmsAPC_B
        WHERE si="T"
        group by cyear, clm_id, rev_dt
        order by cyear, clm_id, rev_dt;
        quit;

    proc sort data=spcost.revclmsAPC_B out=revclmsAPC_notSI_T   ;
        WHERE si ne "T";
        by cyear clm_id rev_dt;
    run;

    *************************************************************************** ;
    ** COMBINE DISCOUNTING AND NON-DISCOUNTING INFO- DISCOUNT WEIGHT;
    ***************************************************************************;
    data costutil.&cohrt.&pct._OPPSq;
        set revclmsAPC_notSI_T revclmsAPC_siT ;
        by cyear clm_id rev_dt;
        retain countdiscount;
        if first.rev_dt then countdiscount=0;
        ** DEAL WITH DISCOUNTING IN THE OPPS;
        if si ne "T" then APCwgt_tcode=APCwgt;
        ** Case where the max relweight is duplicated, one gets discounted;
        if si eq "T" and maxweight = APCwgt and countdiscount=1 then
            APCwgt_tcode=APCwgt*.5;
        ** HCPCS code with a T are discounted when multiple show up on a claim on a single day;
        ** (according ot the claims processing manuals);
        ** The HCPCS code with the max weight is not discounted. ;
        if si eq "T" and maxweight = APCwgt and countdiscount=0 then do;
            APCwgt_tcode=APCwgt;
            countdiscount=1;
            end;
        if si eq "T" and maxweight ne APCwgt and rev_dt=maxrev_dt
            then APCwgt_tcode=APCwgt*.5;
        *******************************************************************;
        *** GENERATE KEY VARIABLE WHICH EXPLAINS THE TYPES OF OP CLM;
        *******************************************************************;
        if costutiltype=1 then outpatient_Q=APCwgt*confact;
        ** Codes which report payrate and no APCwgt -- the payrate is used mostly s codes;
        if costutiltype=1 & APCwgt=. and payrate ne . then outpatient_Q=payrate;
        if costutiltype=2 then outpatient_Q=payrate;
        if costutiltype=3 then outpatient_Q=revallpay;
        if costutiltype=5 then outpatient_Q=revallpay;
        if costutiltype=6 then outpatient_Q=revallpay;
        if costutiltype=0 then outpatient_Q=revallpay;
        ** 0067T are colonscopy and it looks like maybe this was billed early,;
        ** they didnt start reimbursing for that code till 06. This is placed in group 6 for ;
        ** because they fall in group 1 but have no weight or payment amont- small amount of claims. ;
        outpatient_QTcode=outpatient_Q;
        if costutiltype=1 and APCwgt_tcode ne . then outpatient_QTcode=APCwgt_tcode*confact;
        *** Add variable here to the final output;
        keep si apc hcpcs_cd costutiltype outpatient_Q APCwgt confact bene_id dgn_date
             rev_dt payrate cyear revallpay outpatient_QTcode APCwgt_tcode clm_id diag_id  si_clms
             pmtmthd1 rev_month NewTechAPC from_dt thru_dt      ;

        LABEL
            si= "status indicator from Addendum B"
            outpatient_Q= "Cost utilization measure, use with costutiltype"
            outpatient_QTcode= "Similar to Outpatient_Q, except enfoces the .5 downrate for multiple T-code"
            costutiltype= "Indicator the type of claim, see medicare docs for documentation"
            APCwgt= "APC wght"
            APCwgt_tcode="APC wght with associated T code down grades"
            confact="Conversion factor, $ per APC wght"
            pmtmthd1="Payment method/ status indicator from the claims"
            rev_month=""
            NewTechAPC=""
            si_clms=""
            apc=""
            payrate=""
            revallpay=""
            ;

    run;


    proc sql;
       select costutiltype, sum(outpatient_Q) as outpatient_QTotal,sum(outpatient_QTcode) as outpatient_QTcodeTotal,
           sum(APCwgt_tcode) as APCwgt_tcode,sum(revallpay) as revallpay
       from costutil.&cohrt.&pct._OPPSq
        group by costutiltype;
    run;


    *######################################### ;
    **AGGREGATE UP TO THE YEAR LEVEL -- FOR TESTING;
    *#########################################;
    proc sort data=costutil.&cohrt.&pct._OPPSq;
        by cyear;
    run;

    data averageprovapcs&testlos.
        (keep=cyear totnonOPPS totOPPSwght totOPPSpayrate totUnAdjOPPS tot_rev
               APCwghtTot APCwghtTotDiscount ratio_wght  ratio_wghtDIS confact outpatient_Q outpatient_QTcode) ;
        set costutil.&cohrt.&pct._OPPSq ;
        where (rev_dt-dgn_date<=&testlos. and rev_dt-dgn_date >=0) ;
        by cyear ;

        retain totnonOPPS totOPPSwght totOPPSpayrate totUnAdjOPPS tot_rev totoutpatient_Q
               totoutpatient_QTcode APCwghtTot APCwghtTotDiscount ratio_wght  ratio_wghtDIS 0;

        if first.cyear then do;
            totoutpatient_Q=0;
            totoutpatient_QTcode=0;
            totnonOPPS=0;
            totOPPSwght=0;
            totOPPSpayrate=0;
            totUnAdjOPPS=0;
            tot_rev=0;
            APCwghtTot=0;
            APCwghtTotDiscount=0;
            end;

        *ADD UP ALL PAYMENTS;
        if revallpay ne .  then tot_rev=tot_rev+revallpay;
        *ONLY ADD UP PAYNENTS WHICH ARE PAYED THROUGH OPPS;
        if costutiltype=0 then totnonOPPS=totnonOPPS+revallpay ;
        if costutiltype=1 then totOPPSwght=totOPPSwght+revallpay ;
        if costutiltype=2 then totOPPSpayrate=totOPPSpayrate+revallpay ;
        if costutiltype=3 then totUnAdjOPPS=totUnAdjOPPS+revallpay ;
        if totoutpatient_Q ne . then totoutpatient_Q=outpatient_Q+totoutpatient_Q;
        if totoutpatient_QTcode ne . then totoutpatient_QTcode=outpatient_QTcode+totoutpatient_QTcode;
        **ADD UP WEIGHTS;
        if APCwgt_tcode ne . and costutiltype=1  then APCwghtTotDiscount=APCwghtTotDiscount+APCwgt_tcode;
        if APCwgt ne . and costutiltype=1  then APCwghtTot=APCwghtTot+APCwgt;

        if last.cyear then do;
            if APCwghtTotDiscount  ne 0 then ratio_wght=totOPPSwght/APCwghtTotDiscount;
            if ratio_wghtDIS ne 0 then ratio_wghtDIS=totOPPSwght/APCwghtTot;
            output;
            end;
    run;


    *######################################### ;
    **CHECK COSTS PER STATUS INDICATOR (si);
    *#########################################;
    TITLE "TOTAL WEIGHTS AND COSTS PER YEAR WITH A LOS OF &testlos.";
    proc print data=averageprovapcs&testlos.;
    run;
    TITLE "";



/*    %archiveoldLogfiles(pct=&pct.,cohrt=&cohrt.,yearin=&yearin.,
        yearout=&yearout.,los=&testlos.)               ;*/

    %mend;













