
%macro CombineOPclms_revcenter(pct=,cohrt=,yearin=,yearout=);
    ** #### START PROCESSING CLAIMS AND REV CENTERS  ###;
    ** Note that there are some elements we need which exist at the;
    *  claims level and others which exist at the rev center level;
    *  the idea is to merge them together at the revcenter level. ;
    *  Next we would then merge in the APC and aggregate everything;
    *  claims levels, adding together APC relative weights.;

    *#########################################;
    *### READ IN REVENUE CENTERS;
    *#########################################;
    data spcost.&cohrt.revcenter&yearin._&yearout. ;
        set opex.&cohrt.&pct._oprevcntrs;
        where fileYear>=(&yearin.-1);
        rev_year=year(rev_dt);
        rev_month=month(rev_dt);

        *** revenue centers which have been aggregated -- double counts costs;

        *stat_ind=substr(PMTMTHD,1,1);
        revallpay=REVPMT;
        if revblood ne . then revallpay=revallpay+revblood;
        if wageadj ne . then revallpay=revallpay+wageadj;
        if rdcdcoin ne . then revallpay=revallpay+rdcdcoin;
        if revdctbl ne . then revallpay=revallpay+revdctbl;
        if REV_MSP1 ne . then revallpay=revallpay+REV_MSP1;
        if REV_MSP2 ne . then revallpay=revallpay+REV_MSP2;
    run;

    *#########################################;
    *### READ IN CLAIMS;
    *#########################################;
    data spcost.&cohrt.clms&yearin._&yearout. ;
        set opex.&cohrt.&pct._opclms;
        where fileYear >= (&yearin.-1) ;
        from_yr = year(from_dt);
        thru_yr = year(thru_dt);
        allpay = pmt_amt;
        if prpayamt ne . then allpay = allpay + prpayamt;
        if ptb_ded  ne . then allpay = allpay + ptb_ded;
        if ptb_coin ne . then allpay = allpay + ptb_coin;
        if blddedam ne . then allpay = allpay + blddedam;
    run;

    *#########################################;
    *### GET STATS TO MAKE SURE THAT COSTS ADD UP IN REV AND CLMS;
    *#########################################;
    *Reveneu center and claims are almost identical in terms of total costs;
    proc sql;
        select fileyear, sum(allpay) as clmPay, sum(pmt_amt) as pmtamttot, sum(prpayamt) as prpayamttot, sum(ptb_ded) as dedtot, sum(ptb_coin) as cointot, sum(blddedam) as blddedam
            from spcost.&cohrt.clms&yearin._&yearout.
        group by fileyear;
        quit;

    proc sql;
        select fileyear, sum(revallpay) as revPay , sum(revpmt) as revpaytot,
                         sum(wageadj) as wageadkAll , sum(rdcdcoin) as cointot,
                         sum(revdctbl) as dctbltot,sum(rev_msp1) as revm1tot ,
                         sum(rev_msp2) as revm2tot
            from spcost.&cohrt.revcenter&yearin._&yearout. where rev_cntr ne "0001"
            group by fileyear;
        quit;

    *#########################################;
    *## MERGE TOGETHER REV AND CLMS;
    *#########################################;
    proc sort data=spcost.&cohrt.revcenter&yearin._&yearout.;
        by clm_id  diag_id  bene_id fileyear;
    run;

    proc sort data=spcost.&cohrt.clms&yearin._&yearout. ;
        by clm_id  diag_id  bene_id  fileyear;
    run;

    data spcost.&cohrt.merge_revclms ;
        merge spcost.&cohrt.revcenter&yearin._&yearout. (in=rev) spcost.&cohrt.clms&yearin._&yearout. (in=clm ) ;
        by clm_id  diag_id  bene_id fileyear;
        rev_fl=rev;
        clm_fl=clm;
        if rev_year=. then rev_year=from_yr;
        cyear=rev_year;
        if rev_dt=. then rev_dt=thru_dt;
        if rev_dt=. then rev_month=month(thru_dt);
        /*flag2001April=0;
        if rev_year=2001 & rev_month >=4 then flag2001April=1;*/
        if rev_year < &yearin. then delete;
        /*keep cyear  fileyear  diag_id  bene_id clm_id clm_fl rev_fl dgn_date
             REVPMT revblood wageadj rdcdcoin revdctbl REV_MSP1 REV_MSP2
             rev_year hcpcs_cd rev_dt thru_dt rev_cntr apchipps revallpay ;*/
    run;

    x "rm &spcost./&cohrt.revcenter&yearin._&yearout..* -f";
    x "rm &spcost./&cohrt.clms&yearin._&yearout..* -f";
%mend;
