** Generates transfer flags occuring in the MedPAR files only;
** The program take the ICD9-CM codes as input, code= and adds flags
** to the medpar extracts harmonized dataset. Appends transfer flag
** variable to indx and medparclms files.;

** Make sure the index files and medpar claims cover the same years when running this,
** script.
**Maurice Dalton, daltonm.at.nber.org;
**;
** PROGRAM STRUCTURE;
** The program relies on the data being sorted in the proper order-by ep_indxNT.;
**;
*!!!!WRAPPER MACRO FOUND AT THE END ---%RunDefineIndexEvents!!!!!;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./read_sysparm.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";
libname medex  "&medparExt.";
libname indxex "&indxExt.";



%macro FlagTRansfers(cohrt=,pct=, code=);
    **CHECK WHETHER FLAG SCEN VARIABLES HAVE BEEN ADDED YET IF THEY HAVE DO NOT RUN CODE;
    ************************************************************************************;
    ** STEP1: SORT BE THE NEWLY CREATED INDEX;
    ************************************************************************************;
        proc sort data=medex.&cohrt.&pct._medparclms;
            by diag_id ep_indxNT;
        run;

    ************************************************************************************;
    ** STEP3: GENERATE TRANSFER FLAGS;
    ************************************************************************************;
        data TransferFlag;
            set medex.&cohrt.&pct._medparclms ;
        ********TRANSFER TAGS*******************;
            by diag_id;
            dgnCD1_lag=lag(dgnscd1);
            if first.diag_id then dgnCD1_lag="";

            clm_end_lag=lag(dschrgdt);
            if first.diag_id then clm_end_lag=.;

            difEndStart=clm_end_lag-admsndt;

            if first.diag_id then difEndStart=.;

            dgnCD1_lag=substr(dgnCD1_lag,1,3);
            dgnCD1_stub=substr(dgnscd1,1,3);

            flagScen1=0;
            flagScen2=0;
            flagScen3=0;

            if first.diag_id then  flagScen1=0;
            if first.diag_id then  flagScen2=0;
            if first.diag_id then  flagScen3=0;


*SCENARIO1:This is the case where the index event is not classified as the first one. We dont have this problem with ;
* our algorithm, except with the SNF exception.;
**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
* This relies on the assumption that we are using a 1 year window;
* around the index event to pull claims and that we do not allow canidate claims falling within 1 year of each other to be ;
* a index event - we keep the first one and drop the rest  ;
**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!            ;
            if  dgn_date>admsndt and dgnCD1_stub="&code." then flagScen1=1;


            *HARD CODE ACS BECAUSE IT HAS MORE THEN 1 CODE;
            if "&cohrt."="acs" then do;
*SCENARIO2:This is the case where we have and individual who has been hospitalized before the index event with ;
*a different dgn_cd but is then transfered into another hospitalization  where  an AMI is reported as the principal diagnosis.;
                if (difEndStart=-1 or difEndStart=0 ) and (admsndt=dgn_date
                    and (dgnCD1_stub="410" or dgnCD1_stub="411" or dgnCD1_stub="413" or dgnCD1_stub="414"))
                    and (dgnCD1_lag ne "410" or dgnCD1_lag ne "411" or dgnCD1_lag ne "413" or dgnCD1_lag ne "414" )then flagScen2=1;
                if difEndStart=. then flagScen2=0;


*SCENARIO3:This is a rule medex type case. An individual goes in for an AMI. The claim start and stop date is the same date- from where it becomes ;
*However there is a second claim starting on the same day with a separate principle diagnosis- suggesting that there may have been a;
*miss diagnosis or tests which ruled medex the diagnosis.;
                if (difEndStart=0 or difEndStart=1)
                    and ((admsndt-dgn_date=1 or admsndt-dgn_date=0 )
                    and (dgnCD1_stub="410" or dgnCD1_stub="411" or dgnCD1_stub="413" or dgnCD1_stub="414"))
                    and (dgnCD1_stub ne "410" or dgnCD1_stub ne "411" or dgnCD1_stub ne "413" or dgnCD1_stub ne "414" )
                    then flagScen3=1;
                if difEndStart=. then flagScen3=0;
                end;

            else do;
*SCENARIO2:This is the case where we have and individual who has been hospitalized before the index event with ;
*a different dgn_cd but is then transfered into another hospitalization  where  an AMI is reported as the principal diagnosis.;
                if (difEndStart=-1 or difEndStart=0 ) and (admsndt=dgn_date and dgnCD1_stub="&code." ) and dgnCD1_lag ne "&code." then flagScen2=1;
                if difEndStart=. then flagScen2=0;


*SCENARIO3:This is a rule out type case. An individual goes in for an AMI. The claim start and stop date is the same date- from where it becomes ;
*However there is a second claim starting on the same day with a separate principle diagnosis- suggesting that there may have been a;
*miss diagnosis or tests which ruled out the diagnosis.;
                if (difEndStart=0 or difEndStart=1)  and ((admsndt-dgn_date=1 or admsndt-dgn_date=0 ) and dgnCD1_lag="&code." ) and dgnCD1_stub ne "&code." then flagScen3=1;
                if difEndStart=. then flagScen3=0;
                end;
**********************;

    run;

    *Tag Transfer Index Events;
        proc sort data=TransferFlag (keep=diag_id flagScen1) out=flag1 nodupkey;
            WHERE flagScen1=1;
            by diag_id;
        run;

        proc sort data=TransferFlag (keep=diag_id flagScen2) out=flag2 nodupkey;
            WHERE flagScen2=1;
            by diag_id;
        run;

        proc sort data=TransferFlag (keep=diag_id flagScen3) out=flag3 nodupkey;
            WHERE flagScen3=1;
            by diag_id;
        run;

        proc sort data=indxex.&cohrt.&pct._indx;
            by diag_id;
        run;

    *MErge in Flags--;
        data indxex.&cohrt.&pct._indx;
            merge flag1 flag2 flag3 indxex.&cohrt.&pct._indx (in=inindx) ;
            by diag_id;
            if inindx=1;
            if flagScen1=. then flagScen1=0;
            if flagScen2=. then flagScen2=0;
            if flagScen3=. then flagScen3=0;

        LABEL
         flagScen1="Transfer flag, diagnosis event 1-year prior to index event"
         flagScen2="Transfer flag, transfer into the index event from non-diagnosis event"
         flagScen3="Transfer flag, transfer medex of the index event with a non-diagnosis event";

        run;

    *Merge in Flags;
        data medex.&cohrt.&pct._medparclms;
            merge flag1 flag2 flag3 medex.&cohrt.&pct._medparclms (in=inmclm)  ;
            by diag_id;
            if inmclm=1;
            if flagScen1=. then flagScen1=0;
            if flagScen2=. then flagScen2=0;
            if flagScen3=. then flagScen3=0;
        run;
libname medex  "&medparExt.";
libname indxex "&indxExt.";

        x "st &medparExt./&cohrt.&pct._medparclms.sas7bdat &medparExt./&cohrt.&pct._medparclms.dta -Y ";
        x "st &indxExt./&cohrt.&pct._indx.sas7bdat &indxExt./&cohrt.&pct._indx.dta -Y ";

%mend;

** USERS NEED TO IDENTIFY THE 3 DIGIT PORTION OF THE ICD9_CM diagnostic CODE USED TO IDENTIFY THE INDEX;
** NOTE THAT ACS EXAMPLE HAS BEEN HARDCODED.;
%FlagTRansfers(cohrt=&cohrt.,pct=&pct., code=&code.);


*%FlagTRansfers(cohrt=ami,pct=100, code=410);
*%FlagTRansfers(cohrt=hip,pct=100, code=820);
*%FlagTRansfers(cohrt=chf428,pct=100, code=428);


