%macro OrderMedPARClaims(libname=,start=,end=,sampleRule=mn, diag=, dgnPos=,pct=,identifier=);
    ** Sorts files within diag episode in order to get them in chronological order;
    ** Sorting criteria are as follows, getting somewhat more speculative as numbers increase:;
    ** 1) Admit date;
    ** 2) Discharge date (with flag to ensure that missing discharge dates go at the end);
    ** 3) Admissions where the patient dies go after others;
    ** 4) Emergency admissions (identified one of two ways) go before non-emergency admissions;
    ** 5) Admissions where the source of admission is a transfer go after non-transfers.;
    ** 6) Admissions that have more procedure codes are assumed to come later;
    data &libname..&diag.&pct._&dgnPos._claims_&samplerule._&identifier.;
        set &libname..&diag.&pct._&dgnPos._claims_&samplerule._&identifier.;
          * I want to be able to treat the discharge date as a claim end date;
        * so I replace the missing discharge dates using the length of stay;
        * variables;
            if dschrgdt = . then do;
                dschrgdt = admsndt + loscnt - 1;
                end;

            dschgMiss = (dschrgdt = .);
            transfer = (src_adms = "4");
            died = (dstntncd = "20");
            noEmerg1 = not (type_adm = "1");
            noEmerg2 = not (src_adms = "7");

        run;

    proc sort data=&libname..&diag.&pct._&dgnPos._claims_&samplerule._&identifier.;
        by diag_id admsndt dschgMiss dschrgdt died noEmerg1 noEmerg2 transfer prcdrcnt;
    run;

** DATA STEP 14;
    data &libname..&diag.&pct._&dgnPos._claims_&samplerule._&identifier.;
        set &libname..&diag.&pct._&dgnPos._claims_&samplerule._&identifier.;
        by diag_id admsndt dschgMiss dschrgdt died noEmerg1 noEmerg2 transfer prcdrcnt;

       * nt stands for <<no ties>> (ties broken arbitrarily);
        retain ep_indx ep_indxNT;

        * flag ambiguous orderings;
        ambigOrder = 0;
        if not (first.prcdrcnt and last.prcdrcnt) then do;
            ambigOrder = 1;
            end;

        * flag orderings that are ambiguous if using only the dates and the death code;
        ambigOrder_dd = 0;
        if not (first.died and last.died) then do;
            ambigOrder_dd = 1;
            end;

        * impose orderings within diag episodes;
        if first.diag_id then do;
            ep_indx = 1;
            ep_indxNT = 1;
            end;
        else do;
            ep_indxNT = ep_indxNT + 1;
            if not ambigOrder then do;
                ep_indx = ep_indx + 1;
                end;
            end;

        drop dschgMiss transfer died noEmerg1 noEmerg2;
    run;

    %mend;

