** This program makes use of the population level views I have generated for the carrier file;
** the aim of this program is to generate physician level counts of beto codes in order to aid;
** in assigning a doctor to a specializaiton;
** ;
** The program will basically bring in the sas view, merge in the AMA crosswalk
** then compress the data;
***********************************************************************;
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./generateEnrollRest.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spxw "&spxw.";
libname spcar "&spcar.";
libname spden "&spden.";

libname here ".";
libname indxex "&indxExt.";
libname carex  "&carext.";
libname cartmp "&cartmp.";

libname bene "&inbenexw.";
libname xwfile "&xwfile.";
libname carvw  "&carext./view";
libname carvwtm  "&carext./view/temp";

libname opvw  "&opext./view";
libname opvwtm  "opext./view/temp";
libname globex "&globex";
x "mkdir &carext./view/temp -p";

%let texout=&texroot.;
x "mkdir -p &texroot./05/globalstats";
x "mkdir -p &texroot./20/globalstats";
x "mkdir -p &texroot./100/globalstats";



%macro pulldenominatorinfo(pct=,yearin=,yearout=);
    %do y=&yearin. %to &yearout.;
        x "cp &inden./pop&pct._demo_bene_id&y.* &spden./ -f ";
        %end;

    x "cp &inden./pop&pct._demo_bene_idcharvar&yearout.* &spden./ -f ";
    x "bunzip2 &spden./*&pct.*.*bz2  ";


    %do yrloop=&yearin. %to &yearout.;
        data processdenom&yrloop. ;
            *(keep=flag: refDate&yrloop. bene_id year);
            merge spden.pop&pct._demo_bene_idcharvar&yearout. (in=other)
                %do yr=&yearin. %to &yearout.; spden.pop&pct._demo_bene_id&yr. (in=indem ) %end;;
            by bene_id;
            if indem and other;
            refDate&yrloop. = MDY(1,1,&yrloop.);
            *let months&yrloop.=%eval((&yearout. - &yrloop. +1)*12 -1 );
            age&yrloop. = &yrloop. - year(sdob);
            yrref=year(refDate&yrloop.);

            %generateEnrollRest(indxDateVar=refDate&yrloop.,end=&yearout.,start=&yearin.,
                FFSmonthpost=1, HMOmonthpost=1,
                FFSmonthpre=12,   HMOmonthpre=12  );
            %generateEnrollRest(indxDateVar=refDate&yrloop.,end=&yearout.,start=&yearin.,
                FFSmonthpost=1, HMOmonthpost=0,
                FFSmonthpre=12,   HMOmonthpre=0  );
            %generateEnrollRest(indxDateVar=refDate&yrloop.,end=&yearout.,start=&yearin.,
                FFSmonthpost=12, HMOmonthpost=0,
                FFSmonthpre=12,   HMOmonthpre=0  );
            %generateEnrollRest(indxDateVar=refDate&yrloop.,end=&yearout.,start=&yearin.,
                FFSmonthpost=11, HMOmonthpost=11,
                FFSmonthpre=11,   HMOmonthpre=11  );

            %generateEnrollRest(indxDateVar=refDate&yrloop.,end=&yearout.,start=&yearin.,
                FFSmonthpost=12, HMOmonthpost=12,
                FFSmonthpre=12,   HMOmonthpre=12  );
            year=&yrloop.;
            flag_01HMO12_01FFS12=0;
            if eHMO_post1=1 and eHMO_pre12=1 and eFFS_post1=1 and eFFS_pre12=1 then flag_01HMO12_01FFS12=1;
            flag_00HMO00_12FFS01=0;
            if eFFS_post1 and eFFS_pre12 then flag_00HMO00_12FFS01=1;
            flag_00HMO00_12FFS12=0;
            if eFFS_post12 and eFFS_pre12 then flag_00HMO00_12FFS12=1;
            flag_11HMO11_11FFS11=0;
            if eHMO_post11 and eHMO_pre11 and eFFS_post11 and eFFS_pre11 then flag_11HMO11_11FFS11=1;
            flag_12HMO12_12FFS12=0;
            if eHMO_post12 and eHMO_pre12 and eFFS_post12 and eFFS_pre12 then flag_12HMO12_12FFS12=1;
            flag_12HMO01_12FFS01=0;
            if eHMO_post1 and eHMO_pre12 and eFFS_post1 and eFFS_pre12 then flag_12HMO01_12FFS01=1;

        run;

        %end;


    data enroldata ;
        set     %do y=&yearin. %to &yearout.; processdenom&y.  %end;;
    run;

    proc sql;
        create table enrollment as
        select year, sum(flag_12HMO12_12FFS12) as H1212_F1212,
            sum(flag_11HMO11_11FFS11) as H1111_F1111,
            sum(flag_01HMO12_01FFS12) as H0112_F0112,
            sum(flag_12HMO01_12FFS01) as H1201_F1201,
            sum(flag_00HMO00_12FFS12) as H0000_F1212,
            sum(flag_00HMO00_12FFS01) as H0000_F1201
            from enroldata
            group by year;
        quit;

    data toprint;
        set enrollment;
        H1212_F1212= H1212_F1212 / (10*6);
        H1111_F1111= H1111_F1111 / (10*6);
        H0112_F0112= H0112_F0112 / (10*6);
        H1201_F1201= H1201_F1201 / (10*6);
        H0000_F1212= H0000_F1212 / (10*6);
        H0000_F1201= H0000_F1201 / (10*6);
run;


    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/enrollmentcount.tex"  (notop nobot) newfile=table ;
    proc sql;
        select *
            from toprint
        quit;
    ods tagsets.tablesonlylatex ;

        x "rm &spxw./* -f";
        x "rm &spden./* -f";

    %mend;

*%pulldenominatorinfo(pct=0001,yearin=1984,yearout=2011);
%pulldenominatorinfo(pct=05,yearin=1984,yearout=2011);
*%pulldenominatorinfo(pct=20,yearin=1984,yearout=2011);
*%pulldenominatorinfo(pct=100,yearin=1992,yearout=2011);
