** This program makes use of the population level views I have generated for the carrier file;
** the aim of this program is to generate physician level counts of beto codes in order to aid;
** in assigning a doctor to a specializaiton;
** ;
** The program will basically bring in the sas view, merge in the AMA crosswalk
** then compress the data;
***********************************************************************;
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spxw "&spxw.";
libname spcar "&spcar.";
libname here ".";
libname indxex "&indxExt.";
libname carex  "&carext.";
libname carvw  "&carext./view";
libname carvw  "&carvw.";
libname carvwtm  "&carvw./tmp";
libname bene "&inbenexw.";
libname xwfile "&xwfile.";


%let texout=&texroot.;
x "mkdir -p &texroot./0001/globalstats";
x "mkdir -p &texroot./05/globalstats";
x "mkdir -p &texroot./20/globalstats";
x "mkdir -p &texroot./100/globalstats";


%macro DecompressPartYear(spaceDir=,dataRoot=,year=,pctsuffix=,pct=,part=);
        ***************************************************************************;
        ** Decompress file(s);
        * Due to space limitations, only one file is decompressed at a time for a given year;
        ***************************************************************************;
    %if &year. >= 2002 %then %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=car,pct=&pct.,year=&year.,subtype=clms,pctsuffix=&pctsuffix.,indx=&part.);

        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=car,pct=&pct.,year=&year.,subtype=lnits,pctsuffix=&pctsuffix.,indx=&part.);
        %end;
    %else %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=car,pct=&pct.,year=&year.,pctsuffix=&pctsuffix.,indx=&part.);
        %end;

    %mend;


%macro sumcarriercosts(year=,pctsuffix= ,pct=,part=,view=,spaceDir=,dataRoot=);


    data cartmp;
        set carvw.car&pct.&suffix._clmline_&year._&part. (keep=lalowchg expnsdt1 fileyear pmtdnlcd);
        WHERE pmtdnlcd NE "0";
    run;

    proc sql;
         create table sumcosts as
            select DISTINCT year(expnsdt1) as expyr, sum(lalowchg) as carcost, count(*) as countraw
            from cartmp             ;
        quit;

    proc append base =spcar.car&pct.costsum
                data =sumcosts ;
    run;

    proc sql;
        create table sumcosts as
            select DISTINCT fileyear, sum(lalowchg) as carcost, count(*) as countraw
            from carvw.car&pct.&suffix._clmline_&year._&part.
             WHERE pmtdnlcd NE "0";
        quit;

    proc append base =spcar.car&pct.costsum_fileyear
                data =sumcosts ;
    run;

    ** Clean up datasets no longer needed;
    x "rm &spcar./* -f ";

    %mend;

%macro generatefinal(pct=);

    data globex.car_millions;
        set spcar.car&pct.costsum;
        carcostm=carcost/(10**6);
        countrawm=countraw/(10**6);
    run;

    data globex.car_millions_fileyear;
        set spcar.car&pct.costsum_fileyear;
        carcostm=carcost/(10**6);
        countrawm=countraw/(10**6);
    run;

    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_car_annual_lalowchg.tex"  (notop nobot) newfile=table ;
        proc sql;
                select distinct expyr, sum(carcostm) as totalcost_mill, sum(countrawm) as countraw_mil
                from globex.car_millions
                group by expyr;
            quit;
    ods tagsets.tablesonlylatex;

        ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_car_annual_lalowchg_fileyear.tex"  (notop nobot) newfile=table ;
        proc sql;
                select distinct fileyear, sum(carcostm) as totalcost_mill, sum(countrawm) as countraw_mil
                from globex.car_millions_fileyear
                group by fileyear;
            quit;
    ods tagsets.tablesonlylatex;


%mend;
**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunCarExtraction(pct="",yearin=,yearout=,clmDTA=,view=);

    ** Copy formatted xwfiles to local space drives for faster processing;
**************************************************************************;
** THROW ERROR FOR BAD PARAMETERS ;
**************************************************************************;
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    x "rm &spcar./* -f " ;
    x "rm &spcar./* -f ";
    **clear old datasets;
    ** Copy formatted xwfiles to local space drives for faster processing;

    x "rm &spxw./* -f ";
    x "cp &inbenexw./ehicbenex_unique_bene_indx&pct..* &spxw./ -f ";
    x "cp &inbenexw./ehicbenex_unique&pct..* &spxw./ -f ";
    x "bunzip2 &spxw./*&pct.*.*bz2  ";

**************************************************************************;
********Deal with a crash if defined in the parameter - crashStart********;
**************************************************************************;
****************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
    %do y=&yearin. %to &yearout.;
       **************************************************************************;
       ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
            %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);
           **This macro creates the num_file macro which is used to loop through;
        %do z= 1 %to &num_file.;
            %if &z. = 1 and &y.=&yearin. %then %do;
                x "rm &spcar./car&pct.costsum* -f ";
                %end;

            %breakFilename2parts(ftype=car,pct=&pct.,z=&z.,year=&y.);
            *******************************************************************;
            ** Decompress single file;
            **************************************************************************;
            %DecompressPartYear(spaceDir = &spcar., dataRoot=&dataRoot., year = &y.,
                            pctsuffix = &suffix., pct = &pct., part = &part.);


            %sumcarriercosts(pct=&pct.,year = &y., pctsuffix = &suffix.,view=&view.,
                part = &part.,spaceDir = &spcar., dataRoot=&dataRoot.);
            %end;

        %end;

        %generatefinal(pct=&pct.);

        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE LOG/LST FILE;
        %archiveoldLogfiles(pct=&pct.,cohrt=carcost,yearin=&yearin.,yearout=&yearout.);
        x "rm &spxw./* -f";
        x "rm &spcar./* -f";

        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
        %let tAfterRun=%sysfunc(datetime());
        %put &tAfterRun.-&tBeforeRun.;
        %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
        %put <TIMER> Process Years  ALL took &elapsedRun. minutes.;

        %mend;


** probelm here is that we dont have all residency programs!  ;
%RunCarExtraction(pct=05,
    yearin=2009,yearout=2011,
    clmDTA=0,view=on);
/*
%RunCarExtraction(pct=05,
    yearin=1999,yearout=2011,
    clmDTA=0,view=on);
%RunCarExtraction(pct=20,
    yearin=1999,yearout=2011,
    clmDTA=0,view=on);










