** This program makes use of the population level views I have generated for the medpar file;
** the aim of this program is to generate physician level counts of beto codes in order to aid;
** in assigning a doctor to a specializaiton;
** ;
** The program will basically bring in the sas view, merge in the AMA crosswalk
** then compress the data;
***********************************************************************;
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;

%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./generateEnrollRest.sas";
%include "&SASmac./ConformMedPar.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./errorCheckparameters.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spxw "&spxw.";
libname here ".";
libname indxex "&indxExt.";
libname spmed "&spmed.";
libname medex  "&medparExt.";
libname medvw  "&medvw.";
libname medvwtm  "&medvw./tmp";
libname medtmp "&medtmp.";


libname bene "&inbenexw.";
libname xwfile "&xwfile.";


%let texout=&texroot.;
x "mkdir -p &texroot./0001/globalstats";
x "mkdir -p &texroot./05/globalstats";
x "mkdir -p &texroot./20/globalstats";
x "mkdir -p &texroot./100/globalstats";


%macro DecompressPartYear(dirout=,dataRoot=,year=,libout=,pct=,dflag=);
        ***************************************************************************;
        ** Decompress file(s);
        * Due to space limitations, only one file is decompressed at a time for a given year;
        ***************************************************************************;
    %decompressMedPar(yr=&year.,pct=&pct., libout=&libout., dataroot=&dataroot.,
        dirout=&spmed.,dflag=&dflag.);


    %mend;


%macro summedparcosts(year=,pct=,spaceDir=,dataRoot=);

data mtmp;
set medvw.medpar&pct._&year. (keep=admsndt drgprice outlramt passthru fileyear );
run;
        proc sql;
            create table sumcosts as
                select DISTINCT year(admsndt) as admyr, sum(sum(drgprice,outlramt,passthru)) as mparcost , count(*) as rawobs
                from mtmp
                group by admyr;
            quit;

        proc sql;
            create table sumcosts_fileyear as
                select DISTINCT fileyear, sum(sum(drgprice,outlramt,passthru)) as mparcost , count(*) as rawobs
                from mtmp
                group by fileyear;
            quit;


    proc append base =spmed.mpar&pct.costsum
    data =sumcosts ;
    run;
    proc append base =spmed.mpar&pct.costsum_fileyear
    data =sumcosts_fileyear ;
    run;

    %mend;

%macro generatefinal(pct=);

    data medpar_millions;
        set spmed.mpar&pct.costsum;
        mparcostm=mparcost/(10**6);
        mrawobs=rawobs/(10**6);
    run;

    proc freq data=medpar_millions;
        table admyr /missing;
    run;
    data medpar_millions_fileyear;
        set spmed.mpar&pct.costsum_fileyear;
        mparcostm=mparcost/(10**6);
        mrawobs=rawobs/(10**6);
    run;

    proc freq data= medpar_millions_fileyear;
        table fileyear /missing;
    run;


    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_medpar_annual_allreimb.tex"  (notop nobot) newfile=table ;
    proc sql;
        select distinct admyr, sum(mparcostm) as totalcost_mill, sum(mrawobs) as obs_mill
            from medpar_millions
            group by admyr;
        quit;
        ods tagsets.tablesonlylatex;
    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_medpar_annual_allreimb_fileyear.tex"  (notop nobot) newfile=table ;

    proc sql;
        select distinct fileyear, sum(mparcostm) as totalcost_mill, sum(mrawobs) as obs_mill
            from  medpar_millions_fileyear
            group by fileyear;
        quit;
        ods tagsets.tablesonlylatex;

    %mend;
**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunMEdExtraction(pct="",yearin=,yearout=,clmDTA=);

    ** Copy formatted xwfiles to local space drives for faster processing;
**************************************************************************;
** THROW ERROR FOR BAD PARAMETERS ;
**************************************************************************;
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    x "rm &spmed./* -f " ;
    **clear old datasets;
    ** Copy formatted xwfiles to local space drives for faster processing;
    x "rm &spxw./* -f ";
    x "cp &inbenexw./ehicbenex_unique_bene_indx&pct..* &spxw./ -f ";
    x "cp &inbenexw./ehicbenex_unique&pct..* &spxw./ -f ";
    x "bunzip2 &spxw./*&pct.*.*bz2  ";

**************************************************************************;
********Deal with a crash if defined in the parameter - crashStart********;
**************************************************************************;
****************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
    %do y=&yearin. %to &yearout.;


        *******************************************************************;
        ** Decompress single file;
        **************************************************************************;
        %DecompressPartYear(dirout=&spmed.,dataRoot=&dataroot.,year=&y.,libout=spmed,pct=&pct.,dflag=1);

        %summedparcosts(pct=&pct.,year = &y.,
            spaceDir = &spmed., dataRoot=&dataRoot.);
        %end;

    %generatefinal(pct=&pct.);

        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE LOG/LST FILE;
    %archiveoldLogfiles(pct=&pct.,cohrt=medparcost,yearin=&yearin.,yearout=&yearout.);
    x "rm &spmed./* -f " ;
    x "rm &medmp./* -rf ";
    x "rm &spxw./* -f";

        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
    %let tAfterRun=%sysfunc(datetime());
    %put &tAfterRun.-&tBeforeRun.;
    %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
    %put <TIMER> Process Years  ALL took &elapsedRun. minutes.;

    %mend;


** probelm here is that we dont have all residency programs!  ;
%RunMEdExtraction(pct=0001,
    yearin=1999,yearout=2011,
    clmDTA=0);


%RunMEdExtraction(pct=05,
    yearin=1999,yearout=2011,
    clmDTA=0);
%RunMEdExtraction(pct=20,
    yearin=1999,yearout=2011,
    clmDTA=0);
%RunMEdExtraction(pct=100,
    yearin=1999,yearout=2011,
    clmDTA=0);

*  %DecompressPartYear(dirout=&spmed.,dataRoot=&dataroot.,year=1992,libout=spmed,pct=05,dflag=1);
