** This program makes use of the population level views I have generated for the op file;
** the aim of this program is to generate physician level counts of beto codes in order to aid;
** in assigning a doctor to a specializaiton;
** ;
** The program will basically bring in the sas view, merge in the AMA crosswalk
** then compress the data;
***********************************************************************;
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

***********************************************************************;
* DEFINE DIRECTORIES****;
***********************************************************************;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname spxw "&spxw.";
libname spop "&spop.";
libname here ".";
libname indxex "&indxExt.";
libname opex   "&opext.";
libname opvw  "&opvw.";
libname opvwtm  "&opvw./tmp";
libname optmp  "&optmp.";
libname bene "&inbenexw.";
libname xwfile "&xwfile.";


%let texout=&texroot.;
x "mkdir -p &texroot./05/globalstats";
x "mkdir -p &texroot./20/globalstats";
x "mkdir -p &texroot./100/globalstats";


%macro DecompressPartYear(spaceDir=,dataRoot=,year=,pctsuffix=,pct=,part=);
        ***************************************************************************;
        ** Decompress file(s);
        * Due to space limitations, only one file is decompressed at a time for a given year;
        ***************************************************************************;
    %if &year. >= 2001 %then %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=op,pct=&pct.,year=&year.,subtype=clms,indx=&part.);

        %end;
    %else %do;
        %decompress_i(spaceDir=&spaceDir.,dataRoot=&dataRoot.,
            ftype=op,pct=&pct.,year=&year.,subtype=,indx=&part.);
        %end;

    %mend;


%macro sumopcosts(year=,pctsuffix= ,pct=,part=,spaceDir=,dataRoot=);



        data optmp;
            set opvw.op&pct._&year._clms_&part. (keep=from_dt pmt_amt ptb_ded ptb_coin blddedam prpayamt);
        run;



/*
            %end;
    %if &year<=1995 and &year>=1989 %then %do;
    data optmp;
            set opvw.op&pct._&year._clms_&part. (keep=from_dt prvdrpmt ptb_ded ptb_coin blddedam prpayamt);
        run;


    proc sql;
         create table sumcosts as
            select DISTINCT year(from_dt) as fromyr, sum(sum(prvdrpmt, ptb_ded, ptb_coin, blddedam, prpayamt )) as opcost, count(*) as obsraw
            from optmp
            group by fromyr;
        quit;

    proc sql;
         create table sumcosts_fileyear as
            select DISTINCT fileyear, sum(sum(prvdrpmt, ptb_ded, ptb_coin, blddedam, prpayamt )) as opcost, count(*) as obsraw
            from optmp
            group by fileyear;
        quit;

        %end;
    %if &year<=1988 and &year>=1986 %then %do;
    data optmp;
            set opvw.op&pct._&year._clms_&part. (keep=from_dt prvdrpmt ptb_ded ptb_coin  prpayamt)
        run;
*/
    proc sql;
         create table sumcosts as
            select DISTINCT year(from_dt) as fromyr, sum(sum(prvdrpmt, ptb_ded, ptb_coin, prpayamt)) as opcost, count(*) as obsraw
            from optmp
             group by fromyr;
        quit;

    proc sql;
         create table sumcosts_fileyear as
            select DISTINCT fileyear, sum(sum(prvdrpmt, ptb_ded, ptb_coin, prpayamt)) as opcost, count(*) as obsraw
            from optmp
            group by fileyear;
        quit;

  *      %end;

    proc append base =optmp.op&pct.costsum
                data =sumcosts ;
    run;

    proc append base =optmp.op&pct.costsum_fileyear
                data =sumcosts_fileyear ;
    run;

    ** Clean up datasets no longer needed;
    x "rm &spop./* -f ";
    %mend;

%macro generatefinal(pct=);

    data globex.op_millions;
        set optmp.op&pct.costsum;
        opcost=opcost/(10**6);
        obsrawm=obsraw/(10**6);
    run;
    data globex.op_millions_fileyear;
        set optmp.op&pct.costsum_fileyear;
        opcost=opcost/(10**6);
        obsrawm=obsraw/(10**6);
    run;

    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_op_annual_allreimb.tex"  (notop nobot) newfile=table ;
        proc sql;
                select distinct fromyr, sum(opcost) as totalcost_mill, sum(obsrawm) as totalobs_mill
                from globex.op_millions
                group by fromyr;
            quit;
    ods tagsets.tablesonlylatex;

    ods tagsets.tablesonlylatex file="&texout./&pct./globalstats/unrestricted_op_annual_allreimb_fileyear.tex"  (notop nobot) newfile=table ;
        proc sql;
                select distinct fileyear, sum(opcost) as totalcost_mill, sum(obsrawm) as totalobs_mill
                from globex.op_millions_fileyear
                group by fileyear;
            quit;
    ods tagsets.tablesonlylatex        ;
%mend;
**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunOpExtraction(pct="",yearin=,yearout=,clmDTA=);

    ** Copy formatted xwfiles to local space drives for faster processing;
**************************************************************************;
** THROW ERROR FOR BAD PARAMETERS ;
**************************************************************************;
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());
    x "rm &spop./* -f " ;
    x "rm &optmp./* -f ";
    **clear old datasets;
    ** Copy formatted xwfiles to local space drives for faster processing;
    x "rm &spxw./* -f ";
    x "cp &inbenexw./ehicbenex_unique_bene_indx&pct..* &spxw./ -f ";
    x "cp &inbenexw./ehicbenex_unique&pct..* &spxw./ -f ";
    x "bunzip2 &spxw./*&pct.*.*bz2  ";

**************************************************************************;
********Deal with a crash if defined in the parameter - crashStart********;
**************************************************************************;
****************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
    %do y=&yearin. %to &yearout.;
       **************************************************************************;
       ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
            %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.);
            **This macro creates the num_file macro which is used to loop through;

        %do z= 1 %to &num_file;
            %if &z. = 1 and &y.=&yearin. %then %do;
                x "rm &optmp./op&pct.costsum* -f ";
                %end;

            *******************************************************************;
            ** Decompress single file;
            **************************************************************************;
            %DecompressPartYear(spaceDir = &spop., dataRoot=&dataRoot., year = &y.,
                                pct = &pct., part = &z.);


            %sumopcosts(pct=&pct.,year = &y.,
                part = &z.,spaceDir = &spop., dataRoot=&dataRoot.);
            %end;

        %end;

        %generatefinal(pct=&pct.);

        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE LOG/LST FILE;
        %archiveoldLogfiles(pct=&pct.,cohrt=opcost,yearin=&yearin.,yearout=&yearout.);
        x "rm &optmp./* -rf ";
        x "rm &spxw./* -f";
        x "rm &spop./* -f";

        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
        %let tAfterRun=%sysfunc(datetime());
        %put &tAfterRun.-&tBeforeRun.;
        %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
        %put <TIMER> Process Years  ALL took &elapsedRun. minutes.;

        %mend;


** probelm here is that we dont have all residency programs!  ;

%RunOpExtraction(pct=0001,
    yearin=1992,yearout=2011,
    clmDTA=0);
/*%RunOpExtraction(pct=05,
    yearin=1999,yearout=2011,
    clmDTA=0);

%RunOpExtraction(pct=20,
    yearin=1999,yearout=2011,
    clmDTA=0);
%RunOpExtraction(pct=100,
    yearin=1999,yearout=2011,
    clmDTA=0);









