**Extract index events and corresponding claims from the inpatients and SNF claims (MEDPAR);
**Maurice Dalton, daltonm.at.nber.org,  based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.  All errors are my own.;
**;
** PROGRAM STRUCTURE;
** The program consists of several sas macros which are combined in a macro which sequences the;
** macros correctly.This wrapper macro is found at the end of the program and has several ;
** different parameters defined at the end of the program;

** Also note that the macro CreateReports can be found within the SAS macro directory defined
** below and can simply be called at the end of this program.;

** Note that it is suggested that individuals create extracts using the bene_id if you;
** are interested in the 2006-2008 data. As the code is structured now, extracting index;
** events based on ehic may create some duplicates.;

** IF INTERESTED IN RUNNING 100% or 20% FILE SPACE WILL LIKLY BE AN ISSUE. THE PROGRAM HAS
** BEEN STRUCTURED TO BE ABLE TO WORK WITH A FEW YEAR FILES AT A TIME AND DELETE THEM WHEN;
** THEY ARE DONE. USE THE DELETE FLAG ;

*WRAPPER MACRO FOUND AT THE END ---%RunPrgram;


options pagesize=200;
options nocenter;
*Use these options for debugging;
options symbolgen mlogic mprint mfile ;
options notes stimer fullstimer mprint msglevel=i;
options formdlim=" ";
options mergenoby=error;
options spool;
options errorabend;
options NOQUOTELENMAX;
**** PRELIMINARIES ****;
** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../dirInit.sas";


* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./AutoFileCountPipe.sas";
%include "&SASmac./decompressMedPar.sas";


********************************************************************;
********************RUN THIS SAS SCRIPT ONCE - Corresponding to PCT of interest*******************;
**** ;
%include "&SASmac./CW_create.sas";
       *  %CW_create(pct=05);
       *  %CW_create(pct=0001);
**** ;
********************************************************************;
********************************************************************;


*define libraries that allow access to the various directories specified above;
libname tempDir "&medtmp.";
libname out "&longExt.";
libname spDenom "&spden.";
libname outDen "&denExt.";
libname spMedpar "&spmed.";
libname bene "&benei.";
libname bene "&benei.";
libname xwfile "&xwfile.";




** AGGREGATE ALL MEDPAR FILES;
%macro usexw(pct=,start=,end=);
    %if &start. < 2006 %then %do;
        data ALL_MEDPAR2005;
        *Make sure all variable have the proper length;
            set %do yr=&start. %to 2005; spMedpar.medpar&pct._&yr._all (keep=ehic )%end;;
        run;

        proc sort data=ALL_MEDPAR2005 nodupkey;
            by ehic;
        run;

        proc sql;
            create table partialFile as
                select S.ehic, M.bene_id, M.count,  S.ehic
                from ALL_MEDPAR2005  S LEFT JOIN bene.ehicbenex_unique&pct.  M
                ON  (S.ehic = M.ehic);
            quit;

        data ALLFINALMEDPAR;
            LENGTH ehic $15;
            set partialFile;
            if bene_id="" then do;
                bene_id=ehic;
                flagEmpBene=1;
                end;
            if ehic="" then do;
                ehic=bene_id;
                end;
        run;

        proc sort data=ALLFINALMEDPAR;
            by ehic;
        run;

        %do yr=&start. %to 2005;
            proc sort data=spMedpar.medpar&pct._&yr._all;
                by ehic;
            run;


            data spMedpar.medpar&pct._&yr._all_bene;
                merge spMedpar.medpar&pct._&yr._all (in=medparraw) ALLFINALMEDPAR;
                by ehic;
                if medparraw;
            run;
            %end;
        %if &end >= 2006 %then %do;
            %do yr=2006 %to &end.;
                data spMedpar.medpar&pct._&yr._all_bene;
                    set spMedpar.medpar&pct._&yr._all ;
                **Define count variable as 1- one-bene_id to ehic post 2005;
                    count=1;
                    keep count ehic bene_id;
                run;
                %end;
            %end;
        %end;
    %else %do;
        %do yr=2006 %to &end.;
            data spMedpar.medpar&pct._&yr._all_bene;
                set spMedpar.medpar&pct._&yr._all ;
                **Define count variable as 1- one-bene_id to ehic post 2005;
                count=1;
                keep count ehic bene_id;
            run;
            %end;
        %end;
    %mend;

**#############################################################################;
*** BEGIN  WRAPPER MACRO HERE**************************************************;
**#############################################################################;
%macro CreateMedPARBENE(yearin=,yearout=,pct=,);
***STEP 1: PRELIMINARY MACRO WRAPPER PARAMETER DEFINITIONS---;

    *Make Sure we are starting with an empty dataset;
    proc datasets lib=work nolist kill ; run;


**#############################################################################;
*****---------TIMER CODE ----------;
**#############################################################################;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());

   ****************************************************;
   ** DECOMPRESS MEDPAR FILE;
   ****************************************************;
    %do y=&yearin. %to &yearout. ;
        %decompressMedPar(yr=&y.,pct=&pct.,fname=medpar,dflag=0);
        %end;


 ****************************************************;
   ** APPLY CROSS WALK;
   ****************************************************;

    %usexw(pct=&pct.,start=&yearin.,end=&yearout.);
    **#############################################################################;
    *****---------TIMER CODE ----------;
    **#############################################################################;
    %let tAftercohrt=%sysfunc(datetime());
    %let elapsedcohrt=%sysevalf(%sysevalf((&tAftercohrt.-&tBeforeRun.)/60));
    %put <TIMER> FINAL  took &elapsedcohrt. minutes  ;


    **#############################################################################;
    *Delete all temp files;
    **#############################################################################;



    %let tAfterRun=%sysfunc(datetime());
    %let elapsedrun=%sysevalf(%sysevalf((&tAfterRun.-&tBeforeRun.)/60));
    %put <TIMER> FINAL  took &elapsedrun. minutes  ;
    %mend;

*%CreateMedPARBENE(yearin=2006,yearout=2008,pct=05);
%CreateMedPARBENE(yearin=1984,yearout=2008,pct=20);
%CreateMedPARBENE(yearin=1992,yearout=2008,pct=100);
