/*
Program Overview;
Maurice Dalton,  dalton.at.nber.org
Based on code originally written by Matt Fiedler in Stata. All errors are my own.

    The program defines all procedure coding regimes for specific procedures of interest. It then
    proceeds to tag all claims files with an associated code. Note that instance in which more than one code
    for a procedure exists for a single index event across claims results in several procedures to be tagged.

    Look at the end of the program to call the macro;

/*	$Id: Step1_tagProcs.sas,v 1.4 2011/02/22 18:02:53 daltonm Exp daltonm $	*/




options pagesize=200;
options nocenter;
options mlogic;
options notes stimer fullstimer mprint msglevel=i;
options formdlim=" ";
options mergenoby=error;

*****PRELIMINARIES************
** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "/disk/agedisk1/medicare.work/wise-DUA16702/daltonm/Medicode/dirInit.sas";


* define libraries;
libname spcar "&spcar.";
libname longEx  "&longExt.";
libname carEx   "&carExt.";
libname OpEx   "&OpExt.";
libname procs   "&proc.";


* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./AutoFileCountPipe.sas";
* load files with macros that conform the files of various years into a common format;




*Define ICD9-CM coding regimes for different diagnosis-these are applied to the OP and MedPAR files;
%macro ICD9CMProc(diag=);
    length procType $15;
    procType="";

    prcdrcd=compress(prcdrcd," ");
    prcdrcd=compbl(prcdrcd);

    %if "&diag."="ami" or "&diag."="acs"  %then %do;
        pci_all=0;
        stent=0;
        cabg=0;
        cath=0;

       *angioplasty and artherectomy (with and without stent insertion);
        * Define PCI based on ICD9-CM Codes. Code 00.66 was introduced in 2007;
        if prcdrcd = "3601"
            or prcdrcd = "3602"
            or prcdrcd = "3605"
            or prcdrcd = "3609"
            or prcdrcd = "3600"
            or prcdrcd="360" or "0066"
            then pci_all=1;


       * Define stent based on ICD9-CM Codes- PCI with stent;
        if prcdrcd = "3606"
            or prcdrcd = "3607"
            then stent=1;


       * Define cabg  based on ICD9-CM Codes- ;
        if (substr(prcdrcd,1,3) = "361")
            then cabg=1;


    **CATH (and CAG);
      ***Code only left (372.2) or left & right together (372.3);
      ***Code CAG as well 88.55-88.57;
        if  prcdrcd = "3722"
            or prcdrcd = "3723"
            or prcdrcd= "8855"
            or prcdrcd = "8856"
            or prcdrcd = "8857"
            then cath=1;

            *BEcause a cath often time acompanies a pci or CABG (cabg) procedure we automatically code these together.;
            *Dont add this in know becuase it complicates things
            if cabg=1 or pci_all=1 then cath=1;

        if pci_all=1 then procType="pci_all";
        if stent=1 then procType="stent";
        if cabg=1 then procType="cabg";
        if cath=1 then procType="cath";

        %end;
   %mend;

%macro MedparProcess(cohrt=,DGNMX=,pct=,sampleRule=,id=);

 *************MEDPAR***************************;
    ** Need to reshape the claim files from long to wide because there are several procedures reported per claims, however;
    ** first I need to make an index of every observation in the claims dataset so that it can be reshaped;

    data ForReshape;
        set longEx.&cohrt.&pct._&DGNMX._claims_&sampleRule._&id. (keep=diag_id  dgn_date prcdrdt: prcdrcd: admsndt dschrgdt diag_year ) ;
        if admsndt < dgn_date then delete;
        retain ExtClmIndx 0;
        ExtClmIndx= ExtClmIndx+1;
    run;


    proc transpose data=ForReshape (keep=diag_year dgn_date diag_id admsndt dschrgdt prcdrcd:  ExtClmIndx ) out=LongTempCD prefix=prcdrcd ;
        by ExtClmIndx admsndt dschrgdt diag_id diag_year dgn_date;
        var prcdrcd:;
    run;


    proc transpose data=ForReshape (keep=ExtClmIndx prcdrdt: ) out=LongTempDT prefix=prcdrdt ;
        by ExtClmIndx  ;
        var prcdrdt:;
    run;


    data LongTempCD;
        set LongTempCD;
        procIndx=substr(_name_, 8);
        rename prcdrcd1=prcdrcd;
    run;


    data LongTempDT;
        set LongTempDT;
        procIndx=substr(_name_, 8);
        rename prcdrdt1=prcdrdt;
    run;



    proc sort data=LongTempCD out=LongTempCDnodupe nodupkey;
        by  ExtClmIndx procIndx;
    run;

    proc sort data=LongTempDT out=LongTempDTnodupe nodupkey;
        by  ExtClmIndx procIndx;
    run;

    proc contents data=LongTempCD ;
    run;

    proc means data=LongTempCD ;
    run;

    proc means data=LongTempDT ;
    run;


    data  procs.&cohrt.&pct._&DGNMX._mpPull_&sampleRule._&id.;
    *data  procs.ami05_1_medpar_ProcPull_mn;
        merge LongTempCDnodupe (in=CD drop=_name_ _label_) LongTempDTnodupe (in=DT drop=_name_ _label_) ;
        by ExtClmIndx procIndx;
        if prcdrcd="" then delete;
        inDT=DT;
        inCD=CD;

        if DT and CD;

        %ICD9CMProc(diag=&cohrt.);
        if admsndt < dgn_date then delete;

        if procType="" then delete;


        claimFile="MEDPAR";
        clmStart_medpar=admsndt;
        clmEnd_medpar=dschrgdt;

            *Since we are assuming that admission date are correct and that procedure dates maybe incorrect;
            *We go ahead and assign missing proc date vlaues to the admission date and also proc date which ;
            *fall outside of the admission dates to be equal to the admission date;
        procDate=prcdrdt;
        if prcdrdt=. or (prcdrdt>dschrgdt or prcdrdt<admsndt) then procDate=admsndt;

        retain procID_medpar 0;
        procID_medpar=procID_medpar+1;

        flagAssume=0;
        keep  procID_medpar inDT inCD claimFile diag_id dgn_date clmStart_: clmEnd_:  procDate prcdrcd procType  &procVars. flagAssume fileyear;

        LABEL
            ExtClmIndx = "Index created from extract claims - partial key"
            procIndx   = "Index of procedure variable  - partial key";

        output;
            *Impose conditions on proc in order to duplicate observations *;
        if procType="stent" then do;
            procType="pci_all";
            pci_all=1;
            flagAssume=1;
            output;

            end;
        if procType="pci_all" then do;
            procType="cath";
            cath=1;
            flagAssume=1;
            output;
            end;
        if procType="cabg" then do;
            procType="cath";
            cath=1;
            flagAssume=1;
            output;
            end;

    run;

    %mend;



%macro RunProgram(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrtN=,DGNMAX=,pct=,sampleRuler=,id=);

         %let procVars=%STR(pci_all stent cabg cath );
        %MedparProcess(cohrt=&&cohrt&j..,DGNMX=&DGNMAX.,pct=&pct.,sampleRule=&sampleRuler.,id=&id.);



        %end;
    %mend;
/****************************************************************************************************************;
**********CALL THE PROGRAM BY DEFINING THE FOLLOWING WRAPPER PROGRAMS******************************************;
** cohrt1     = Defines the first cohort to loop through;
** cohrt2     = Defines the second cohrot to loop through;
** ....

** cohrtN     = The number of cohorts defined.
*
** pct        = The percent of interest

** DGNMX      = The number of diagnosis codes used to define the diagnosis. For example, in most cases;
*               we are only interested in dgnosis occuring in the princpal diagnosis which refers to a DGNMX =1;
*               The program uses it to call the correct file name;

** sampleRule = Refers to the sample of interest defined;
*
** id         =  Referes to whether the data uses bene_id or and ehic as the final identifier;
*
***************************************************************************************************************;
***************************************************************************************************************;
*/

*        proc datasets lib=procs KILL ;run;
%RunProgram(cohrt1=ami,cohrtN=1,DGNMAX=1,pct=05,sampleRuler=mn,id=bene_id);

/*
*Sample code to write reports, need to fill in macro variables and directory locations.
   *Output procedures  to excel;
ODS HTML FILE="..../Output/Proc/&cohrt.&pct._&DGNMX._OPRev_procType_&sampleRule._&id..xls" STYLE=statistical;
TITLE "Long Claim File-Procedure Codes by year-HCCS CODES USED IN to define Procedures";
proc freq data=procs.&cohrt.&pct._&DGNMX._OpRevProcPull_&sampleRule._&id.;
    table  procType*diag_year /norow nocol nopercent ;
run;
ODS HTML  CLOSE;


            *Output procduer codes to excel;
ODS HTML FILE="..../Output/Proc/&cohrt.&pct._&DGNMX._all_procType_&sampleRule._&id..xls" STYLE=statistical;
TITLE "Combined procedures";
proc freq data=procs.&cohrt.&pct._&DGNMX._ProcPull_&sampleRule._&id. ;
    table  proc*diag_year procs*claimFile /norow nocol nopercent ;
run;

proc freq data=procs.&cohrt.&pct._&DGNMX._ProcPull_&sampleRule.WIDE_&id. ;
    table  sum_: /norow nocol nopercent ;
run;

ODS HTML  CLOSE;


*Output raw procedure codes to excel-;
ODS HTML FILE="..../Output/Proc/&cohrt.&pct._&DGNMX._medPar_procType_&sampleRule._&id..xls" STYLE=statistical;
TITLE "PRocedures  by year";
proc freq data= procs.&cohrt.&pct._&DGNMX._medparProcPull_&sampleRule._&id.;
    table  procType*diag_year /norow nocol nopercent ;
run;
ODS HTML  CLOSE;


    *Output procduer codes to excel;
ODS HTML FILE="..../Output/Proc/&cohrt.&pct._&DGNMX._OPClsum_procType_&sampleRule._&id..xls" STYLE=statistical;
TITLE "Long Claim File-Procedure Codes by year";
proc freq data=procs.&cohrt.&pct._&DGNMX._OPCProcPull_&sampleRule._&id.;
    table  procType*diag_year /norow nocol nopercent ;
run;
ODS HTML  CLOSE;



