        
options pagesize=200;
options nocenter;
*options symbolgen mlogic mprint mfile ;
options notes stimer fullstimer mprint msglevel=i; 
options formdlim=" ";
options mergenoby=error;
options spool;
*options errorabend;

**** PRELIMINARIES ****;
* directory where extracts should be placed;
%let extractdir=/disk/agero5/medicare.work/wise-DUA16702/daltonm/LongExtract;

* directory where denominantor and enrollment files can be decompressed and manipulated;
%let spdirDenom=/space/daltonm/denom05.NOBACKUP;
*%let spdirDenom=/age1space/daltonm/denom05.NOBACKUP;

* directory where denominantor and enrollment files can be saved;
%let outDenom=/disk/agero5/medicare.work/wise-DUA16702/daltonm/denom05.NOBACKUP;

* directory where the MedPAR files can be decompressed and manipulated;
%let spdirMedpar=/disk/agero5/medicare.work/wise-DUA16702/daltonm/medpar05.NOBACKUP;
*%let spdirMedpar=/space/daltonm/medpar05.NOBACKUP;
*%let spdirMedpar=/age1space/daltonm/medpar05.NOBACKUP;

* directory where temporary files can be written;
%let tempEx=/disk/agero5/medicare.work/wise-DUA16702/daltonm/medpar05.NOBACKUP/TempExtract;

* directory where the NBER keeps compressed raw claims data;
%let dataRoot = /disk/agedisk1/medicare/data.NOBACKUP/u/c;

* directory where the SAS macros can be found ;
%let SASmac =/disk/agedisk1/medicare.work/wise-DUA16702/daltonm/SASmacros;

*Post 2005 data found here;
%let dataroot2= /disk/agero9/medicare/data;

*ehic to ehic crosswalk found here; 
%let benei= /disk/agero5/medicare.work/wise-DUA16702/daltonm/beneID_cw;


* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./AutoFileCountPipe.sas";

*Put final variable labels in this file;
%include "&SASmac./Labels.sas";
*Runs a program which flags the different transfer scenarios referenced in the documentation;
%include "&SASmac./FlagTransfersv2.sas";

*Program which mergers in the crosswalk;
%include "&SASmac./cw_bene_ehic_Extract.sas";

* load files with macros that conform the files of various years into a common format;
%include "&SASmac./ConformDenom.sas";
%include "&SASmac./ConformMedPAR.sas";
%include "&SASmac./CreateReports.sas";

*define libraries that allow access to the various directories specified above;
libname tempDir "&tempEx.";
libname out "&extractdir.";
libname spDenom "&spdirDenom.";
libname outDen "&outDenom.";
libname spMedpar "&spdirMedpar.";
libname bene "&benei.";
** This is a macro which is used at three different places in the wrapper files to decompress the ;
** fname = medpar , fname = denominator , and/or fname = enrollment files;






%macro CallDecompress(yr=,pctd=,fname=);
    %if &yr.<=2005 %then %do;
        %let root=&dataroot.;
        %let mtyp=medpar;
        %let dtyp=denom;
        %end;
    %else  %do;
        %let mtyp=med;
        %let dtyp=den;
        %let root=&dataroot2.;
        %end;

*DATA STEP 1;
 * MACRO WHICH decompresses the &pctd. medpar, enrollment and denom files for the years where they exist.Data step 1 only deals with the medpar file;
    %if &fname.=enrol %then %do;
    *enrollment file does not exit at smaller extracts then 5%, so use 5% sample for smaller samples;
        %if &pctd.<05 %then %do;
            %let pctd=05;
            %end;

        * decompress the 5 percent extract of the enrollment file;
        %if not %sysfunc(fileexist("&outDenom./nrol&pctd._1984_2001.sas7bdat")) %then %do;
            x "bzcat &dataRoot./&pctd.pct/denom/nrol/nrol&pctd._1984_2001.sas7bdat.bz2 > &outDenom./nrol&pctd._1984_2001.sas7bdat";
            %end;    
        %else %do;
            %put "FILE EXISTS ALREADY NOT DECOMPRESSED";
            
            %end;        
        %end;

    %if &fname.=medpar %then %do;
        %if &yr. <=2005 %then %do ;                                  
        *Determines the number of part each file has for Denom files;
        *IMPORTANT TO CHECK TO MAKE SURE THESE ARE READING ALL OF THE FILES;     
            *Medpar files only have one part. If they ever have more then one we will use the DetermineMax macro to loop through and append;
            %decompress_i(spaceDir=&spdirMedpar.,dataRoot=&root.,ftype=&mtyp.,pct=&pctd.,year=&yr.,indx=1);

    /*proc datasets lib=spMedpar;
        DELETE &mtyp.&pctd._&yr._&z.;
                run;
                */
           *Sort by ehic for use below. We sort here so it is only sorted once.;                          
            %end;
        %if &yr. >=2006 %then %do;
            %if not %sysfunc(fileexist("&spdirMedpar./medpar&pctd._&yr._1*")) %then %do;      
        *these are already decompressed;
                x "rm &spdirMedpar./medpar&pctd._&yr.* -f ";
                x "rm &spdirMedpar./med&pctd._&yr._* -f ";
                %DetermineMax(datadir=&root.,pct=&pctd,ftype=&mtyp.,year=&yr.,subtype=,pctsuffix=);        
        *autocount is a dataset the previous macro outputs which simply has one observation equal to;
        *the total number of files available in the folder.;

                data _NULL_;
                    set autocount;
                    if _n_=1 then do;
                        call symputx('medpar_max',n);
                        stop;
                        end;
                run;
                
                %do z=1 %to &medpar_max.;
                    %decompress_i(spaceDir=&spdirMedpar.,dataRoot=&root.,ftype=&mtyp.,pct=&pctd.,year=&yr.,indx=&z.);

                *We merge all of the part to the 1 part to match the previous years;
                    proc append base=spMedpar.medpar&pctd._&yr.  data=spMedpar.&mtyp.&pctd._&yr._&z. force;
                    run;


                    proc datasets lib=spMedpar;
                        DELETE &mtyp.&pctd._&yr._&z.;
                    run;

                    
                    %end;

                data spMedpar.medpar&pctd._&yr._1;
                    set  spMedpar.medpar&pctd._&yr.  ;
                run;

                proc datasets lib=spMedpar;
                    DELETE medpar&pctd._&yr.;
                run;
                
                %end ;                      
            %end;
        %end;

    %if &fname.=denom %then %do;
    /* x "&outDenom./denom&pctd._&yr._1.sas7bdat  -f";*/
        %if not %sysfunc(fileexist("&outDenom./denom&pctd._&yr._1.sas7bdat")) %then %do;    
            %if &yr. >= 1992 %then %do;
                x "rm &spdirDenom./denom&pctd._&yr.* -f ";
                
        *Determines the number of part each file has for Denom files;
        *IMPORTANT TO CHECK TO MAKE SURE THESE ARE READING ALL OF THE FILES;     
                %DetermineMax(datadir=&dataroot.,pct=&pctd,ftype=&dtyp.,year=&yr.,subtype=,pctsuffix=);
                *autocount is a dataset the previous macro outputs which simply has one observation equal to the max number of files in the folder.;
                data _NULL_;
                    set autocount;
                    if _n_=1 then do;
                        call symputx('denom_max',n);
                        stop;
                        end;
                run;        
                %do z=1 %to &denom_max.;                                             
                    %decompress_i(spaceDir=&spdirDenom.,dataRoot=&dataRoot.,ftype=&dtyp.,pct=&pctd.,year=&yr.,indx=&z.);           
                    proc append base=outDen.denom&pctd._&yr._1  data=spDenom.&dtyp.&pctd._&yr._&z. force;
                    run;

                    x "rm &spdirDenom./&dtyp.&pctd._&yr._&z.* -f ";
                    %end;
                %end;
            %else %do;
                %put "FILE -outDen.denom&pctd._&yr._1 -EXISTS ALREADY NOT DECOMPRESSED";
                %end;

            %end;        

        %end;
    %mend;


%macro RunDecompress(yearin=,yearout=);
    %do yrs=&yearin %to &yearout. ; 
    %CallDecompress(yr=&yrs.,pctd=100,fname=denom);
    %end;
%mend;

%RunDecompress(yearin=1992,yearout=1995);
