*/*******************************************************************************************
*  Cost summary for the  Carrier Files-
* By: Maurice Dalton, daltonm@nber.org, March 24, 2010
* Based on modified code provided by Matt Fiedler
*
* The purpose of this do file is to create some simple cost measures from the Carrier file outputs.
*
*********************************************************************************************/
/* PRELIMINARIES */
clear
pause off
set memory 4000M
// REad in directories from this file
do ../../dirInit.do

local pct 05

///Define the total number of diagnosis variables used to index events (principle versus any secondary diagnosis)
local DGNMX 1


foreach diag in "ami" {

clear
use diag_id dgn_date expnsdt1 lalowchg if expnsdt1 >= dgn_date    ///
  using "$carExt/`diag'`pct'_`DGNMX'_carlnits_mn_bene_id.dta"


gen diag_year = year(dgn_date)


/* HORIZON COST VARIABLE */
gen start_t7  = (expnsdt1 - dgn_date) <= 7
gen start_8t30 = ((expnsdt1 - dgn_date) > 7) & ((expnsdt1 - dgn_date) <= 30)
gen start_31t90 = ((expnsdt1 - dgn_date) > 30) & ((expnsdt1 - dgn_date) <= 90)
gen start_91t180 = ((expnsdt1 - dgn_date) > 90) & ((expnsdt1 - dgn_date) <= 180)
gen start_181t270 = ((expnsdt1 - dgn_date) > 180) & ((expnsdt1 - dgn_date) <= 270)
gen start_271tyear = (expnsdt1 - dgn_date) > 270


gen startid=1 if start_t7==1
replace startid=2 if start_8t30==1
replace startid=3 if start_31t90==1
replace startid=4 if start_91t180==1
replace startid=5 if start_181t270==1
replace startid=6 if start_271tyear==1

gen num=1
tab diag_year


/* COLLAPSE DATA */
collapse (sum) lalowchg num (first) diag_year, by(diag_id startid)

forvalues i=1/6 {
  statsmat lalowchg if  startid==`i' ,by(diag_year)  s(median) mat(cost`i'Med)  f(%4.0f)
  statsmat lalowchg if  startid==`i' ,by(diag_year)  s(mean) mat(cost`i'Mea)  f(%4.0f)



  if `i'== 1 {
    local days "less then 7 days"
  }
  if `i'== 2 {
    local days "between 8 and 30 days"
  }
  if `i'== 3 {
    local days "between 31 and 90 days"
  }
  if `i'== 4 {
    local days "between 91 and 180 days"
  }
  if `i'== 5 {
    local days "between 181 and 270 days"
  }
  if `i'== 6 {
   local days "271 or more"
  }


  mat colnames cost`i'Med  = "`days'"
  mat colnames cost`i'Mea  = "`days'"



  }

statsmat lalowchg   ,by(diag_year)  s(median) mat(costMedT)  f(%4.0f)
statsmat lalowchg   ,by(diag_year)  s(mean) mat(costMeaT)  f(%4.0f)


  mat colnames costMedT = Total
  mat colnames costMeaT  = Total



 mat CostMed=(cost1Med, cost2Med, cost3Med, cost4Med, cost5Med, cost6Med, costMedT)
 mat CostMea=(cost1Mea,  cost2Mea,  cost3Mea,  cost4Mea,  cost5Mea,  cost6Mea, costMeaT)


  mat rownames CostMed = Median:
  mat rownames CostMea  = Mean:

  mat cost= (CostMed \ CostMea)

  ///NEED THIS IF STATEMENT TO MAKE THE FIRST ITERATION REPLACE XML FILE
! rm $carCost/CarrCost.xls -f
local name1 CarrCost
local name2 $S_DATE
local name3 .xls
local name `name1'`name2'`name3'


if "`diag'"=="chf" {
  xml_tab cost using "$carCost/`name'",  sheet(Car_`diag',nogridlines)  format((S3110) (S3230 N3120))  lines(COL_NAMES 4 LAST_ROW 13 SCOL_NAMES 2)   cblanks(7 14) tblanks(3) font("Garamond" 11)  title(" Cost statistics over Disease Episode from the  Carrier Claims Files")   note("These statistics are computed by first summing across the claims and then summarizing the costs for each diagnosis episode. Costs simplly consist of a a single Medicare variable (not constructed).  Note1: The amount includes beneficiary-paid  amounts (i.e., deductible and coinsurance). Note2: The allowed charge is determined by the \r lower of three charges: prevailing, customary or \r actual.") replace
}
else {
  xml_tab cost  using "$carCost/`name'",  sheet(Car_`diag',nogridlines)   format((S3110) (S3230 N3200))  lines(COL_NAMES 4 LAST_ROW 13 SCOL_NAMES 2)     cblanks(7 14) tblanks(3) font("Garamond" 11)  title("Cost statistics over Disease Episode from the  Carrier Claims Files")   note("These statistics are computed by first summing across the claims and then summarizing the costs for each diagnosis episode. Costs simplly consist of a a single Medicare variable (not constructed).  Note1: The amount includes beneficiary-paid  amounts (i.e., deductible and coinsurance). Note2: The allowed charge is determined by the \r lower of three charges: prevailing, customary or \r actual.") append
}


}

