*/*******************************************************************************************
*  Cost summary for the  Outpatient Files-
* By: Maurice Dalton, daltonm@nber.org, March 24, 2010
* Based on modified code provided by Matt Fiedler
*
* The purpose of this do file is to create some simple cost measures from the Carrier file outputs.
*

*********************************************************************************************/

    /* PRELIMINARIES */
  clear
pause off

set memory 2G
// REad in directories from this file
do ../../dirInit.do

/// Used to define the right extract
local percent 05
///Define the total number of diagnosis variables used to index events (principle versus any secondary diagnosis)
local DGNMX 1
/// Used to index the loop
local i=0


foreach diag in "ami"  {
local n=`n'+1
di "INDEX `n'"

use "$opExt/`diag'`percent'_`DGNMX'_opclms_mn_bene_id.dta",clear


  drop if from_dt < dgn_date

  gen diag_year = year(dgn_date)



  // temporary hack
  replace blddedam = 0 if blddedam == .


  /*
LIMITATIONS :
Prior to 4/6/93, on inpatient, outpatient, and
physician/supplier claims containing a
CLM_DISP_CD of '02', the amount shown as the Medicare
reimbursement does not take into consideration
any CWF automatic adjustments (involving erroneous
deductibles in most cases).  In as many as 30% of
the claims (30% IP, 15% OP, 5% PART B), the
reimbursement reported on the claims may be over
or under the actual Medicare payment amount.
*/

  gen visit_cost = .
  replace visit_cost = pmt_amt + ptb_ded + ptb_coin + blddedam + prpayamt if fileyear >= 1996
  replace visit_cost = prvdrpmt + ptb_ded + ptb_coin + blddedam + prpayamt if fileyear >= 1989 & fileyear <= 1995
  replace visit_cost = prvdrpmt + ptb_ded + ptb_coin + prpayamt if fileyear >= 1986 & fileyear <= 1988

  //Deductible and coinsurance fields are not available for 1984 and 1985.
  //One approach would be to attempt to calculate deductible and coinsurance fields
  //from the program rules, but this would be extremely difficult.
  //
    //Rather, since deductibles are small and most services are subject to coinsurance
  //equal to 20 percent of total charges, I simply add on 20 percent of total charges.
  //On average, this is similar to the amount of cost-sharing one observes in 1986.
  //
    //It would be worthile to investigate this further at a later date.
  replace visit_cost = pmt_amt + .2*tot_chrg if fileyear >= 1984 & fileyear <= 1985


  gen lengthid=.

  replace lengthid  =1  if  (from_dt - dgn_date) <= 7
  replace lengthid  =2 if ((from_dt - dgn_date) > 7) & ((from_dt - dgn_date) <= 30)
  replace lengthid  =3 if ((from_dt - dgn_date) > 30) & ((from_dt - dgn_date) <= 90)

  replace lengthid  =4 if ((from_dt - dgn_date) > 90) & ((from_dt - dgn_date) <= 180)
  replace lengthid  =5 if ((from_dt - dgn_date) > 180) & ((from_dt - dgn_date) <= 270)
  replace lengthid  =6 if (from_dt - dgn_date) > 270

  tab lengthid
  count

  /* COLLAPSE DATA */
    collapse (sum) visit_cost  (first) diag_year, by( lengthid diag_id)

  count
  ///Create summary statistics by date
  forvalues i=1/6 {
    statsmat visit_cost if lengthid==`i' ,by(diag_year)  s(median) mat(cost`i'med)  f(%4.0f)
    statsmat visit_cost if lengthid==`i' ,by(diag_year)  s(mean) mat(cost`i'mea)  f(%4.0f)



    if `i'== 1 {
      local days "less then 7 days"
    }
    if `i'== 2 {
      local days "between 8 and 30 days"
    }
    if `i'== 3 {
      local days "between 31 and 90 days"
    }
    if `i'== 4 {
      local days "between 91 and 180 days"
    }
    if `i'== 5 {
      local days "between 181 and 270 days"
    }
    if `i'== 6 {
      local days "271 or more"
    }

    mat colnames cost`i'mea = "`days'"
    mat colnames cost`i'med  = "`days'"
  }

  statsmat visit_cost   ,by(diag_year)  s(median) mat(costMed)  f(%4.0f)
  statsmat visit_cost   ,by(diag_year)  s(mean) mat(costMea)  f(%4.0f)

  mat colnames costMed = EntireStay
  mat colnames costMea = EntireStay

  mat CostMedian=(cost1med, cost2med, cost3med, cost4med, cost5med, cost6med, costMed)
  mat CostMean=(cost1mea,  cost2mea,  cost3mea,  cost4mea,  cost5mea,  cost6mea, costMea)


  mat rownames CostMean = Mean:
    mat rownames CostMedian  = Median:


      mat final= ( CostMean \ CostMedian)



///NEED THIS IF STATEMENT TO MAKE THE FIRST ITERATION REPLACE XML FILE

local name1 CostOp_`percent'
local name2 $S_DATE
local name3 .xls
local name `name1'`name2'`name3'


if `n'==1 {
    xml_tab final using "$OPcost/`name'",  sheet(OP_`diag' mean,nogridlines)  format((S3110) (S3230 N3120))  lines(COL_NAMES 4 LAST_ROW 13 SCOL_NAMES 2)   cblanks(7 14) tblanks(3) font("Book Antigua" 11)  title("Summary Statistics over Disease Episode from the Outpatient  Claims files")   note("Enter note here") replace
  }
  if `n'!=1 {
    xml_tab final  using "$OPcost/`name'",  sheet(OP_`diag'mean,nogridlines)   format((S3110) (S3230 N3200))  lines(COL_NAMES 4 LAST_ROW 13 SCOL_NAMES 2)     cblanks(7 14) tblanks(3) font("Book Antigua" 11)  title("Summary Statistics over Disease Episode from the Outpatient  Claims files")   note("Enter note here") append
  }
}


