** Extract a 1 year window from the Carrier files for the given index events extracted in the
** LongitudinalExtractScript.SAS. ;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which
** sequences them correctly.This wrapper macro is found at the end of the program and has
**  several different parameters defined at the end of the code.;

** Maurice Dalton, daltonm.at.nber.org based on code initially written by Jean Roth and refined;
** by Matt Fiedler. All errors are my own.;
**;


options pagesize=200;
options nocenter;
** These options create large log files ;
options mprint mlogic;
options  msglevel=i;
options notes stimer fullstimer;
options formdlim=" ";
options mergenoby=error;
options errorabend;
** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../dirInit.sas";


* define libraries;
libname spcar "&spcar.";
libname longEx  "&longExt.";
libname out   "&carExt.";
libname tempEx "&carErz.";
libname tempDir "&cartmp.";
libname bene "&benei.";

libname xwfile "/disk/agedisk1/medicare.work/wise-DUA16702/daltonm/Medicode/Auxiliary/codeTest";

** load files with macros that conform the files of various years into a common format;

/*
proc datasets lib=xwfile;
run;

proc print data=xwfile.VARCARFILELAYOUTS;
run;



*/


    /**********************************************************************
         *   PRODUCT:   SAS
         *   VERSION:   9.3
         *   CREATOR:   External File Interface
         *   DATE:      29SEP11
         *   DESC:      Generated SAS Datastep Code
         *   TEMPLATE SOURCE:  (None Specified.)
         ***********************************************************************/
            data xwfile.carrierxw
                ;
                * MAKE SURE TO SAVE THE FILE IN TAB SEPERATED FORMAT WITH;
                infile '/homes/nber/daltonm/Medicare/Documentation/ClaimsNavigators/VarCarFileLayouts.txt' delimiter='09'x MISSOVER
        DSD lrecl=32767 firstobs=2 ;
            LENGTH
                        finalvar $20
                        y1984 $20
                        y1985 $20
                        y1986 $20
                        y1987 $20
                        y1988 $20
                        y1989 $20
                        y1990 $20
                        y1991 $20
                        y1992 $20
                        y1993 $20
                        y1994 $20
                        y1995 $20
                        y1996 $20
                        y1997 $20
                        y1998 $20
                        y1999 $20
                        y2000 $20
                        y2001 $20
                        y2002 $20
                        y2003 $20
                        y2004 $20
                        y2005 $20
                        y2006 $20
                        y2007 $20
                        y2008 $20
                        lengthvar $20
                        character $20
            ;

                input
                        finalvar $
                        y1984 $
                        y1985 $
                        y1986 $
                        y1987 $
                        y1988 $
                        y1989 $
                        y1990 $
                        y1991 $
                        y1992 $
                        y1993 $
                        y1994 $
                        y1995 $
                        y1996 $
                        y1997 $
                        y1998 $
                        y1999 $
                        y2000 $
                        y2001 $
                        y2002 $
                        y2003 $
                        y2004 $
                        y2005 $
                        y2006 $
                        y2007 $
                        y2008 $
                        lengthvar $
                        character $
            ;

            run;

            proc print data=xwfile.carrierxw;run;


%macro GenerateAnnualVariableListFromXw(yr=);
    %global rawvarlist;
    %global createvar;
    %global renamevar;
    %global lngth_ch;
    %global lngth_num;
    %global finalvarlist;


    proc sql ;
        select y&yr. into :rawvarlist separated by ' '
            FROM xwfile.carrierxw WHERE y&yr. ne "NULL";
    run;

    proc sql ;
        select finalvar into :createvar separated by '=   ;'
            FROM xwfile.carrierxw WHERE y&yr. eq "NULL";
    run;


    proc sql ;
        select catx(' $',y&yr.,lengthvar) into: lngth_ch separated by ' '
            FROM xwfile.carrierxw WHERE y&yr. ne "NULL" AND character="1";
    run;

    %let lengthlist_num=;
    proc sql ;
        select catx(' ',y&yr.,lengthvar) into: lngth_num separated by ' '
            FROM xwfile.carrierxw WHERE y&yr. ne "NULL" AND character="0";
    run;


    %put  &var&yr.;

    proc sql ;
        select catx('=',finalvar,y&yr.) into:renamevar separated by ' '
            FROM xwfile.carrierxw WHERE y&yr. ne "NULL";
    run;

    proc sql ;
        select finalvar into:finalvarlist separated by ' '
            FROM xwfile.carrierxw ;
    run;


    %mend;
%macro runme;
%GenerateAnnualVariableListFromXw(yr=1985);
    %put  VAR       = &rawvarlist.;
    %put  CREATEVAR = &createvar.;
    %put  RENAME    = &renamevar.;
    %put  LENGTH-CHAR    = &lngth_ch.;
    %put  LENGTH-NUM    = &lngth_num.;
    %put  FINALLIST = &finalvarlist.;
%GenerateAnnualVariableListFromXw(yr=2008);
    %put  VAR       = &rawvarlist.;
    %put  CREATEVAR = &createvar.;
    %put  RENAME    = &renamevar.;
    %put  LENGTH-CHAR    = &lngth_ch.;
    %put  LENGTH-NUM    = &lngth_num.;
    %put  FINALLIST = &finalvarlist.;


    %mend;
%runme;
