###############################################################################
## - is bash scripts which goes through and runs all of the                  ##
##   the sas or stata prgms from a single file. It just makes it easier      ##
##   to run the prgm in a single instance --as long as they do not crash     ##
###############################################################################

###############################################################################
## USER INSTRUCTIONS
##
## 1. Users need to make sure that they have properly defined the directories 
##    at the top of the dirInit.sas and dirInit.do programs
##
## 2. Next users need to properly define the macros found at the end of each SAS program;
## 
## 3. Finally the user needs to make sure this programs is running all of the programs of interest. 
##    or comment out and/or add other programs for this master program to run
## 4. SET EMAILON to 1 or 0 depending on whether you want to receive an email on crash
## 5. To run this bash scrip from the terminal, type in "bash test_op_sas.sh"
## 6. MAKE SURE YOU ONLY RUN PROGRAMS WHICH YOUR DUA COVERS!
###################################################################################

##--------------------------------------------------------------------------------| 
## DEFINES BASH FUNCTION USED TO CALL SAS PROGRAMS BELOW			  | 
##--------------------------------------------------------------------------------| 
## USAGE runcode relative/directory/to/file basefilename.sas			  | 
##										  | 
## NOTE THAT basefilename should include the .sas ending			  | 
##										  | 
## THE PROGRAM WILL RUN THE SAS/STATA CODE IN THE SEQUENCE YOU DEFINE. AS WELL AS | 
## THROWING AN ERROR AND SENDING YOU AN EMAIL IN THE CASE THAT THE FILES	  | 
## CRASH									  | 
##--------------------------------------------------------------------------------| 
runcode() {
##set up log file
    LOGLOCATION=`pwd`/mainprgm.log
    BASELOCATION=`pwd`
    SYSPARM="-MEMSIZE 2G"
    BLANK=""
    if [ -z $1 ]
# Checks if any params.
    then
        echo "No folder location given. Make sure it is relative to where the test_op_sas.sh file is found. Example call, runcode 1PrimaryExtractionPrmgs medparCanditates.sas . "
        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
        exit 0
    else

        if [ -z $2 ]
# Checks if any params.
        then
            echo "ERROR: NO BASE PROGRAM SPECIFIED AFTER DIRECTORY." >> $LOGLOCATION
            echo "ERROR: MAKE SURE TO INCLUDE THE .sas/.do ENDING " >> $LOGLOCATION
            echo "Example function call:: runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents medparCandidates  " >> $LOGLOCATION
            mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
            exit 0

        else
	    
            if [ -e $1/$2 ] 
            then
                ## CHANGE TO LOCATION OF THE PROGRAM
                cd $1
                if [[ "$2" == *.sas ]]
                then
                    BASEFILE=`echo "$2" | sed -e s/\\.sas//p | sort | uniq`
                    BASEFILELOG=$BASEFILE".log"
                    PRGM=sas		    
                    if [ -n "$3" ]
                    then
			SYSPARM="-sysparm cohrt=$3,pct=$4,yearin=$5,yearout=$6,NOTE=$7 -MEMSIZE 2G"
			echo "FOUND  $SYSPARM" 
                    fi
                    if [ -z "$3" ]
                    then
			SYSPARM=""
			echo "NO SYSPARM " 
                    fi
                fi

                if [[ "$2" == *.do ]]
                then
                    BASEFILE=`echo "$2" | sed -e s/\\.do//p | sort | uniq`
                    BASEFILELOG=$BASEFILE".log"
                    PRGM="statamp -b do"
                fi


                echo "##################################################################" >> $LOGLOCATION
                echo "RUNNING $1/$2 ::macro call::for user verification" >> $LOGLOCATION
                echo `tail $2 --lines=6` >> $LOGLOCATION
                echo "###############################################################################" >> $LOGLOCATION
                echo `date` >> $LOGLOCATION
                echo "$PRGM $2 $SYSPARM" >> $LOGLOCATION
                $PRGM $2 $SYSPARM
                echo "#####  GREP FOR ERRORS SHOW UP BELOW  #########################################" >> $LOGLOCATION
                if [[ `grep '^ERROR' "$BASEFILELOG" -c` -gt  0 ]]; then  
                echo "NUMBER OF ERRORS FOUND `grep '^ERROR' $BASEFILELOG -c`" >> $LOGLOCATION               
                grep '^ERROR' $BASEFILELOG >> $LOGLOCATION
                    if [ $EMAILON -eq 1 ]; then  
                        echo "CRASH SENDING EMAIL"; 
                        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
                        exit  0  
                    fi
                fi          
                if [[ `grep 'r([0-9]*);' "$BASEFILELOG" -c` -gt  0 ]]; then  
                    grep 'r([0-9]*);' $BASEFILELOG >> $LOGLOCATION
                    if [ $EMAILON -eq 1 ]; then  
                        echo "CRASH SENDING EMAIL"; 
                        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
                        exit  0  
                    fi
                fi          

            else
                ## WRITE ERROR MESSAGE IF CANT FIND FILE;
                echo "ERROR: CANNOT FIND THIS FILE::(see next line)"
                echo "ERROR: $1/$2" >> $LOGLOCATION
                echo "ERROR: MAKE SURE YOU SET DIRECTORY RELATIVE TO THE PROGRAM ROOT " >> $LOGLOCATION
                echo "Example function call:: runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents medparCandidates.sas  " >> $LOGLOCATION
                mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
                exit 0  
                
            fi
        fi
        echo "   "
        echo "   "
        echo "   "
        cd $BASELOCATION
    fi
}
###############################################################################
## END BASH FUNCTION DEFINITION 
###############################################################################


##*********************************************************************************
##               BEGIN CALLING PROGRAMS                                          **
##*********************************************************************************
##!!!!!!!!!!!!!!!--ONLY RUN WHAT YOUR DUA COVERS !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!


##------------------------------------------------------------------------------
## DO YOU WANT THE PROGRAM TO EMAIL YOU ON CRASH - SET TO 1 FOR YES
##------------------------------------------------------------------------------
EMAILON=1
LOGNAME=mainprgm.log
rm $LOGNAME -f
touch $LOGNAME
echo "RUNNING PROGRAM ON THIS SERVER:: `uname -n`" >$LOGNAME

###################################################################################
## RUNS SPEED TESTS
###################################################################################
COHRT=ami
YEARIN=2005
YEAROUT=2006
NOTE=SETUP
PCT=100 


##EXAMPLE USING TIME TO GET MEMORY. IO and CPU
/usr/bin/time -f "%c Context Switches \n %Z System Page Size (bytes)  \n %e Elapsed Real Time (secs) \n %S CPU-seconds \n %M Max Resident Set Size (Kb)" statamp -b do SHARE_HARM_HEALTH_secC_G.do



#NOTE=AGESAS2_SINGLE
#runcode mainprgm OpExtract.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE 

NOTE=AGESAS2_6LOADOTHER
echo "TEST LOAD :: `uptime`" > $LOGNAME
#runcode mainprgm OpExtract.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE &
sleep 2m
runcode mainprgm opCandidates.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE &
sleep 2m
runcode mainprgm MedparExtract.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE &
sleep 2m
runcode mainprgm 1B_ImposeDenominatorRestrictions.sas  &
sleep 2m
PCT=20 
runcode mainprgm carrierCandidates.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE &
sleep 2m
runcode mainprgm CarrierExtract.sas $COHRT $PCT $YEARIN $YEAROUT $NOTE &





############END########################################################
### IGNORE - for future development
#######################################################################
#FOR FURTHER DEVELOPMENT OF SCRIPT::SAS error code - not working
#Condition Exit Status Code
#All steps terminated normally 0
#SAS System issued warnings 1
#SAS System issued errors 2
#User issued ABORT statement 3
#User issued ABORT RETURN statement 4
#User issued ABORT ABEND statement 5
#SAS could not initialize because of a severe error 6
#User issued ABORT RETURN n statement n
#User issued ABORT ABEND n statement n
# not working -- if [$? != 0 ];then - put comments here to maybe work on later
##
##
## WEBSITE FOR IMPLEMENTING ALL CONTROLS FROM THIS BASH SCRIPT USING THE -SYSPARM OPTION
##http://www.sas.com/offices/NA/canada/downloads/presentations/Toronto09/Batch.pdf
## EXAMPLE
## sas sas.sas -sysparm 'name1=value1,name2=value2,)   
##%let sysparm = name1=value1,name2=value2,name3=value3 ;
##data _null_;
##length sysparm express param value $ 200;
##sysparm = symget('sysparm');
##do i=1 to 50 until(express = '');
##express = left(scan(sysparm, i, ',')); /* name=value */
##param = left(upcase(scan(express, 1, '='))); /* name */
##value = left(scan(express, 2, '='));
##valid = not verify(substr(param, 1, 1),'ABCDEFGHIJKLMNOPQRSTUVWXYZ_')
##and not verify(trim(param),'ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789')
##and length(param) <=32 ; /* Ensure valid V8 macrovar name */
##if valid then call symput(param, trim(left(value)));
##end;
##run; 
##
##
##
##
######################################################################################

