***********************************************************************************;
** The ImposeDenominatorRestrictions file takes the candidate index events flagged *;
** by the sas programs found in the 1A_FlagcandidateEvents folder, converts them  ;
** from ehic to bene_id for pre-2006 years (%CombinecandidateIndxEvents). Next
** a new macro (%ImposeSampleRest) merges the data with the denominator ;
** information and creates a set of restrictions (enrollment restriction included);
** to generate the final list of index events. Finally the final macro (%generate_indxDemo_dataset);
** cleans up the index events. THOSE THREE MACROS SHOULD BE RUN IN THAT ORDER.;

**
** THERE ARE 3 MACRO IN THIS FILE WHICH RUN SEQUENTIALLY. USING MACROS ALLOWS
** US TO EASILY CHANGE THE NAME OF THE FILES SO IT IS FLEXIBLE ENOUGH TO DEAL WITH ;
** DIFFERENT cohrt NAMES;

***********************************************************************************;
**Maurice Dalton, daltonm.at.nber.org,  based on code initially written by Jean Roth;
** and further refined by Matt Fiedler.  All errors are my own.;
*!!!!3 WRAPPER MACRO FOUND AT THE END !!!!!;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
*Program which mergers in the crosswalk;
%include "&SASmac./applycrosswalk.sas";
* load files with macros that conform the files of various years into a common format;
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./generateEnrollRest.sas";

%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformMedPar.sas";
%include "&SASmac./CreateReports.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./decompressMedPar.sas";
%include "&SASmac./errorCheckparameters.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
x "mkdir &tmprootDir./opex -p";
%let opex=&tmprootDir./opex;

* Defines local directories depending on which server currently running;
libname spmed "&spmed.";
libname spden "&spden";
libname spxw "&inbenexw.";
libname inDen  "&inden.";
libname xwfile "&xwfile.";
libname here ".";
libname hrrxw "&inHRRzipxw.";

libname denex "&opex.";
libname indxex "&opex.";
libname indxerz "&indxerz.";
libname medex  "&opex";
libname ipex "&opex.";

%macro CombinecandidateIndxEvents(cohrt=,pct=,med=,car=,op=,ip=,yearout=,yearin=,
                                  ip_dgnPos= ,ip_prcPos=, med_dgnPos=, med_prcPos=,
                                  car_dgnPos=, car_prcPos=0, op_dgnPos=, op_prcPos=);


    %if &med.=1 %then %do;
        proc contents data=medex.&cohrt.&pct._d&med_dgnPos.p&med_prcPos._medparcandidates;run;
            %end;
        %if &car.=1 and &pct. ne 100 %then %do;
        proc contents data=carex.&cohrt.&pct._d&car_dgnPos.p0_carcandidates;run;
            %end;
        %if &op.=1 %then %do;
        proc contents data=opex.&cohrt.&pct._d&op_dgnPos.p&op_prcPos._opcandidates;run;
            %end;
        %if &ip.=1 %then %do;
        proc contents data=ipex.&cohrt.&pct._d&op_dgnPos.p&op_prcPos._ipcandidates;run;
            %end;

    data indxerz.&cohrt.&pct._candidateIndx;
        length ehic $11;
        set
        %if &med.=1 %then %do;
              medex.&cohrt.&pct._d&med_dgnPos.p&med_prcPos._medparcandidates
                  %end;
        %if &ip.=1 %then %do;
                ipex.&cohrt.&pct._d&op_dgnPos.p&op_prcPos._ipcandidates
                    %end;

       %if &car.=1 and &pct. ne 100 %then %do;
                carex.&cohrt.&pct._d&car_dgnPos.p0_carcandidates
                %end;
        %if &op.=1 %then %do;
                opex.&cohrt.&pct._d&op_dgnPos.p&op_prcPos._opcandidates
                 %end;

            ;


        ** THIS RANKING HERE IS USED TO BREAK TIES WRT INDEX CANDIDATES OCCURRING ON THE SAME DATE.;
        ** INDX CANDIDATES ARE SORTED BY THIS RANKING SO THAT THE LOWER RANKED OBSERVATION IS USED AS THE INDEX EVENT;
        if file="med" then rankfile=1;
        if file="ipb" then rankfile=2;
        if file="opc" then rankfile=3;
        if file="opb" then rankfile=4;
        if file="opr" then rankfile=5;
        if file="car" then rankfile=6;

        retain diag_id 0;
        diag_id = diag_id + 1;

    run;

%mend;


%macro ImposeSampleRest(cohrt=, pct=, start=, end=, FFSmonthpost=,HMOmonthpost=,FFSmonthpre=,
                            HMOmonthpre=, diaglastmonths=, subsquentDgnDayRest=);
    ********************************************************************************************************;
    ** Copy denominator files to local space drives for faster processing;
    ********************************************************************************************************;
    %if &pct. =0001 %then %do;
        %let pctden=05;
        %end;
        %else %do;
        %let pctden=&pct.;
        %end;

    x "rm &spden./*&pctden.* -f ";
    x "cp &inden./pop&pctden._demo_bene_idcharvar&end.* &spden./ -f ";
    %do yr=&start. %to &end.;
        x "cp &inden./pop&pctden._demo_bene_id&yr.* &spden./ -f ";
        %end;
    x "bunzip2 &spden./*&pctden.*.*bz2  ";

    ********************************************************************************************************;
    ** Get the list of final variable -- years doesnt matter -- CREATE SEPARATE MACRO;
    ********************************************************************************************************;
    ** Sort data sets to prepare for the ensuing data step;
    proc sort data=indxerz.&cohrt.&pct._candidateIndx;
        by bene_id  dgn_date;
    run;
    TITLE "FREQ FiLE YEAR";
    proc freq data=indxerz.&cohrt.&pct._candidateIndx;
        table fileyear;
    run;

    TITLE "FREQ FiLE YEAR-missing";
    proc freq data=indxerz.&cohrt.&pct._candidateIndx;
        where bene_id="";
        table fileyear;
    run;
    TITLE "";
    ********************************************************************************************************;
    ** MERGE IN ENROLL INFO AND RESTRICT DATA SET !USES MEDPAR AND DENOMINATOR FILES!;
    ********************************************************************************************************;
    data indxex.&cohrt.&pct._candidateflag
        (keep =  ehic  fl_: bene_id diag: file
                 dgn_date diag_id fdiagRec subsequentDgn:
                 ageAtdiag  eHMO: eFFS: badDOD
                 dobMissing repeatid   sdod  fileyear )
        indxex.&cohrt.&pct._indx
        (drop  = buyin: hmo: fl_:  fdiagRec subsequentDgn: monthsAheadHMO
                 eHMO: eFFS: badDOD m deathmonth monthsAheadFFS
                 dobMissing repeatid  m diagmonth last_dgn_date   )
        denex.&cohrt.&pct._demo
        (keep = bene_id ehic  sdod sdob  race sex buyin: hmo:);

        merge indxerz.&cohrt.&pct._candidateIndx (in=inCore )
              spden.pop&pctden._demo_bene_idcharvar&end. (in=indem )
            %do year=&start. %to &end.;
              spden.pop&pctden._demo_bene_id&year. (in=indem )
            %end;;
        by bene_id;

        ***********************************************************************************************;
        ** Create permanent flag variables from the merge;
        ***********************************************************************************************;
        ** Useful variables for determining how well the MedPAR and DENOM files are merging;
        fl_incore=inCore;
        fl_indem=indem;
        *Only keep individuals which are in the indx files;
        if fl_incore;
        fdiagRec = first.bene_id;
        diag_year=year(dgn_date);

        ***************************************************************************************************;
        ** Set flag for an diag in last 12 months and for repeat individuals in the index event;
        ***************************************************************************************************;
        repeatid=0;
        retain last_dgn_date repeatid ;

        ***************************************************************************************************;
        ** flag number of index events are occurring because of repeat ehics;
        ***************************************************************************************************;
        if first.bene_id then repeatid = 0;
        repeatid = repeatid + 1;

        ***************************************************************************************************;
        ** FLAG 1 YEAR RESTRICTION ON INDEX EVENTS;
        ***************************************************************************************************;
        ** Note that we create the subsequentDgnFlag for diag_id which have not been transferred;
        if &subsquentDgnDayRest. = 0 then do;
            subsequentDgn&subsquentDgnDayRest.Flag = 0;
            end;
        else if first.bene_id or (dgn_date - last_dgn_date > &subsquentDgnDayRest.) then do;
            subsequentDgn&subsquentDgnDayRest.Flag = 0;
            end;
        else do;
            subsequentDgn&subsquentDgnDayRest.Flag = 1;
            end;

        last_dgn_date = dgn_date;

        ***************************************************************************************************;
        ** Calculate age at diag;
        ***************************************************************************************************;
        if sdob = . then do;
            dobMissing = 1;
            end;
        else do;
            dobMissing = 0;
            if (month(dgn_date) > month(sdob))
                or ( (month(dgn_date) = month(sdob)) and (day(dgn_date) >= day(sdob)) ) then do;
                ageAtdiag = year(dgn_date) - year(sdob);
                end;
            else do;
                ageAtdiag = year(dgn_date) - year(sdob) -1;
                end;
            end;

       ****************************************************************************************************;
       ** FLAG NONSENSICAL DEATH DATES TO BE DROPPED;
       ****************************************************************************************************;
       **Look for dates of death that come _after_ diag admission;
       if sdod ne . then do;
            Baddod = sdod < dgn_date;
            end;
        else do;
            badDOD = 0;
            end;
        **************************************************************************************************;
        ** ENROLLMENT RESTRICTION ENFORCED BELOW;
        **************************************************************************************************;
        ** Macro which generates enrollment flags from denominator and dgn_date var;
        %generateEnrollRest(indxDateVar=dgn_date,end=&end.,start=&start.,
                            FFSmonthpost=&FFSmonthpost., HMOmonthpost=&HMOmonthpost.,
                            FFSmonthpre=&FFSmonthpre.,   HMOmonthpre=&HMOmonthpre.  );
        ***************************************************************************************************;
        ** Restrict the sample to index events last less than the claims window.;
        ***************************************************************************************************;
        output indxex.&cohrt.&pct._candidateflag;

        ***************************************************************************************************;
        ** WRITE OUT DEMO FILE;
        ***************************************************************************************************;
        if first.bene_id then
            output denex.&cohrt.&pct._demo ;

        LABEL
            rankfile="Determines how index candidate events occuring on the same date and separate files are broken."
            diag_id="Unique index event identifier (unique to dgn_date and bene_id)"
            diag_year="Year of claim defining the index event admission ";


        *************************************************************************************************;
        *!!!!!!!!!!   BEGIN ENFORCING RESTRICTIONS !!!!!!!*;
        *************************************************************************************************;
        * Drops individuals who do not match between denom and medpar files.;
        * NOTE::FOR 5% SAMPLE::
        *     There will be some individuals who are found in the medpar file but not the denominator file;
        *     because beginning in 2006 an enhanced 5% is included in the data. The denominator file drops;
        *     the enhanced 5% sample, so that through this merge the enhanced 5% is also dropped from medpar;
        if fl_incore and fl_indem;
        *FOR CREATING EXTRACTS USING DIFFERENT ASSUMPTIONS WORK HERE ADD YOUR OWN HERE;
        * Implement criteria for including diags like those in McClellan and Newhouse and;
        * Udvarhelyi, et al.;
        * 1) Must be no other diag admission in the last year;
        * 2) Must have traditional Medicare enrollment for a 25-month (12+1+12) window around;
        * the diag AND that must be captured in the data set.;
        * 3) Must be 66 at the time of the diag - makes enrollment issue easier to deal with ;
        * 4) Has a date of death on or after the diag date;
        * 5) Has a valid date of birth;
        * 6) LOS is not longer then the claims windows. Default is, less than a year. IGNORE FOR NOW ;
        *    LET INDIVIDUALS CHOOSE HOW THEY WILL TREAT THIS;
        if  (not subsequentDgn&subsquentDgnDayRest.Flag and
            eHMO_post&HMOmonthpost. and eFFS_post&FFSmonthpost. and
            eHMO_pre&HMOmonthpre. and eFFS_pre&FFSmonthpre. and
            ageAtdiag >= 66 and
            not dobMissing and
            not badDOD)
            then do;
           output indxex.&cohrt.&pct._indx;
            end;
    run;


    proc sort data=indxex.&cohrt.&pct._indx;
        by bene_id dgn_date;
    run;
    TITLE "candidateS..";
    proc freq data=indxerz.&cohrt.&pct._candidateIndx;
        table fileyear*file;
    run;

    TITLE "FREQ FINAL INDX";
    proc freq data=indxex.&cohrt.&pct._indx;
        table fileyear*file;
    run;

   *Delete temp datasets which we no longer need;
    x "rm &spden./*&pct.* -f ";
    ** ARCHIVE OLD FILES;
    %archiveoldLogfiles(pct=&pct.,cohrt=&cohrt.,yearin=&start.,yearout=&end.);

    %mend;


%macro generate_indxDemo_dataset(cohrt=,pct=);

************************************************************************************;
* DATASTEP - Generate a processed output file with AGE/SEX INFO -- OPTIONAL;
************************************************************************************;
    data indxex.&cohrt.&pct._indxdemo;
        set  indxex.&cohrt.&pct._indx
                          (in=Indx)
               ;
        by bene_id;
        flag=0;
        %let days=3 7 30 90 180 365;
        %let dNum=6;
        %do i=1 %to &dNum.;
            surv_%scan(&days.,&i.)=0;
            if sdod=. or ((sdod- dgn_date) >= %scan(&days.,&i.)) then surv_%scan(&days.,&i.)=1;
            %end;

        ageAtdiag = year(dgn_date) - year(sdob);

        if ((month(dgn_date) < month(sdob))
            or (month(dgn_date) = month(sdob) and day(dgn_date) < day(sdob))) then do;
            ageAtdiag=  ageAtdiag-1;
            end;

        ag65t69 = 0 ;
        ag70t74 = 0 ;
        ag75t79 = 0 ;
        ag80t84 = 0 ;
        ag85t89 = 0 ;
        ag90t94 = 0 ;
        ag95p   = 0 ;

        if (ageAtdiag >= 65) and (ageAtdiag <= 69) then ag65t69 = 1 ;
        if (ageAtdiag >= 70) and (ageAtdiag <= 74) then ag70t74 = 1 ;
        if (ageAtdiag >= 75) and (ageAtdiag <= 79) then ag75t79 = 1 ;
        if (ageAtdiag >= 80) and (ageAtdiag <= 84) then ag80t84 = 1 ;
        if (ageAtdiag >= 85) and (ageAtdiag <= 89) then ag85t89 = 1 ;
        if (ageAtdiag >= 90) and (ageAtdiag <= 94) then ag90t94 = 1 ;
        if (ageAtdiag >= 95)  then ag95p = 1 ;

        age_grp = .;
        if ag65t69=1 then age_grp = 1 ;
        if ag70t74=1 then age_grp = 2 ;
        if ag75t79=1 then age_grp = 3 ;
        if ag80t84=1 then age_grp = 4 ;
        if ag85t89=1 then age_grp = 5 ;
        if ag90t94=1 then  age_grp = 6;
        if ag95p=1 then  age_grp = 7 ;

        survival = .;
        if surv_3 = 1 then survival = 1;
        if surv_7 = 1 then survival = 2;
        if surv_30 = 1 then survival = 3;
        if surv_90 = 1 then survival = 4;
        if surv_180 = 1 then survival = 5 ;
        if surv_365 = 1 then  survival = 6;

        died=1;
        if sdod=. then died=0;

        male=0;
        if sex="1" then male = 1;
        drop flag;
        zip_indx_num=input(zip_indx,5.);

        ** NOT WORKING PERFECTLY YET;
        **denomiator file is frozen in march of the following year;
        ** in order to merge, used admision date to make sure they correct;
        ** zip code is used. Also note that starting in 2009 the BSF files is;
        ** update annually;
        *if month(dgn_date)>=4 and fileyear<=2008 then demoyear=year(dgn_date);
        *if month(dgn_date)<3 and fileyear<=2008  then demoyear=year(dgn_date)-1;
        *if fileyear>2008  then demoyear=year(dgn_date);
        * demoyear= Year used for merging with enrollment files -not perfect;

        LABEL   surv_3="The individual was alive 3 days after the diagnosis."
                surv_7="The individual was alive 7 days after the diagnosis."
                surv_30="The individual was alive 30 days after the diagnosis."
                surv_90="The individual was alive 90 days after the diagnosis."
                surv_180="The individual was alive 180 days after the diagnosis."
                surv_365="The individual was alive 365 days after the diagnosis."
                ageatdiag= "Individuals age corresponding to the index events date of admission"
                ag65t69= "Individual is between the age of 65 and 69 inclusive of endpoints"
                ag70t74= "Individual is between the age of 70 and 74 inclusive of endpoints"
                ag75t79= "Individual is between the age of 75 and 79 inclusive of endpoints"
                ag80t84= "Individual is between the age of 80 and 84 inclusive of endpoints"
                ag85t89= "Individual is between the age of 85 and 89 inclusive of endpoints"
                ag90t94= "Individual is between the age of 90 and 94 inclusive of endpoints"
                ag95p= "Individual is 95 years of age an over"
                age_grp= "The age group the individual is in"
                died="Whether or not the individuals is reported dead in the data."
                male= "indicates whether the respondent is a male"
                zip_indx_num= "Zipcode for the index event saved as number";
    run;


    proc contents data=hrrxw.masterhrrcross ;run;
    proc contents data=indxex.&cohrt.&pct._indxdemo ;run;

    proc sort data=hrrxw.masterhrrcross nodupkey;
        by zipcode  year;
    run;

    proc sort data=indxex.&cohrt.&pct._indxdemo;
        by bene_id diag_year;
    run;


    **merge in HRR xwalk using index zipcode;
    proc sql;
       create table  indxex.&cohrt.&pct._indxdemo as
        select I.*, X.hsanum, X.hsacity, X.hsastate,
                    X.hrrnum, X.hrrcity, X.hrrstate, X.rawyear as hrryear
        from  indxex.&cohrt.&pct._indxdemo as I
        LEFT JOIN  hrrxw.masterhrrcross  as X
       ON ( I.diag_year=X.year and X.zipcode=I.zip_indx_num);
    quit;

    proc sql;
       select fileyear, count(fileyear) as TotalCountIndx
       from indxex.&cohrt.&pct._indxdemo
        group by fileyear;
    quit;
    x "rm &spden./*&pct.* -f ";
    %mend;


***********************Call Wrapper Program Below-***********************;
*WRAPPER MACRO DOCUMENTATION --SAME AS DOC FOUND AT BEGINNING OF SCRIPT ---;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will be called.;
***
*** xx_dgnPos=1-- Determines the candidates file used where xx is ip, op , car or med referring to the claims file.;
**             -- this should match what is used in the respective flag candidate file from step 1A.;
**             -- Tells use the number of Diagnostic codes looped over (more then just primary or not) ;
**             -- when creating the candidate index events;
**
*** xx_prcPos=1-- Determines the candidates file used where xx is ip, op , car or med referring to the claims file.;
**             -- this should match what is used in the respective flag candidate file from step 1A.;
**             -- Tells use the number of procedure codes looped over (more then just primary or not) ;
**             -- when creating the candidate index events. car_prcPos is not defined an is hard coded to zero.;

*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in. Use .01% for debugging where possible;
***;
*** clmDTA     -- Set equal to one if you want to convert the all files into a Stata format (DTA)*;
***               ONLY WORKS IF YOU ARE RUNNING ON A SERVER WITH STAT TRANSFER ;
***;
*** FOLLOWING PARAMETERS DEFINE RESTRICTIONS - DEFAULTS OFTEN USED in (#) ;
***;
*** subsquentDgnDayRest(365 ) Defines the minimum amount of time allowed to pass before a beneficiaries with ;
***                      more then one candidate index event can be treated as a index event. The restriction;
***                      drops all candidate index events which are within XX days of each other and it keeps;
***                      the first one. The restriction is important because it helps ensure that no 2 index;
***                      events in the final data set are directly related, through a transfer or something similar.;
***                      THIS OPTION CAN BE IGNORED BY SETTING IT EQUAL TO 0;
***;
*** HMOmonth[pre/post](12) = Defines the number of months of continuos HMO enrollement needed before and after;
***            the index event month, including the month of the index event, used to restrict the sample;
***;
*** FFSmonth[pre/post](12) = Defines the number of months of continuos FFS enrollement need before and after;
***                the index event month, including the month of the index event, used to;
***                restrict the sample;
***;
****************************************************************************************************;
***!!! The imposerestriction macro uses the denominator file  !!!*****;
***!!! YOUR DUA MUST COVER THE DENOM FILE IN ORDER TO USE IT  !!!*****;



**Combine the files and apply the crosswalk;
%CombinecandidateIndxEvents(cohrt=ami, pct=100, yearin=1992, yearout=2011,
                           ip= 0 ,  ip_dgnPos =1, ip_prcPos =1,
                           med=1,   med_dgnPos=1, med_prcPos=0,
                           car=0,   car_dgnPos=1,
                           op=0 ,   op_dgnPos =1, op_prcPos =2
                           );


**Imposes restrictions to generate final index events;
%ImposeSampleRest(cohrt=ami,pct=100, start=1992,end=2011,
                  subsquentDgnDayRest=365,FFSmonthpost=12,HMOmonthpost=12,FFSmonthpre=12,
                            HMOmonthpre=12);

**Creates a modified indx file with useful denominator information;
%generate_indxDemo_dataset(cohrt=ami,pct=100);


/*
**Combine the files and apply the crosswalk;
%CombinecandidateIndxEvents(cohrt=ami, pct=100, yearin=1992, yearout=2011,
                           ip= 0 ,  ip_dgnPos =1, ip_prcPos =1,
                           med=1,   med_dgnPos=1, med_prcPos=0,
                           car=0,   car_dgnPos=1,
                           op=0 ,   op_dgnPos =1, op_prcPos =2
                           );


**Imposes restrictions to generate final index events;
%ImposeSampleRest(cohrt=ami,pct=100, start=1992,end=2011,
                  subsquentDgnDayRest=365,FFSmonthpost=12,HMOmonthpost=12,FFSmonthpre=12,
                            HMOmonthpre=12);

**Creates a modified indx file with useful denominator information;
%generate_indxDemo_dataset(cohrt=ami,pct=100);

