** Extract a X year window of claims from the Carrier files for the given index events extracted in the
** CarrierExtract.sas. Use the index events defined in the 1B program to pull claims. ;
**;
** PROGRAM STRUCTURE;
** The program consists of several SAS macros which are wrapped together using a macro which
** sequences them correctly.This wrapper macro is found at the end of the program and has
**  several different parameters defined at the end of the code.;

** Maurice Dalton, daltonm.at.nber.org based on code initially written by Jean Roth and refined;
** by Matt Fiedler. All errors are my own.;
**;
***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
*import macros usedin the creations of sas views for doc;
%include "read_sysparm.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./ConformCarrier.sas";
%readincarrierxw;

*macros used in the programs below;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";

x "mkdir &tmprootDir./opex -p";
%let opex=&tmprootDir./opex;

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
libname here ".";
libname indxex "&indxExt.";
libname carex  "&opex.";
libname cartmp "&cartmp.";
libname spxw "&inbenexw.";
libname xwfile "&xwfile.";
libname carvw  "&carvw4e.";
libname carvwtm  "&carvw4e./tmp";
libname carvw  "&carext./view4extract";
libname carvwtm  "&carext./view4extract/tmp";


*************************************************************************************;
** BEGIN MACRO DEFINITIONS CALLED AT THE END IN THE WRAPPER PROGRAM;
*************************************************************************************;
%macro code2manipulateclms(year=,pctsuffix= ,cohrt=,pct=,part=,winyear=);

    ** Code in this macro pulls the assocaited clms with the carrier file.;
    ** However this programs can also be used to created any type of extract from ;
    ** the claims files. Just add your own code below and make sure that it is ;
    ** appended together since this code process each part, 1 at a time;
    **(bufsize=50k bufno=10) dataset options to mess around with;
    %let winday=%sysevalf(&winyear.*365);
    ** using a sas view helps with I/O ISSUES;
    proc sql _METHOD BUFFERSIZE=1048576;
        create view cartmp.temp_index_carlnits  as
            select  C.*
            from carvw.car&pct.&suffix._clmline_&year._&part. C
            where
            (C.expnsdt1 ne .) and
            (C.expnsdt2 ne .) and
            (C.expnsdt1 >= (C.dgn_date - &winday.)) and
            (((C.expnsdt2 - C.dgn_date) <= &winday.) or (C.expnsdt1 = C.dgn_date) )
            ;
        quit;
    run;

    ** Outputs the the manipulated clms into a temp file which aggregated across years.;
    proc append base = cartmp.&cohrt._carlnits&year.
                data = cartmp.temp_index_carlnits  force  ;
    run;

    x "rm &cartmp./temp_index_carlnits.sas* -f"
    %mend;


%macro appendYearFiles(cohrt=,pct=,start=,stop=,clmDTA=0);
***************************************************************************;
** Combine the files and dump the final extract to stata if need be;
***************************************************************************;
    ** call macro which calls the carrier labels and export into outlabels var;
    %LabelVarsXw(outLabels=carLabels,filename=carrierxw);
    data carex.&cohrt.&pct._carlnits;
        **Fix lengths which differ between years;
        set %RepeatN(cartmp.&cohrt._carlnits,&start.,&stop.);
        label &carLabels. ;
    run;

    proc sql;
       select fileyear, count(fileyear) as TotalCount
       from carex.&cohrt.&pct._carlnits
        group by fileyear;
    run;

    ** Define flag - send sas file to stat-transfer - via system command;
        %if &clmDTA.=1 %then %do;
            x "st &carext./&cohrt.&pct._carlnits.sas7bdat
                  &carext./&cohrt.&pct._carlnits.dta -y -od -v";
            %end;
    %mend;



**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunCarExtraction(pct="",cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrtN=,yearin=,yearout=,clmDTA=,crashStart=0,winyear=,note=);
*######################################################################;
* PRELIMINARIES:: PROGRAM SET UP;
*######################################################################;
    ** THROW ERROR FOR BAD PARAMETERS ;
    %errorCheckparameters(cohrt1=&cohrt1.,cohrtN=&cohrtN.,yearin=&yearin.,yearout=&yearout.,
                          pct=&pct.,prgm=Carrier);
    ** Define macro variables for timing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());

    ********Deal with a crash if defined in the parameter - crashStart********;

        %if &crashStart.=&yearin. or &crashStart.=0 %then %do;
            x "rm &cartmp./* -f " ;
            %let beginLoop=&yearin.;
            %end;
        %else %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
            %do j=1 %to &cohrtN.;
                proc datasets lib=cartmp;
                    DELETE %RepeatN(&&cohrt&j.._carlnits,&crashStart.,&yearout.);
                    DELETE %RepeatN(Samp&&cohrt&j..,&crashStart.,&yearout.);
                run;
                %end;
        %end;


*######################################################################;
* BEGIN CALLING MACRO TO PROCESS CLAIMS;
*######################################################################;
    **read sas file into memory;
    sasfile spxw.ehicbenex_unique_bene_indx&pct. open;
        %do y=&beginLoop. %to &yearout.;
            **---------------------------------------------------------------------------------------;
            ** 1:: CALL MACROS WHICH TELLS THE PROGRAM WHERE THE RAW DATA LIVES AND HOW MANY PARTS ;
            **     ARE FOUND IN THE DIRECTORY;
            **---------------------------------------------------------------------------------------;
            **This macro creates the num_file macro which is used to loop through each part below;
            %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);

            ** --- define libname for raw data :: directory differs by year and percent;
            ** ::: this directory is referenced by the sas views (data sets referenced by carvw lib);
            libname spcar "&dataRoot./&pct.pct/car/&y./";

            %do j=1 %to &cohrtN.;
                **---------------------------------------------------------------------------------------;
                **     VIEWS READ IN INDEX FILES AND ONLY KEEP THOSE INDIVIDUALS. ;
                **     RENAME INDEX FILE SO THAT VIEW CAN FIND;
                **     variables needed in index file are  bene_id, dgn_date and diag_id (only bene_id;
                **     is really needed) these are already defined;
                **---------------------------------------------------------------------------------------;
            data cartmp.indxfile;
                set indxex.&&cohrt&j..&pct._indx (keep=dgn_date bene_id diag_id ehic);
                WHERE (year(dgn_date) >= %sysevalf(&y. - &winyear.)) and
                    (year(dgn_date) <= %sysevalf(&y. + &winyear.)) ;
            run;
            **reads entire file into memory;
            %if &y.<2010 %then %do;sasfile cartmp.indxfile open; %end;

                %do z= 1 %to &num_file.;
                **---------------------------------------------------------------------------------------;
                **2:: unique to the carrier file this macro deals with different raw data names over the years;
                **---------------------------------------------------------------------------------------;
                %breakFilename2parts(ftype=car,pct=&pct.,z=&z.,year=&y.);
                **---------------------------------------------------------------------------------------;
                **3:: Extract window of claims for each beneficiaries index event  ;
                **---------------------------------------------------------------------------------------;
                %code2manipulateclms(cohrt = &&cohrt&j.., pct=&pct.,year = &y., pctsuffix = &suffix.,
                                      part = &part.,  winyear = &winyear.);
                    %end;
                *close file in memory;
                %if &y.<2010 %then %do; sasfile cartmp.indxfile close; %end;
                %end;
            %end;

      **---------------------------------------------------------------------------------------;
      **5:: Append temporary years files generated into a single file;
      **---------------------------------------------------------------------------------------;
        %do j=1 %to &cohrtN.;
            %appendYearFiles(cohrt = &&cohrt&j.., pct=&pct., start= &yearin., stop = &yearout.,
                      clmDTA=&clmDTA.);


             *****---------TIMER CODE ----------;
             %let tAfterCohrt=%sysfunc(datetime());
             %let elapsedCohrt=%sysevalf(%sysevalf((&tAfterCohrt.-&tBeforeRun.)/60));
             %put <TIMER> Process Years  &cohrt. cohrt took &elapsedCohrt. minutes.;
             %put FILLER;

            %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,yearin=&yearin.,yearout=&yearout.,note=);
        %end;
        **close sas file read into memory;
        sasfile spxw.ehicbenex_unique_bene_indx&pct. close;
        x "rm &cartmp./* -f ";
    %mend;




********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%RunCarExtraction;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;

*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=N/A   -- This parameter is only used in the 1A and 1B programs ;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
**
*** clmDTA     -- Flag which pass SAS dataset to appendYearFilessfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;

%RunCarExtraction(pct=&pct.,
    cohrt1=&cohrt,
    cohrtN=1,
    yearin=&yearin.,yearout=&yearout.,
    clmDTA=0,winyear=1,note=&note.);

