********************************************************;
** Flag candidate Index Events in the Carrier files **;
** *****************************************************;
**  Program uses the HCPCS codes found   ***;
**  Accompanying files to flag  potential index events.                          ***;
** Note this code processes one part of the code at a time;
** *****************************************************;
**
** Only use this file if you interested in pulling   ***;
** index events from the carrier files - other wise ignore ***;
***;
*** Instructions::;
*** Change HCPCS code to define cohort in the HCPCScohrtDef.sas file;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;

***********************************************************************
* DEFINE SAS OPTIONS ****;
***********************************************************************;
**READ IN SAS OPTIONS;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
** load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ImportVariableXW.sas";
%include "&SASmac./CreateXWmacro.sas";
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./breakFilename2parts.sas";
%include "&SASmac./errorCheckparameters.sas";
%readincarrierxw;
%include "ICD9cohrtDef.sas";
%include "HCPCScohrtDef.sas";

x "mkdir &tmprootDir./opex -p";
%let opex=&tmprootDir./opex;

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
%include "read_sysparm.sas";
* Defines local directories depending on which server currently running;
x "mkdir &cartmp./xw";
libname here ".";
libname carex  "&opex.";
libname cartmp "&cartmp.";
libname spxw "&inbenexw.";
libname xwfile "&xwfile.";
libname carvw  "&carvw.";
libname carvwtm  "&carvw./tmp";



**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!**;
** BEGIN MACRO DEFINITIONS CALLED AT THE END IN THE WRAPPER PROGRAM;
**!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!**;
***************************************************************************;
** Flags claims with code of interest (candidate index events);
***************************************************************************;
%macro TagcandidateIndxEventsCar(year=,pctsuffix= ,cohrt=,pct=,part=,dgnPos=,prcPos=);

    data cartmp.carcandidates_&cohrt. / view=cartmp.carcandidates_&cohrt.;
        length dICD9_indx $5 pICD9_indx $4 phcpcs_indx $5 ;
        set carvw.car&pct.&suffix._clmline_&year._&part. ;
        ** Generate empty variables;
        prcIndxNum=0;
        dgnIndxNum=0;
        pICD9_indx="";
        phcpcs_indx="";
        taghcpcs=0;
        tagPrc1=0;
        tagDgn1=0;

        *!!!!!!!!!!!!MACROS WHICH FLAG CANDIDATES!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
        %ICD9cohrtDef(cohrt=&cohrt.,numProcCodes=0,numDgnCodes=&dgnPos.,file=car,
                      dgnsPfx=icd_dgns_cd );
        %HCPCScohrtDef(cohrt=&cohrt.,hcpcs=hcpcs_cd);
        *!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;

         ** KEEP candidates;
         if taghcpcs=1 ;
         ***********************************************************;
         *** HARMONIZE VARIABLES;
         ***********************************************************;
         phcpcs_indx=hcpcs_cd;
         dgn_date=expnsdt1;
         dgn_date2=expnsdt2;
         dICD9_indx=line_icd_dgns_cd;
         file="car";
        zip_indx=zip_car;
        keep bene_id ehic fileyear file dICD9_indx pICD9_indx phcpcs_indx part carrawindx
             dgn_date dgn_date2 prcIndxNum dgnIndxNum  zip_indx;
    run;


    ** proc append is faster then a set statement, place processed part into year file;
    proc append base = cartmp.&cohrt._carindx&year.
                data = cartmp.carcandidates_&cohrt. force ;
    run;


    %mend;


%macro Combinecandidates(samplerule,cohrt=,pct=,start=,stop=,dgnPos=,prcPos=,clmDTA=0);
***************************************************************************;
** Combine the files and dump the final extract to stata if need be;
***************************************************************************;
    data carex.&cohrt.&pct._d&dgnPos.p&prcPos._carcandidates;
        **Fix lengths which differ between years;
        set %RepeatN(cartmp.&cohrt._carindx,&start.,&stop.);
            LABEL
                fileyear = "Carrier raw file year"
                file = "Source file of the index event claim "
                dICD9_indx = "Diagnostic ICD9-CM code defining the candidate"
                pICD9_indx = "Procedure ICD9-CM code defining the candidate"
                phcpcs_indx= "Procedure HCPCS code defining the candidate"
                dgn_date = "Line item candidate start date"
                dgn_date2 = "Line item candidate start date"
                prcIndxNum = "Procedure number generating the candidate indx event"
                dgnIndxNum = "Diagnostic number generating the candidate indx event"
                carrawindx = "Obs number in raw data. Combined with file/part/fileyear/bene_id/dgn_date generates unique match"
                zip_indx="Zip code on the claim generating the indx"
                part = "Raw file part for a given file/fileyear"
                ;
    run;

    proc contents data=carex.&cohrt.&pct._d&dgnPos.p&prcPos._carcandidates;run;

    proc sql;
       select fileyear, count(fileyear) as TotalCount
       from carex.&cohrt.&pct._d&dgnPos.p&prcPos._carcandidates
        group by fileyear;
    run;

    ** Delete datasets used to generate the current dataset;
    x "rm &cartmp./&cohrt._carindx* -f ";

    ** Define flag - send sas file to stat-transfer - via system command;
        %if &clmDTA.=1 %then %do;
            x "st &carext./&cohrt.&pct._d&dgnPos.p&prcPos._carcandidates.sas7bdat
                  &carext./&cohrt.&pct._d&dgnPos.p&prcPos._carcandidates.dta -y -od -v";
            %end;
    %mend;

**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro RunCarExtraction(pct="",cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrtN=,yearin=,yearout=,dgnPos=,clmDTA=,crashStart=0,note=);
  ** Define macro variables for timiing the runs -- used at the end of the loop ;
    %global tBeforeRun;
    %let tBeforeRun=%sysfunc(datetime());



**************************************************************************;
********Deal with a crash if defined in the parameter - crashStart********;
**************************************************************************;
    %do j=1 %to &cohrtN.;
        %if &crashStart.=&yearin. or &crashStart.=0 %then %do;
            x "rm &cartmp./* -f ";
            %let beginLoop=&yearin.;
            %end;
        %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
            proc datasets lib=cartmp;
                DELETE %RepeatN(&&cohrt&j.._carindx,&crashStart.,&yearout.);
            run;
            %end;
        %end;
****************************************************************;
** START LOOP THROUGH YEARs;
**************************************************************************;
        %do y=&beginLoop. %to &yearout.;
       **************************************************************************;
       ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=car,year=&y.);
       **This macro creates the num_file macro which is used to loop through;
       *******************************************************************;
       ** define lib;
       **************************************************************************;
       ** FIles are no longer saved zipped and new 10g line no longer makes it important;
       ** to move files to scratch;
       ** change libname which views use to the year/type/file being processed;
       libname spcar "&dataRoot./&pct.pct/car/&y./";

       *******************************************************************;
       ** START LOOP THROUGH EACH FILE PART AND PULL CLMS RELEVANT FOR EACH COHORT ;
       **************************************************************************;
            %do z= 1 %to &num_file.;
            **DEAL WITH DIFFENRT YEAR NAMING CONVENTIONS;
            %breakFilename2parts(ftype=car,pct=&pct.,z=&z.,year=&y.);
                %do j=1 %to &cohrtN.;
                    %TagcandidateIndxEventsCar(year=&y.,pctsuffix=&suffix.,cohrt = &&cohrt&j..,
                        pct=&pct.,part=&part.);
                    %end;
                %end;
            %end;

        *******************************************************************;
        ** LOOP  THROUGH ALL COHORTS-COMBINE ALL YEAR FILES AND EXPORT TO STAT TRANSFER;
        **************************************************************************;
        %do j=1 %to &cohrtN.;
            %Combinecandidates(cohrt = &&cohrt&j.., pct=&pct.,
                start= &yearin., stop = &yearout.,
                dgnPos=&dgnPos.,prcPos=0, clmDTA=&clmDTA.);

        *******************************************************************;
        ** PRINT OUT TIME:COHRT;
        **************************************************************************;
        %let tAfterCohrt=%sysfunc(datetime());
        %let elapsedCohrt=%sysevalf(%sysevalf((&tAfterCohrt.-&tBeforeRun.)/60));
        %put <TIMER> Process Years  &&cohrt&j.. cohrt took &elapsedCohrt. minutes.;
        %put FILLER;

        *******************************************************************;
        ** Copy log files to subdirectory;
        **************************************************************************;
        ** ARCHIVE OLD FILES;
        %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,dgnPos=&dgnPos.,yearin=&yearin.,yearout=&yearout.,note=&note.);
        %end;
        *******************************************************************;
        ** PRINT OUT FINAL RUN TIME;
        **************************************************************************;
        x "rm &cartmp./xw/* -f";
        x "rm  &cartmp./* -rf &";
        %let tAfterRun=%sysfunc(datetime());
        %put &tAfterRun.-&tBeforeRun.;
        %let elapsedRun=%sysevalf((&tAfterRun.-&tBeforeRun.)/60);
        %put <TIMER> Process Years  ALL cohrt took &elapsedRun. minutes.;

    %mend;




********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%RunCarExtraction;
********************************************************************************************;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;

*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=1   -- Determine how many diagnosis variables (principal versus secondary) were used to;
***               create the index event data. Most of the time it will be equal to  1 (the ;
***               principle diagnosis).;
*** prcPos=N/A -- OPTION NOT ALLOWED. HARD CODED TO ZERO. Note that this is only relevant for ICD9;
**                procedure codes, we do not pull these in teh carrier claims.;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in.;
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;

%RunCarExtraction(pct=&pct.,
    cohrt1=&cohrt.,
    cohrtN=1,
    dgnPos=1,
    yearin=&yearin.,yearout=&yearout.,
    clmDTA=0,note=&note.);



