********************************************************;
** Flag candidate Index Events in the MedPAR file**;
** *****************************************************;
**  Program uses the ICD9-CM found in the    ***;
**  accompanying HCPCS and ICD9 SAS files to flag    ***;
**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the medpar files - other wise ignore ***;
********************************************************;

*** Instructions::;
*** Change ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;
*!!!!WRAPPER MACRO FOUND AT THE END ;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
*options FILELOCKS NONE;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* READ IN SAS MACRO FOUND IN OTHER FILES  ;
***********************************************************************;
%include "read_sysparm.sas";
* load file containing various simple macros that make programming easier;
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
* load files with macros that conform the files of various years into a common format;
%include "&SASmac./ImportVariableXW.sas";
%readinmedparxw;
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./decompressMedPar.sas";
%include "ICD9cohrtDef.sas";
%include "&SASmac./errorCheckparameters.sas";
***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
* Defines local directories depending on which server currently running;
x "mkdir &medtmp./xw ";
x "mkdir &tmprootDir./opex -p";
%let opex=&tmprootDir./opex;

libname here "."            ;
libname spmed "&spmed."     ;
libname medtmp "&medtmp."   ;
libname medex  "&opex" ;
libname medvw  "&medvw.";
libname medvwtm  "&medvw./tmp";
libname xwfile "&xwfile.";
libname spxw "&inbenexw."   ;

%macro Extractdiag(yr=, cohrt=, pct=, prcPos=, dgnPos=,start=,end=,identifier=);
    %if &yr<= 1986 and &prcPos.>5 %then %do;
            %let  prcPos = 3 ;
            %end;
        %else %do;
            %let prcPos = &prcPos.;
            %end;
    ***********************************************************************************;
    *DATA STEP 1 - TAG candidate INDEX EVENTS -- ADDITIONAL RESTRICTIONS TAKEN LATER;
    ***********************************************************************************;
    /*proc contents data=medvw.medpar&pct._&yr.;run;*/

    data medtmp.&cohrt.&yr. ;
        *Make sure all variable have the proper length;
        length dICD9_indx $5 pICD9_indx $4 ;
        set medvw.medpar&pct._&yr. ;

        **Creates a unique ID which allows the variable to be linked back to the raw data;
        medrawindx=_N_;
        ** Generate empy variables;
        pICD9_indx="";
        prcIndxNum=0;
        dgnIndxNum=0;
        tagPrc1=0;
        tagDgn1=0;
*!!!!!!!!INSERT SELECTION CRITERIA HERE!!!!*****;
        * define your ifthen code block in the file with same name as this macro;
        * The macro should create tagPrc# or tagDgn# dummy variables so the right combo;
        * of dummys can be dropped in the following if then statement ;
        %ICD9cohrtDef(cohrt=&cohrt.,numProcCodes=&prcPos.,numDgnCodes=&dgnPos.,file=medpar,
                          dgnsPfx=dgnscd,prcdPfx=prcdrcd);
*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;

        ****************************************************************;
        ** KEEP candidates;
        ****************************************************************;
        %if &prcPos.=0 %then %do;
                if tagDgn1=1 %do i=2 %to &dgnPos.; or tagDgn&i.=1 %end;
                ;
                %end;
            %else %if &dgnPos.=0 %then %do;
                if tagPrc1=1 %do i=2 %to &prcPos.; or tagPrc&i.=1 %end;
                ;
                %end;
            %else  %do;
                if tagPrc1=1 %do i=2 %to &prcPos.; or tagPrc&i.=1 %end;
                             %do i=1 %to &dgnPos.; or tagDgn&i.=1 %end;
                ;
                %end;
        **HARMONIZE VARIABLES;
        dgn_date=admsndt;
        **USE LOS TO GENERATE DATES FOR MISSING VALUES;
        if admsndt=. and loscnt ne . and  dschrgdt ne . then dgn_date=dschrgdt - loscnt +1;

        dgn_date2=dschrgdt;
        if dschrgdt=. and loscnt ne . and  admsndt ne . then dgn_date2=admsndt + loscnt -1;

        fileyear=&yr.;
        file="med";
        diag_year=year(dgn_date);
        * Has a valid diag_year, eg bene_id=######   there is an instance which reports;
        * a diagnosis date of October 11,2018. We drop the bad years;
        if diag_year >&end. then put "CHECK bene_id"  ehic diag_year  ;
        if diag_year >&end. then delete ;
        zip_indx=zip_med;
        keep bene_id ehic fileyear file dICD9_indx pICD9_indx medrawindx
             dgn_date dgn_date2  prcIndxNum dgnIndxNum loscnt zip_indx;
    run;

    ***********************************************************************************;
    * DATA STEP 2: APPEND ALL YEAR candidate INDEX EVENTS;
    ***********************************************************************************;
    ** When we have reached the final year, merge all of the annual dataset together and;
    ** creates and id for the index events. Need to drop diag_id here because it is kept;
    %if &yr.=&end. %then %do;
        data medex.&cohrt.&pct._d&dgnPos.p&prcPos._medparcandidates;
            set  %RepeatN(medtmp.&cohrt.,&start.,&end.);
            LABEL
                fileyear = "Raw file year"
                file = "Type of file contributing claims"
                dICD9_indx = "Diagnostic ICD9-CM code defining the candidate"
                pICD9_indx = "Procedure ICD9-CM code defining the candidate"
                dgn_date = "Indx event start date"
                dgn_date2 = "Indx event end date"
                prcIndxNum = "Procedure number generating the candidate indx event"
                dgnIndxNum = "Diagnostic number generating the candidate indx event"
                medrawindx = "Obs number in raw data. Combined with file/fileyear/bene_id/dgn_date generates unique match"
                loscnt ="length of stay index"
                zip_indx="Zip code on the claim generating the indx"
                ;

       run;

        proc freq data=medex.&cohrt.&pct._d&dgnPos.p&prcPos._medparcandidates;
            tables fileyear  /missing;
        run;


        ** Delete datasets;
        proc datasets lib=medtmp nolist;DELETE  %RepeatN(&cohrt.,&start., &end.);run;
     %end;
  %mend;

**#############################################################################;
*** BEGIN  WRAPPER MACRO HERE**************************************************;
**#############################################################################;
%macro TagcandidateIndexEvents(cohrt1=,cohrt2=,cohrt3=,cohrt4=,cohrt5=,cohrt6=,cohrt7=,
    cohrtN=,prcPos=, dgnPos=,yearin=,yearout=,pct=,winyear=,dflag=1,clmDTA=, note=);
**#############################################################################;
*****---------TIMER CODE ----------;
**#############################################################################;
        %global tBeforeRun;
        %let tBeforeRun=%sysfunc(datetime());

**#############################################################################;
***STEP 1: PRELIMINARY ---COPY LARGE DATASETS TO SPACE DRIVES FOR FAST PROCESSING;
**#############################################################################;
    *Make Sure we are starting with an empty dataset;
    proc datasets lib=work nolist kill ; run;
    proc datasets lib=medtmp nolist kill ; run;
    proc datasets lib=spmed nolist kill ; run;

    **************************************************************************;
    ** THROW ERROR FOR BAD PARAMETERS ;
    **************************************************************************;
    %errorCheckparameters(cohrt1=&cohrt1.,cohrtN=&cohrtN.,yearin=&yearin.,yearout=&yearout.,
                          pct=&pct.,winyear=&winyear.,prgm=LongExtract);

**##################################################################;
***STEP 2: DECOMPRESS AND TAG candidateS;
**#############################################################################;
    *****************************************************************;
    ** BEGIN LOOPING THROUGH ALL YEARS OF INTEREST AND COHORTS   ****;
    *****************************************************************;
    %do y=&yearin. %to &yearout. ;

        %do j=1 %to &cohrtN.;

            %if &j.=1 %then %do;
                %decompressMedPar(yr=&y.,pct=&pct., libout=spmed, dataroot=&dataroot.,
                    dirout=&spmed.,dflag=&dflag.);
                %end;

       *************************************************************************;
       ** TAG ALL INDEX EVENT candidateS. MERGE ALL MEDPAR FILE ON LAST YEAR;
       *************************************************************************;
            %Extractdiag(yr=&y.,cohrt=&&cohrt&j..,pct=&pct,dgnPos=&dgnPos.,prcPos=&prcPos.,
                         start=&yearin.,end=&yearout);

            %if &j.= &cohrtN. %then %do;
               ** delete raw dataset;
               x "rm &spmed./medpar&pct._&y._all* -f " ;
               %end;

           %end;

       %end;

        **#############################################################################;
        *****---------TIMER CODE ----------;
        **#############################################################################;
            %let tAftercohrt=%sysfunc(datetime());
            %let elapsedcohrt=%sysevalf(%sysevalf((&tAftercohrt.-&tBeforeRun.)/60));
            %put <TIMER> FINAL  took &elapsedcohrt. minutes  ;
        **#############################################################################;
        *Copy log and lst files to archive folder with same name and attach date being run;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=&cohrt1.,dgnPos=&dgnPos.,yearin=&yearin.,
            yearout=&yearout.,note=&note.)               ;

    **#############################################################################;
    *Delete all temp files;
    **#############################################################################;
        x "rm &medtmp./* -f";
        x "rm &spmed./* -f";

        %let tAfterRun=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&tAfterRun.-&tBeforeRun.)/60));
        %put <TIMER> FINAL  took &elapsedrun. minutes  ;

    %mend;



***********************Call Wrapper Program Below-***********************;
*WRAPPER MACRO DOCUMENTATION --SAME AS DOC FOUND AT BEGINNING OF SCRIPT ---;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running several;
***            -- (4 plus)the efficiently of the program maybe impacted. ;
*** .....;
*** cohrtN=1   -- Define the total number of cohorts you are creating;
***;
***  dgnPos=1  -- Determine how many diagnosis you want to use to create the index event. Most of the time;
***            -- this will be equal to 1 (the principle diagnosis). However this is useful for better;
***            -- understanding the data. For example investigating what principal diagnosis are recorded;
***            -- for individuals with who report an AMI or hip fracture as a comorbidity (second diagnosis;
***            -- Diagnosis variables range from 1 to 5 in the early years and was increased from 1 to 10;
***            -- later on. ;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
*** pct=05     -- Define the percent extract you are interested in. Use .01% for debugging where possible;
***;
*** dflag      -- Set equal to one if you want to delete raw files as you run the program;

*** clmDTA     -- Set equal to one if you want to convert the all files into a stata format (DTA)*;
***;
****************************************************************************************************;


%TagcandidateIndexEvents(cohrt1=&cohrt.,cohrtN=1,
                        dgnPos=&MED_DXN.,prcPos=&MED_PROC.,
                        pct=&pct.,
                        yearin=&yearin.,yearout=&yearout.,
                        dflag=1,clmDTA=&clmDTA.,note=&note.);

