********************************************************;
** Flag candidate Index Events in the Outpatient sample**;
** *****************************************************;
**  Program uses the ICD9-CM and HCPCS codes found   ***;
**  Accompanying HCPCS and ICD9 SAS files to flag    ***;
**  potential index events.                          ***;
** *****************************************************;
** Only use this file if you interested in pulling   ***;
** index events from the OP files - other wise ignore ***;
***
*** Instructions::
*** Change HCPCS and ICD9_CM codes in the accompanying *;
*** files. Fill out the wrapper program at the bottom of programs;
********************************************************;

***********************************************************************;
* READ IN SAS OPTIONS ****;
***********************************************************************;
*Use these options for debugging;
*options symbolgen mlogic mprint mfile ;
%include "../../../sasoptions.sas";

** ALL DIRECTORIES LIVE HERE -- READS IN DIRECTORIES;
%include "../../../dirInit.sas";

***********************************************************************;
* DEFINE LIBRARIES ;
***********************************************************************;
%let tmprootDir=/tmp/&username./medicare.work/&DUAfolder./&projectName./&vid./&branch.;
X "mkdir &tmprootDir./opex -p";
libname opex "&tmprootDir./opex";


* Defines local directories depending on which server currently running;
libname here ".";
libname optmp "&optmp.";
* these libnames need to be defined in order for the sas views to work;
libname spxw "&inbenexw.";
libname opvw  "&opvw.";
libname opvwtm  "&opvw./tmp";

*import useful simple utility macros;
%include "read_sysparm.sas";
%include "&SASmac./UtilityMacros.sas";
%include "&SASmac./DetermineMax.sas";
%include "&SASmac./ImportVariableXW.sas";
%readinopxw;
%include "&SASmac./archiveoldLogfiles.sas";
%include "&SASmac./errorCheckparameters.sas";
%include "ICD9cohrtDef.sas";
%include "HCPCScohrtDef.sas";



%macro candidateIndxFlag(year=,pctsuffix=,cohrt=,pct=,part=,file=,prcPos=,dgnPos=);
    ************************************************************************;
    **           DEFINE ID IN THE RAW DATA TO SORT AND MERGE BY;
    ************************************************************************;
    %if &year<= 1986 and &dgnPos.>6 %then %do;
        %let  prcPos = 3 ;
        %end;
    %else %do;
        %let  prcPos = &prcPos.;
        %end;

    ** SINGLE DATASTEP IS MODIFIED WITH MACRO TO ACCOUNT FOR INTER YEAR DIFFERENCES;
    data optmp.op&year._&cohrt._clms&part. / view=optmp.op&year._&cohrt._clms&part.;
        length  dICD9_indx $5 pICD9_indx $4  ;
        set opvw.op&pct._&year._clms_&part. ;
           ** Generate empty variables;
           prcIndxNum=0;
           dgnIndxNum=0;
           dICD9_indx ="";
           pICD9_indx ="";
           tagDgn1=0;
           tagPrc1=0;
           *!!!!!!!!FINISH candidate FLAGGING  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
           dgn_date=from_dt;
           dgn_date2=thru_dt;
           part=&part.;
           fileyear=&year.;
           opclmrawindx=_N_;

            *CHOOSE ICD9 candidate here;
            %ICD9cohrtDef( cohrt=&cohrt.,numProcCodes=&prcPos.,numDgnCodes=&dgnPos.,
                          file=op, dgnsPfx=dgnscd,prcdPfx=prcdrcd);
            if pICD9_indx ne "" or dICD9_indx ne ""  then flagclm=1;
            zip_indx=zip_cd;

             keep bene_id ehic fileyear dICD9_indx pICD9_indx  part  opclmrawindx
                  dgn_date dgn_date2  prcIndxNum dgnIndxNum  tag: clm_id zip_indx               ;
    run;


    data optmp.op&year._&cohrt._revcntrs&part. / view=optmp.op&year._&cohrt._revcntrs&part.;
        length   phcpcs_indx $5 ;
        set opvw.op&pct._&year._revcntrs_&part. ;
        oprevrawindx=_N_;
        counthcpcsRevField=0;
        *HCPCS CODE ARE IN LONG FORM;
        %HCPCScohrtDef(cohrt=&cohrt.,hcpcs=hcpcs_cd);

        if taghcpcs=1 ;
        oprevrawindx=_N_;
        dgn_dte_rev=rev_dt;
        phcpcs_indx=hcpcs_cd;

        keep bene_id ehic  phcpcs_indx  oprevrawindx counthcpcsRevField
             dgn_dte_rev  clm_id  taghcpcs;
      run;


    proc sort data=optmp.op&year._&cohrt._clms&part. out=clm;
        by bene_id clm_id;
    run;
    proc sort data=optmp.op&year._&cohrt._revcntrs&part. out=rev;
        by bene_id clm_id;
    run;

    **MERGE TOGETHER THE REV AND CLMS IN CASE INDIVIDUALS WANT TO DEFINE INDEX EVENT AS SUCH;
        data op_candidate_&cohrt.;
            merge clm (in=clm)
                  rev (in=rev);
            by bene_id clm_id;
*!!!!!!!!FINISH candidate FLAGGING  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!;
            *!!!!!!!!INSERT AND SELECTION CRITERIA HERE!!!!*****;
            * define your ifthen code block in the file with same name as this macro;
            * The macro should create tagPrc# or tagDgn# dummy variables so the right combo;
            * of dummys can be dropped in the following if then statement. You can get rid of;
            * macros and insert your own criteria hear ;
            %if &prcPos.=0 %then %do;
                if tagDgn1=1 %do i=2 %to &dgnPos.; or tagDgn&i.=1 %end;
                or taghcpcs=1;
                %end;
            %else %if &dgnPos.=0 %then %do;
                if tagPrc1=1 %do i=2 %to &prcPos.; or tagPrc&i.=1 %end;
                or taghcpcs=1;
                %end;
            %else  %do;
                if tagPrc1=1 %do i=2 %to &prcPos.; or tagPrc&i.=1 %end;
                             %do i=1 %to &dgnPos.; or tagDgn&i.=1 %end;
                or taghcpcs=1;
                %end;

            if clm=1 and rev=0 then file="opc";
            if clm=0 and rev=1   then file="opr";
            if clm=1 and rev=1 then file="opb";
            *drop tag: flagclm flagrev retain: &clmindx.;
            part=&part.;
            fileyear=&year.;

    run;

    ************************************************************************;
    **    COMBINE HARMONIZED PARTS - APPEND IS FASTEST;
    ************************************************************************;
        proc append base = optmp.&cohrt.opindx_&year.
                    data = op_candidate_&cohrt. force ;
        run;

        x "rm &optmp./op&year._&cohrt._*&part.* -f";
    %mend;


%macro CompileIndxEvents(cohrt=,pct=,start=,end=,dgnPos=,prcPos=,clmDTA=0);
   ************************************************************************;
   ** Combine the CLMS  and dump the final extract to stata dta file;
   ************************************************************************;
    data opex.&cohrt.&pct._d&dgnPos.p&prcPos._opcandidates;
        set %RepeatN(optmp.&cohrt.opindx_,&start.,&end.);
        if dgn_dte_rev=. then dgn_dte_rev=dgn_date;
        LABEL
                bene_id = "Encrypted beneficiary identifier (individual unique identifier)"
                ehic = "Encrypted HIC  (OLD identifier)"
                fileyear = "Raw file year"
                file = "Type of file contributing claims"
                dICD9_indx = "Diagnostic ICD9-CM code defining the candidate"
                pICD9_indx = "Procedure ICD9-CM code defining the candidate"
                phcpcs_indx= "Procedure HCPCS code defining the candidate"
                dgn_date = "Claim index candidate START date"
                dgn_dte_rev  = "Revenue center candidate date - if missing assign dgn_date"
                dgn_date2 = "Claim index candidate END date"
                prcIndxNum = "Procedure number generating the candidate indx event"
                dgnIndxNum = "Diagnostic number generating the candidate indx event"
                opclmrawindx = "obs number claims data. unique with file/part/fileyear/bene_id/dgn_date"
                oprevrawindx = "Obs number revenue ceneter data. unique with file/part/fileyear/bene_id/dgn_date"
                part = "Raw file part for a given file/fileyear"
                counthcpcsRevField = "Counts number of revenue centers codes matching criteria within a claim"
                zip_indx="Zip code on the claim generating the indx"
                ;

    run;

    proc datasets lib=optmp;
        DELETE %RepeatN(&cohrt.opindx_,&start.,&end.);
    run;

    proc freq data=opex.&cohrt.&pct._d&dgnPos.p&prcPos._opcandidates;
        table fileyear*file /norow nocol nopercent;
    run;


    proc contents data=opex.&cohrt.&pct._d&dgnPos.p&prcPos._opcandidates;;run;
   ************************************************************************;
   ** SEND TO STAT-TRANSFER;
   ************************************************************************;
    %if &clmDTA.=1 %then %do;
        x "st &opext./&cohrt.&pct._&dgnPos._opcandidates.sas7bdat
              &opext./&cohrt.&pct._&dgnPos._opcandidates.dta -y -od -v";
        %end;
    %mend;





**************************************************************************;
****************          WRAPPER MACRO     ******************************;
**************************************************************************;
%macro FlagcandidateOPindx(pct=,cohrt1=,cohrt2=,cohrt3=,cohrt4=,
                          cohrtN=4,dgnPos=,prcPos=,yearin=,yearout=,clmDTA=0,crashStart=0, note=);
************************************************************************;
**          CATCH ERRORS IN PARAMETERS                    ;
************************************************************************;
  *For timing;
  %global tBeforeRun;
  %let tBeforeRun=%sysfunc(datetime());
  %put TIMER Begin run at time &SYSTIME.;

  **************************************************************************;
  ********Deal with a crash if defined in the parameter - crashStart - DELETE OLD DATASETS***;
  **************************************************************************;
      %if &crashStart.=&yearin. or &crashStart.=0 %then %do;
            x "rm &optmp./* -f" ;
            %let beginLoop=&yearin.;
            %end;
        %if &crashStart.>&yearin. %then %do;
            %let beginLoop=&crashStart.;
            *Delete files no longer needed;
            x "rm &optmp./op*&&cohrt&j.._* -f";
            %do j=1 %to &cohrtN.;
               proc datasets lib=optmp;
                  DELETE
                    %RepeatN(&&cohrt&j..opindx_,&crashStart.,&yearout.)
                run;
            %end;
        %end;

    ****************************************************************;
    ** START LOOP THROUGH YEARs;
    **************************************************************************;
    %do y= &beginLoop. %to &yearout. ;
        %let suffix=;
        %let stypem=;
        %if &y. >=2001 %then %do;
            %let stypem=clms;
            %end;
        **************************************************************************;
        ** DETERMINE HOW MANY FILES NEED TO BE DECOMPRESSED AND STRIP OUT INFO  **;
        **************************************************************************;
         **Macro generate the num_file macro;
         %DetermineMax(datadir=&dataroot.,pct=&pct.,ftype=op,year=&y.,subtype=&stypem.,
                      pctsuffix=&suffix.);
         *******************************************************************;
         ** define lib;
         **************************************************************************;
         ** FIles are no longer saved zipped and new 10g line no longer makes it important;
         ** to move files to scratch;
         ** change libname which views use to the year/type/file being processed;
         libname spop "&dataRoot./&pct.pct/op/&y./";

         *******************************************************************;
         ** START LOOP THROUGH EACH FILE PART AND DISEASE COHORT;
         **************************************************************************;
         *For testing purposes set numfile =1 num_file ;
         %do z=1 %to &num_file.;
            %do j=1 %to &cohrtN.;
                 **************************************************************************;
                 ** FLAG CANDITATE INDEX EVENTS FOR 1B programs  ***;
                 **************************************************************************;
                %candidateIndxFlag(year=&y.,cohrt=&&cohrt&j..,pct=&pct.,part=&z.,
                                      dgnPos=&dgnPos., prcPos=&prcPos.);
                %end;
            %end;
        %end;
        *******************************************************************;
        ** COMBINE ALL candidate INDX EVENTS;
        **************************************************************************;
    %do j=1 %to &cohrtN.;
        %CompileIndxEvents(cohrt=&&cohrt&j..,pct=&pct.,start=&yearin.,end=&yearout.,
                           prcPos=&prcPos., dgnPos=&dgnPos.,clmDTA=0);
       **#############################################################################;
       *****---------TIMER CODE ----------;
       **#############################################################################;
        %let tAfterRunCht=%sysfunc(datetime());
        %let elapsedcohrt=%sysevalf(%sysevalf((&tAfterRunCht.-&tBeforeRun.)/60));
        %put <TIMER> Total  &&cohrt&j.. took &elapsedcohrt. minutes.;

        **#############################################################################;
        ** Copy log and lst files, gip for archiving ;
        **#############################################################################;
        %archiveoldLogfiles(pct=&pct.,cohrt=&&cohrt&j..,dgnPos=&dgnPos.,
                            yearin=&yearin.,yearout=&yearout.,note=&note.);
            %end;
        **clear space directory;
        x "rm &optmp./* -f &";
        %let rundone=%sysfunc(datetime());
        %let elapsedrun=%sysevalf(%sysevalf((&rundone.-&tBeforeRun.)/60));
        %put TIMER END run at time &elapsedrun.;
    %mend;



********************************************************************************************;
*WRAPPER MACRO PARAMETER DOCUMENTATION ---%runprgOp;
********************************************************************************************;
*** It has the following options;
*** It has the following options;
*** cohrt1=    -- These reference the ICD-9-CM codes in the code and define what these files will;
***               be called.;
*** cohrt2=    -- You can add as many of these as you would like, however if you start running;
***               several;
*** .....;

*** cohrtN=2   -- Define the total number of cohorts you are creating;
***            -- NOTE: More than 4 cohorts the efficiently of the program maybe impacted. ;
***;
*** dgnPos=1   -- Determine how many diagnosis variables (principal versus secondary) were used to;
***               create the index event data. Most of the time it will be equal to  1 (the ;
***               principle diagnosis).;
***;
*** prcPos=0   -- Determine how many ICD9-CM procedure code are used to loop through. ;
***               Most people will not use the procedure ICD9 code to flag indx events.;
***;
*** yearin=    -- Start year for the run;
*** yearout=   -- End year for the run;
***;
*** pct=05     -- Define the percent extract you are interested in.;
***;
*** clmDTA     -- Flag which pass SAS dataset to stattransfer -- create DTA file;
***;
*** crashStart -- If program crashed, set equal to the year program crashed and it will restart;
***               from that year and aggregate the program once finished processing from the;
***               yearin to yearout dates. ;
**CALL WRAPPER MACRO BELOW;
******************************************************************************************;


%FlagcandidateOPindx(pct=&pct.,
          cohrt1=&cohrt.,
          cohrtN=1,
          yearin=&yearin., yearout=&yearout.,
          dgnPos=1, prcPos=2,
          clmDTA=0,note=&note. );

