
%macro ConformDenom(year=,adVar=year);
    ** This macro conforms the denominator files of different years;
    ** into the format for 2005.  Called by macro ExtractDenomInfo;
    ** (see below).;
    **;
    ** the year of the denominator file being conformed.;
    **;
    ** See spreadsheet DenomFileLayouts.xlsx for information on the;
    ** layout of the denominator files.;

    %if &year. >= 1992 and &year. <= 1995 %then %do;
        array aentflag{1:12} $ 1 entflag1-entflag12;
        array ahmoflag{1:12} $ 1 hmoflag1-hmoflag12;
        do i=1 to 12;
            aentflag(i) = substr(entitl12,i,1);
            ahmoflag(i) = substr(hmo12,i,1);
            end;

        state_den = put(state,z2.0);
        county_den = put(county,z3.0);
        zipcode_den = put(zip,5.0);

        sex_str = put(sex,1.0);
        race_str = put(race,1.0);

        keep &adVar. ehic
            state_den county_den zipcode_den
            sbdate sddate validdt
            sex_str race_str
            entflag1-entflag12 hmoflag1-hmoflag12
            hicov smicov hmocov
            oentitl centitl esrd status ;


        rename state_den=state_de county_den=county_de zipcode_den=zipcode_de
            sbdate=sdob sddate=sdod validdt=v_death_sw
            sex_str=sex race_str=race
            entflag1-entflag12=buyin1-buyin12 hmoflag1-hmoflag12=hmoind1-hmoind12
            status=ms_cd oentitl=orec centitl=crec esrd=esrd_ind
            hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo;

        %end;
    %else %if &year. >= 1996 and &year. <= 2001 %then %do;

        length hicov 3;
        length smicov 3;
        length hmocov 3;
        hicov = input(dcovmpa,2.0);
        smicov = input(dcovmpb,2.0);
        hmocov = input(dcovmhmo,2.0);

        %if &year. = 1996 or &year. = 1997 %then %do;
            %let zipVar=dzip5;
            %end;
        %else %do;
            %let zipVar=dzip;
            %end;

        keep &adVar. ehic
            dstate dcounty &zipVar.
            dbdate dddate dvddate
            dsex drace
            dpyri01-dpyri12 dhmoi01-dhmoi12
            hicov smicov hmocov
            dorec dcrec desrdind dmedsta    ;


        rename dstate=state_de dcounty=county_de &zipVar.=zipcode_de
            dbdate=sdob dddate=sdod dvddate=v_dod_sw
            dsex=sex drace=race
            dpyri01-dpyri12=buyin1-buyin12 dhmoi01-dhmoi12=hmoind1-hmoind12
            dorec=orec dcrec=crec desrdind=esrd_ind dmedsta=ms_cd
            hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo;
        %end;
    %else %if &year. >= 2002 and &year. <= 2005 %then %do;

        keep &adVar. ehic
            state county zipcode
            sdob sdod death_sw
            sex race
            entitl1-entitl12 hmo1-hmo12
            hicov smicov hmocov
            oentitl centitl esrd msc  ;

        rename
            state=state_de county=county_de zipcode=zipcode_de entitl1-entitl12=buyin1-buyin12 hmo1-hmo12=hmoind1-hmoind12
        hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo
        msc=ms_cd oentitl=orec centitl=crec esrd=esrd_ind death_sw=v_dod_sw;

        %end;
     %else %if &year. >= 2006 %then %do;

        length hicov 3;
        length smicov 3;
        length hmocov 3;

        hicov = input(a_mo_cnt,2.0);
        smicov = input(b_mo_cnt,2.0);
        hmocov = input(hmo_mo,2.0);

        keep &adVar.
           bene_id
            state_cd
            cnty_cd
            bene_zip
            bene_dob
            death_dt
            v_dod_sw
            sex
            race
            buyin01-buyin12
            hmoind01-hmoind12
            hicov
            smicov
            hmocov
            orec
            crec
            esrd_ind
            ms_cd
            ;

            * Recall we only rename the 01 through 09 because we want to drop the 0 in front of;
            *  the numbers to match our harmonized variables.;
        rename
            state_cd=state_de
            cnty_cd=county_de
            bene_zip=zipcode_de
            bene_dob=sdob
            death_dt=sdod
            buyin01-buyin09=buyin1-buyin9
            hmoind01-hmoind09=hmoind1-hmoind9
            hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo;
        %end;
    %mend;

%macro keepVarDenom(year=,adVar=,pct=);
    %if &pct. = 05 %then %let pctvars=efivepct fivepct;
    %if &pct. ne 05 %then %let pctvars= ;
    %put TEST &pctvars. ;
    %if &year. >= 1992 and &year. <= 1995 %then %do;
        keep=&adVar. ehic
            state county zip
            sbdate sddate validdt
            sex race
            entitl12 hmo12
            hicov smicov hmocov
            oentitl centitl esrd status
        %end;
    %else %if &year. >= 1996 and &year. <= 2001 %then %do;
        %if &year. = 1996 or &year. = 1997 %then %do;
            %let zipVar=dzip5;
            %end;
        %else %do;
            %let zipVar=dzip;
            %end;

        keep=&adVar. ehic
            dstate dcounty &zipVar.
            dbdate dddate dvddate
            dsex drace
            dpyri01-dpyri12 dhmoi01-dhmoi12
            dcovmpa dcovmpb dcovmhmo
            dorec dcrec desrdind dmedsta
        %end;
    %else %if &year. >= 2002 and &year. <= 2005 %then %do;
        keep=&adVar. ehic
            state county zipcode
            sdob sdod death_sw
            sex race
            entitl1-entitl12 hmo1-hmo12
            hicov smicov hmocov
            oentitl centitl esrd msc
        %end;
    %else %if &year. >= 2006  %then %do;
        keep=bene_id
            state_cd
            cnty_cd
            bene_zip
            bene_dob
            death_dt
            v_dod_sw
            sex
            race
            buyin01-buyin12
            hmoind01-hmoind12
            a_mo_cnt
            b_mo_cnt
            hmo_mo
            orec
            crec
            esrd_ind
            ms_cd
            &adVar. &pctvars.
        %end;

    %mend;


