%macro ConformOp_ClmsGenChargeVar(year=);
    %if &year. >= 1986 and &year. < 1989 %then %do;
        * Generate a total charge field using the 001 revenue center field;
        * which is supposed to total all charges associated with the claim;
        * Almost always, the 001 code appears in last (non-missing) revenue center field.;
        * Occasionally, however, it appears in some other position, usually;
        * the first one.  In these case, I iterate over the revenue centers;
        * (note that the array iterated over was defined in ConformOp_WriteRevcntrs) to ;
        * find the appropriate one;
        array revcntra{1:%eval(&numFields.)} &rev_cntr.1-&rev_cntr.&numFields.;
        array rvpchga{1:%eval(&numFields.)} &rev_chrg.1-&rev_chrg.&numFields.;
        if orevccco > 0 then do;
            if revcntra{orevccco} = "001" then do;
                tot_chrg = rvpchga{orevccco};
                end;
            else do;
                do i=1 to 30;
                    if revcntra{i} = "001" then do;
                        tot_chrg = rvpchga{i};
                        leave;
                        end;
                    end;
                end;
            end;
        else do;
            tot_chrg = 0;
            end;
        * Throw an PROGRAM WARNING in the event that no total charge revenue center was found;
        * Sum over all revenue centers present;
        if tot_chrg = . then do;
            put "PROGRAM WARNING: No revenue center code 001 was found.  Summing
                  over all revenue centers.  EHIC: " ehic " DATE: " ;
            tot_chrg = 0;
            do i=1 to 30;
                if rvpchga{i} ne . then do;
                    tot_chrg = tot_chrg + rvpchga{i};
                    end;
                else do;
                    leave;
                    end;
                end;
            end;

        %end;
    %mend;

%macro ConformOp_ClmsChar2Numeric(year=);
    %if &year. >= 1984 and &year. < 1986 %then %do;
        * convert dates;
        * Note: I simply assume that claims begin and end on the same day;
        * this is clearly not exactly right, but probably the best option;
        * in this context given that most claims are of very short duration;
        &from_dt.=datejul(input(fromdt_temp,5.0));
        thru_dt=&from_dt.;
        prstate = substr(oprovno,1,2);
        %end;
    %else %if &year. >= 1986 and &year. < 1996 %then %do;
        * convert dates to a useable format;
        &from_dt.=input(put(fromdt_temp,z8.0),yymmdd8.);
        &thru_dt.=input(put(thrudt_temp,z8.0),yymmdd8.);
        prstate = substr(oprovno,1,2);
        %end;
    %else %if &year. >= 1989 and &year. < 1996 %then %do;
        %do t=1 %to 10;
            osrgdt&t_tmp=osrgdt&t.
            if osrgdt&t_tmp eq 0 then do;
                osrgdt&t. = .;
                end;
            else do;
                osrgdt&t. = input(put(osrgdt&t_tmp,z8.0),yymmdd8.);
                end;
            %end;
        %end;
    %if &year>=2001 and &year. <= 2005 %then %do;
         clm_id=put(trim(clmindx_temp),19.);
        %end;
    %mend;



%macro ConvertStr2Num_setrenameOp(y=,pct=,filevarin=);
    %if &year. >= 1984 and &year. < 1986 %then %do;
        (rename=(&from_dt=fromdt_temp))
            %end;
    %if &year. >= 1986 and &year. < 1996 %then %do;
        (rename=(&thru_dt.=thrudt_temp &from_dt.=fromdt_temp))
            %end;
    %if (&y. >= 1999 and &y. <= 2000 and &filevarin.=rev) %then %do;
        (rename=(&clmindx.=clmindx_temp ))
            %end;
   %if (&y. >= 2001 and &y. <= 2005 and &filevarin.=rev) %then %do;
        (rename=(&clmindx.=clmindx_temp &pricng.=pricing_temp ))
            %end;
    %if (&y. >= 1999 and &y. <= 2005 and &filevarin.=clm) %then %do;
        (rename=(&clmindx.=clmindx_temp ))
            %end;

    %mend;


* This macro loops over each of the revenue center fields for each year;
* and, where these fields are non-empty, writes a separate record containing;
* HCPCS code, APC code, reimbursement, etc);
%macro ConformOp_WriteRevcntrs(year=,cohrt=,dir=,part=);
    **********************************************************************;
    ***SETUP ARRAYS;
    **********************************************************************;
   %if &year. >= 1984 and &year. < 2001 %then %do;
       array revcntra{1:%eval(&numFields.)} &rev_cntr.1-&rev_cntr.&numFields.;
       array rvpchga{1:%eval(&numFields.)} &rev_chrg.1-&rev_chrg.&numFields.;
       %end;
   %if &year. >= 1986 and &year. < 2001 %then %do;
       array hcpcsa{1:%eval(&numFields.)} &hcpcs_cd.1-&hcpcs_cd.&numFields.;
       array mdfr1a{1:%eval(&numFields.)} &mdfr_cd1.1-&mdfr_cd1.&numFields.;
       array mdfr2a{1:%eval(&numFields.)} &mdfr_cd2.1-&mdfr_cd2.&numFields.;
   %end;
   %if &year. >= 1996 and &year. < 2001 %then %do;
       array revdatea{1:%eval(&numFields.)} rev_dt1-rev_dt&numFields.;
       %end;
   %if &year. >= 1999 and &year. < 2001 %then %do;
       array mdfr3a{1:%eval(&numFields.)} &mdfr_cd3.1-&mdfr_cd3.&numFields.;
       array mdfr4a{1:%eval(&numFields.)} &mdfr_cd4.1-&mdfr_cd4.&numFields.;
       array mdfr5a{1:%eval(&numFields.)} &mdfr_cd5.1-&mdfr_cd5.&numFields.;
       array apca{1:%eval(&numFields.)} &apchipps.1-&apchipps.&numFields.;
       array revpmta{1:%eval(&numFields.)} &revpmt.1-&revpmt.&numFields.;
       array rvblda{1:%eval(&numFields.)} &revblood.1-&revblood.&numFields.;
       array rvdtbla{1:%eval(&numFields.)} &revdctbl.1-&revdctbl.&numFields.;
       array wgdja{1:%eval(&numFields.)} &wageadj.1-&wageadj.&numFields.;
       array rdcdcna{1:%eval(&numFields.)} &rdcdcoin.1-&rdcdcoin.&numFields.;
       array rvmsp1a{1:%eval(&numFields.)} &rev_msp1.1-&rev_msp1.&numFields.;
       array rvmsp2a{1:%eval(&numFields.)} &rev_msp2.1-&rev_msp2.&numFields.;
       array rvrta{1:%eval(&numFields.)} &rev_rate.1-&rev_rate.&numFields.;
       array rvunta{1:%eval(&numFields.)} &rev_unit.1-&rev_unit.&numFields.;
       array pricnga{1:%eval(&numFields.)} &pricng.1-&pricng.&numFields.;
       array packa{1:%eval(&numFields.)} &packaging.1-&packaging.&numFields.;
       array pmtthda{1:%eval(&numFields.)} &pmtmthd.1-&pmtmthd.&numFields.;
       %end;

    **********************************************************************;
    ***START LOOPING THROUGH REV CENTER VARIABLES- OUTPUT TO LONG FORMAT;
    **********************************************************************;
    %if &year. >= 1984 and &year. < 1986 %then %do;
        orevccco=8;
        do i=1 to 8;
            ** Only loop through if reventer is nonmissing;
            if revcntra{i} ne "" then do;
                &rev_cntr. = revcntra{i};
                &rev_chrg. =rvpchga{i};
             *REvenue codes are only 3-digits between 1984 and 1988, there fore we add a zero;
             **to the start of the code to harmonize the variabes over time;
                if &rev_cntr. ne "" then &rev_cntr.="0" || &rev_cntr.;
                cntrindex = i;
                    output ;
                end;
           * do not continue iterating once a missing revenue code is encountered;
           else do;
               orevccco = i-1;
               leave;
               end;
           end;
       %end;
   %else %if &year. >= 1986 and &year. < 1996 %then %do;
        * loop over the revenue center fields;
       do i=1 to orevccco;
            * A few records during these years report more revenue centers than are allowed;
            * The files for these years do not allow records to overflow to the next record.;
            * I simply stop processing when I hit the field maximum;
           if i > &numFields. then do;
               put "PROGRAM WARNING: Record reports " orevccco "revenue centers
                    but the maximium is &numfields.  EHIC: " ehic " Date: " ;
               leave;
               end;
           &hcpcs_cd. = hcpcsa{i};
           &mdfr_cd1. = mdfr1a{i};
           &mdfr_cd2. = mdfr2a{i};
           &rev_cntr. = revcntra{i};
           &rev_chrg. = rvpchga{i};
            *REvenue codes are only 3-digits between 1984 and 1988, there fore we add a zero;
            **to the start of the code to harmonize the variabes over time;
           %if &year. >= 1986 and &year. < 1989 %then %do;
               if &rev_cntr. ne "" then &rev_cntr.="0" || &rev_cntr.;
               %end;
           cntrindex = i;
               output ;
           end;

       %end;
   %else %if &year. >= 1996 and &year. < 1999 %then %do;
       linecnt = &numFields.;
       do i=1 to &numFields.;
           if revcntra{i} = "" then do;
               linecnt = i - 1;
               leave;
               end;
           end;
        * As noted in ExtractOp.sas, claims for 1999-2000 can be split across;
        * records.  This code sets the maximum iteration index given this;
        * fact;
       iterLimit=linecnt;
       do  i=1 to iterLimit;
           &hcpcs_cd. = hcpcsa{i};
           &mdfr_cd1. = mdfr1a{i};
           &mdfr_cd2. = mdfr2a{i};
           &rev_cntr. = revcntra{i};
           &rev_dt. = revdatea{i};
           &rev_chrg. =rvpchga{i};
           cntrindex = i;
               output ;
           end;
       %end;
   %else %if &year. >= 1999 and &year. < 2001 %then %do;
         * As noted in ExtractOp.sas, claims for 1999-2000 can be split across;
         * records.  This code sets the maximum iteration index given this;
         * fact if not on the final segment of the record, then iterate to the last field;
         * if on the final segment, then calculate the number of items on this record;
       if sgmt_num < sgmt_cnt or sgmt_cnt=. then do;
           iterLimit = &numFields.;
           end;
       else do;
           iterLimit=linecnt-&numFields.*(sgmt_num-1);
           end;

       do  i=1 to iterLimit;
           &hcpcs_cd. = hcpcsa{i};
           &mdfr_cd1. = mdfr1a{i};
           &mdfr_cd2. = mdfr2a{i};
           &mdfr_cd3. = mdfr3a{i};
           &mdfr_cd4. = mdfr4a{i};
           &mdfr_cd5. = mdfr5a{i};
           &rev_cntr. = revcntra{i};
           &rev_dt. = revdatea{i};
           &apchipps. = apca{i};
            * set revenue center index, recalling that claims for;
            * 1999-2000 may span multiple records;
           cntrindex = i + &numFields.*(sgmt_num - 1);
           * revenue center level payments;
           &revpmt. = revpmta{i};
           &revblood. = rvblda{i};
           &revdctbl. = rvdtbla{i};
           &wageadj. = wgdja{i};
           &rdcdcoin. = rdcdcna{i};
           &rev_msp1. = rvmsp1a{i};
           &rev_msp2. = rvmsp2a{i};
           &packaging. =packa{i};
           &rev_unit. =rvunta{i};
           &rev_rate. =rvrta{i};
           &rev_chrg. =rvpchga{i};
           &pricng. =put(trim(pricnga{i}),2.);
           &pmtmthd. =pmtthda{i};
               output ;
           end;
       %end;
   *******************************************************;
   ** CONVERT TO CHARACTER;
  *******************************************************;
   %if &year.>=2001 and &year<=2005  %then %do;
       clm_id=put(trim(clmindx_temp),19.);
       &pricng.=put(trim(pricing_temp),2.);
       %end;

    %mend;
