***********************************************************************;
** SEVERAL MACROS TO GENERATE RAW VARIABLE NAME FROM THE CROSS WALK;
***********************************************************************;
** Generates several different macros from the crosswalk files which make ;
** it easier to harmonize variable names over times. Also writes out labels.
***********************************************************************;
** Maurice Dalton daltonm@nber.org, 11/30/2012 ;
***********************************************************************;

%macro GenerateAnnualVariableListFromXw(yr=,filename=,filevarin="" ,pct=,pctsuffix="");
    %if &filevarin. ne "" %then %do;
        %let allfiles=0;
        %global createvarCH_&filevarin.;
        %global createvarNum_&filevarin.;
        %global renamevar_&filevarin.;
        %global len_ch_&filevarin.;
        %global len_num_&filevarin.;
        %global len_chnull_&filevarin.;
        %global len_numnull_&filevarin.;
        %global finalvarlist_&filevarin.;
        %global rawvarlist_&filevarin.;
        %end;
    %else %do;
        %let allfiles=1;
        %let filevarin=;
        %global createvarCH_;
        %global createvarNum_;
        %global renamevar_;
        %global len_ch_;
        %global len_num_;
        %global len_chnull_;
        %global len_numnull_;
        %global finalvarlist_;
        %global rawvarlist_;
        %end;

        %let createvarCH_&filevarin.= ;
        %let createvarNum_&filevarin.= ;
        %let renamevar_&filevarin.= ;
        %let len_ch_&filevarin.= ;
        %let len_num_&filevarin.= ;
        %let len_chnull_&filevarin.= ;
        %let len_numnull_&filevarin.= ;
        %let finalvarlist_&filevarin.= ;
        %let rawvarlist_&filevarin.= ;

    ** TAKE CARE OF YEARS WHERE NAMING CONVENTIONS CHANGE;
    %if (&yr. = 1998 or &yr. = 1999) and
        &pctsuffix.=i and
        &filename. = carrierxw  %then %do;
        %let yr=2000;
        %end;

   *****************************************************************************;
   ** GENERATE FINAL VAR LIST;
   ****************************************************************************;
   **Before 2001 varnames are stub names so we keep any variable with the stub;
   %if &filevarin.=rev and &filename.=opxw and &yr < 2001 %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev";
        quit;
        %end;
    %else %if &filevarin.=rev and &filename.=ipxw and &yr < 2002 %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev";
        quit;
        %end;
    %else %if &filevarin.=rev_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev_indx";
        quit;
        %end;
    %else %if &filevarin.=clm_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="clm_indx";
        quit;
        %end;
    %else %if &filevarin.=both_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="both_indx";
        quit;
        %end;

    %else %do;
        proc sql NOPRINT ;
            select y&yr. into :rawvarlist_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
                %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." or ( filevarin="both" and y&yr. ne "NULL")  %end;;
                quit;
     %end;

   *****************************************************************************;
   ** CREATE MISSING VARIABLES: PLACEHOLDERs;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx('=""',finalvar,';')   into :createvarCH_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE  y&yr. eq "NULL" and character eq "1"
            and generated ="0" and key ne "bene_id"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
            quit;

    proc sql NOPRINT ;
        select catx('=.',finalvar,';')   into :createvarNum_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. eq "NULL" and character eq "0"
            and generated ="0"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;



   *****************************************************************************;
   ** GENERATE LENGTH STATEMETN;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx(' $',y&yr.,lengthvar) into:len_ch_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
            AND y&yr. ne "NULL"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;

    proc sql NOPRINT ;
        select catx(' ',y&yr.,lengthvar) into:len_num_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
             AND y&yr. ne "NULL"
            %if &allfiles. = 0 %then %do;AND filevarin="&filevarin." %end;;
    quit;

    **FOR OUTPATIENT-;
    %if &filevarin.="rev" %then %do;
        proc sql NOPRINT ;
            select catx(' $',finalvar,lengthvar) into:len_ch_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
                AND y&yr. ne "NULL"
                %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
                quit;

        proc sql NOPRINT ;
            select catx(' ',finalvar,lengthvar) into:len_num_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
                AND y&yr. ne "NULL"
                %if &allfiles. = 0 %then %do;AND filevarin="&filevarin." %end;;
                quit;
                %end;
    proc sql NOPRINT ;
        select catx(' $',finalvar,lengthvar) into:len_chnull_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
            AND y&yr. = "NULL"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;

    proc sql NOPRINT ;
        select catx(' ',finalvar,lengthvar) into:len_numnull_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
            AND y&yr. = "NULL"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;
   *****************************************************************************;
   ** GENERATE RENAME STATEMENT;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx('=',y&yr.,finalvar) into:renamevar_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" AND generated="0"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;
   *****************************************************************************;
   ** GENERATE FINAL VARIABLE STATEMENT TO KEEP;
   ****************************************************************************;
    proc sql NOPRINT ;
        select finalvar into:finalvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE key ne "revnum"
            %if &allfiles. = 0 %then %do; AND  filevarin="&filevarin." or filevarin="both"  %end;;
    quit;
    %mend;



%macro GenerateAnnualVariableListFromXw(yr=,filename=,filevarin="" ,pct=,pctsuffix="");
    %if &filevarin. ne "" %then %do;
        %let allfiles=0;
        %global createvarCH_&filevarin.;
        %global createvarNum_&filevarin.;
        %global renamevar_&filevarin.;
        %global len_ch_&filevarin.;
        %global len_num_&filevarin.;
        %global len_chnull_&filevarin.;
        %global len_numnull_&filevarin.;
        %global finalvarlist_&filevarin.;
        %global rawvarlist_&filevarin.;
        %end;
    %else %do;
        %let allfiles=1;
        %let filevarin=;
        %global createvarCH_;
        %global createvarNum_;
        %global renamevar_;
        %global len_ch_;
        %global len_num_;
        %global len_chnull_;
        %global len_numnull_;
        %global finalvarlist_;
        %global rawvarlist_;
        %end;

        %let createvarCH_&filevarin.= ;
        %let createvarNum_&filevarin.= ;
        %let renamevar_&filevarin.= ;
        %let len_ch_&filevarin.= ;
        %let len_num_&filevarin.= ;
        %let len_chnull_&filevarin.= ;
        %let len_numnull_&filevarin.= ;
        %let finalvarlist_&filevarin.= ;
        %let rawvarlist_&filevarin.= ;

    ** TAKE CARE OF YEARS WHERE NAMING CONVENTIONS CHANGE;
    %if (&yr. = 1998 or &yr. = 1999) and
        &pctsuffix.=i and
        &filename. = carrierxw  %then %do;
        %let yr=2000;
        %end;

   *****************************************************************************;
   ** GENERATE FINAL VAR LIST;
   ****************************************************************************;
   **Before 2001 varnames are stub names so we keep any variable with the stub;
   %if &filevarin.=rev and &filename.=opxw and &yr < 2001 %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev";
        quit;
        %end;
    %else %if &filevarin.=rev and &filename.=ipxw and &yr < 2002 %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev";
        quit;
        %end;
    %else %if &filevarin.=rev_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="rev_indx";
        quit;
        %end;
    %else %if &filevarin.=clm_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="clm_indx";
        quit;
        %end;
    %else %if &filevarin.=both_indx %then %do;
          proc sql NOPRINT ;
        select catx('',y&yr.,':')  into :rawvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
            AND filevarin="both_indx";
        quit;
        %end;

    %else %do;
        proc sql NOPRINT ;
            select y&yr. into :rawvarlist_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE y&yr. ne "NULL" and key ne "revnum"
                %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." or ( filevarin="both" and y&yr. ne "NULL")  %end;;
                quit;
     %end;

   *****************************************************************************;
   ** CREATE MISSING VARIABLES: PLACEHOLDERs;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx('=""',finalvar,';')   into :createvarCH_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE  y&yr. eq "NULL" and character eq "1"
            and generated ="0" and key ne "bene_id"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
            quit;

    proc sql NOPRINT ;
        select catx('=.',finalvar,';')   into :createvarNum_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. eq "NULL" and character eq "0"
            and generated ="0"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;



   *****************************************************************************;
   ** GENERATE LENGTH STATEMETN;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx(' $',y&yr.,lengthvar) into:len_ch_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
            AND y&yr. ne "NULL"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;

    proc sql NOPRINT ;
        select catx(' ',y&yr.,lengthvar) into:len_num_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
             AND y&yr. ne "NULL"
            %if &allfiles. = 0 %then %do;AND filevarin="&filevarin." %end;;
    quit;

    **FOR OUTPATIENT-;
    %if &filevarin.="rev" %then %do;
        proc sql NOPRINT ;
            select catx(' $',finalvar,lengthvar) into:len_ch_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
                AND y&yr. ne "NULL"
                %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
                quit;

        proc sql NOPRINT ;
            select catx(' ',finalvar,lengthvar) into:len_num_&filevarin. separated by ' '
                FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
                AND y&yr. ne "NULL"
                %if &allfiles. = 0 %then %do;AND filevarin="&filevarin." %end;;
                quit;
                %end;
    proc sql NOPRINT ;
        select catx(' $',finalvar,lengthvar) into:len_chnull_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
            AND y&yr. = "NULL"
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;

    proc sql NOPRINT ;
        select catx(' ',finalvar,lengthvar) into:len_numnull_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
            AND y&yr. = "NULL"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;
   *****************************************************************************;
   ** GENERATE RENAME STATEMENT;
   ****************************************************************************;
    proc sql NOPRINT ;
        select catx('=',y&yr.,finalvar) into:renamevar_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" AND generated="0"
            %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;
   *****************************************************************************;
   ** GENERATE FINAL VARIABLE STATEMENT TO KEEP;
   ****************************************************************************;
    proc sql NOPRINT ;
        select finalvar into:finalvarlist_&filevarin. separated by ' '
            FROM xwfile.&filename. WHERE key ne "revnum"
            %if &allfiles. = 0 %then %do; AND  filevarin="&filevarin." or filevarin="both"  %end;;
    quit;
    %mend;




%macro rawVarXw(harVar=,yr=,outputvar=,filename=,pct=,pctsuffix=);
   *****************************************************************************;
   ** TAKE CARE OF INSTANCE WHERE A YEAR FOR A PERCENT ARE DIFFERENT;
   ****************************************************************************;
    %if (&yr. = 1998 or &yr. = 1999) and
        (&pctsuffix.=i) and
        &filename. = carrierxw  %then %do;
        %let yr=2000;
        %end;
   *****************************************************************************;
   ** GENERATE MACRO WHICH HOLD RAW VAR;
   ****************************************************************************;
    %global &outputvar.;
    proc sql NOPRINT ;
        select y&yr. into :&outputvar. separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" AND key="&harVar." ;
    quit;

    %global &outputvar._final;
    proc sql NOPRINT ;
        select finalvar into :&outputvar._final separated by ' '
            FROM xwfile.&filename. WHERE y&yr. ne "NULL" AND key="&harVar." ;
    quit;
    %mend;


%macro rawVarXwLength(harVar=,yr=,outputvar=,filename=,pct=,pctsuffix=);
   *****************************************************************************;
   ** TAKE CARE OF INSTANCE WHERE A YEAR FOR A PERCENT ARE DIFFERENT;
   ****************************************************************************;
    %if (&yr. = 1998 or &yr. = 1999) and
        (&pctsuffix.=i) and
        &filename. = carrierxw  %then %do;
        %let yr=2000;
        %end;
   *****************************************************************************;
   ** GENERATE MACRO WHICH HOLD RAW VAR;
   ****************************************************************************;
    %global &outputvar.;

    proc sql NOPRINT ;
        select catx(' $',y&yr.,lengthvar) into:&outputvar. separated by ' '
            FROM xwfile.&filename. WHERE character eq "1"  AND generated ="0"
            AND y&yr. ne "NULL" AND key="&harVar."
        %if &allfiles. = 0 %then %do; AND filevarin="&filevarin." %end;;
    quit;

    proc sql NOPRINT ;
        select catx(' ',y&yr.,lengthvar) into:&outputvar. separated by ' '
            FROM xwfile.&filename. WHERE character eq "0" AND generated ="0"
             AND y&yr. ne "NULL" AND key="&harVar."
            %if &allfiles. = 0 %then %do;AND filevarin="&filevarin." %end;;
    quit;
%mend;


   *****************************************************************************;
   ** GENERATE LABELS;
   ****************************************************************************;
%macro LabelVarsXw(outLabels=,filename=,filevarin="");
    %global &outLabels.;
    proc sql NOPRINT ;
        select catx(' ',finalvar,'=','"',labelvar,'"') into:&outLabels. separated by ' '
            FROM xwfile.&filename.  WHERE key ne "revnum"
             %if &filevarin. ne "" %then %do; and  filevarin="&filevarin." %end;;   ;
    quit;


    %mend;

%macro genLineItemVarsToLoop(yr=,pct=,pctsuffix=,filename=);
    *** THIS MACRO TAKES ALL OF THE REV CENTER FILES AND;
    *** GENERATES A MACRO NAME EQUAL TO THE FINAL VAR NAME WITH THE ;
    *** RAW VARNAME UNDERNEATH;
    proc sql NOPRINT ;
        select finalvar into: lineitemvars separated by ' '
            FROM xwfile.&filename. WHERE filevarin="rev" AND y&yr. ne "NULL" ;
    quit;

    proc sql NOPRINT ;
        select count(*) into:count
            FROM xwfile.&filename. WHERE filevarin="rev" AND y&yr. ne "NULL" ;
    quit;

    %do i=1 %to &count.;
        %global %scan(&lineitemvars.,&i.);
        %let %scan(&lineitemvars.,&i.)= ;
        %rawVarXw(harVar=%scan(&lineitemvars.,&i.),yr=&yr,outputvar=%scan(&lineitemvars.,&i.),filename=&filename.,pct=&pct.,pctsuffix=&pctsuffix.);
        %end;

    %mend;

