***********************************************************************;
** FILE INLCUDES SEVERAL USEFUL MACROS;
***********************************************************************;
**  Perhaps the most useful macros are the decompression macros, which are;
**  based on code from Jean Roth.;
***********************************************************************;

%macro decompress_i(spaceDir=,dataRoot=,ftype=,pct=,year=,subtype=,pctsuffix=,indx=);
  * This macro navigates the Medicare claims data directory structure and decompresses;
    * the appropriate file to the requested location.  Adapted from code provided by Jean Roth.;
    * ;
    * spaceDir - the directory to which the file should be decompressed;
    * dataRoot - the root directory of the NBER claims data hierarchy;
    * ftype - the type of claims file (medpar, denom, car, op, ip, etc);
    * pct - the percentage extract to retrieve;
    * year - the year of the file to retrieve;
    ***********************************************************************************;
    * ***TURNED OF THIS FEATURE--DetermineMax MAcro Counts it now***********************;
            ***** min - For some years, claims data are split across multiple numbered files.;
            *****       This is the number of the first file;
            ***** max - this is the number of the last file;
    **************************************************************************;
    * subtype - used when there are two types of files for a given year;
    *           (e.g. claims and revenue center files);
    * pctsuffix - rarely-used option for when the file format includes some string after the extract percentage;

    *FOR COUTNING;
    *Note that 20% carrier files are made up of 4 %5 draws in year 98 - 05;
    %if &year>=2010 %then %do;
        %let newsubtype=&subtype.;
        %if &subtype.=lnits %then %let newsubtype=l;
        %if &subtype.=clms %then %let newsubtype=c;
        %if &subtype.=revcntrs %then %let newsubtype=r;

        %let unzippedcompFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&newsubtype.&year..sas7bdat;
        %let compFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&newsubtype.&year..sas7bdat.bz2;
        %let zipFile=&spaceDir./&ftype.&newsubtype.&year..sas7bdat.bz2;
        %let decompFile=&spaceDir./&ftype.&pct.&pctsuffix._&year._&subtype.1.sas7bdat;
        %end;
    %else %if &year=2009 %then %do;
        %let newsubtype=&subtype.;
        %if &subtype.=lnits %then %let newsubtype=l;
        %if &subtype.=clms %then %let newsubtype=c;
        %if &subtype.=revcntrs %then %let newsubtype=r;

        %let unzippedcompFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&newsubtype._&year._&indx..sas7bdat;
        %let compFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&newsubtype._&year._&indx..sas7bdat.bz2;
        %let zipFile=&spaceDir./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat.bz2;
        %let decompFile=&spaceDir./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat;
        %end;
    %else %if &year< 2009 %then %do;
        %let unzippedcompFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat;
        %let compFile=&dataRoot./&pct.pct/&ftype./&year./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat.bz2;
        %let zipFile=&spaceDir./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat.bz2;
        %let decompFile=&spaceDir./&ftype.&pct.&pctsuffix._&year._&subtype.&indx..sas7bdat;
        %end;

     ** if file exists uncompressed use the uncompressed version;
    x "rm &decompFile. -f";
     %if %sysfunc(fileexist("&unzippedcompFile.")) %then %do;
        x "cp &unzippedcompFile.  &decompFile.";
        %put "cp &unzippedcompFile.  &decompFile.";
        %end;
    %else %do;
        %let tBefore=%sysfunc(datetime());
        x "rm &zipFile. -f";
        x "cp &compFile.  &zipFile.";
        x "bzcat &zipFile. > &decompFile.";
        x "rm &zipFile. -f";
        %let tAfter=%sysfunc(datetime());
        %let elapsed=%sysevalf(%sysevalf(%sysevalf(&tAfter.-&tBefore.)/60));
        %put Decompressing file &ftype.&pct.&pctsuffix._&year._&subtype.&indx. took &elapsed. minutes.;
        %end;
    %mend;


%macro RepeatN(pfx,Nlow,Nhigh);
    %* Generate a numbered list of symbols starting with the value of pfx;
    %* Ex: if pfx=Hello, Nlow=1, and Nhigh=3, then the macro generates;
    %* Hello1 Hello2 Hello3;

    %do i=&Nlow. %to &Nhigh.;
        &pfx.&i.
            %end;

    %mend;

%macro GenYM(pfx,Ylow,Yhigh);
    %* Generate a list of variables for each month of the year starting in year;
    %* Ylow and ending in year Yhigh in format <pfx>YYYYmM;

    %do y=&Ylow. %to &Yhigh.;
        %do m=1 %to 12;
            &pfx.&y.m&m.
                %end;
            %end;

    %mend;



