##--------------------------------------------------------------------------------| 
## DEFINES BASH FUNCTION USED TO CALL SAS PROGRAMS BELOW			  | 
##--------------------------------------------------------------------------------| 
## USAGE runcode relative/directory/to/file basefilename.sas			  | 
##										  | 
## NOTE THAT basefilename should include the .sas ending			  | 
##										  | 
## THE PROGRAM WILL RUN THE SAS/STATA CODE IN THE SEQUENCE YOU DEFINE. AS WELL AS | 
## THROWING AN ERROR AND SENDING YOU AN EMAIL IN THE CASE THAT THE FILES	  | 
## CRASH									  | 
##--------------------------------------------------------------------------------| 
runcode() {
##set up log file
    LOGLOCATION=`pwd`/runAllprgms.log
    BASELOCATION=`pwd`
    mkdir -p runAllprgms
    ##for running sas, set memory to max

    BLANK=""
    ##label inputs so easier to understand programs
    PRGM2RUN=$2
    DIRECTORY=$1
echo "$BASELOCATION $DIRECTORY $PRGM2RUN"
    if [ -z $DIRECTORY ]
# Checks if any params.
    then
        echo "No folder location given. Make sure it is relative to where the runAllprgms.sh file is found. Example call, runcode 1PrimaryExtractionPrmgs medparCanditates.sas . "
        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
        exit 0
    else

        if [ -z $PRGM2RUN ]
# Checks if any params.
        then
            echo "ERROR: NO BASE PROGRAM SPECIFIED AFTER DIRECTORY." >> $LOGLOCATION
            echo "ERROR: MAKE SURE TO INCLUDE THE .sas/.do ENDING " >> $LOGLOCATION
            echo "Example function call:: runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents medparCandidates  " >> $LOGLOCATION
            mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
            exit 0
        else
            if [ -e $DIRECTORY/$PRGM2RUN ] 
            then
                ## CHANGE TO LOCATION OF THE PROGRAM
                cd $DIRECTORY
                if [[ "$PRGM2RUN" == *.sas ]]
                then
		    MEMPARM="-MEMSIZE 10G -SORTSIZE 10G -REALMEMSIZE 9G"
                    BASEFILE=`echo "$PRGM2RUN" | sed -e s/\\.sas//p | sort | uniq`
                    BASEFILELOG=$BASEFILE".log"
                    CALLSOFTWARE=sas
                    #echo "DEFINED FILE  $BASEFILE $BASEFILELOG";
                    if [ -n "$3" ]
                    then

                    #SYSPARM="-sysparm cohrt=$3,pct=$4,yearin=$5,yearout=$6,NOTE=$7,clmDTA=$8,winyear=$9,ip_dxn=${10},op_dxn=${11},med_dxn=${12},car_dxn=${13},ip_proc=${14},med_proc=${15},op_proc=${16},ip=${17},med=${18},car=${19},op=${20},subsquentDgnDayRest=${21},FFSmonthpost=${22},FFSmonthpre=${23},HMOmonthpost=${24},HMOmonthpre=${25}"
                    SYSPARM="-sysparm ${3} ${4} ${5} ${6} ${7} ${8} ${9} ${10} ${11}"
                    #echo "DEFINED SYSPARM $SYSPARM";
                    fi
                    if [ -z "$3" ]
                    then
			SYSPARM=""
			echo "NO SYSPARM " 
                    fi
                fi

                if [[ "$PRGM2RUN" == *.do ]]
                then
                    BASEFILE=`echo "$PRGM2RUN" | sed -e s/\\.do//p | sort | uniq`
                    BASEFILELOG=$BASEFILE".log"
                    CALLSOFTWARE="statamp -b do"
                    echo "cohrt=$3,pct=$4,yearin=$5,yearout=$6"  >> $LOGLOCATION
                    SYSPARM="$3 $4 $5 $6"

                fi


                echo "##################################################################" >> $LOGLOCATION
                echo "RUNNING $DIRECTORY/$PRGM2RUN ::macro call::for user verification" >> $LOGLOCATION
                echo "MACRO CALLED WITH THE FOLLOWING PARAMETERS::  $SYSPARM"  >> $LOGLOCATION
                echo "RUNNING THE FOLLOWING :: $CALLSOFTWARE $PRGM2RUN  $SYSPARM $MEMPARM " >> $LOGLOCATION
                echo "###############################################################################" >> $LOGLOCATION
                echo `date` >> $LOGLOCATION
                echo "$CALLSOFTWARE $PRGM2RUN" >> $LOGLOCATION
                echo "-------- REPORT PROGRAM LEVEL STATS AFTER PROGRAM FINSISHED OR CRASHES -----------" >> $LOGLOCATION
		#echo "debug - run prgm"
                /usr/bin/time -a --output=$LOGLOCATION -f " %c Context Switches \n %Z System Page Size (bytes)  \n %e Elapsed Real Time (secs) \n %S CPU-seconds \n %M Max Resident Set Size (Kb)" $CALLSOFTWARE $PRGM2RUN $SYSPARM $MEMPARM 
		#echo "/usr/bin/time -a --output=$LOGLOCATION -f ' %c Context Switches \n %Z System Page Size (bytes)  \n %e Elapsed Real Time (secs) \n %S CPU-seconds \n %M Max Resident Set Size (Kb)' $CALLSOFTWARE $PRGM2RUN $SYSPARM $MEMPARM "
                echo "-----------------------------------------------" >> $LOGLOCATION
		#echo "debug - erro check"
                if [[ `grep '^ERROR' "$BASEFILELOG" -c` -gt  0 ]]; then  
                echo "#####  GREP FOR ERRORS SHOW UP BELOW  #########################################" >> $LOGLOCATION
                echo "NUMBER OF ERRORS FOUND `grep '^ERROR' $BASEFILELOG -c`" >> $LOGLOCATION               
                grep '^ERROR' $BASEFILELOG >> $LOGLOCATION
                    if [ $EMAILON -eq 1 ]; then  
                        echo "CRASH SENDING EMAIL"; 
                        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
                    fi
                    
		    exit 0

                fi          
                if [[ `grep 'r([0-9]*);' "$BASEFILELOG" -c` -gt  0 ]]; then  
                echo "#####  GREP FOR ERRORS SHOW UP BELOW  #########################################" >> $LOGLOCATION
                    grep 'r([0-9]*);' $BASEFILELOG >> $LOGLOCATION
                    if [ $EMAILON -eq 1 ]; then  
                        echo "CRASH SENDING EMAIL"; 
                        mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
                    fi
                    exit 0
                fi          
            else
                ## WRITE ERROR MESSAGE IF CANT FIND FILE;d
                echo "ERROR: CANNOT FIND THIS FILE::(see next line)"
                echo "ERROR: CANNOT FIND THIS FILE::(see next line)" >> $LOGLOCATION
                echo "ERROR: $DIRECTORY/$PRGM2RUN NOT FOUNT" >> $LOGLOCATION
                echo "ERROR: MAKE SURE YOU SET DIRECTORY RELATIVE TO THE PROGRAM ROOT " >> $LOGLOCATION
                echo "Example function call:: runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents medparCandidates.sas  " >> $LOGLOCATION
                if [ $EMAILON -eq 1 ]; then  
                mail -s "MEDICARE CODE:CRASH" `whoami`@nber.org < $LOGLOCATION
		fi
                exit 0  
                
            fi
        fi
        echo "   "
        echo "   "
        echo "   "
        cd $BASELOCATION
	cp $LOGLOCATION $BASELOCATION/runAllprgms/runAllprgms_`date +"%m%d%Y"`_${NOTE}.log -f
    fi
}
###############################################################################
## END BASH FUNCTION DEFINITION 
###############################################################################
############END########################################################
### IGNORE - for future development
#######################################################################
#FOR FURTHER DEVELOPMENT OF SCRIPT::SAS error code - not working
#Condition Exit Status Code
#All steps terminated normally 0
#SAS System issued warnings 1
#SAS System issued errors 2
#User issued ABORT statement 3
#User issued ABORT RETURN statement 4
#User issued ABORT ABEND statement 5
#SAS could not initialize because of a severe error 6
#User issued ABORT RETURN n statement n
#User issued ABORT ABEND n statement n
# not working -- if [$? != 0 ];then - put comments here to maybe work on later
##
