###################################################################################
## runAllprgms.sh - is bash scripts which runs the sas programs in the correct order 
##                  calling SAS or stata. In addition it also will send you an email if the prgms crash
##                  and it provides several other automations. IN particular it allows for defining of parameters in one file which are then passed to SAS or Stata files
###################################################################################

###################################################################################
## USER INSTRUCTIONS (TODOS)
##
## TODO1. Users need to make sure that they have properly defined the directories 
##    at the top of the dirInit.sas and dirInit.do programs
##
## TODO2. SET EMAILON to 1 or 0 depending on whether you want to receive an email on crash
## 
## TODO3. Next users need to ensure that parameters are defined correctly for cohrt they are looking 
##    define. The section has several variables, some of which for the different restrictions the 
##    programs place on the cohorts. Everything should be explained in this section. The bash prgm
##    passes all of these parameters to the sas prgms.
##    NOTE: users need to define the ICD9 OR HCPCS codes they are using in the 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents UNDER
##           HCPCScohrtDef.sas or/and ICD9cohrtDef.sas files. The cohorts defined their should match the COHRT NAME as well.
##
## TODO4. Finally the user needs to make sure this programs is running all of the programs of interest. 
##    or comment out and/or add other programs for this master program to run
##
## TODO5. To run this bash scrip from the terminal, type in "bash runAllprgms.sh"
##
## TODO6. MAKE SURE YOU ONLY RUN PROGRAMS WHICH YOUR DUA COVERS!
###################################################################################

## IMPORT FUNCTION -'runcode'  WHICH IS USED TO RUN SAS/STATA PRGRMS AND AUTOMATE LOGS AND ERROR CHECKING
source SASmacros/runcode.sh

##------------------------------------------------------------------------------
## TODO2: DO YOU WANT THE PROGRAM TO EMAIL YOU ON CRASH - SET TO 1 FOR YES
##----------------------------------------------------b-------------------------
## EMAIL WILL BE SENT TO YOUR NBER EMAIL
EMAILON=1
rm runAllprgms.log -f
touch runAllprgms.log
echo "RUNNING PROGRAM ON THIS SERVER:: `uname -n`" >runAllprgms.log

##------------------------------------------------------------------------------
## TODO3: DEFINE VARIABLES TO BE PASSED ONTO SAS MACRO WITHIN EACH PROGRAMS
##------------------------------------------------------------------------------

##I have defined loops here - you should just need to put your percent and cohort names in their,
for p in  20    ; do
    for cohrt  in  ami   ; do
       ## PARAMETERS USED BY ALL FILES
             ## COHORT LABEL USED TO SAVE DATASETS - YOU CREATE THIS. 
             ##   SHOULD MATCH THAT FOUND IN 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents UNDER
             ##   THE FOLLOWING FILES HCPCScohrtDef.sas or/and ICD9cohrtDef.sas 
        COHRT=$cohrt
             ##THE FIRST YEAR OF DATA YOU WANT TO PROCESS :: CAR/OP/MEDPAR/IP MAY ALL HAVE DIFFERNT START DATES
             ## DIFFERENT PERCENTS ALSO HAVE DIFFERENT START DATES
	if [[ "$p" -eq "05" ]]
	then
            MEDYEARIN=1992
            CARYEARIN=1992
            OPYEARIN=1992
            IPYEARIN=1997
	fi;

	if [[ "$p" -eq "20" ]]
	then
            MEDYEARIN=2006
            CARYEARIN=2006
            OPYEARIN=2006
            IPYEARIN=2006
	fi;

	if [[ "$p" -eq "100" ]]
	then
            MEDYEARIN=1992
            OPYEARIN=1996
            IPYEARIN=1997
	fi;


             ##THE LAST YEAR OF DATA YOU WANT TO PROCESS 
        YEAROUT=2010
             ##NOTE TO BE PLACED IN THE LOG FILE ARCHIVES
        NOTE=benchmark
             ##SIZE OF FILES YOU ARE RUNNING
        PCT=$p
             ##WINDOW OF CLAIMS TO PULL BEFORE AND AFTER INDEX EVENT DATE- IN YEARS
        WINYR=1
             ##STAT-TRANSFER THE FILES FROM SAS TO STATA (1=YES)
        CONVERT2STATA=1
        
       ## 1B PRGM PARAMETERS -- RESTRICTIONS
             ##~~~~ VARIABLES DENOTING WHICH CLAIMS FILES USED TO DEFINE AN INDEX EVENTS
             ##     A ZERO HERE TURNS OF THE DXN AND PROC BELOW
             ##     YOU ALSO NEED TO MAKE SURE TO RUN THE CORRECT 1A PRGMS BELOWS. FOR EXAMPLE
             ##     IF I PLANNED TO USE CARRIER FILE THEN THE runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents carrierCandidates.sas
             ##     PRGM SHOULD BE UNCOMMENTED AND THE 'CAR' VARIABLE BELOW SHOULD BE SET TO 1
        IP=0   
        MED=1   
        CAR=0   
        OP=0    
        
             ## ~~~ For each claim used denote the number of procedure or diagnostic codes used 
             ##     (for ip_prcPos=2 use the first 2 procedure codes from IP file)
        
             ## ~~~ DIAGNOSTIC VARIABLES USED (i.e a 2 would loop through the 1st and 2nd dgn vars - 
             ##     set to 1 if you only want the principal diagnosis)
        IP_DXN=0 
	if [[ "$cohrt" == "hipkne" ]]
	then
            MED_DXN=0 
            MED_PROC=6
	else 
            MED_DXN=1 
            MED_PROC=0
	fi;

        CAR_DXN=0              
        OP_DXN=0 
             ## ~~~ PROCEDURE CODES USED (i.e. 2 would loop trhough the 1st and 2nd proc vars - 0 ignores them)
        IP_PROC=0 
 
        OP_PROC=0 
        
             ## ~~~ NUMBER OF DAYS WHICH MUST PASS BETWEEN A REPEAT INDEX EVENT, FOR A SINGLE BENEFICIARY
             ##     BEFORE THE CLAIM CAN BE CONSIDERED A NEW INDEX EVENT
        DAYS_BETWEEN_NEWINDEX_EVENT=365                            
        
             ## ~~~ ENROLMENT RESTRICTIONS - NUMBER OF MONTHS ENROLLED IN BOTH PART A AND B FEE-FOR-SERVICE 
             ##     (POST INDEX EVENT / PRE INDEX EVENT)
        FFSmonthpost=12
        FFSmonthpre=12
             ## ~~~ HMO ENROLMENT RESTRICTIONS -- NUMBER OF MONTHS NOT ENROLLED IN HMO
        HMOmonthpost=12
        HMOmonthpre=12
##------------------------------------------------------------------------------
## <END> DEFINE VARIABLES TO BE PASSED ONTO SAS MACRO WITHIN EACH PROGRAMS
##------------------------------------------------------------------------------

##------------------------------------------------------------------------------
## CHECK TO MAKE SURE COHORT HAS BEEN DEFINED CORRECTLY -- AUTOMATED
##------------------------------------------------------------------------------
        if [[ `grep "$COHRT" '1PrimaryExtractionPrmgs/1A_FlagCandidateEvents/ICD9cohrtDef.sas' -c` -eq  0 ]] &&  [[ `grep '$COHRT' '1PrimaryExtractionPrmgs/1A_FlagCandidateEvents/HCPCScohrtDef.sas' -c` -eq  0 ]] ; then  
            echo "#####  COHRT NOT DEFINED CORRECTLY !! ---  #########################################"  >> runAllprgms.log
            echo "COMPARE THE COHRT VARIABLE IN runAllprgms.sh AND THE COHRT DEFINITIONS FOUND IN 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents/*Def.sas" >> runAllprgms.log
            if [ $EMAILON -eq 1 ]; then  
                echo "CRASH SENDING EMAIL"; 
                mail -s "MEDICARE CODE CRASH: COHRTS NOT DEFINED CORRECTLY" `whoami`@nber.org 
            fi                    
	    echo "COHRT NOT DEFINED CORRECTLY"
	    exit 0
        fi          
##------------------------------------------------------------------------------



##------------------------------------------------------------------------------
## TODO4: REVIEW FOLLOWING LIST OF PROGRAMS TO BE RUN -- COMMENT OUT PRGMS WHICH
##        DO NOT COVER DUA OR WHICH YOU HAVE NO INTEREST IN RUNNING.
##------------------------------------------------------------------------------
###################################################################################
## STEP 1:: 1PrimaryExtractionPrmgs : Extract and select candidates index events
###################################################################################
##NOTE: ONLY RUN THE FILES WHICH YOU USE TO DEFINE THE INDEX EVENTS. DO NOT SWITCH ORDER OF VARIABLES 
##------------------------------------------------------------------------------

#runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents ipCandidates.sas cohrt=$COHRT,pct=$PCT,yearin=$IPYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR,ip_dxn=$IP_DXN,ip_proc=$IP_PROC,ip=$IP
runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents medparCandidates.sas cohrt=$COHRT,pct=$PCT,yearin=$MEDYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR,med_dxn=$MED_DXN,med_proc=$MED_PROC,med=$MED
#runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents opCandidates.sas	 cohrt=$COHRT,pct=$PCT,yearin=$OPYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR,op_dxn=$OP_DXN,op_proc=$OP_PROC,op=$OP
#runcode 1PrimaryExtractionPrmgs/1A_FlagCandidateEvents carrierCandidates.sas cohrt=$COHRT,pct=$PCT,yearin=$CARYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR,car_dxn=$CAR_DXN,car=$CAR

###################################################################################
## STEP 1B:: BRING IN DENOMINATOR FILE AND ENFORCE ENROLLMENT RESTRICTIONS
###################################################################################
## THIS step generated the final list of index events used in the 1C scripts
## to extract a 1-year window of claims around the index event.
	runcode 1PrimaryExtractionPrmgs 1B_ImposeDenominatorRestrictions.sas cohrt=$COHRT,pct=$PCT,yearin=$MEDYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR,ip_dxn=$IP_DXN,ip_proc=$IP_PROC,ip=$IP,med_dxn=$MED_DXN,med_proc=$MED_PROC,med=$MED,op_dxn=$OP_DXN,op_proc=$OP_PROC,op=$OP,car_dxn=$CAR_DXN,car=$CAR,subsquentDgnDayRest=$DAYS_BETWEEN_NEWINDEX_EVENT,FFSmonthpost=$FFSmonthpost,FFSmonthpre=$FFSmonthpre,HMOmonthpost=$HMOmonthpost,HMOmonthpre=$HMOmonthpre



###################################################################################
## STEP 1C:: EXTRACT CLAIMS ##--ONLY RUN WHAT YOUR DUA COVERS
###################################################################################
	runcode 1PrimaryExtractionPrmgs/1C_PullClaims MedparExtract.sas cohrt=$COHRT,pct=$PCT,yearin=$MEDYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR


 	if [[ "$p" -ne "100" ]]
 	then

 	    runcode 1PrimaryExtractionPrmgs/1C_PullClaims CarrierExtract.sas cohrt=$COHRT,pct=$PCT,yearin=$CARYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR                
            echo "test"
 	fi
	
 
	runcode 1PrimaryExtractionPrmgs/1C_PullClaims IpExtract.sas  cohrt=$COHRT,pct=$PCT,yearin=$IPYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR
	runcode 1PrimaryExtractionPrmgs/1C_PullClaims OpExtract.sas cohrt=$COHRT,pct=$PCT,yearin=$OPYEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA,winyear=$WINYR

###################################################################################
## STEP 2:: 2SecondaryManipPrgms : GENERATE INDEX LEVEL STATISTICS
###################################################################################
####---------------------------------------------------------------------------------
#### COMPILE TOTAL REIMBURSEMENTS AT THE INDEX LEVEL
# define X day cost you want to generate after index event, ie 30 creates cost occuring 30 days after index
	DAY1=30
	DAY2=90
	DAY3=365
#dunmber of cost stats
	DNUM=3
##FIRST YEAR TO USE TO CREATE STATS
	YEARIN=$MEDYEARIN
       runcode 2SecondaryManipPrgms/completecostmetric CumulativeCostsPerIndx.sas cohrt=$COHRT,pct=$PCT,yearin=$YEARIN,yearout=$YEAROUT,NOTE=$NOTE,day1=$DAY1,day2=$DAY2,day3=$DAY3,day4=$DAY4,day5=$DAY5,day6=$DAY6,day7=$DAY7,dNum=$DNUM
####---------------------------------------------------------------------------------

####---------------------------------------------------------------------------------
## GENERATE HCC COMORBIDITY DUMMYS USING MEDPAR CLAIMS - LOOK BACK - AT THE INDX
##	runcode 2SecondaryManipPrgms/comorbid ExtComorbidCC.sas cohrt=$COHRT,pct=$PCT,NOTE=$NOTE
####---------------------------------------------------------------------------------

 	if [[ "$p" -ne "100" ]]
	then
####---------------------------------------------------------------------------------
#### GENERATE COST UTILIZATION MEASURES 
#####################################################################################
##    NOTE OP CU MEASURE START IN 2001 - HARD CODED TO START  IN 2001
	    runcode 2SecondaryManipPrgms/costutilization 2A_CallAllCostUtilizationPrgms.sas cohrt=$COHRT,pct=$PCT,yearin=$YEARIN,yearout=$YEAROUT,NOTE=$NOTE,clmDTA=$CONVERT2STATA

#### SUM THOSE COSTS TO THE INDEX LEVEL
            #define day costs intrested in created
	    DAY1=30
	    DAY2=90
	    DAY3=365
            #dunmber of cost stats
	    DNUM=3
            #limit to contiguous 48 states - suggested to keep this 1=yes 
	    CONT48=1
##FIRST YEAR TO USE TO CREATE STATS
	    YEARIN=$MEDYEARIN
	    runcode 2SecondaryManipPrgms/costutilization 2B_GenerateIndxLevelsCostUtilStats.sas cohrt=$COHRT,pct=$PCT,yearin=$MEDYEARIN,yearout=$YEAROUT,NOTE=$NOTE,day1=$DAY1,day2=$DAY2,day3=$DAY3,day4=$DAY4,day5=$DAY5,day6=$DAY6,day7=$DAY7,dNum=$DNUM,contigious48=$CONT48
####---------------------------------------------------------------------------------
	fi          

    done;
done;

mail -s "FINISHED RUN" `whoami`@nber.org 

####---------------------------------------------------------------------------------
## GENEARTE PROCEDURE DUMMY FOR AMI WHICH CROSS CHECK THE PROCEDURE PHYSICAIN 
## PROCEDURES WITH THE INSTITUTIONAL CLAIMS
## NEED TO DEFINE THE PROCEDURE CODE OF INTEREST - CURRENTLY ONLY SET UP FOR AMIs
runcode 2SecondaryManipPrgms/procedures Step1_tagProcs.sas cohrt=$COHRT,pct=$PCT,NOTE=$NOTE
runcode 2SecondaryManipPrgms/procedures Step2_matchProcs.sas cohrt=$COHRT,pct=$PCT,NOTE=$NOTE
####---------------------------------------------------------------------------------

####---------------------------------------------------------------------------------
## FLAG TRANSFERS IN THE MEDPAR CLAIMS FILES
##ICD9 CODE TO LOOK FOR -- USED FOR DEFINING TRANSFERS
##CODE=428
runcode 2SecondaryManipPrgms/transfers FlagTransfers.sas cohrt=$COHRT,pct=$PCT,code=$CODE
####---------------------------------------------------------------------------------

###################################################################################
## STEP 3:: 3FinalReportGenerationCALLSOFTWAREs : Write reports
###################################################################################
runcode 3FinalReportGenerationPrgms/3A_prepDataForReportWriting CombineCohortCosts.do $COHRT $PCT 



