/* Version ID v3.30-3-g6c5a848
Thu Nov 10 16:24:55 EST 2011
*/

%macro ConformDenom(year=,adVar=year);
    ** This macro conforms the denominator files of different years;
    ** into the format for 2005.  Called by macro ExtractDenomInfo;
    ** (see below).;
    **;
    ** the year of the denominator file being conformed.;
    **;
    ** See spreadsheet DenomFileLayouts.xlsx for information on the;
    ** layout of the denominator files.;
    %if &year. >= 1996 and &year. <= 2001 %then %do;

        length hicov 3;
        length smicov 3;
        length hmocov 3;

        hicov = input(dcovmpa,2.0);
        smicov = input(dcovmpb,2.0);
        hmocov = input(dcovmhmo,2.0);

        %if &year. = 1996 or &year. = 1997 %then %do;
            %let zipVar=dzip5;
            %end;
        %else %do;
            %let zipVar=dzip;
            %end;

        keep &adVar. ehic
            dstate dcounty &zipVar.
            dbdate dddate dvddate
            dsex drace
            dpyri01-dpyri12 dhmoi01-dhmoi12
            hicov smicov hmocov
            dorec dcrec desrdind dmedsta zipcode_cnfm;


        rename dstate=state_de dcounty=county_de &zipVar.=zipcode_de
            dbdate=sdob dddate=sdod dvddate=death_sw
            dsex=sex drace=race
            dpyri01-dpyri12=buyin1-buyin12 dhmoi01-dhmoi12=hmoind1-hmoind12
            dorec=orec dcrec=crec desrdind=esrd_ind dmedsta=ms_cd
            hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo;

        zipcode_cnfm = substr(&zipVar., 1, 5);

        %end;
    %else %if &year. >= 2002 and &year. <= 2005 %then %do;

        keep &adVar. ehic
            state county zipcode zipcode_cnfm
            sdob sdod death_sw
            sex race
            entitl1-entitl12 hmo1-hmo12
            hicov smicov hmocov
            oentitl centitl esrd msc;

        rename state=state_de county=county_de zipcode=zipcode_de entitl1-entitl12=buyin1-buyin12 hmo1-hmo12=hmoind1-hmoind12
        hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo
        msc=ms_cd oentitl=orec centitl=crec esrd=esrd_ind;

        zipcode_cnfm = substr(zipcode, 1, 5);

        %end;
     %else %if &year. >= 2006 %then %do;

        length hicov 3;
        length smicov 3;
        length hmocov 3;

        hicov = input(a_mo_cnt,2.0);
        smicov = input(b_mo_cnt,2.0);
        hmocov = input(hmo_mo,2.0);

        keep &adVar.
           bene_id
            state_cd
            cnty_cd
            bene_zip
            zipcode_cnfm
            bene_dob
            death_dt
            v_dod_sw
            sex
            race
            buyin01-buyin12
            hmoind01-hmoind12
            hicov
            smicov
            hmocov
            orec
            crec
            esrd_ind
            ms_cd
            ;

            * Recall we only rename the 01 through 09 because we want to drop the 0 in front of;
            *  the numbers to match our harmonized variables.;
        rename
            state_cd=state_de
            cnty_cd=county_de
            bene_zip=zipcode_de
            bene_dob=sdob
            death_dt=sdod
            buyin01-buyin09=buyin1-buyin9
            hmoind01-hmoind09=hmoind1-hmoind9
            v_dod_sw=death_sw
            hicov=a_mo_cnt smicov=b_mo_cnt hmocov=hmo_mo;

        zipcode_cnfm = substr(bene_zip, 1, 5);
        %end;
    %mend;

%macro keepVarDenom(year=,adVar=,pct=);
    %if &pct. = 05 %then %let pctvars=efivepct fivepct;
    %if &pct. ne 05 %then %let pctvars= ;
    %put TEST &pctvars. ;
    %if &year. >= 1992 and &year. <= 1995 %then %do;
        keep=&adVar. ehic
            state county zip
            sbdate sddate validdt
            sex race
            entitl12 hmo12
            hicov smicov hmocov
            oentitl centitl esrd status
        %end;
    %else %if &year. >= 1996 and &year. <= 2001 %then %do;
        %if &year. = 1996 or &year. = 1997 %then %do;
            %let zipVar=dzip5;
            %end;
        %else %do;
            %let zipVar=dzip;
            %end;

        keep=&adVar. ehic
            dstate dcounty &zipVar.
            dbdate dddate dvddate
            dsex drace
            dpyri01-dpyri12 dhmoi01-dhmoi12
            dcovmpa dcovmpb dcovmhmo
            dorec dcrec desrdind dmedsta
        %end;
    %else %if &year. >= 2002 and &year. <= 2005 %then %do;
        keep=&adVar. ehic
            state county zipcode
            sdob sdod death_sw
            sex race
            entitl1-entitl12 hmo1-hmo12
            hicov smicov hmocov
            oentitl centitl esrd msc
        %end;
     %else %if &year. >= 2006 %then %do;
        keep=bene_id
            state_cd
            cnty_cd
            bene_zip
            bene_dob
            death_dt
            v_dod_sw
            sex
            race
            buyin01-buyin12
            hmoind01-hmoind12
            a_mo_cnt
            b_mo_cnt
            hmo_mo
            orec
            crec
            esrd_ind
            ms_cd
            &adVar. &pctvars.
        %end;
    %mend;


%macro MergeDenomBene(pct=, year=);
    proc sort data=outDen.denom&pct.&year._cnfm; by ehic; run;
    proc sort data=bene.ehicbenex_unique; by ehic; run;

    data outDen.denom&pct.&year._cnfm;
        merge outDen.denom&pct.&year._cnfm (in=denom) bene.ehicbenex_unique (in = xwalk);
        by ehic;
        if denom and xwalk;
    run;
%mend;
