         ** Determine max files in a directory, to be used in combination with the decompress macro;
         ** which Jean wrote.  ;
         ** Script is based on a SAS scrip  Jean Roth provided, although all errors are my own.;
         ** By Maurice Dalton , daltonm@nber.org ;
%macro DetermineMax(datadir=,pct=,ftype=,year=,subtype=,pctsuffix= );
    %if (&ftype.=car or &ftype=op or &ftype=ip) and &year.>=2009 %then %do;
        %let subtype=c;
        %end;
    %else %if &ftype.=ip and (&year.>=2002 and &year.<=2008 or &year.=1997) %then %do;
        %let subtype=clms;
        %end;
    %else %if (&ftype.=car) and &year.>=2002 and &year.<=2008   %then %do;
        %let subtype=clms;
        %end;
    %else %if (&ftype=op) and &year.>=2001 and &year.<=2008   %then %do;
        %let subtype=clms;
        %end;
    %else %do;
        %let subtype=;
        %end;

    %let thisDir=&dataDir./&pct.pct/&ftype./&year.;
  %if &year.>=2010  %then %do;
        %let thisFile1=&thisDir./&ftype.&subtype.&year..sas7bdat;
        %let thisFile2= ;
        %let thisFile3= ;
        *%let thisFile4=&thisDir./&ftype.&subtype.&year.???.sas7bdat.bz2;
        %end;

    %else %if &year.<2009 %then %do;
        %if (&ftype. = car  and  &year. < 2000) %then %do;
            %let thisFile1=&thisDir./&ftype.&pct.?_&year._&subtype.?.sas7bdat;
            %let thisFile2=&thisDir./&ftype.&pct.?_&year._&subtype.??.sas7bdat;
            %let thisFile3=&thisDir./&ftype.&pct.?_&year._&subtype.???.sas7bdat;
            %end;
        %else %if (&ftype. = car  and &year. >= 2000 and &year. < 2006)  %then %do;
            %let thisFile1=&thisDir./&ftype.&pct.i_&year._&subtype.?.sas7bdat;
            %let thisFile2=&thisDir./&ftype.&pct.i_&year._&subtype.??.sas7bdat;
            %let thisFile3=&thisDir./&ftype.&pct.i_&year._&subtype.???.sas7bdat;
            %end;
        %else %do ;
            %let thisFile1=&thisDir./&ftype.&pct.*_&year._&subtype.?.sas7bdat;
            %let thisFile2=&thisDir./&ftype.&pct.*_&year._&subtype.??.sas7bdat;
            %let thisFile3=&thisDir./&ftype.&pct.*_&year._&subtype.???.sas7bdat;
            %end;
        %end;
    %else %if &year>=2009 and ( &pct. ne 100 or &ftype. = ip) %then %do;
        %let thisFile1=&thisDir./&ftype.&subtype._&year._?.sas7bdat;
        %let thisFile2=&thisDir./&ftype.&subtype._&year._??.sas7bdat;
        %let thisFile3=&thisDir./&ftype.&subtype._&year._???.sas7bdat;
        %end;
    %else %do ;
        %let thisFile1=&thisDir./&ftype.&subtype._&year._?.sas7bdat.bz2;
        %let thisFile2=&thisDir./&ftype.&subtype._&year._??.sas7bdat.bz2;
        %let thisFile3=&thisDir./&ftype.&subtype._&year._???.sas7bdat.bz2;
        %end;

    ** Getting file size ;
    ** Defining UNIX command which captures file ;
    ** Note that the maximum length of the quoted string in the pipe is 262 characters long;
    ** So, change to the directory first, then look for files
    ** /usr/bin/ls - was used before but doesnt work on all servers;
     x "cd &thisDir.";
     filename psetenv pipe "ls -al --time-style long-iso &thisFile1. &thisFile2. &thisFile3. ";
     options linesize=162 ;
     ** Parsing the information from UNIX command ;
     ** Note that date format can vary with date of the file ;
    data work.ls;
        retain numid 0;
        numid=numid +1;
        length permiss $10 filelink 3 owner $8  group $8
            size 8 monthdayyr $10 time filename $200 ;
      ** Reading STDOUT from UNIX command *;
      infile psetenv lrecl=162  missover pad;
      ** Inputting whole STDOUT line *;
      input permiss filelink owner group size monthdayyr time filename ;
    run;

    FILENAME psetenv CLEAR ;

    proc print data=work.ls;
    run;

    proc means data=ls n ;
        output out=autocount n=n;
        var filelink;
     run;

    ** Writing num_files to a macro variable ;
     **Create global macro variable so macro can be called out of the current macro ;
    %global num_file;
    data _null_;
        set autocount;
        if _n_=1 then do;
            call symputx('num_file',n);
            stop;
            end;
    run;


    %put ******************************************************************************;
    %put ********IF NUM_FILES IS MISSING THEN FILES DO NOT EXIST***********************;
    %put ><MAX FILE CHECK>>>>  &thisDir. Max # of files  = &num_file;
    %put ******************************************************************************;
    %put ******************************************************************************;
    %put *** NOTE: IN ORDER TO PASS THE INFORMATION FROM THIS CODE I RELY ON THE DATASET "n"*****;


    %mend;

